;;; language-detection.el --- Automatic language detection from code snippets

;; Copyright (C) 2016 Andreas Jansson

;; Author: Andreas Jansson <andreas@jansson.me.uk>
;; URL: https://github.com/andreasjansson/language-detection.el
;; Package-Requires: ((emacs "24") (cl-lib "0.5"))
;; Version: 0.1.0

;; This file is NOT part of GNU Emacs.

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; Automatic programming language detection using pre-trained random
;; forest classifier.
;;
;; Supported languages:
;;
;;  * ada
;;  * awk
;;  * c
;;  * clojure
;;  * cpp
;;  * csharp
;;  * css
;;  * dart
;;  * delphi
;;  * emacslisp
;;  * erlang
;;  * fortran
;;  * fsharp
;;  * go
;;  * groovy
;;  * haskell
;;  * html
;;  * java
;;  * javascript
;;  * json
;;  * latex
;;  * lisp
;;  * lua
;;  * matlab
;;  * objc
;;  * perl
;;  * php
;;  * prolog
;;  * python
;;  * r
;;  * ruby
;;  * rust
;;  * scala
;;  * shell
;;  * smalltalk
;;  * sql
;;  * swift
;;  * visualbasic
;;  * xml
;;
;; Entrypoints:
;;
;;  * language-detection-buffer
;;    - When called interactively, prints the language of the current
;;      buffer to the echo area
;;    - When called non-interactively, returns the language of the
;;      current buffer
;;  * language-detection-string
;;    - Non-interactive function, returns the language of its argument

;;; Code:

(require 'cl-lib)

(defconst language-detection-token-pattern "\\([a-zA-Z0-9_]+\\|[^ a-zA-Z0-9_\n\t]+\\)")

;;;###autoload
(defun language-detection-buffer (&optional print-message)
  "Predict the programming language of the current buffer and output it to messages."
  (interactive "p")
  (let ((language (language-detection-string
                   (buffer-substring-no-properties (point-min) (point-max)))))
    (when print-message
      (message (format "%s" language)))
    language))

;;;###autoload
(defun language-detection-string (string)
  "Return the predicted programming language of STRING as a symbol."
  (let* ((tokens (language-detection-tokenize-string string))
         (freqs (language-detection-token-frequencies tokens)))
    (gethash (language-detection-forest-lookup freqs) language-detection-index-to-languages)))

(defun language-detection-forest-lookup (freqs)
  "Using the token frequencies FREQS, traverse the trees in the forest for predictions and return the majority vote."
  (let* ((table (make-hash-table :test 'equal))
         (predictions (cl-loop for tree in language-detection-forest
                               for (prediction prediction-proba) = (language-detection-tree-lookup tree freqs)
                               do (puthash prediction (+ (gethash prediction table 0) prediction-proba) table))))
    (cl-loop with max-count = 0
             with max-element = nil
             for prediction being the hash-key of table
             for count = (gethash prediction table)
             when (> count max-count)
             do (setq max-count count
                      max-element prediction)
             finally (return max-element))))

(defun language-detection-tree-lookup (tree freqs)
  "Traverse the decision tree TREE by comparing the token frequencies in FREQS to the thresholds at the nodes in the tree."
  (let ((node tree))
    (while (= (length node) 4)
      (if (<= (gethash (elt node 0) freqs 0) (elt node 1))
          (setq node (elt node 2))
        (setq node (elt node 3))))
    (list (elt node 0) (elt node 1))))

(defun language-detection-token-frequencies (tokens)
  "Create a bag-of-tokens by counting the frequencies of each token in TOKENS.  Frequencies are multiplied by 1000 to minimize number of trailing zeroes in forest blob."
  (cl-loop with table = (make-hash-table :test 'equal)
           with increment = (/ 1000.0 (length tokens))
           for token in tokens
           for current = (gethash token table 0)
           do (puthash token (+ increment current) table)
           finally (return table)))


(defun language-detection-tokenize-string (string)
  "Return a list of extracted tokens from STRING."
  (let* ((start-pos 0)
         (singles (cl-loop for match-pos = (string-match language-detection-token-pattern string start-pos)
                           while match-pos
                           for match = (match-string 1 string)
                           collect match
                           do (setf start-pos (+ match-pos (length match)))))
         (pairs (cl-loop for (a b) on singles while b
                         collect (format "%s %s" a b))))
    (cl-loop for token in (append singles pairs)
             collect (gethash token language-detection-tokens-to-index))))

(defun language-detection-alist-to-hashmap (alist)
  "Return a hashmap from ALIST."
  (let ((table (make-hash-table :test 'equal)))
    (cl-loop for (k . v) in alist
             do (puthash k v table))
    table))

;; BEGIN AUTO-GENERATED CODE

(defconst language-detection-tokens-to-index (language-detection-alist-to-hashmap '(("Math ." . 3585) ("content" . 4939) (":- X" . 2462) (". AddWithValue" . 1464) ("AS" . 3045) ("@ IBAction" . 3011) ("IBAction func" . 3431) ("{ padding" . 7580) ("names =" . 6215) ("[] byte" . 4223) ("]; then" . 4348) ("%)" . 297) ("nbsp" . 6224) ("with |" . 7434) (") Dim" . 834) (": expected" . 2380) ("A |" . 3035) ("forward" . 5446) ("hObject ," . 5582) ("xsd" . 7484) ("*( exp" . 1045) ("hook" . 5619) ("init ];" . 5792) ("lisp /" . 6014) ("line =~" . 6003) ("TBitmap" . 3945) ("}}," . 7764) ("score" . 6828) ("\"$" . 107) ("- transform" . 1375) (", 9" . 1115) ("\") end" . 119) ("As Double" . 3082) ("mode -" . 6150) ("<>" . 2746) ("android ." . 4537) ("} impl" . 7701) ("( spec" . 638) ("text_field" . 7162) ("\"]]" . 212) ("vector <" . 7365) ("EXIT" . 3285) ("function (){" . 5485) ("Assigned" . 3090) ("ruby -" . 6773) ("TextView android" . 3984) ("17" . 2068) (">>>" . 2989) ("endl" . 5239) ("( eval" . 548) ("R =" . 3799) ("; };" . 2617) ("UTF" . 4050) ("> ///" . 2946) ("expect" . 5307) ("M ," . 3568) (". Handle" . 1495) ("</ html" . 2717) ("Server" . 3878) ("HashMap" . 3414) ("X |" . 4124) ("any" . 4557) ("\" func" . 73) ("view addSubview" . 7375) ("strlen" . 7029) (". Item" . 1502) ("mark" . 6101) ("n =" . 6196) ("path" . 6449) ("exit 1" . 5302) ("String []" . 3915) (". objects" . 1685) ("CGPoint (" . 3144) ("end function" . 5226) ("; for" . 2567) ("/ 1" . 1786) ("tbody" . 7121) ("addSubview (" . 4494) (". position" . 1702) ("fa (" . 5335) ("vendor" . 7366) ("cl" . 4849) ("real (" . 6661) ("] [," . 4293) (": 5" . 2299) ("cmd" . 4874) ("=\"<? php" . 2883) ("& &" . 314) (";&#" . 2623) ("dev" . 5071) ("/ rack" . 1855) ("-[" . 1428) ("rand" . 6639) ("Table" . 3964) (". Message" . 1508) ("= None" . 2781) ("| html" . 7647) ("asParser ," . 4619) ("[ j" . 4187) (": layout_height" . 2403) ("( remove" . 623) (". eclipse" . 1612) ("</ body" . 2712) ("partial" . 6442) ("li" . 5983) ("graphicx" . 5558) ("rw" . 6787) ("Just" . 3523) ("share" . 6903) ("'\"" . 365) ("mnesia" . 6145) ("localhost" . 6034) ("binary" . 4705) ("Byte" . 3128) ("100 %;" . 2030) ("/ repository" . 1859) ("), ." . 943) ("Write" . 4109) ("templates" . 7136) ("id ." . 5677) ("ierr" . 5690) (":-" . 2461) (") import" . 870) ("viewDidLoad ()" . 7377) ("DelegatingMethodAccessorImpl ." . 3255) ("| l" . 7648) ("\" }," . 100) ("fprintf (" . 5451) (") If" . 841) ("defining" . 5044) ("current_user ." . 4985) ("/ gcc" . 1830) ("-> a" . 1411) ("= io" . 2817) ("awk :" . 4659) ("case _" . 4800) ("<%= f" . 2697) ("$(\"#" . 279) ("golang" . 5544) ("\"\"," . 104) ("char *)" . 4834) ("Test" . 3971) ("3L" . 2175) ("coll" . 4881) ("active_support" . 4468) ("}'" . 7729) ("show :" . 6912) ("a (" . 4416) ("erts" . 5272) (". util" . 1745) ("| 1" . 7627) ("ARGV [" . 3044) ("warnings ;" . 7397) ("anonfun $" . 4552) ("x y" . 7465) ("$('#" . 282) (". getElementById" . 1631) ("= {}" . 2847) ("<- as" . 2702) ("deriving" . 5065) ("arising" . 4596) ("require \"" . 6712) ("subtype" . 7056) ("bash" . 4682) (";\">" . 2619) ("*/ public" . 1060) ("equal ?" . 5250) ("{ FS" . 7528) ("Net" . 3685) ("iterator" . 5880) ("< std" . 2673) ("As Byte" . 3081) ("Future [" . 3378) ("\" >>" . 46) ("if ((" . 5696) ("< label" . 2660) ("Width =\"" . 4104) ("( id" . 568) ("\"?>" . 199) ("Classes ," . 3184) ("0 ;" . 1919) ("+ '" . 1064) ("Sub" . 3921) ("t match" . 7095) ("2016 -" . 2124) (". bounds" . 1575) (")" . 791) ("()." . 728) ("X ,[" . 4121) ("( message" . 594) ("tableView :" . 7109) (". height" . 1641) ("3 4" . 2156) ("springframework" . 6952) ("Qt4" . 3792) ("document }" . 5133) ("Future" . 3377) ("FUNCTION" . 3336) ("borrow" . 4729) (". st" . 1728) ("( c" . 515) ("(*)" . 740) ("r *" . 6623) (", R" . 1145) ("csv" . 4978) ("- bottom" . 1275) ("''," . 369) ("bufio" . 4753) ("forKey :@\"" . 5427) ("MsgBox" . 3610) ("new {" . 6243) ("-->" . 1395) ("For Each" . 3360) ("]; [" . 4342) ("( Tail" . 497) ("UITableView ," . 4036) ("\\==" . 4275) ("input $" . 5800) ("; PROCEDURE" . 2543) (". 2" . 1451) ("value" . 7343) (": 14" . 2286) ("+ 01" . 1067) ("- transition" . 1376) ("0 .." . 1914) ("deps" . 5060) ("2 2" . 2098) ("frame :" . 5458) ("minor" . 6143) ("boolean" . 4719) ("28" . 2138) ("w :" . 7388) ("b :=" . 4668) ("( err" . 547) ("log" . 6040) ("Void in" . 4088) ("with get" . 7432) ("printStackTrace ();" . 6535) ("1 do" . 2015) ("\" 0" . 38) ("scene" . 6818) ("1 ," . 1995) ("YES" . 4145) ("current -" . 4983) ("android =\"" . 4539) ("SSL" . 3859) ("u8" . 7277) (")];" . 1020) ("DOCTYPE" . 3238) ("fn new" . 5406) ("75" . 2237) ("() =" . 705) ("\"\\" . 201) ("-> Option" . 1406) ("list" . 6015) ("renewcommand {\\" . 6698) ("parent" . 6439) ("=\" application" . 2856) ("valueForKey" . 7350) ("// TODO" . 1889) ("replace" . 6703) ("failed" . 5343) ("attr (\"" . 4646) ("=~" . 2936) ("As Integer" . 3085) (") :" . 818) ("err !=" . 5261) ("< br" . 2646) ("> 0" . 2947) ("< property" . 2670) ("hide" . 5612) ("cpan" . 4963) (":: [" . 2476) ("} ]" . 7687) ("match_parent \"" . 6108) ("anonfun" . 4551) ("init /" . 5791) ("100 ." . 2032) ("nil )" . 6261) ("collapse" . 4882) ("q" . 6613) ("- lock" . 1327) ("project ." . 6570) ("Free" . 3369) ("command -" . 4899) ("in `" . 5759) ("else (" . 5193) ("( Unknown" . 498) ("FSharp ." . 3335) ("( defun" . 538) ("(" . 429) ("ggplot" . 5526) (". RT" . 1524) ("private type" . 6556) ("cos (" . 4955) ("import UIKit" . 5740) ("else echo" . 5196) (". org" . 1687) ("FILE *" . 3328) ("pygame ." . 6609) ("put (" . 6598) ("=\"@ drawable" . 2885) ("script >" . 6831) ("tempAnimal at" . 7131) ("( [" . 502) ("tr" . 7231) ("factor" . 5338) ("tab -" . 7100) ("]). -" . 4321) ("\" data" . 64) (". Lines" . 1506) ("TButton" . 3946) ("async" . 4627) ("( 11" . 437) ("( set" . 633) ("[&" . 4204) ("WriteLine" . 4110) ("' gem" . 357) (", ?" . 1117) ("); printf" . 1004) ("akka ." . 4506) ("<<" . 2739) ("3 )." . 2147) (") =>" . 828) ("Classes" . 3183) ("dart ';" . 5001) ("text >" . 7158) ("\" echo" . 67) ("warn" . 7394) ("import android" . 5741) ("for k" . 5422) ("-> '" . 1401) ("from django" . 5464) ("Next" . 3691) ("disp" . 5089) ("console ." . 4927) ("..$ :" . 1768) ("GO" . 3387) ("/ Python" . 1797) ("_POST" . 4390) ("{\"" . 7606) ("on" . 6353) (". apache" . 1564) ("; then" . 2600) ("up" . 7297) ("rust" . 6782) ("while read" . 7415) ("o )" . 6329) ("111" . 2044) ("dt" . 5150) ("expression" . 5312) ("Eq" . 3304) ("( Socket" . 493) ("! @" . 3) ("accept" . 4455) (". setText" . 1721) ("ls" . 6056) ("56" . 2216) ("has" . 5588) ("as $" . 4613) ("/ polymer" . 1852) ("setq" . 6897) ("Async ." . 3093) ("- width" . 1384) ("/ 3" . 1793) ("\\@" . 4276) ("ls -" . 6058) ("-> case" . 1413) ("- frame" . 1307) ("func" . 5472) ("/ etc" . 1828) ("As EventArgs" . 3083) ("main $" . 6075) ("] =" . 4288) (". id" . 1648) (": addEventListener" . 2354) (". addBody" . 1558) ("(@\"%@\"," . 773) ("] ==" . 4289) ("echo -" . 5178) ("\\=" . 4274) ("the first" . 7171) ("nullable :" . 6316) ("Buffer" . 3118) ("& (" . 315) ("A ]" . 3034) ("rails /" . 6635) ("str (" . 6998) ("/ jquery" . 1837) ("DESC" . 3234) (":= make" . 2505) ("pdflatex" . 6454) ("strict ;" . 7008) ("Application ." . 3070) ("= case" . 2803) (": 7" . 2303) ("( list" . 585) ("dired -" . 5088) ("println (" . 6548) (", cellForRowAtIndexPath" . 1172) ("<? xml" . 2750) ("deallocate (" . 5027) ("native" . 6218) ("typechecker" . 7263) ("\\ textwidth" . 4265) ("( TForm" . 496) ("( Object" . 480) ("- 08" . 1251) ("cout <<\"" . 4961) ("IN" . 3444) ("} close" . 7691) ("- size" . 1364) ("- test" . 1371) ("\";" . 178) ("each |" . 5166) ("extern crate" . 5321) ("3 3" . 2155) ("Log ." . 3563) ("are" . 4583) ("junit" . 5910) ("-( void" . 1390) (":/" . 2464) ("{ panic" . 7581) ("} type" . 7716) ("for =\"" . 5415) ("i =" . 5662) ("juan" . 5908) ("border =\"" . 4728) ("++ show" . 1070) ("\" -" . 33) ("strict" . 7007) ("})" . 7731) ("' T" . 349) ("Of String" . 3719) (", DIMENSION" . 1125) ("$ _SESSION" . 255) ("9 ." . 2253) ("a ></" . 4427) ("plot" . 6490) ("belongs_to :" . 4702) ("isEqualToString :@\"" . 5867) ("end %>" . 5214) ("program main" . 6567) (". end" . 1614) ("- point" . 1346) ("Seq [" . 3875) ("range 1" . 6645) ("() {" . 719) (". performWithDelay" . 1694) ("( if" . 569) ("11 )" . 2040) ("(- n" . 749) ("pkg /" . 6483) ("shift ;" . 6908) ("54" . 2214) ("widget" . 7417) ("weight :" . 7407) ("7" . 2232) ("Graphics" . 3397) ("list1" . 6021) ("texmf" . 7147) (". RestFn" . 1527) ("<' T" . 2699) ("unless" . 7289) ("TextView" . 3983) (". Text_IO" . 1534) ("FALSE ," . 3326) ("new (" . 6231) ("X2" . 4127) ("_ )" . 4370) ("< p" . 2667) ("IBAction )" . 3430) ("# print" . 229) ("{ article" . 7539) ("numel" . 6321) (", P" . 1143) ("( a" . 504) ("then ((" . 7177) ("_ |" . 4382) ("== null" . 2910) ("];" . 4338) (". then" . 1739) ("last" . 5942) (": T" . 2332) ("2001" . 2111) ("allocatable ::" . 4521) ("H2" . 3408) ("( dart" . 531) ("factory" . 5340) ("google" . 5545) ("help :" . 5603) ("entry" . 5241) ("First" . 3353) ("php if" . 6474) ("- hook" . 1312) ("perl5 /" . 6462) ("\"]; [" . 209) (". 4" . 1453) ("user =" . 7317) (": 12" . 2284) ("/\\" . 1898) ("://" . 2466) ("ATOM" . 3047) ("*, \"" . 1056) ("is N" . 5854) ("' Chapter" . 341) ("0l0" . 1971) ("sexp" . 6898) ("local" . 6031) ("backgroundColor =" . 4678) ("{ match" . 7575) ("(:, 1" . 761) ("(\"@" . 669) ("<$>" . 2693) ("argument" . 4592) ("0 &" . 1903) ("destructor" . 5070) (",," . 1228) ("make -" . 6085) ("ones" . 6360) ("a ." . 4421) ("eval -" . 5280) ("try {" . 7253) ("{ background" . 7540) ("pid" . 6481) ("IBOutlet weak" . 3434) ("Println (" . 3769) ("=\"<?" . 2882) (". out" . 1690) ("IN (" . 3445) ("of {" . 6348) ("objectForKey :@\"" . 6338) ("( frame" . 557) ("Gtk" . 3402) ("is record" . 5862) ("( handles" . 565) ("!!" . 7) ("Add ('" . 3059) ("t /" . 7093) (". clj" . 1581) ("assets" . 4625) ("author" . 4650) ("exit (" . 5300) ("= match" . 2822) ("Bool {" . 3112) ("c (" . 4769) ("i );" . 5651) ("key (" . 5919) ("- -" . 1241) ("=`" . 2934) ("> 2" . 2949) ("Memo1" . 3589) ("</ paper" . 2724) ("file1" . 5374) ("concurrent ." . 4916) ("--" . 1391) ("5 ." . 2202) ("document )." . 5131) ("';" . 407) ("{ noreply" . 7577) ("foreach (" . 5430) ("timer" . 7200) (": false" . 2381) ("} case" . 7688) ("screen" . 6829) ("( Item" . 467) ("ngx ." . 6259) ("dependencies ." . 5057) ("main" . 6074) ("100 ," . 2031) ("( cond" . 524) ("Array [" . 3075) ("where import" . 7412) ("[ warn" . 4194) ("file -" . 5370) ("window" . 7425) ("navbar" . 6221) ("Put (" . 3785) (")) +" . 910) ("=\"{" . 2889) ("msg" . 6170) ("= <" . 2769) ("$ file" . 260) ("] {" . 4307) ("mode )" . 6149) (")))" . 915) ("= false" . 2811) ("retain )" . 6731) ("&&" . 324) ("public int" . 6586) ("[$" . 4201) ("}); });" . 7736) ("texmf -" . 7148) (", nil" . 1199) ("Async" . 3092) ("1 (" . 1985) ("<:" . 2738) ("string []" . 7021) ("println" . 6544) ("https ://" . 5643) ("; print" . 2586) ("13" . 2055) ("; var" . 2607) ("assoc" . 4626) ("rep" . 6699) ("\\ subsection" . 4261) ("for i" . 5420) ("Content -" . 3208) ("] as" . 4296) ("\"}" . 216) (". Printf" . 1520) ("} override" . 7705) ("- USER" . 1266) ("' my" . 358) ("]);" . 4324) ("?)" . 2999) ("| (" . 7625) ("L =" . 3532) (": isolate" . 2401) ("deallocate" . 5026) ("addMorph :" . 4490) ("subplot (" . 7051) ("local function" . 6033) ("indexPath :" . 5782) ("x =" . 7461) ("forKey" . 5425) ("= [\"" . 2794) ("))))" . 917) ("NSLog (@\"" . 3653) ("number" . 6320) ("T" . 3931) ("{ itemize" . 7570) ("], [" . 4330) ("b ," . 4665) ("spawn" . 6945) ("private :" . 6552) ("/ 5" . 1795) ("As Object" . 3087) (". text" . 1738) ("items" . 5878) ("0000000" . 1941) ("P" . 3735) ("iter" . 5879) ("ch" . 4827) ("3 |" . 2160) ("=\" UTF" . 2854) ("i As" . 5663) ("pas" . 6444) ("n 1" . 6194) ("; @" . 2541) ("] src" . 4305) ("instanceVariableNames" . 5810) ("width" . 7419) ("G ," . 3380) ("Ada" . 3054) ("* sin" . 1039) ("objects" . 6339) ("generic" . 5508) ("'] =" . 419) ("real ," . 6663) (") \\" . 848) ("name \":" . 6201) ("( New" . 479) ("This is" . 3994) (", file" . 1184) ("php echo" . 6473) ("( data" . 532) ("sender As" . 6868) ("content =\"" . 4940) ("rubies /" . 6771) ("rs" . 6767) ("( '" . 432) ("\\ tex" . 4263) ("with Ada" . 7431) ("bundle" . 4757) ("addEventListener (" . 4487) ("SizeOf (" . 3891) ("js :" . 5903) ("Checked" . 3181) ("=\"@ string" . 2886) ("character" . 4838) (": b" . 2366) ("( nil" . 604) ("yourself" . 7503) (", int" . 1190) ("info" . 5784) ("save -" . 6803) ("( \"" . 430) ("height =\"" . 5600) ("py" . 6606) ("PACKAGE" . 3737) (")," . 939) ("-> m" . 1419) (": aString" . 2349) ("($ 0" . 674) ("font -" . 5409) ("i ;" . 5659) ("center ;" . 4822) ("Closure" . 3193) ("server" . 6877) ("female (" . 5357) ("http -" . 5639) ("% v" . 293) ("\"); $" . 135) ("$ query" . 264) (":: String" . 2475) ("| 5" . 7631) ("); $" . 980) ("){" . 1023) ("point" . 6503) ("Seq ." . 3874) ("gen_tcp :" . 5507) ("9 ," . 2252) (". catalina" . 1579) ("_ ." . 4375) ("\" t" . 92) ("CL" . 3150) ("168 ." . 2067) ("- path" . 1345) ("|]" . 7663) ("/ go" . 1833) (":= grid" . 2503) ("of" . 6342) (") #" . 794) ("\",\"" . 155) (". random" . 1709) ("do local" . 5120) ("overriding" . 6405) ("5" . 2199) ("nn ." . 6275) ("wait" . 7392) ("If Next" . 3468) ("cut" . 4988) ("- decoration" . 1289) ("else" . 5192) ("=$ 1" . 2893) ("]=" . 4350) ("let !" . 5973) ("getString" . 5521) (". Cells" . 1470) ("\" \"" . 24) ("do print" . 5121) ("0 ])." . 1926) ("jQuery" . 5888) ("3 0" . 2153) ("_ ->" . 4374) ("{ }" . 7605) ("set -" . 6886) ("[ UIView" . 4175) ("bin /" . 4704) (". a" . 1555) (": &'" . 2267) (": 10" . 2281) ("\" fmt" . 72) ("client" . 4861) ("127" . 2053) ("Value =\"" . 4074) ("use" . 7305) (":= self" . 2510) ("fo" . 5407) ("; self" . 2593) ("const int" . 4931) ("cin" . 4847) ("span class" . 6942) ("ERROR ]" . 3283) (". 6" . 1456) ("%@\"," . 308) ("at System" . 4634) ("xsd :" . 7485) ("48" . 2195) ("; 0" . 2537) (". 1427" . 1449) ("{ int" . 7568) ("dart '" . 5000) ("13 :" . 2057) ("forms" . 5445) ("unit =" . 7288) ("created" . 4969) ("24" . 2131) ("- gradient" . 1310) ("( funcall" . 559) ("? x" . 2998) ("idx" . 5689) ("Jun" . 3521) ("xmlns ='" . 7477) ("width ," . 7420) ("- local" . 1326) ("dir" . 5084) ("0x00" . 1978) ("$ do" . 258) ("DEFAULT" . 3233) ("= T" . 2785) (") ;" . 822) ("h1" . 5577) ("gem" . 5498) (", FMX" . 1130) (")^" . 1021) ("(&" . 682) ("local /" . 6032) ("aValue" . 4443) ("/ css" . 1820) ("media" . 6123) ("Int ->" . 3484) ("image" . 5716) ("go func" . 5543) ("SET @" . 3852) ("newText" . 6246) ("- 3" . 1260) ("']);" . 421) ("main =" . 6080) ("{ fn" . 7559) ("5 ," . 2201) ("Lines ." . 3553) ("']; $" . 424) ("javax ." . 5896) ("TForm1 ." . 3952) ("}" . 7665) ("fun" . 5467) ("nextPutAll" . 6254) ("| 3" . 7629) ("fclose (" . 5354) ("& \\\\" . 319) ("= {" . 2846) ("x (" . 7450) ("ERROR" . 3281) ("FormCreate (" . 3364) (": {" . 2445) ("; override" . 2582) ("CASE" . 3140) ("( conj" . 525) (", NA" . 1140) ("qw (" . 6620) ("temp" . 7127) ("unwrap ();" . 7296) ("set" . 6883) ("awt" . 4660) ("))+" . 925) ("]. ]." . 4334) ("]] =" . 4354) ("repository /" . 6706) (". frame" . 1628) ("case class" . 4801) ("mail" . 6073) (", 1L" . 1100) ("decoration" . 5032) ("\"]=> string" . 211) ("texlive" . 7145) ("has_many" . 5589) (".\"" . 1757) ("10 :" . 2028) ("org" . 6380) ("text :" . 7155) ("AbstractCallSite" . 3048) (",*)" . 1227) (", 3" . 1104) ("=\" width" . 2871) ("db ->" . 5020) ("*) malloc" . 1049) ("os ." . 6389) ("loop ;" . 6050) ("^ self" . 4366) ("net ." . 6228) ("</ head" . 2716) ("/ ardnew" . 1811) ("textField" . 7160) ("comment :" . 4902) ("Sender :" . 3871) ("defining Unicode" . 5045) ("SQL" . 3857) ("? creep" . 2996) (". Top" . 1536) ("x86_64 -" . 7470) (": CGRectMake" . 2314) ("\"] [" . 205) ("'; $" . 408) ("imshow (" . 5752) ("internal ." . 5837) ("x ;" . 7459) ("IntPtr" . 3489) (",[ X" . 1234) ("Unicode" . 4054) (": polymer" . 2415) (", in" . 1189) ("include <" . 5771) ("save" . 6802) ("foreground" . 5433) ("* pi" . 1038) ("not found" . 6296) ("log (\"" . 6043) ("} pub" . 7710) ("\" Then" . 53) ("NSDictionary" . 3642) ("if not" . 5706) ("( save" . 629) ("b ." . 4667) ("/$" . 1881) ("kind" . 5923) ("1 to" . 2019) ("/ tmp" . 1874) ("\" os" . 87) ("ls )" . 6057) ("location" . 6036) ("packages \\" . 6419) ("Drawing" . 3266) (": absolute" . 2351) ("^" . 4364) ("7 )" . 2233) ("endl ;" . 5240) ("artifactId" . 4609) ("Printf (\"%" . 3767) ("center" . 4820) ("hidden ;" . 5610) ("cond [(" . 4919) ("j <" . 5886) ("' end" . 355) ("str ," . 7000) ("e )" . 5155) ("double precision" . 5143) (", k" . 1193) ("lstlisting" . 6062) (". Open" . 1517) ("(\\" . 786) ("Any" . 3066) ("' a" . 350) ("i ]." . 5666) ("- get" . 1309) (": 3" . 2297) ("int main" . 5820) ("kind =" . 5924) ("add :" . 4481) ("so" . 6929) (":= 0" . 2493) ("1px solid" . 2080) ("gsub" . 5571) ("- in" . 1315) ("rm" . 6752) ("} def" . 7692) ("err ." . 5263) ("Integer" . 3492) ("interactive" . 5831) ("Mat" . 3583) ("47" . 2194) ("member" . 6124) ("</ ul" . 2734) (") then" . 887) ("ON" . 3708) ("
" . 0) ("{ printf" . 7584) ("out ." . 6396) ("REAL" . 3803) ("frame -" . 5456) ("18 :" . 2071) ("'; When" . 409) ("'((" . 373) ("3 ;" . 2157) ("?) {" . 3000) ("filter (" . 5382) (")." . 957) ("length (" . 5970) ("Host" . 3420) ("command not" . 4900) ("; char" . 2553) ("command" . 4898) ("for _" . 5418) ("...)" . 1771) ("viewDidLoad ];" . 7378) ("21" . 2127) ("; j" . 2576) ("\" )" . 30) ("Value :" . 4072) ("append ([" . 4570) ("/ activesupport" . 1806) (":[:" . 2519) ("| f" . 7644) ("n \"," . 6187) (", true" . 1213) ("face -" . 5337) ("filename" . 5376) ("node_modules" . 6283) ("( else" . 544) ("}; let" . 7746) ("max -" . 6116) ("LaTeX" . 3543) ("Integer ;" . 3497) ("api ." . 4561) ("BEGIN" . 3099) ("define (" . 5041) ("id \":" . 5674) ("< asp" . 2643) ("const" . 4929) ("{ error" . 7554) ("cellForRowAtIndexPath indexPath" . 4819) ("] Compiling" . 4291) ("( String" . 494) ("position" . 6514) ("if ([" . 5698) ("Method" . 3597) ("- uclibc" . 1378) (") type" . 888) (": NSError" . 2325) ("'])" . 420) ("path ." . 6451) ("node" . 6279) ("CL -" . 3151) ("Dictionary new" . 3261) ("plugins" . 6495) ("href =\"" . 5627) ("+ \"" . 1063) ("00 0" . 1934) ("{ log" . 7572) ("\"));" . 130) ("ApplicationController" . 3071) ("3" . 2143) ("insert (" . 5804) ("=<" . 2901) ("var" . 7354) ("Lua" . 3565) (". save" . 1716) ("extends PolymerElement" . 5317) ("WITH" . 4093) ("]; if" . 4344) ("db ." . 5021) (">()" . 2967) (". codehaus" . 1585) ("Runtime" . 3841) (". c" . 1576) ("gen_tcp" . 5506) ("classVariableNames" . 4856) ("zone" . 7510) ("goroutine" . 5547) ("imread" . 5749) ("10px ;" . 2038) (":= range" . 2509) ("MsgBox (\"" . 3611) ("Array (" . 3073) ("FMX ." . 3330) ("EventArgs )" . 3314) ("USE" . 4047) ("recent call" . 6669) ("but" . 4761) ("allocate (" . 4523) ("fclose" . 5353) ("},{" . 7740) ("linear -" . 6005) ("/ apk" . 1808) ("join" . 5897) ("] init" . 4299) ("/ future_impl" . 1829) ("contains" . 4938) (", T" . 1153) ("/ dependencies" . 1822) ("properties" . 6571) (": 10px" . 2283) ("contentWidth" . 4942) ("line -" . 6001) ("Some" . 3895) ("get ()" . 5512) ("java ." . 5892) ("anonymous" . 4553) ("Users" . 4063) (". origin" . 1688) ("all" . 4517) (". f90" . 1623) ("26" . 2136) ("app" . 4564) ("append" . 4568) ("can" . 4789) ("Printf" . 3765) ("\") if" . 120) ("NSString stringWithFormat" . 3662) ("; 2" . 2539) ("begin //" . 4693) ("( y" . 661) ("p ~" . 6411) ("; /*" . 2535) ("f )" . 5324) ("File ." . 3345) ("import org" . 5744) ("( value" . 652) ("parent (" . 6440) ("[ |" . 4199) ("mapView" . 6095) ("else {" . 5198) ("( ns" . 607) ("gz" . 5573) ("$ apply" . 256) ("'( 1" . 372) ("Size" . 3889) ("REAL (" . 3804) ("int ," . 5816) ("cin >>" . 4848) ("= NO" . 2777) ("- 1" . 1253) ("\">
 <" . 189) ("name ," . 6203) ("eclipse ." . 5180) ("touch" . 7229) ("system" . 7084) ("As String" . 3088) ("@ Override" . 3014) ("files" . 5377) ("Result" . 3829) ("important" . 5747) (": constant" . 2373) ("n (" . 6190) ("||" . 7664) ("stdio" . 6988) ("(:," . 760) ("(& self" . 684) ("{" . 7512) ("rwxr --@" . 6790) ("invoke" . 5839) ("nn" . 6274) ("borrowed" . 4730) (". Model" . 1509) (". Parameters" . 1518) (": i" . 2390) ("- align" . 1268) ("); end" . 996) ("Task" . 3969) ("} {:" . 7721) (")) )" . 909) (", aes" . 1167) ("[ _" . 4178) ("time =" . 7199) (") return" . 883) ("newline" . 6249) ("],[" . 4331) ("interactive )" . 5832) (", 1" . 1094) ("() if" . 712) ("strconv" . 7003) ("map [" . 6093) (") '(" . 801) (") !" . 792) ("AFn ." . 3039) ("URLWithString" . 4046) ("` (`" . 4399) ("load -" . 6029) (": Int" . 2320) ("Json" . 3520) ("result =" . 6729) ("\\ Microsoft" . 4238) ("\"," . 144) ("- region" . 1354) ("build /" . 4755) ("0d0" . 1968) ("animation" . 4547) ("From" . 3371) ("error ]" . 5271) ("print *," . 6532) ("( map" . 590) ("if (=" . 5697) ("AbstractCallSite ." . 3049) ("- seq" . 1361) ("Control ." . 3210) (") is" . 873) ("display" . 5090) ("Put_Line (\"" . 3789) ("CGPointMake (" . 3146) ("do i" . 5117) ("?-" . 3003) ("run (" . 6777) ("),(" . 954) ("- shadow" . 1363) ("interface" . 5833) ("title ('" . 7204) ("each select" . 5164) ("2 ]" . 2105) ("aStack" . 4440) ("function (" . 5482) ("padde admin" . 6421) ("sys /" . 7083) ("gmail" . 5536) ("- moz" . 1335) ("type '" . 7257) ("(|" . 789) ("range (" . 6644) (":// localhost" . 2467) ("uint" . 7280) ("Unbounded_String" . 4053) ("[[ $" . 4215) ("schemas ." . 6825) ("0 ." . 1913) ("168" . 2066) ("CGRect" . 3147) ("; END" . 2542) (": attribute" . 2364) ("isEqualToString" . 5866) ("\"$ 1" . 108) ("malloc" . 6088) ("version >" . 7371) ("< ActiveRecord" . 2630) ("- click" . 1282) ("sin" . 6916) ("new ArrayList" . 6238) (": user" . 2437) ("/> </" . 1897) ("receive" . 6666) ("config" . 4920) ("as ." . 4614) ("blah blah" . 4709) ("imageNamed :@\"" . 5720) ("- packages" . 1343) ("play" . 6486) ("= Nothing" . 2782) ("- regexp" . 1353) ("string \"" . 7010) ("string >" . 7020) ("{ 1" . 7522) (", L1" . 1134) (", i" . 1187) ("Vec <" . 4081) ("cd" . 4809) ("= imread" . 2815) ("moz -" . 6167) (": -" . 2272) ("documentclass {" . 5136) ("Functor" . 3376) ("=> array" . 2925) ("= math" . 2823) ("tmp" . 7207) ("- weight" . 1383) (". push_back" . 1706) ("( display" . 541) ("equals" . 5251) ("should" . 6909) ("host" . 5622) ("45" . 2192) ("Erlang" . 3305) ("T )" . 3932) ("new Ada" . 6237) ("INSERT" . 3449) ("AND" . 3041) (". Length" . 1505) ("(\"~" . 672) ("Self ." . 3869) ("w3" . 7390) (")(" . 905) ("apk" . 4562) ("0 to" . 1929) ("\") let" . 121) ("< div" . 2649) ("NSMutableArray" . 3654) ("Main" . 3576) ("for [" . 5417) ("Margin" . 3581) ("x ))" . 7452) ("\" +" . 31) ("/ rails" . 1856) ("not" . 6294) (". Clear" . 1473) ("TextBox1 ." . 3982) ("error :" . 5270) ("MetaClassImpl ." . 3596) ("get" . 5509) ("</ th" . 2731) ("document ." . 5132) ("Margin =\"" . 3582) ("ads :" . 4499) ("namespace" . 6216) ("apply -" . 4577) ("\") (" . 114) ("Fatal (" . 3341) ("category" . 4807) ("XML" . 4130) ("mean" . 6122) ("cdr (" . 4811) ("_POST ['" . 4391) ("touch \"," . 7230) ("); }" . 1011) ("login" . 6046) ("vector" . 7363) ("Toast" . 4002) ("options :" . 6374) ("ListItem" . 3560) ("byte" . 4765) ("I =" . 3427) ("com /" . 4897) ("new ." . 6235) ("=> {" . 2929) ("{ figure" . 7556) ("gen_server" . 5503) ("Actor" . 3053) ("Y ):-" . 4139) ("As Exception" . 3084) ("d" . 4991) ("Monad m" . 3608) ("=>" . 2913) ("255" . 2133) ("tex /" . 7143) (". e" . 1610) ("set !" . 6884) ("$ data" . 257) ("CharField (" . 3179) ("- top" . 1374) (". Core" . 1481) ("true )" . 7243) ("\\ label" . 4249) ("derive" . 5063) ("Name =" . 3676) ("End Function" . 3295) ("module (" . 6156) ("1" . 1980) ("UPDATE" . 4044) ("dependency >" . 5059) ("3 ," . 2149) ("with" . 7428) ("\": 1" . 171) ("Path" . 3752) ("< td" . 2679) ("numeric" . 6323) ("Columns" . 3199) ("the type" . 7173) ("statement" . 6976) ("groupId >" . 5570) ("\", line" . 153) ("<% end" . 2695) ("string ]" . 7022) ("-> receive" . 1424) ("unit" . 7287) ("- webkit" . 1382) ("12 :" . 2051) ("fs" . 5466) ("20" . 2108) ("--> <" . 1396) (".(*" . 1760) (",&" . 1225) ("/ 0" . 1785) ("receive {" . 6667) ("123" . 2052) ("( nth" . 608) ("with :" . 7430) ("<|" . 2751) ("reader" . 6657) (":( id" . 2458) ("toc tic" . 7218) ("bytes" . 4767) ("null )" . 6311) ("threads" . 7190) ("=\" xsd" . 2874) ("( as" . 511) ("data )" . 5009) ("= string" . 2837) ("}}\">" . 7763) ("- variable" . 1381) ("2 :" . 2100) ("exp (-" . 5304) ("timer ." . 7201) ("0f ," . 1970) ("ghc" . 5528) ("ul li" . 7283) ("( P" . 482) ("alert" . 4507) ("/=" . 1894) ("(:" . 756) ("> (" . 2944) ("public partial" . 6587) (". 0000000" . 1441) ("Bitmap" . 3108) (", System" . 1152) ("cons" . 4924) ("X is" . 4123) ("Strings" . 3918) ("Handle" . 3410) ("=$(" . 2894) ("- face" . 1302) ("6L" . 2230) ("exception" . 5290) ("static final" . 6978) ("C :/" . 3135) ("color" . 4889) ("where" . 7411) ("= data" . 2806) ("{ position" . 7582) ("\" %" . 27) ("y" . 7491) ("call" . 4781) ("( S" . 488) (". 11" . 1447) ("] }" . 4308) (". dylib" . 1609) ("y =" . 7497) ("%#" . 295) ("TextBlock" . 3979) (":@ selector" . 2516) ("# state" . 230) ("names" . 6213) ("; import" . 2573) ("ifFalse" . 5707) ("/ net" . 1845) ("layout_weight" . 5956) (", 7" . 1112) ("99" . 2257) ("multicolumn" . 6171) (": 6" . 2302) ("sep" . 6870) ("rest" . 6726) (": orientation" . 2413) ("Pid" . 3755) ("'*';" . 390) ("{ echo" . 7552) ("swing ." . 7075) ("paper -" . 6432) ("FROM" . 3332) ("T )." . 3933) ("\"." . 160) ("template" . 7132) ("INFO" . 3446) (". Compiler" . 1479) ("UITextField" . 4039) ("break ;" . 4742) ("Seq (" . 3873) ("19" . 2072) ("() main" . 715) ("Item =>" . 3509) ("active" . 4465) ("- key" . 1318) (". New" . 1513) ("empty ($" . 5207) ("\\ hline" . 4246) ("dequeueReusableCellWithIdentifier" . 5061) ("python" . 6610) ("char U" . 4837) ("match_parent" . 6107) ("TForm )" . 3950) ("/ zone" . 1880) ("bottom" . 4731) ("get (" . 5510) ("panic" . 6429) ("self )" . 6855) ("pkg" . 6482) ("Parameters ." . 3749) ("1 ));" . 1989) (". Put_Line" . 1523) ("title :" . 7205) ("setFillColor (" . 6890) ("( require" . 625) (". html" . 1646) ("State }." . 3904) ("/ sh" . 1867) ("zip" . 7509) ("0 ," . 1911) ("} -" . 7672) ("hudson" . 5644) ("- of" . 1341) ("NSDictionary *" . 3643) ("' /" . 335) ("models ." . 6154) (", v" . 1215) ("Z" . 4149) ("& 0" . 316) ("caption {" . 4793) ("File_Type" . 3349) ("menu" . 6129) ("typeof (" . 7270) ("[ clojure" . 4180) ("ignore" . 5712) ("1L ," . 2078) ("Method ." . 3599) ("2015" . 2121) ("', array" . 396) ("Execute" . 3318) ("/ active_record" . 1804) ("=> 1" . 2919) (": IN" . 2319) ("nil t" . 6268) ("* from" . 1036) ("TABLE" . 3944) ("nil ))" . 6262) ("( t" . 645) ("argv [" . 4595) (". sun" . 1731) ("( decimal" . 533) ("46" . 2193) ("<- data" . 2704) ("USER" . 4048) ("( concat" . 523) ("COUNT" . 3153) ("sql" . 6955) (": /" . 2274) ("14 ." . 2059) (") VALUES" . 846) ("Patient" . 3753) (", 0L" . 1090) ("at /" . 4632) ("xs" . 7480) ("- 00" . 1243) ("{ 3" . 7524) ("43" . 2190) ("elseif" . 5199) ("=\"\"" . 2876) ("AddressOf" . 3062) ("\": null" . 174) ("name \"" . 6200) ("Source" . 3897) ("< table" . 2678) ("2 -" . 2092) ("RestFn ." . 3828) ("192 ." . 2074) ("recur" . 6672) ("td align" . 7125) ("POST" . 3742) ("type :" . 7259) ("dat" . 5006) ("commons" . 4903) (") ((" . 803) (")*" . 934) ("api" . 4560) (":= os" . 2508) ("#<" . 243) ("Position" . 3761) ("creep Call" . 4973) ("maps" . 6096) ("{\\" . 7618) ("named :" . 6210) ("gfortran" . 5524) ("} public" . 7711) ("AND (" . 3042) ("die" . 5079) ("( isset" . 575) ("Section" . 3866) ("[{ file" . 4232) ("= //" . 2762) ("labyrinth" . 5935) ("tabular" . 7111) ("\" value" . 95) ("VARCHAR" . 4069) ("- eabi" . 1294) ("- length" . 1321) ("( in" . 570) ("runat =\"" . 6779) ("}) }" . 7732) ("fn main" . 5405) ("Event" . 3312) ("Runtime :" . 3842) ("* cell" . 1034) ("private" . 6550) ("3 ]," . 2159) ("127 ." . 2054) ("=\"@+ id" . 2888) ("B =" . 3098) ("hs" . 5629) ("( nonatomic" . 605) (") -" . 808) ("( println" . 616) ("Enter the" . 3303) ("size" . 6920) ("stdcall" . 6985) ("((=" . 694) ("args ," . 4589) ("aborting" . 4445) (") self" . 884) ("]; char" . 4343) ("box -" . 4737) ("INTEGER" . 3452) ("scrollView" . 6834) ("( (" . 433) ("b" . 4663) ("urn :" . 7304) ("ifTrue" . 5709) ("NSURL" . 3663) ("( this" . 647) ("NA ," . 3623) (">();" . 2968) ("'{" . 426) (". _1" . 1553) ("do echo" . 5115) ("1 .." . 1998) ("04 -" . 1954) ("( cons" . 526) ("?" . 2993) ("[-" . 4209) ("querySelector" . 6617) ("I :=" . 3426) ("is" . 5851) ("3 ." . 2151) (">;" . 2977) ("ac" . 4452) (": [^" . 2344) (",{" . 1238) ("( interactive" . 574) ("if ;" . 5699) ("\\ renewcommand" . 4257) ("new ();" . 6233) ("\"];" . 208) ("# import" . 227) ("500" . 2209) ("navbar -" . 6222) ("< String" . 2636) ("frac {" . 5453) ("chomp" . 4844) (", H" . 1131) ("= array" . 2799) ("Not" . 3700) (". 5cm" . 1455) ("String name" . 3917) ("($ ch" . 677) ("asString" . 4621) ("core /" . 4952) (",$" . 1223) ("22" . 2128) ("${" . 285) ("syntax -" . 7079) ("]];" . 4356) ("backward" . 4679) ("\"`" . 214) ("), intent" . 947) ("return nil" . 6741) ("< Setter" . 2635) ("using" . 7324) ("foreach ($" . 5431) (". NativeMethodAccessorImpl" . 1512) ("\", @\"" . 149) ("centering" . 4824) (")))))))" . 923) ("class =\"" . 4854) ("!)" . 14) ("> <!--" . 2952) ("T ]" . 3938) ("?, ?," . 3002) ("2 \\" . 2104) (": hover" . 2388) ("/ pkg" . 1851) ("PROCEDURE" . 3746) ("elements" . 5190) (": NO" . 2324) ("rel =\"" . 6688) ("], L" . 4328) ("wx ." . 7448) ("0 );" . 1909) ("size :" . 6923) ("void main" . 7384) ("'), write" . 381) ("; implementation" . 2572) ("putStrLn" . 6601) ("mut" . 6173) (". Get" . 1494) ("G" . 3379) ("std ;" . 6984) ("0f" . 1969) ("EventArgs e" . 3315) ("), (\"" . 942) ("REAL ," . 3805) ("int (" . 5813) ("table ." . 7103) ("End If" . 3297) ("n ," . 6192) ("li a" . 5987) ("be" . 4684) ("1 Error" . 2008) ("func viewDidLoad" . 5478) ("Color" . 3196) ("2 ))" . 2084) ("} /**" . 7676) ("System open" . 3930) (". pl" . 1698) ("sqrt" . 6956) ("echo" . 5170) ("9L" . 2258) ("); print" . 1003) ("\" do" . 65) ("lists :" . 6026) ("NSURL (" . 3664) ("unsigned int" . 7294) ("extern" . 5320) ("sty" . 7037) ("( File" . 459) ("/ action_dispatch" . 1802) ("y :=" . 7496) ("NO ];" . 3631) ("addObject :" . 4492) ("' BEGIN" . 340) (", 5" . 1108) ("www" . 7445) ("delete" . 5054) ("default -" . 5038) ("}, {" . 7739) ("$ _" . 253) ("%%" . 296) ("( eq" . 545) ("x86_64" . 7469) ("src" . 6959) ("br />" . 4739) ("(\"\\ n" . 671) ("push (" . 6593) ("y )" . 7493) ("pub struct" . 6580) ("NO" . 3629) ("start (" . 6971) ("mut self" . 6174) ("k ," . 5913) ("50px" . 2210) ("} catch" . 7689) ("| _" . 7638) ("^ 2" . 4365) ("FormCreate" . 3363) ("=\" 100" . 2852) ("list (" . 6017) ("js /" . 5902) ("NSBundle" . 3638) ("{ public" . 7588) ("reference" . 6679) ("- SNAPSHOT" . 1265) ("</ polymer" . 2725) ("destroy" . 5069) ("[," . 4207) ("Text_IO ;" . 3988) ("sample" . 6799) ("; printf" . 2587) ("usepackage" . 7311) ("v in" . 7338) (":// schemas" . 2468) ("No such" . 3695) ("typedef struct" . 7266) ("_Future ." . 4387) ("hover {" . 5624) ("Ok (" . 3721) ("home" . 5617) ("= -" . 2761) ("/ django" . 1825) (", 255" . 1102) ("::{" . 2487) ("L" . 3527) ("layer" . 5950) ("0pt" . 1973) ("( progn" . 617) ("scala >" . 6813) ("active_record /" . 4467) ("< stdio" . 2674) ("w http" . 7389) ("Void" . 4087) ("alert (" . 4508) ("! !" . 2) ("port" . 6513) ("UIImageView" . 4029) ("\\" . 4235) ("orientation =\"" . 6385) ("22 ." . 2129) (">< br" . 2980) ("s -" . 6796) ("else begin" . 5195) ("2013" . 2117) ("=\"{ Binding" . 2890) ("global -" . 5535) ("( Eq" . 457) ("if event" . 5704) ("values (" . 7353) ("background =\"@" . 4676) ("example" . 5288) ("!(\"{:?}\"," . 12) ("X" . 4114) ("animated" . 4545) ("Set" . 3879) ("( char" . 520) ("hidden =" . 5611) ("person" . 6465) ("regexp -" . 6684) ("beginning" . 4700) ("string :" . 7018) ("2 </" . 2102) ("rc" . 6649) ("CGRectMake (" . 3149) ("---" . 1394) (". Close" . 1475) ("( SELECT" . 489) ("in" . 5753) ("UIImage" . 4025) ("description" . 5067) ("replace -" . 6704) ("clojure ." . 4867) ("\", $" . 146) (":= Array" . 2495) ("fun x" . 5471) ("message" . 6131) (") library" . 876) ("List [" . 3559) ("Object" . 3715) (", m" . 1196) ("( r" . 619) ("From ," . 3372) ("1 ]" . 2011) ("ResponseWriter ," . 3825) ("user" . 7314) ("COUNT (" . 3154) (", loop" . 1195) ("41" . 2188) (". runtime" . 1715) ("err }" . 5266) ("))))) (" . 920) ("- family" . 1303) (". !" . 1430) ("dbo ].[" . 5025) ("} val" . 7717) ("String )" . 3907) (", undefined" . 1214) ("grep" . 5561) ("swing" . 7074) ("out" . 6395) (", EventArgs" . 1128) ("- 02" . 1245) ("tagged" . 7114) ("' package" . 360) (") (*" . 804) ("textwidth" . 7165) (">
 <" . 2941) ("#:" . 242) ("cannot" . 4790) ("= as" . 2800) ("ex As" . 5287) ("end ," . 5216) ("@ _" . 3015) ("( Self" . 490) ("collections ::" . 4888) ("| x" . 7654) ("= \"\"" . 2754) ("} //" . 7677) (") +" . 807) ("TD" . 3948) ("} -(" . 7673) ("fprintf" . 5450) (": layout_width" . 2405) ("conj" . 4922) ("scale =" . 6815) ("defn" . 5047) ("false ;" . 5348) ("sc" . 6808) (";\"> <" . 2620) ("textSize" . 7161) ("anObject" . 4532) ("NSMutableArray alloc" . 3656) (": line" . 2408) ("text \"" . 7150) (": \"" . 2260) ("N )" . 3617) ("gmail ." . 5537) (". Text" . 1533) ("path (" . 6450) ("= null" . 2829) ("MATLAB" . 3570) ("View" . 4083) (". doInvoke" . 1608) (". js" . 1661) ("addBody" . 4482) ("g ;" . 5493) (". y" . 1755) ("event )" . 5282) ("typechecker ." . 7264) ("matrix (" . 6112) ("True ," . 4013) ("native ." . 6219) ("GHC" . 3383) ("SKAction" . 3853) ("00 :" . 1936) ("=" . 2752) (": usize" . 2438) ("buffer )" . 4750) ("|>" . 7657) (">=" . 2986) ("( setq" . 635) ("():" . 730) ("</" . 2707) ("text /" . 7154) ("aNumber" . 4439) ("w3 ." . 7391) ("Nothing" . 3701) ("Y ," . 4140) (": 18" . 2290) ("solid" . 6933) ("} %" . 7669) ("lawlist -" . 5949) ("- mode" . 1332) ("take" . 7116) ("use =\"" . 7306) (": 0px" . 2279) ("Main ;" . 3577) ("div" . 5099) (". Forms" . 1492) ("http ://" . 5641) ("Var" . 4075) ("ERROR :" . 3282) ("info ]" . 5785) ("displayed -" . 5095) ("png \"" . 6500) ("[]," . 4228) ("perl use" . 6460) ("locationManager" . 6037) ("core -" . 4950) ("rec" . 6665) (":: string" . 2483) ("++) {" . 1073) ("Response ." . 3823) ("CGPoint" . 3143) ("at scala" . 4642) ("(:,:," . 764) ("dist" . 5096) ("data -" . 5010) ("button" . 4762) ("Control" . 3209) ("scope ." . 6827) ("io ." . 5844) ("2 &" . 2082) ("[] (" . 4219) (". printStackTrace" . 1703) ("\" src" . 90) ("helper" . 5604) (") do" . 857) ("`)" . 4408) ("(>" . 768) (".. \"" . 1765) ("click" . 4859) ("Model ):" . 3605) ("x ." . 7456) (") THEN" . 844) ("catch (" . 4806) ("@ 0" . 3009) ("nil );" . 6263) (". Show" . 1529) ("For i" . 3361) ("E" . 3269) ("IF ;" . 3440) ("[ self" . 4189) ("- max" . 1330) ("python2 ." . 6612) ("apache ." . 4559) ("; if" . 2571) ("sprockets" . 6954) ("rabbitmq" . 6628) ("int *" . 5815) ("implicit" . 5730) ("order" . 6379) ("n \");" . 6186) ("erl" . 5254) ("() As" . 706) ("subroutine" . 7052) ("pragma" . 6518) ("copy" . 4947) ("io" . 5843) (": textSize" . 2432) ("callback" . 4785) ("1 \">" . 1983) ("DECLARE @" . 3232) (") :-" . 819) ("mod" . 6147) ("self ];" . 6861) ("javax" . 5895) ("- child" . 1281) ("math ." . 6110) ("asInteger" . 4617) ("60" . 2228) ("family :" . 5350) (".[" . 1776) ("_ import" . 4381) ("this ." . 7188) ("patch" . 6447) (". 000000" . 1440) ("byte []" . 4766) ("\"*" . 143) ("1 >" . 2007) ("UIViewController" . 4041) ("buffer [" . 4752) ("rank" . 6646) ("note" . 6297) ("board" . 4715) ("C ." . 3134) ("crate" . 4967) ("chr" . 4845) ("btn" . 4746) (". android" . 1563) ("fun _" . 5470) ("[ 0" . 4158) ("h" . 5574) ("< iostream" . 2658) ("\"\"\"" . 103) ("mode" . 6148) ("===" . 2911) ("NA" . 3622) ("Font" . 3355) ("Unit" . 4056) (":>" . 2513) ("ul" . 7281) ("= inherit" . 2816) ("( kbd" . 578) ("ctx" . 4979) (". Rows" . 1528) ("white" . 7416) ("Windows ," . 4106) ("): return" . 974) ("created ()" . 4970) ("gcc" . 5495) (". gz" . 1639) ("4 ." . 2181) ("n \";" . 6189) ("CREATE" . 3155) ("; color" . 2554) ("lib ." . 5990) ("/ tex" . 1871) ("++)" . 1072) ("= New" . 2780) ("( Compiler" . 454) ("groovy :" . 5567) ("0 (" . 1905) ("' In" . 345) ("</ script" . 2726) (": int" . 2398) ("title >" . 7206) ("= open" . 2830) (", 4L" . 1107) ("using System" . 7326) ("11" . 2039) (". Button1Click" . 1466) ("WITH Ada" . 4094) ("GHC ." . 3384) ("( while" . 658) ("- export" . 1300) ("using namespace" . 7327) ("![" . 22) ("2011" . 2114) ("Button1Click" . 3123) ("groupId" . 5569) ("description >" . 5068) ("tail" . 7115) ("cursor" . 4986) ("pl line" . 6485) ("acc" . 4454) ("{ for" . 7561) ("WriteLine (\"" . 4112) ("= FALSE" . 2774) (": command" . 2371) ("the trait" . 7172) ("run" . 6776) ("($ _POST" . 676) ("( most" . 596) ("listen ((" . 6024) ("uses" . 7323) ("[ x" . 4197) (": xmpp" . 2443) ("due" . 5151) ("player" . 6488) ("top" . 7222) ("Call" . 3159) ("&" . 312) (", N1" . 1139) ("X1 ," . 4126) ("decoration :" . 5033) ("lock -" . 6039) ("( Integer" . 466) ("38" . 2173) ("l |" . 5930) ("value >" . 7348) ("border" . 4725) ("\" ++" . 32) ("( IBAction" . 463) ("). X" . 961) ("ArrayList" . 3077) ("\", &" . 147) ("cabal" . 4778) ("=\" 0" . 2850) ("border :" . 4727) ("quote" . 6618) ("alist" . 4516) ("pub fn" . 6579) ("put (\"" . 6599) (", c" . 1171) ("unwrap" . 7295) ("WRITE" . 4095) ("abc" . 4444) ("( RT" . 486) ("fid" . 5362) (": CGFloat" . 2313) ("( current" . 530) ("CASE WHEN" . 3141) ("version =\"" . 7370) ("is a" . 5856) ("is access" . 5857) ("label {" . 5934) ("beans" . 4686) ("() \"" . 696) ("- 04" . 1247) ("li ><" . 5986) ("site -" . 6919) ("edge" . 5181) ("re" . 6652) ("NSError" . 3644) ("Name =>" . 3678) ("layer ." . 5951) ("form -" . 5436) ("*)" . 1047) ("[$ 1" . 4202) ("8 )," . 2244) ("a4paper" . 4437) ("end {" . 5236) ("Height" . 3418) ("READ" . 3802) (". w3" . 1748) ("Put_Line (" . 3788) ("= '" . 2759) ("symbol" . 7077) ("'." . 400) ("print ('" . 6531) (") )" . 806) ("keys" . 5920) ("cell =" . 4816) ("price" . 6523) ("= seq" . 2833) ("end ." . 5218) ("u '" . 7275) ("reduce" . 6676) ("model" . 6152) ("If If" . 3467) ("} \\" . 7685) ("sbt ." . 6807) ("top :" . 7224) ("names (" . 6214) ("=> println" . 2926) ("ans =" . 4556) (": template" . 2429) ("float" . 5396) ("String ->" . 3909) ("</ xs" . 2735) ("dimension (" . 5083) ("array (" . 4602) ("(). unwrap" . 729) ("dimension" . 5082) ("load (" . 6028) ("return self" . 6742) ("{'" . 7612) ("=$" . 2892) (". rb" . 1710) ("[, 1" . 4208) ("xsi" . 7486) ("Get" . 3391) ("set ;" . 6887) ("DataSource =" . 3248) ("} print" . 7706) ("github ." . 5532) ("t +" . 7090) ("return false" . 6740) ("-> do" . 1414) ("| T" . 7634) ("do begin" . 5114) (";" . 2526) ("package main" . 6416) (": Color" . 2315) ("super ." . 7068) ("foo" . 5410) ("function" . 5480) ("| Xs" . 7636) (", L" . 1133) ("format )" . 5442) ("public class" . 6584) ("text -" . 7153) ("\"> </" . 192) ("<-" . 2701) ("documentclass" . 5134) ("[[ NSMutableArray" . 4216) ("latex" . 5945) ("complete" . 4906) ("previous error" . 6522) ("- radius" . 1349) ("([ A" . 776) ("<< std" . 2743) ("{ this" . 7598) ("shadow :" . 6902) ("o :" . 6331) ("printfn \"%" . 6543) ("ToString ());" . 4000) ("( array" . 510) ("ul >" . 7282) (") Then" . 845) ("response ." . 6725) (", 0x0" . 1092) ("( AbstractCallSite" . 450) ("#[" . 245) ("apply" . 4574) ("=> Array" . 2921) ("phase" . 6469) ("rubygems" . 6775) ("== 0" . 2905) (": refer" . 2418) ("192" . 2073) ("Unicode char" . 4055) ("opt" . 6368) ("=\" utf" . 2870) ("Click" . 3188) ("- f" . 1301) ("ms" . 6168) ("pygame" . 6608) (": Vec" . 2340) ("creep Exit" . 4974) ("href =\"#\">" . 5628) ("Map [" . 3580) ("DECLARE" . 3231) ("loop (" . 6049) ("} sub" . 7715) ("char *" . 4833) ("| otherwise" . 7649) ("end type" . 5235) ("@ property" . 3022) (". eps" . 1615) ("- 9" . 1263) ("container" . 4937) ("library" . 5994) ("button >" . 4763) ("x ," . 7453) ("=\" wrap_content" . 2872) ("END" . 3273) ("RT ." . 3810) ("/ bundler" . 1816) ("ID" . 3435) ("\" else" . 68) ("( format" . 556) ("C" . 3130) ("item" . 5873) ("< Grid" . 2632) ("removeSelf" . 6695) ("/ share" . 1868) ("aString" . 4442) ("(<" . 765) ("59" . 2219) ("cout <<" . 4960) ("item >" . 5874) (": %@\"," . 2265) ("CallSiteArray" . 3161) ("\": \"" . 169) ("add -" . 4480) ("', '" . 394) ("1 )*" . 1990) ("td" . 7122) ("moz" . 6166) ("completion" . 4907) ("/ 2015" . 1791) ("000000" . 1940) ("( M" . 473) ("const char" . 4930) ("=\"$" . 2879) ("utf -" . 7332) ("5 :" . 2204) ("} fn" . 7697) ("8 /" . 2247) ("[ 2" . 4160) (") def" . 855) (", self" . 1206) (", State" . 1150) ("10 ," . 2025) ("for" . 5412) ("attribute" . 4648) ("UIButton" . 4022) ("( 6" . 444) ("IO ." . 3460) ("c :" . 4775) ("i ," . 5655) (": Label" . 2322) ("style :" . 7040) ("html |" . 5636) ("drawable" . 5147) ("rnorm (" . 6754) ("( JSONException" . 469) (": UITextField" . 2338) ("\"; my" . 182) (". groovy" . 1638) (",:)" . 1230) ("} elsif" . 7694) ("Socket" . 3893) ("Windows ." . 4107) ("[(" . 4206) ("invokeMethod" . 5841) ("proc_lib" . 6558) ("NSMutableArray *" . 3655) (". each" . 1611) (":= False" . 2497) ("4 ," . 2180) ("{ width" . 7603) (": ((" . 2271) ("[] string" . 4224) ("). edge" . 962) ("plt ." . 6493) ("11 :" . 2043) ("charset" . 4840) ("--@ 1" . 1399) ("\") =" . 115) ("click (" . 4860) ("centering \\" . 4825) ("R" . 3794) ("setlength" . 6894) ("new ()" . 6232) ("s )" . 6795) ("/** *" . 1885) ("\\/" . 4273) ("TRUE )" . 3960) ("; WITH" . 2546) ("{}" . 7620) ("Z )," . 4151) ("=$( echo" . 2895) ("maze" . 6119) (". Drawing" . 1486) ("]) :-" . 4315) ("7 /" . 2236) ("Create" . 3222) ("record" . 6670) ("def \\" . 5035) ("$ _POST" . 254) ("maps ." . 6097) ("02" . 1948) ("sdk" . 6835) ("Text )" . 3974) ("CALL" . 3139) ("NULL ;" . 3671) ("End Sub" . 3299) ("stringWithFormat" . 7026) ("padding" . 6422) ("', :" . 395) ("C ," . 3132) ("< item" . 2659) (":= tempAnimal" . 2511) ("$" . 248) ("the expression" . 7170) (":: vector" . 2484) ("\"); scanf" . 140) ("8 )" . 2243) ("println !(\"{}\"," . 6546) ("36" . 2169) (". %" . 1433) ("./" . 1772) ("progn" . 6564) ("2013 -" . 2118) ("rack /" . 6630) ("=\" 2" . 2853) ("key" . 5918) ("FNR" . 3331) ("< a" . 2640) ("region" . 6685) (", nonatomic" . 1200) (", a" . 1166) ("2 ." . 2093) ("/ opt" . 1847) ("xmpp :" . 7479) ("a =" . 4424) ("root" . 6757) ("31" . 2164) (". Font" . 1491) ("implements" . 5729) ("addChild (" . 4485) ("- templates" . 1370) ("lines" . 6006) ("]]," . 4355) ("Println" . 3768) ("- 06" . 1249) ("callback :" . 4786) (", NULL" . 1141) (": aborting" . 2350) ("erl :" . 5257) ("; --" . 2534) ("TObject ;" . 3958) ("| |" . 7656) ("width =\"" . 7423) ("OFS" . 3706) ("read (" . 6654) ("InnoDB" . 3478) ("- min" . 1331) (". Caption" . 1469) ("tex" . 7142) (". Position" . 1519) ("Tail ," . 3967) ("%> </" . 305) ("then begin" . 7179) ("invoke (" . 5840) ("$('." . 283) (":]" . 2523) ("spawn (" . 6946) ("( fn" . 554) ("w ." . 7387) ("# 1" . 222) ("\\ 377" . 4237) ("== by" . 2908) ("]; return" . 4346) ("conn" . 4923) ("\" #" . 25) ("eps" . 5245) ("Foo {" . 3358) ("perl5" . 6461) ("/ res" . 1860) ("INNER" . 3447) ("N -" . 3620) ("load ." . 6030) (". log" . 1671) ("in call" . 5761) (")->" . 956) ("record ;" . 6671) ("Fatal" . 3340) ("(); let" . 734) ("x ==" . 7462) ("GET /" . 3382) ("{%" . 7611) ("isolate" . 5868) (", write" . 1216) ("l" . 5926) ("- name" . 1338) ("'\\\\'" . 417) ("web" . 7401) ("{ e" . 7551) ("- month" . 1334) ("buffer -" . 4751) (". }" . 1756) ("i :=" . 5658) ("procedure" . 6560) ("$ 3" . 252) ("named" . 6209) ("squared" . 6958) ("stream" . 7006) ("=' urn" . 2898) ("isset" . 5869) ("mode 1" . 6151) ("[ B" . 4164) ("- file" . 1304) ("Integer =" . 3498) ("9" . 2251) ("object" . 6333) (": indexPath" . 2395) ("VALUES" . 4067) ("= fopen" . 2812) ("due to" . 5152) (") and" . 849) ("user /" . 7316) (", forKey" . 1185) ("min ." . 6139) ("INNER JOIN" . 3448) ("t )" . 7088) ("\" http" . 77) ("esac" . 5273) ("table (" . 7102) ("])" . 4312) ("release ];" . 6692) ("( html" . 566) ("typesafe ." . 7273) ("fromIntegral" . 5465) ("# define" . 223) ("\"; \"" . 179) ("equation" . 5252) ("- color" . 1283) ("])," . 4319) ("User" . 4061) ("TRUE" . 3959) ("Array new" . 3076) ("performWithDelay" . 6455) ("multicolumn {" . 6172) ("webkit -" . 7405) ("contrib ." . 4945) ("at clojure" . 4636) ("rnorm" . 6753) ("0 ];" . 1927) ("father" . 5351) ("0x00 ," . 1979) ("Cells (" . 3175) ("SetLength (" . 3881) ("- d" . 1287) ("= @" . 2770) ("- ref" . 1352) ("X2 ," . 4128) ("NSIndexPath *)" . 3648) ("ResponseWriter" . 3824) (": in" . 2394) ("1 end" . 2016) ("get ('" . 5511) ("\" @" . 47) ("attr" . 4645) ("( self" . 631) ("IF" . 3438) ("\"); }" . 141) (") lib" . 875) ("> using" . 2961) ("@\"" . 3026) ("{ if" . 7566) ("indexPath )" . 5780) ("` json" . 4406) ("> {" . 2962) ("check" . 4841) ("transform" . 7234) ("integer" . 5824) (". scala" . 1717) (")); end" . 930) ("usepackage [" . 7312) ("A" . 3027) ("Transform" . 4009) ("didReceiveMemoryWarning" . 5077) ("( do" . 542) (") {" . 896) ("li {" . 5988) ("boolean ;" . 4720) ("++; }" . 1076) ("< string" . 2676) ("let mut" . 5978) ("[ a" . 4179) ("chapter" . 4831) ("\"))" . 126) ("string -" . 7015) ("' AND" . 339) ("</ p" . 2723) ("/ 2013" . 1790) (") of" . 878) (") fmt" . 863) ("word" . 7435) ("64" . 2229) ("lawlist" . 5948) ("<' a" . 2700) ("..$" . 1767) ("undef" . 7284) ("): self" . 975) ("void *" . 7383) ("- data" . 1288) ("[{" . 4231) ("END {" . 3278) ("); println" . 1005) ("variable name" . 7360) ("01 :" . 1946) ("options" . 6373) ("<- read" . 2706) ("With" . 4108) ("1 :" . 2004) ("( 4" . 441) ("File \"/" . 3344) ("10 ." . 2027) ("{ $" . 7516) ("error" . 5267) (". widget" . 1750) ("%;" . 299) ("len (" . 5968) ("shell" . 6905) ("( check" . 521) ("; left" . 2577) ("ORDER" . 3711) ("do if" . 5118) ("my -" . 6181) (": UITableView" . 2337) ("{ x" . 7604) ("update" . 7298) ("xlabel" . 7471) ("MessageBox" . 3592) ("web ." . 7402) ("angular /" . 4542) ("kwargs" . 5925) ("dist /" . 5098) ("Create ;" . 3224) ("ada ." . 4475) ("\\ site" . 4260) ("( core" . 528) (". callsite" . 1578) (", char" . 1173) (")));" . 924) ("num" . 6317) ("context" . 4943) ("loop" . 6048) ("::" . 2470) ("const {" . 4932) ("\" alt" . 60) ("hObject" . 5581) (". factory" . 1624) ("expansion" . 5306) ("ALL" . 3040) ("\" content" . 63) ("Reason" . 3814) ("{ fmt" . 7558) ("~/" . 7769) ("= c" . 2802) ("doFilter" . 5125) ("*, '" . 1057) (": 20" . 2294) ("property name" . 6574) ("\\-" . 4272) ("unsigned char" . 7293) (") $(" . 797) ("00" . 1932) ("textbf" . 7163) ("remove" . 6694) ("); --" . 983) ("strong" . 7031) ("2001 /" . 2112) ("34" . 2167) ("func didReceiveMemoryWarning" . 5475) ("main import" . 6081) (": '" . 2268) (";
 }
" . 2528) ("{{" . 7619) (". web" . 1749) ("position :" . 6515) ("gen_server ," . 5504) (". Unbounded" . 1538) ("value :" . 7345) ("KEY" . 3525) ("as ?" . 4615) ("id" . 5673) ("Console ." . 3205) (") //" . 814) ("12 -" . 2049) ("at" . 4630) ("* (" . 1026) ("\", :" . 148) ("[^" . 4230) ("< g" . 2651) ("response" . 6724) ("res /" . 6720) ("cellForRowAtIndexPath" . 4818) ("); curl_setopt" . 994) ("sun" . 7065) ("img" . 5723) (": html" . 2389) ("div >
" . 5101) (": nil" . 2411) ("P ," . 3736) ("usr" . 7329) ("return 0" . 6735) ("Println (\"" . 3770) ("\"]];" . 213) ("Shared" . 3883) ("read ." . 6656) ("data :" . 5012) ("spark ." . 6944) ("static" . 6977) ("Windows" . 4105) ("\" Text" . 52) (", null" . 1201) ("-> Int" . 1405) ("; #" . 2529) ("( X" . 499) (". name" . 1676) ("- alist" . 1269) ("lazy val" . 5961) ("Socket ," . 3894) ("echo \"$" . 5172) ("0 |" . 1930) ("usr /" . 7330) ("\\\"," . 4268) ("(\"% s" . 667) ("current" . 4982) ("False" . 3338) ("JSONObject" . 3519) ("bound" . 4734) ("wrap_content" . 7439) ("Do" . 3264) ("submit \"" . 7049) ("j" . 5883) ("Assigned (" . 3091) ("=(" . 2899) ("haskell" . 5592) ("As Boolean" . 3080) ("))] (" . 933) ("article" . 4607) ("\" let" . 79) ("{ var" . 7601) (". addSubview" . 1559) ("i )." . 5650) ("Integer '" . 3493) ("each (" . 5161) ("{#" . 7607) ("module >" . 6157) ("|> List" . 7660) ("none -" . 6288) ("table }" . 7105) ("'(" . 371) ("getString (\"" . 5523) ("io :" . 5845) ("Then Dim" . 3992) ("end return" . 5233) ("$ 1" . 250) ("beg" . 4688) (": xs" . 2444) ("ToString ()" . 3999) ("[ indexPath" . 4185) ("height" . 5597) ("widget ." . 7418) (", @" . 1118) (")\\" . 1016) ("include \"" . 5770) ("use strict" . 7309) ("3 );" . 2148) ("elsif" . 5201) ("rake" . 6638) ("push_back" . 6595) ("varchar" . 7357) ("</ table" . 2728) ("elif" . 5191) ("install :" . 5808) ("show ();" . 6911) ("int64" . 5823) ("end do" . 5223) (") %" . 798) ("{ height" . 7564) ("theta" . 7184) ("Nothing Then" . 3702) ("aborting due" . 4446) ("])." . 4320) ("w ," . 7386) ("do" . 5110) ("at org" . 4640) ("session" . 6882) ("end record" . 5232) ("! important" . 4) (". image" . 1649) (":= [" . 2500) ("p ." . 6408) ("images /" . 5722) ("09 -" . 1964) (". push" . 1705) ("2 ," . 2091) ("length ;" . 5971) ("complexType >" . 4910) ("( move" . 597) ("]); }" . 4325) (". contentHeight" . 1589) ("substr ($" . 7055) ("*}" . 1061) ("extends" . 5316) ("savedInstanceState" . 6804) ("frac" . 5452) ("uploader" . 7299) ("} </" . 7679) ("- rw" . 1357) ("HeaderText" . 3417) ("{ lstlisting" . 7573) ("userInfo" . 7319) ("Y )." . 4138) ("{ Ok" . 7531) ("block ;" . 4713) ("_Future" . 4386) ("File \"" . 3343) ("() #" . 697) ("; public" . 2591) ("Bool" . 3111) ("{ struct" . 7594) (". main" . 1673) ("); void" . 1010) ("input type" . 5801) ("bundler" . 4759) ("php" . 6471) ("GET" . 3381) ("20px ;" . 2126) ("','" . 398) ("_ =>" . 4379) ("( loop" . 586) ("latex \\" . 5947) ("random" . 6641) ("; std" . 2595) ("anon" . 4549) ("( when" . 657) ("Error" . 3308) ("random (" . 6642) ("=> $" . 2915) ("1 )." . 1992) ("hs ," . 5630) ("string /" . 7017) ("delegate" . 5052) ("structure (" . 7036) ("End Using" . 3301) ("END SUBROUTINE" . 3277) ("d ," . 4993) ("Caption :=" . 3168) ("(/ usr" . 755) ("e ." . 5157) ("rgba" . 6747) ("));" . 929) ("NSLog" . 3652) ("frame" . 5454) ("/ torch" . 1875) (", x" . 1217) ("( I" . 462) ("identifier" . 5686) ("sans" . 6801) ("Array" . 3072) ("head >" . 5594) ("} &" . 7670) (", data" . 1177) ("internal" . 5836) ("( my" . 598) ("repository" . 6705) ("Sub End" . 3922) ("rwxr" . 6789) (":: Int" . 2474) ("HandleFunc" . 3412) (". find" . 1626) (". png" . 1701) ("( Of" . 481) (", -" . 1087) ("( 2" . 438) ("Public" . 3779) ("/ lib" . 1841) ("] initWithFrame" . 4300) ("dist -" . 5097) ("arising from" . 4597) ("err =" . 5265) ("graphics" . 5556) ("latex /" . 5946) ("$$" . 273) ("typedef" . 7265) ("push_back (" . 6596) ("include" . 5769) ("- filename" . 1305) ("on -" . 6355) ("; function" . 2568) (". path" . 1692) ("x1" . 7466) ("pl" . 6484) ("System" . 3928) ("error )" . 5268) ("load" . 6027) ("01 -" . 1944) ("{ ok" . 7578) ("integer (" . 5825) ("] public" . 4304) ("putStrLn \"" . 6602) ("animation -" . 4548) (").*" . 966) (". security" . 1718) ("int x" . 5821) ("10" . 2023) ("layout_width =\"" . 5959) ("alt" . 4527) ("Sum" . 3925) ("% {" . 294) (") in" . 871) ("\", scene" . 154) ("args" . 4587) ("addMorph" . 4489) ("map" . 6091) ("O" . 3705) ("gradle ." . 5553) ("component" . 4912) ("END IF" . 3275) ("handle_call" . 5584) ("likes" . 5997) ("( event" . 549) ("Prelude" . 3763) ("if (!" . 5694) ("id )" . 5675) ("# endif" . 224) ("\\+" . 4271) ("; interface" . 2575) ("inline" . 5797) ("Request" . 3820) ("height =" . 5599) ("packages /" . 6418) ("env" . 5244) ("cdr l" . 4812) ("{ get" . 7563) ("anonymous closure" . 4554) ("06" . 1957) ("iwC" . 5881) ("32" . 2165) (">(" . 2966) ("if" . 5692) ("socket" . 6932) ("django ." . 5106) ("\"\", \"" . 105) (", 3L" . 1105) ("END DO" . 3274) ("TComponent" . 3947) ("Value" . 4071) ("Then" . 3990) ("in 1" . 5757) (", Ada" . 1120) ("ByVal" . 3125) ("If (" . 3465) ("49" . 2196) ("( file" . 552) (". 9" . 1459) ("* *" . 1027) ("# fff" . 226) ("([ X" . 778) ("ms -" . 6169) ("\",[" . 158) ("Item" . 3506) (", e" . 1179) ("( j" . 576) ("or directory" . 6378) ("start_link" . 6973) ("Acc" . 3050) ("max_length =" . 6118) (">
 </" . 2942) ("< template" . 2680) ("\"% A" . 111) ("tableView :(" . 7110) ("Unknown Source" . 4059) ("is type" . 5865) ("newline )" . 6250) ("qw" . 6619) ("$ id" . 262) ("aes (" . 4501) ("create" . 4968) ("background -" . 4674) ("a :=" . 4423) ("Vector" . 4082) ("ngx" . 6258) ("image :" . 5717) ("D" . 3227) (". o" . 1684) ("org ." . 6382) ("do end" . 5116) (", dimension" . 1178) ("; -" . 2533) ("Numerics" . 3704) ("sender :" . 6867) ("num2str (" . 6319) (": 50px" . 2300) ("Int ]" . 3486) ("Begin" . 3106) ("Rails" . 3811) ("')." . 383) ("</ asp" . 2711) ("PRIMARY" . 3743) ("# f" . 225) ("0 )." . 1908) ("d /" . 4994) ("Top" . 4004) ("}[" . 7747) ("C1" . 3138) ("{ private" . 7586) ("type =\"" . 7260) ("p >" . 6409) ("< ul" . 2685) ("l ." . 5929) ("apache" . 4558) ("Integer )" . 3494) ("define" . 5040) ("log \"" . 6041) ("( ByVal" . 452) ("__init__" . 4395) (") call" . 852) ("NSNumber" . 3657) ("i )," . 5649) ("NIL" . 3628) ("type variable" . 7262) ("| Tail" . 7635) ("< span" . 2672) ("import (" . 5735) ("div id" . 5103) ("gems /" . 5501) ("sh :" . 6900) ("numpy" . 6325) ("collectionView" . 4886) ("}()" . 7730) (") END" . 835) ("std" . 6982) ("_ ;" . 4377) ("new :" . 6236) ("< anon" . 2641) ("minOccurs =\"" . 6141) ("/ packages" . 1848) ("\">>,<<\"" . 198) ("public virtual" . 6590) ("}% \\" . 7728) (". sh" . 1722) ("param" . 6433) (", F" . 1129) ("A ." . 3032) ("wg" . 7408) ("awk" . 4655) ("<'" . 2698) ("Seq_Float_IO" . 3876) (":= true" . 2512) ("Color ." . 3197) ("== NULL" . 2907) ("alloc ]" . 4519) ("doInvoke (" . 5128) ("Collections" . 3194) ("search" . 6836) ("\"|\"" . 215) ("\"/> </" . 167) ("c -" . 4773) ("OrderedCollection" . 3730) ("; const" . 2555) ("in the" . 5767) ("t ))" . 7089) ("catalina" . 4803) ("fmap" . 5399) (". eq" . 1616) ("het" . 5606) ("im1" . 5714) ("8080" . 2249) ("} fmt" . 7696) ("self ):" . 6856) ("main ()" . 6077) ("<$" . 2692) ("TObject );" . 3957) ("' +" . 333) (". go" . 1634) ("Core ." . 3216) ("boost /" . 4722) (") local" . 877) ("datetime" . 5018) ("OrderedCollection new" . 3731) ("chr1" . 4846) ("% A" . 288) ("groovy -" . 5565) ("end ;" . 5219) ("e ," . 5156) ("get ;" . 5514) ("margin :" . 6100) ("my" . 6177) ("person (" . 6466) ("scala -" . 6810) ("patch /" . 6448) (": 01" . 2277) ("( N" . 475) ("strcmp (" . 7002) (";;;" . 2626) ("1 ]:" . 2014) ("Text" . 3972) ("() print" . 716) ("Unbounded" . 4052) ("Y )," . 4137) ("]," . 4326) ("} procedure" . 7709) ("bar" . 4680) ("CGFloat" . 3142) ("import <" . 5736) (". New_Line" . 1514) ("ncol" . 6226) ("IntToStr (" . 3491) ("or (" . 6376) ("255 ," . 2134) ("1 )," . 1991) ("M" . 3566) (">
" . 2940) ("- value" . 1380) (") CALL" . 833) (": layout_weight" . 2404) ("presentViewController" . 6520) ("static member" . 6979) ("name >" . 6208) ("addEventListener" . 4486) ("Fill" . 3352) ("/ bundle" . 1815) ("} $" . 7668) (". ^" . 1551) ("array" . 4601) ("caption" . 4792) ("nextPutAll :" . 6255) ("0 \"]" . 1902) ("blib" . 4711) ("( memq" . 593) ("}}\"" . 7762) ("). ready" . 964) ("10L" . 2036) ("{ Some" . 7532) ("{ implicit" . 7567) ("UIView" . 4040) ("string )" . 7012) ("( args" . 509) ("Perl" . 3754) ("role =\"" . 6756) ("Strings ." . 3919) ("MPI_COMM_WORLD ," . 3575) ("struct node" . 7033) ("getElementById ('" . 5518) ("toString" . 7214) ("-> x" . 1425) (",\"" . 1221) ("subfigure" . 7047) ("Err" . 3306) ("view ." . 7374) (", #" . 1080) ("( 0" . 434) ("a mut" . 4432) ("DOCTYPE html" . 3239) ("dart \"></" . 4999) ("\")" . 112) ("active_support /" . 4469) ("subclass :" . 7046) (". tools" . 1741) (">< a" . 2979) ("\"; $" . 181) ("$$ anonfun" . 274) (":&" . 2451) ("].[" . 4336) ("tree" . 7239) ("RestFn" . 3827) ("*/" . 1059) ("support" . 7072) ("); begin" . 992) ("of select" . 6346) (">] type" . 2992) ("}];" . 7751) ("element name" . 5189) ("B ," . 3097) ("04" . 1953) (". Tables" . 1532) (": format" . 2384) ("cell }" . 4817) ("td >" . 7123) ("= Array" . 2772) ("SELECT *" . 3850) ("post" . 6517) ("0 0" . 1916) ("d \\" . 4995) ("() --" . 700) ("match =\"" . 6105) (": value" . 2439) ("FMX" . 3329) (": android" . 2357) ("())" . 722) ("30" . 2161) ("cv" . 4990) ("dbo ." . 5024) ("\" then" . 93) ("block in" . 4714) ("I ," . 3425) ("declarations" . 5030) ("into" . 5838) ("style =\"" . 7041) ("." . 1429) ("( max_length" . 592) ("worker" . 7436) (", [" . 1161) ("fd" . 5355) (". Value" . 1539) ("set {" . 6888) ("Items" . 3511) ("bottom :" . 4732) ("element" . 5187) ("require '" . 6713) (":: (" . 2471) ("pointer" . 6505) (": async" . 2363) ("; void" . 2608) ("begin --" . 4692) (": none" . 2412) ("at sun" . 4643) ("cabal -" . 4779) (":\"," . 2449) ("00 app" . 1937) ("type (" . 7258) ("(( null" . 693) ("com" . 4895) ("Groovy" . 3401) ("frame =" . 5459) ("select =\"" . 6850) (":[" . 2518) ("\" minOccurs" . 82) ("a b" . 4430) (">) ->" . 2970) (": #" . 2262) ("-> [" . 1410) ("Function" . 3374) ("password" . 6445) ("X ):-" . 4118) ("sum (" . 7062) ("arr" . 4600) ("([], _" . 785) ("throw" . 7191) ("animal" . 4543) ("(: require" . 757) ("\") Dim" . 116) ("( tableView" . 646) ("cout" . 4959) (". getJSONObject" . 1632) ("X +" . 4119) ("otherwise" . 6393) ("')," . 380) ("tikzpicture }" . 7196) ("></ li" . 2984) (". count" . 1593) ("- at" . 1272) ("$ scope" . 267) (". table" . 1735) ("% d" . 291) ("security ." . 6843) ("hash" . 5591) ("exe" . 5294) (". Canvas" . 1468) ("Typers" . 4018) (". 0000" . 1439) ("others" . 6391) ("v" . 7335) ("} printf" . 7707) ("$ fh" . 259) ("}, \"" . 7738) ("(+" . 743) (") }" . 899) ("= NSURL" . 2778) ("[ H" . 4166) ("async {" . 4629) ("end subroutine" . 5234) ("; begin" . 2550) ("face" . 5336) ("] '" . 4281) ("this )." . 7186) ("\", \"" . 145) ("println \"" . 6547) ("stmt" . 6993) (": 100" . 2282) (". erl" . 1617) ("addChild" . 4484) ("377" . 2171) ("'," . 392) ("_ =" . 4378) ("RT" . 3809) ("/ core" . 1818) ("Transcript" . 4007) ("\" runat" . 88) ("() end" . 711) ("default" . 5037) ("'; my" . 411) (", D" . 1124) ("A ," . 3031) (":\\" . 2521) ("Monad" . 3606) (": @" . 2307) ("tempAnimal" . 7130) ("foreground \"" . 5434) ("stdlib" . 6990) ("( List" . 472) ("() //" . 702) ("k =" . 5914) ("<%" . 2694) ("min (" . 6137) ("status" . 6981) ("EOF" . 3279) ("line =" . 6002) ("\"" . 23) ("enddo" . 5237) ("16 :" . 2065) ("<- c" . 2703) ("Return '" . 3832) ("Thread" . 3995) ("point -" . 6504) (":( NSString" . 2456) ("MODULE ," . 3573) ("drawable /" . 5148) (":\\ Program" . 2522) (":( NSInteger" . 2455) ("\"); exit" . 137) ("NSError *" . 3645) ("Dart" . 3242) ("=\" text" . 2868) ("= np" . 2828) ("r --" . 6625) (":= Dictionary" . 2496) ("Open ()" . 3725) ("@ gmail" . 3017) ("T2" . 3943) ("\"/> <" . 166) ("[ string" . 4190) ("\" ^" . 59) ("( title" . 648) ("category :" . 4808) ("0 ]" . 1925) ("bundler /" . 4760) ("width :" . 7421) ("- n" . 1337) ("Web" . 4097) ("ToString ();" . 4001) ("() '" . 698) ("\"\"" . 101) ("); if" . 999) ("1427 0" . 2061) ("j )" . 5884) ("To" . 3997) ("jar" . 5889) ("NSData *" . 3640) ("] :=" . 4285) ("orientation" . 6384) ("seq (" . 6872) ("echo $" . 5174) (". class" . 1580) ("\") }" . 125) ("nth" . 6309) ("//" . 1888) ("51" . 2211) ("Get (" . 3392) (") case" . 853) ("tmpStream" . 7209) ("..." . 1769) (":( NSIndexPath" . 2454) (": 8" . 2304) ("- list" . 1325) ("solid #" . 6934) ("([ 1" . 775) ("toc" . 7217) ("K" . 3524) ("value -" . 7344) ("\": [" . 172) ("i ][" . 5667) ("; X" . 2547) ("++" . 1069) ("home /" . 5618) ("foreach my" . 5432) ("[ :" . 4162) (". newImage" . 1680) ("DWORD" . 3240) ("AndroidRuntime" . 3064) ("UIViewController {" . 4042) ("compojure" . 4911) ("/ app" . 1809) ("@ IBOutlet" . 3012) ("Nil" . 3693) ("Dictionary" . 3260) ("#+" . 240) ("##" . 235) ("(- 1000" . 748) ("in $" . 5754) (". Web" . 1542) ("anArray" . 4531) ("Console" . 3204) ("]) ->" . 4314) ("new" . 6230) ("\"<" . 185) ("}\\\\" . 7750) ("/ rubies" . 1861) ("no -" . 6277) ("End ;" . 3293) ("= 2" . 2766) ("4 4" . 2183) ("supervisor" . 7071) ("Drawing ." . 3267) ("typeof" . 7269) ("sizeof (" . 6927) ("indexPath {" . 5783) ("includegraphics" . 5772) (", 7L" . 1113) ("x :=" . 7458) ("df <-" . 5075) ("!= null" . 21) ("name" . 6199) ("cell ." . 4815) ("anon >:" . 4550) ("animals" . 4544) ("Can '" . 3164) ("setlength {\\" . 6895) ("method" . 6134) ("ruby" . 6772) ("sub" . 7043) (". xml" . 1754) ("menu -" . 6130) ("integer ," . 5826) ("OleDb ." . 3723) (": Float" . 2318) ("</ name" . 2721) ("1 )))" . 1988) ("Item (\"" . 3508) (") AND" . 830) ("*) tableView" . 1050) ("mat" . 6102) ("vendor /" . 7367) ("u32" . 7276) ("execution" . 5298) ("SUM (" . 3862) ("INTEGER ::" . 3454) ("2L ," . 2141) ("indent" . 5774) ("class >>" . 4855) ("(.: format" . 753) ("30 \\" . 2162) ("0px" . 1974) ("0 >" . 1922) (") File" . 838) ("rep (" . 6700) ("item name" . 5875) ("(); $" . 732) ("ex" . 5285) ("func (" . 5473) (">," . 2973) ("namely" . 6211) ("test -" . 7140) ("IOException" . 3461) ("listen" . 6022) ("-> io" . 1417) ("R1" . 3800) ("... \\" . 1770) ("/ local" . 1842) ("instanceVariableNames :" . 5811) ("As" . 3079) ("/ site" . 1869) ("L )" . 3528) ("," . 1078) ("Params" . 3750) ("- forward" . 1306) (", Y" . 1159) ("( f" . 550) ("- button" . 1278) ("Y =" . 4141) ("html \">" . 5633) ("ActiveRecord ::" . 3052) (":// www" . 2469) (". h" . 1640) ("terminate" . 7138) ("/ schema" . 1866) ("mutable" . 6175) ("| 4" . 7630) ("output" . 6397) ("( NA" . 476) ("( Int" . 465) ("creep" . 4972) ("&\\" . 327) ("Response" . 3822) ("each do" . 5163) ("Exit :" . 3320) (", N" . 1138) ("family" . 5349) ("> <%=" . 2954) ("row ];" . 6765) (", retain" . 1205) ("template <" . 7133) ("{# 1" . 7608) ("nrepl" . 6303) (". Count" . 1482) ("Close" . 3190) (". String" . 1530) ("| t" . 7652) ("String =" . 3912) ("< body" . 2644) ("script" . 6830) ("); my" . 1002) ("schema /" . 6823) ("L2" . 3535) ("polymer -" . 6507) ("imageNamed" . 5719) ("$ user" . 270) ("X )" . 4115) ("float64" . 5398) (", 0l0" . 1091) ("={" . 2935) ("github" . 5531) ("ac -" . 4453) ("() :" . 703) ("; position" . 2585) (". collection" . 1586) ("with member" . 7433) ("decimal" . 5029) (") 1" . 816) ("img src" . 5724) ("valid for" . 7342) ("sizeof" . 6926) ("` 1" . 4400) ("begin return" . 4698) ("; use" . 2605) ("() End" . 708) ("head" . 5593) ("unsafe {" . 7291) ("a =>" . 4425) ("()" . 695) ("sequence" . 6874) ("os" . 6388) ("applyTo (" . 4580) ("( with" . 659) ("n \",[" . 6188) ("compile" . 4904) ("- string" . 1365) ("\" [" . 56) ("; width" . 2611) ("new JSONObject" . 6240) ("dependencies" . 5056) ("male" . 6086) ("End Property" . 3298) ("- ms" . 1336) ("%>" . 301) ("() const" . 709) ("asCharacter" . 4616) ("animated :" . 4546) ("} end" . 7695) ("</ xsd" . 2736) ("ns" . 6306) ("$!\";" . 272) ("Recognized" . 3815) ("curl_setopt ($" . 4981) ("03 -" . 1952) ("require [" . 6716) ("c )" . 4771) ("nbsp ;&" . 6225) ("Start" . 3901) (", :" . 1116) ("pDialog" . 6412) ("try :" . 7252) ("/ scala" . 1865) ("undefined" . 7285) ("for `" . 5419) ("is X" . 5855) ("html >" . 5635) ("{ equation" . 7553) (": if" . 2393) ("ABC" . 3037) ("2 *" . 2089) ("| L" . 7632) ("Exception" . 3317) ("DateTime" . 3252) ("show" . 6910) ("action" . 4457) ("classVariableNames :" . 4857) ("- excursion" . 1299) ("$( document" . 277) ("; [" . 2548) ("cos" . 4954) ("do |" . 5122) ("type" . 7255) (":: Base" . 2472) ("- l" . 1319) ("size =" . 6924) ("doc" . 5129) ("adb" . 4476) ("kbd \"" . 5916) ("} return" . 7712) ("[] args" . 4222) ("= tableView" . 2839) ("; font" . 2566) ("implementation" . 5728) ("int >" . 5817) ("dp" . 5144) ("( new" . 602) ("\\ begin" . 4239) ("seq {" . 6873) ("physicsBody ?." . 6478) ("/ build" . 1814) (". ByteString" . 1467) ("dbo" . 5023) ("Option [" . 3728) ("/ perl5" . 1850) (")')" . 904) ("printString" . 6536) ("runtime ." . 6781) ("n" . 6184) ("close" . 4870) (": :" . 2306) ("( begin" . 513) (")) ;" . 912) ("; z" . 2613) ("I" . 3424) (". min" . 1675) ("t1" . 7096) ("then print" . 7182) ("name :" . 6205) ("newcommand" . 6247) ("] :" . 4284) (". Load" . 1507) ("NOT NULL" . 3634) ("]]; [" . 4357) ("My ." . 3613) (".<" . 1773) ("axis" . 4662) ("print" . 6524) ("(? MODULE" . 770) ("body >" . 4717) ("} END" . 7683) ("[ i" . 4184) ("), append" . 945) ("asParser /" . 4620) ("( C" . 453) ("2px" . 2142) ("- end" . 1297) (", r" . 1204) ("Result :=" . 3830) ("JSONArray" . 3516) (", 0x00" . 1093) ("for (" . 5413) ("submit" . 7048) ("xmlns =\"" . 7476) ("\">" . 187) ("; stdcall" . 2596) (", '" . 1084) ("builder" . 4756) ("Me ." . 3588) ("Int )" . 3482) ("option >" . 6371) ("LIKE" . 3540) ("); cout" . 993) ("a {" . 4434) (". 00" . 1437) ("= 0" . 2763) ("\"> <" . 190) ("] \\" . 4294) (": Bool" . 2311) ("collection" . 4884) ("encoding =\"" . 5210) (") end" . 859) ("my %" . 6179) ("- element" . 1296) ("88" . 2250) ("(.:" . 752) ("N )," . 3618) ("UITableViewCell" . 4037) ("| 2" . 7628) (". java" . 1659) ("RETURN" . 3808) ("Button android" . 3121) ("D ," . 3228) ("fill" . 5378) ("subplot" . 7050) ("; set" . 2594) ("\"; print" . 183) ("(+ 1" . 745) ("X3" . 4129) ("constructor Create" . 4936) ("(\"% d" . 666) (". println" . 1704) ("New" . 3687) ("08" . 1961) ("factory ." . 5341) ("Containers" . 3206) ("cut -" . 4989) ("' Class" . 342) ("1 padde" . 2017) ("subclass" . 7045) ("boost ::" . 4723) ("clj" . 4862) ("array ();" . 4604) ("\") '" . 113) (", Show" . 1148) ("\" }" . 99) ("~=" . 7770) ("&' a" . 326) ("application ." . 4572) ("*" . 1025) ("[ dbo" . 4181) (")] (" . 1018) ("nonatomic )" . 6285) ("cr" . 4965) ("localhost :" . 6035) ("Items ." . 3512) ("constraints" . 4934) ("success" . 7057) ("enum" . 5242) ("Positive" . 3762) ("sin (" . 6917) ("let rec" . 5980) ("_2" . 4384) ("=\" http" . 2862) (". Request" . 1525) ("absolute ;" . 4450) ("PChar (" . 3741) ("BY" . 3103) ("SB -" . 3848) ("index" . 5776) ("Toast ." . 4003) (", _" . 1164) ("() self" . 717) ("-> Bool" . 1403) ("fh" . 5359) ("H |" . 3406) ("1 |" . 2020) ("-> String" . 1407) ("rows" . 6766) ("doCall" . 5123) ("previous" . 6521) ("find" . 5386) ("File ::" . 3346) ("Files" . 3351) ("($ this" . 681) ("== '" . 2904) ("install" . 5807) ("< boost" . 2645) ("3 1" . 2154) ("JSON" . 3515) ("defun" . 5049) ("= event" . 2810) ("dart ." . 5003) ("app [" . 4567) ("- height" . 1311) ("if (" . 5693) ("***" . 1054) ("\"/ usr" . 164) ("parse" . 6441) ("( buffer" . 514) (": 17" . 2289) ("tree )" . 7240) ("; USE" . 2545) ("--@" . 1398) ("abstract" . 4451) ("template >" . 7134) ("); /*" . 984) ("= list" . 2819) ("):" . 968) ("let" . 5972) ("eval (" . 5279) ("polymer /" . 6509) ("JOIN" . 3514) ("echo \"<" . 5173) ("cond" . 4917) ("grep -" . 5562) ("( first" . 553) ("d \"," . 4992) ("each" . 5160) ("project" . 6569) ("i ++)" . 5654) ("erlang :" . 5259) ("/ erlang" . 1827) ("< li" . 2661) ("., 2" . 1763) ("section {" . 6841) ("[ error" . 4183) ("PolymerElement {" . 3759) ("Interfaces" . 3504) ("image =" . 5718) ("= NULL" . 2779) ("r" . 6621) (". hidden" . 1643) ("' with" . 363) ("> =" . 2957) ("(/" . 754) ("TObject" . 3956) ("* argv" . 1033) ("Columns ." . 3200) ("a href" . 4431) (") ifTrue" . 868) ("undefined ," . 7286) ("server \"" . 6878) ("wrap -" . 7438) ("groovy" . 5564) ("nil ," . 6264) ("2012 -" . 2116) (", 10" . 1095) ("C ]:" . 3137) (". app" . 1566) ("the view" . 7174) ("\" .." . 36) (". viewDidLoad" . 1747) ("y :" . 7495) ("json :\"" . 5906) (")) }" . 914) ("{: a" . 7616) ("Button1" . 3122) ("( Pid" . 484) ("\"\" \"\"" . 102) ("<- function" . 2705) (". layer" . 1665) ("cell" . 4814) ("), labyrinth" . 948) ("delete -" . 5055) ("* x" . 1043) ("}; \\" . 7743) ("start" . 6970) ("Text_IO ." . 3987) ("\" encoding" . 69) ("))," . 927) ("list '" . 6016) ("perl -" . 6458) ("Close ();" . 3192) ("Box ::" . 3116) ("NR" . 3635) (". applyTo" . 1569) (", 8" . 1114) ("A (" . 3029) ("T ," . 3934) ("<!" . 2689) ("is procedure" . 5861) ("%}" . 311) ("($ scope" . 680) (". typesafe" . 1744) ("{ \\" . 7536) (": id" . 2392) ("' dart" . 353) ("Html ." . 3422) ("user_id" . 7320) ("string" . 7009) ("ajax" . 4504) ("at com" . 4637) ("\\ section" . 4258) ("service" . 6879) ("ido -" . 5688) ("MiKTeX" . 3600) ("= System" . 2784) ("14" . 2058) ("User ." . 4062) ("cpp" . 4964) ("align =\"" . 4515) (".^ 2" . 1781) ("initWithFrame" . 5793) ("\\ caption" . 4240) ("car" . 4794) ("0 ){" . 1910) ("intent" . 5829) ("1 [" . 2009) ("Option" . 3726) ("f =" . 5328) ("`" . 4398) ("- r" . 1348) ("{ case" . 7542) ("lynxdictionary" . 6067) ("55" . 2215) ("exit 0" . 5301) ("AnyObject )" . 3068) ("of the" . 6347) ("] =>" . 4290) ("- tree" . 1377) ("/ texlive" . 1872) (": UILabel" . 2336) ("temp :=" . 7128) ("servlet" . 6880) ("Character" . 3180) ("int" . 5812) ("( var" . 653) ("date" . 5017) ("by" . 4764) ("][" . 4351) ("(); });" . 737) (": 4" . 2298) ("1 </" . 2006) ("\\\\ \\" . 4278) ("W" . 4089) ("left" . 5962) ("async /" . 4628) (": start" . 2424) ("4L" . 2197) ("stdio ." . 6989) (": a" . 2348) (") print" . 880) ("radius :" . 6633) ("retain" . 6730) (". view" . 1746) ("GeneralLedger" . 3390) ("- lisp" . 1324) ("| []" . 7637) ("\\ centering" . 4241) ("\",@\"" . 157) ("pair" . 6426) ("parameter" . 6434) ("( A" . 448) ("\" end" . 70) ("th" . 7166) ("form >" . 5438) (":\"" . 2448) (",[{ file" . 1236) ("RewriteCond" . 3833) ("sbt" . 6806) (":(. text" . 2460) ("</ item" . 2718) ("-> b" . 1412) ("});" . 7734) ("trait" . 7233) ("each {" . 5165) ("v \\" . 7337) ("2 ))+" . 2085) (", %" . 1082) ("scene )" . 6819) ("id /" . 5678) ("; margin" . 2579) ("( not" . 606) ("( sum" . 644) ("( RestFn" . 487) ("Native" . 3680) ("NSURL *" . 3665) ("middleware" . 6135) ("send (" . 6863) ("br >" . 4740) ("figure }" . 5367) ("otherwise =" . 6394) (") if" . 867) ("Show )" . 3886) ("Value =" . 4073) ("throws" . 7192) ("| 0" . 7626) ("sp" . 6938) (". doFilter" . 1607) ("(( equal" . 692) ("max" . 6114) ("(@" . 771) ("() Dim" . 707) ("begin inherited" . 4697) ("#!/ usr" . 234) ("TYPE" . 3963) ("transition" . 7236) ("partial class" . 6443) ("self ;" . 6860) ("% s" . 292) ("` int" . 4405) ("emacs -" . 5203) ("array [" . 4605) ("viewDidLoad {" . 7379) ("opt /" . 6369) ("write" . 7441) (":= nil" . 2507) ("plot (" . 6491) ("Text =" . 3978) ("\" Value" . 54) ("Last" . 3545) ("Index" . 3476) ("layout ." . 5953) (": ''" . 2269) ("11 ." . 2042) ("ActiveRecord" . 3051) ("0 :" . 1918) (". doCall" . 1606) ("() def" . 710) ("; background" . 2549) ("addObject" . 4491) ("gen_server :" . 5505) ("import" . 5732) ("CGPointMake" . 3145) ("/ clojure" . 1817) (") End" . 836) ("in )" . 5755) ("02 -" . 1949) ("Pointer" . 3757) ("'; package" . 412) ("allocatable" . 4520) ("cp" . 4962) ("Traceback" . 4005) ("gca" . 5494) ("/ 255" . 1792) ("< link" . 2662) ("|> Async" . 7659) ("++){" . 1074) ("Rows (" . 3838) ("(); }" . 736) ("</ label" . 2719) ("stack" . 6969) ("|> ignore" . 7662) ("\" select" . 89) (") AS" . 831) ("lua :" . 6065) ("opacity :" . 6362) ("r )" . 6622) ("resources :" . 6722) ("( b" . 512) (": {}\"," . 2446) ("Free ;" . 3370) ("( let" . 583) ("set (" . 6885) ("True ;" . 4014) ("=\"" . 2849) (". contrib" . 1591) ("app ." . 4565) ("action :" . 4458) ("link_to" . 6009) (": each" . 2376) ("NO ;" . 3630) (":= &" . 2490) (", text" . 1212) ("{}\"," . 7621) (". rs" . 1713) ("match {" . 6106) ("tableView" . 7106) ("\"]." . 207) (". 1" . 1445) ("fopen" . 5411) (": 15" . 2287) ("xml version" . 7473) (": NSIndexPath" . 2326) ("warnings" . 7396) ("2 1" . 2097) ("\"))))" . 129) ("usize" . 7328) ("nvarchar (" . 6327) ("getString (" . 5522) ("|> Array" . 7658) ("[];" . 4229) ("AddWithValue" . 3060) (", [{" . 1163) ("numeric (" . 6324) ("B )," . 3096) ("for I" . 5416) ("excursion" . 5292) ("imread ('" . 5750) ("</ li" . 2720) (") when" . 892) ("Monad ." . 3607) (": sequence" . 2422) ("{ align" . 7538) ("NSObject" . 3658) ("gl" . 5533) ("/ vendor" . 1878) ("!$" . 8) ("js \"></" . 5901) ("x ]" . 7464) ("= @\"" . 2771) ("L2 ," . 3536) ("ng -" . 6257) ("-> get" . 1415) ("v2" . 7339) ("get {" . 5515) ("apk /" . 4563) ("- (" . 1240) ("send" . 6862) ("</ a" . 2709) ("`<" . 4412) ("(-" . 747) ("import Control" . 5737) ("syntax" . 7078) ("([[" . 781) ("5 )" . 2200) ("(\"%" . 665) ("function ()" . 5484) ("form" . 5435) ("`.`" . 4411) (", 12" . 1099) ("1 );" . 1993) ("){ $" . 1024) ("p" . 6406) ("IF (" . 3439) ("` =" . 4401) ("dependency" . 5058) ("new System" . 6242) ("yield" . 7501) ("DWORD ;" . 3241) ("-(" . 1389) (": ~" . 2447) ("5 |" . 2206) ("1 }{" . 2022) ("( or" . 611) ("-> ok" . 1422) (". Controls" . 1480) ("->{" . 1427) ("( insert" . 572) ("line ," . 6000) ("program" . 6566) ("[ -" . 4157) ("boost" . 4721) ("other" . 6390) (") ::" . 820) (". nsc" . 1682) ("in out" . 5764) ("Try End" . 4016) ("( Z" . 501) (". Free" . 1493) (", Vcl" . 1155) ("SQLiteDatabase" . 3858) ("NA >" . 3624) ("perl /" . 6459) ("))." . 928) ("document" . 5130) ("100px" . 2035) ("pairs" . 6427) ("['" . 4205) ("custom" . 4987) ("Text_IO ," . 3986) ("Count -" . 3221) ("(( e" . 690) ("\"%" . 110) ("1 +" . 1994) ("( function" . 560) (". typechecker" . 1743) ("<?" . 2748) ("color :" . 4891) ("AndroidRuntime (" . 3065) ("setFillColor" . 6889) ("sequence >" . 6875) (". toString" . 1740) ("Port" . 3760) ("final" . 5383) ("),'" . 953) ("res" . 6719) ("Z ," . 4153) ("if [[" . 5702) ("window -" . 7426) ("] at" . 4297) ("Public Sub" . 3783) ("MyBase" . 3614) (". clojure" . 1582) ("; struct" . 2597) ("' #" . 329) ("16" . 2064) ("female" . 5356) (": true" . 2434) ("(*,*)" . 741) ("!(\"" . 11) ("unsafe" . 7290) ("- module" . 1333) ("C :\\" . 3136) ("{ self" . 7591) ("End Get" . 3296) ("FALSE" . 3325) ("- p" . 1342) ("57" . 2217) ("eq" . 5246) ("-> if" . 1416) ("true end" . 7249) ("gradient (" . 5551) (". 0f" . 1444) ("Using" . 4065) ("} ." . 7675) ("shadow" . 6901) ("bla" . 4707) ("guess" . 5572) ("\" type" . 94) ("INT" . 3451) ("3L ," . 2176) ("]]; then" . 4358) ("< typename" . 2684) ("XSL" . 4132) ("- map" . 1328) ("done <" . 5141) ("void" . 7381) ("valid" . 7341) ("| sed" . 7650) (". row" . 1712) ("args ]" . 4591) ("managedObjectContext" . 6090) ("f90" . 5333) ("U" . 4019) ("{ (" . 7518) ("div >" . 5100) ("str )" . 6999) ("constructor" . 4935) (") private" . 881) (")*(" . 935) ("clone" . 4869) ("{: name" . 7617) ("]]" . 4353) (". dart" . 1600) ("puts" . 6604) ("range" . 6643) (", **" . 1086) ("112L" . 2045) ("), write" . 951) ("target" . 7118) ("- line" . 1322) ("- 09" . 1252) ("search -" . 6837) ("a0" . 4436) ("}{\\" . 7757) (". init" . 1651) ("Type" . 4017) ("return" . 6732) ("gradient" . 5550) ("====" . 2912) ("/ railties" . 1857) ("( print" . 615) ("x <-" . 7460) ("</ span" . 2727) ("String Dim" . 3914) ("write (" . 7442) ("\":" . 168) ("char **" . 4835) (")** 2" . 937) ("impl" . 5725) ("\") local" . 122) ("= 4" . 2768) ("|" . 7623) ("{})" . 7622) ("http ." . 5640) ("/: id" . 1893) ("noreply" . 6291) (". core" . 1592) ("MAX" . 3571) ("GLIBC_2" . 3385) ("= zeros" . 2845) ("Integer range" . 3500) ("N1" . 3621) ("levels" . 5982) ("Jun 18" . 3522) ("in if" . 5763) ("@ ORM" . 3013) ("Integer_Text_IO ;" . 3502) (". load" . 1670) ("Show" . 3884) ("EXISTS" . 3284) (": UIButton" . 2335) ("echo ${" . 5175) ("max (" . 6115) ("LEFT" . 3538) (". lua" . 1672) ("elem" . 5186) (". Color" . 1477) ("concurrent" . 4915) ("region -" . 6686) ("20 ." . 2109) (") -->" . 810) ("Text ;" . 3977) ("after" . 4502) ("asp" . 4622) (") &" . 799) ("{ document" . 7550) ("i ]);" . 5665) ("amsmath" . 4529) ("End Try" . 3300) ("/ javascript" . 1836) ("3 /" . 2152) ("insert -" . 5805) ("defmacro" . 5046) ("m2 /" . 6072) ("; try" . 2603) ("\\ textbf" . 4264) ("insert" . 5803) ("6" . 2225) ("MetaClassImpl" . 3595) ("scope" . 6826) (")::" . 977) ("As System" . 3089) ("3 Jun" . 2158) ("free" . 5460) ("( define" . 535) ("Override" . 3732) ("] of" . 4302) ("}} \\" . 7761) ("AFn" . 3038) ("</ groupId" . 2715) ("aBlock" . 4438) ("data" . 5007) ("strlen (" . 7030) ("Address" . 3061) ("init" . 5789) (", S" . 1147) ("/// <" . 1891) ("]; NSLog" . 4340) ("runtime" . 6780) ("s /" . 6797) ("hibernate" . 5607) ("indexPath" . 5779) ("OMP" . 3707) (": [" . 2342) ("): 0" . 969) ("true ." . 7247) ("\\\", \\\"" . 4269) (". tableView" . 1736) ("NULL )" . 3668) ("video" . 7372) ("5px ;" . 2224) ("Me" . 3587) ("future_impl ." . 5490) (":= (" . 2492) ("lib \\" . 5992) ("mnesia :" . 6146) ("2 >" . 2103) ("return cell" . 6739) ("abs" . 4447) ("last ):" . 5943) (". 3" . 1452) (": 13" . 2285) ("+ 00" . 1066) ("Return" . 3831) ("eclipse" . 5179) (". pdf" . 1693) ("[] =" . 4221) ("2 3" . 2099) ("Log" . 3562) ("); Ada" . 986) ("xmlns" . 7474) ("opacity" . 6361) ("29" . 2139) (", ierr" . 1188) ("String ;" . 3911) (". Error" . 1487) ("\" xmlns" . 97) ("\", [" . 150) ("HTTP" . 3409) ("database" . 5015) ("T T" . 3937) ("scala :" . 6812) ("\" 1" . 39) (": self" . 2421) ("final String" . 5384) ("Tree" . 4010) ("md" . 6121) ("h2" . 5579) ("member (" . 6125) ("gen" . 5502) (")]" . 1017) (": java" . 2402) ("uclibc" . 7278) ("begin {" . 4699) ("erl \"},{" . 5255) ("Z )." . 4152) ("= column" . 2805) ("tab" . 7099) (": 1" . 2280) ("impl <'" . 5727) ("/ bash" . 1812) ("do :" . 5112) (";; (" . 2625) ("defined" . 5043) ("\"] as" . 206) (") findViewById" . 862) ("> 1" . 2948) ("ready" . 6658) ("Users /" . 4064) ("CoreFoundation" . 3217) ("} void" . 7718) ("findall (" . 5392) ("init (" . 5790) ("closure >" . 4873) ("nullable" . 6315) ("* http" . 1037) ("~" . 7766) ("Canvas" . 3165) ("body" . 4716) ("use std" . 7308) ("Ruby200" . 3840) ("objectAtIndex" . 6335) (": x" . 2442) ("* t" . 1041) ("railties" . 6636) ("clojure /" . 4868) ("my ($" . 6180) ("= async" . 2801) ("y1" . 7498) ("'..'" . 401) (";&" . 2621) ("relative" . 6689) ("]. ^" . 4335) ("Create (" . 3223) ("Call :" . 3160) ("- directory" . 1291) ("( length" . 582) ("( 10" . 436) ("first argument" . 5394) ("strcmp" . 7001) ("/ python2" . 1854) ("span >" . 6941) ("- block" . 1273) ("buffer" . 4748) ("index ." . 5777) ("1 )" . 1986) (", String" . 1151) ("text =" . 7156) ("></" . 2983) ("<=" . 2745) ("m a" . 6070) ("= $(" . 2756) ("' no" . 359) ("req" . 6707) (", completion" . 1174) ("scala" . 6809) ("for j" . 5421) ("contrib" . 4944) ("process" . 6562) ("tex \\" . 7144) (", []," . 1162) ("then echo" . 7180) ("]):" . 4322) ("when" . 7409) (": any" . 2359) ("4L ," . 2198) ("ds" . 5149) (">>=" . 2988) ("- rwxr" . 1358) ("add" . 4478) ("cljs" . 4864) ("> int" . 2960) ("%\\" . 309) ("; fn" . 2565) ("{ it" . 7569) ("({" . 788) ("inherited ;" . 5788) ("spark" . 6943) ("- char" . 1280) ("extent :" . 5319) ("( rest" . 627) ("(+ (" . 744) ("row ]" . 6764) ("hover" . 5623) ("}
" . 7666) (") integer" . 872) ("- v" . 1379) ("Put (\"" . 3786) ("< option" . 2666) (". beans" . 1573) (". didReceiveMemoryWarning" . 1604) ("], X" . 4329) ("'{ print" . 427) ("end --" . 5217) ("int i" . 5819) ("n \\" . 6197) ("print \"" . 6525) ("( add" . 505) ("/ 2" . 1788) (". Id" . 1500) ("when (" . 7410) ("XMLSchema" . 4131) ("return true" . 6743) ("{-#" . 7613) ("( E" . 456) ("Range" . 3812) ("{ Console" . 7527) ("=>\"" . 2930) ("match" . 6103) ("Web ." . 4098) ("Method )" . 3598) ("_GET" . 4388) ("line" . 5999) ("IMPLICIT" . 3442) ("\\ lib" . 4251) ("artifactId >" . 4610) ("S" . 3843) ("< int" . 2657) (", t" . 1211) ("Compiling" . 3203) (")**" . 936) ("execute" . 5296) ("security" . 6842) (": 0" . 2275) ("lis" . 6012) ("go :" . 5542) ("=> (" . 2917) ("nl ," . 6272) ("\">
" . 188) ("\");" . 134) ("recur (" . 6673) ("Name =\"" . 3677) ("< T" . 2637) ("{ \"" . 7514) ("< groupId" . 2652) ("foreach" . 5429) (") let" . 874) ("layout_weight =\"" . 5957) ("err )" . 5262) ("intent (" . 5830) ("m )" . 6069) ("\" fi" . 71) ("CGRectMake" . 3148) (". (" . 1434) ("bson" . 4744) (". 000" . 1438) ("performWithDelay (" . 6456) ("]; }" . 4349) ("debug" . 5028) ("Maybe" . 3586) ("javascript" . 5894) ("- x64" . 1387) ("@ media" . 3020) ("\"></" . 194) ("</ template" . 2730) (":(" . 2453) ("templates select" . 7137) ("Error in" . 3310) ("| c" . 7641) (". filter" . 1625) (")-" . 955) (". append" . 1567) ("lambda" . 5937) ("[ String" . 4170) ("awk '" . 4656) ("i <" . 5660) ("The" . 3989) (": apply" . 2360) ("NSLayoutConstraint" . 3651) ("\" ." . 35) ("; i" . 2570) (": Boolean" . 2312) ("my @" . 6182) ("sqrt (" . 6957) ("br" . 4738) ("lambda ()" . 5939) ("TextBox" . 3980) ("eventdata" . 5284) ("$(" . 276) ("signal" . 6914) ("main ::" . 6079) ("== nil" . 2909) ("exp" . 5303) ("abs (" . 4448) ("filter" . 5381) ("Dim" . 3262) ("ease" . 5167) ("hold on" . 5616) (") $" . 796) ("++;" . 1075) ("apply (" . 4576) (". txt" . 1742) ("(:)," . 759) (": TObject" . 2334) ("4" . 2178) (". Body" . 1465) ("( object" . 610) ("( chan" . 519) ("print $" . 6528) (". jar" . 1658) ("NULL |" . 3672) ("PChar" . 3740) ("etc" . 5274) ("\"<<" . 186) ("| %>" . 7624) ("]:" . 4337) ("mother (" . 6163) ("nsc ." . 6308) ("), {" . 952) ("open System" . 6365) ("xsl :" . 7489) ("size ." . 6922) ("Image (" . 3471) (">::" . 2976) ("in -" . 5756) (". css" . 1596) ("TMemoryStream" . 3954) ("will" . 7424) (",[{" . 1235) ("true ," . 7245) ("Board" . 3109) ("box" . 4736) ("torch" . 7225) ("fn" . 5403) (". 5" . 1454) ("expr" . 5311) ("struct {" . 7034) ("}[ 1" . 7748) ("SysUtils ," . 3927) ("; my" . 2580) ("; top" . 2602) ("; display" . 2558) ("* FROM" . 1031) ("} });" . 7723) ("\"). ToString" . 133) ("; 1" . 2538) ("this" . 7185) ("state (" . 6975) (". support" . 1732) ("Python" . 3790) ("(:, 2" . 762) ("a -" . 4419) ("(\" Enter" . 664) ("xs =" . 7483) ("graphics ." . 5557) ("data $" . 5008) ("R )." . 3795) ("[: id" . 4212) ("\" 3" . 41) ("{ center" . 7543) ("Writeln" . 4113) ("array ('" . 4603) (":= []" . 2501) ("; //" . 2536) ("/:" . 1892) ("(!" . 662) ("make" . 6082) (".[ i" . 1777) ("PATH" . 3739) ("rb :" . 6648) ("< html" . 2654) ("2014 -" . 2120) ("CREATE TABLE" . 3156) ("0px ;" . 1975) ("/ http" . 1835) ("Source )" . 3898) ("top (" . 7223) ("Err (" . 3307) ("Stack" . 3900) ("=\"/" . 2881) ("< paper" . 2668) ("':" . 404) ("args :" . 4590) ("in pairs" . 5765) ("]{" . 4359) ("S ," . 3844) ("documentclass [" . 5135) ("NSIndexPath" . 3646) ("tabular }" . 7112) ("params" . 6436) ("storyboard" . 6995) (") var" . 890) ("= shift" . 2834) ("(:)" . 758) ("MPI_COMM_WORLD" . 3574) ("= UIImage" . 2789) ("direction" . 5085) ("{ override" . 7579) ("closure" . 4872) ("age" . 4503) ("serif" . 6876) ("(\"/" . 668) ("[[[" . 4217) ("%," . 298) ("Unit =" . 4057) ("</ xsl" . 2737) ("/ emacs" . 1826) ("*) indexPath" . 1048) (")) {" . 913) ("file ." . 5371) ("DataSource" . 3247) ("< title" . 2682) ("st" . 6966) (". created" . 1595) (": stylesheet" . 2427) ("[ \"$" . 4155) (": textColor" . 2431) ("found" . 5447) ("[ NSString" . 4169) (")\")" . 901) ("( defmacro" . 536) ("let *" . 5975) ("&'" . 325) ("\"/>" . 165) ("openInWorld ." . 6366) ("); var" . 1009) ("clojure -" . 4866) ("{ float" . 7557) ("[] ->" . 4220) ("access" . 4456) ("3 ))" . 2146) (") ==" . 827) (". lang" . 1664) (", 2" . 1101) ("rack" . 6629) ("12" . 2048) ("' '" . 330) (";& nbsp" . 2622) ("level" . 5981) ("spec" . 6947) ("3px" . 2177) ("net /" . 6229) ("virtual" . 7380) ("- set" . 1362) ("- t" . 1368) ("= function" . 2813) ("- style" . 1366) ("* Main" . 1032) ("override ;" . 6402) (". os" . 1689) ("for the" . 5423) ("x :" . 7457) ("cat" . 4802) ("mysql" . 6183) ("Width" . 4103) ("{ NSString" . 7530) ("$ line" . 263) (") tableView" . 886) ("_SESSION" . 4392) ("rs :" . 6768) (") |>" . 898) ("M \"" . 3567) ("values" . 7352) ("UIApplication" . 4021) ("Q" . 3791) ("wrap_content \"" . 7440) ("strcpy" . 7004) ("interface uses" . 5834) ("/ 4" . 1794) ("browser" . 4743) ("includegraphics [" . 5773) ("\" ];" . 58) ("| awk" . 7640) ("car (" . 4795) ("Head" . 3416) ("transition :" . 7237) ("< Button" . 2631) (". spark" . 1725) ("belongs_to" . 4701) ("argc ," . 4586) ("true ->" . 7246) ("] then" . 4306) ("- search" . 1360) ("[ Transcript" . 4172) ("=> [" . 2923) ("malloc (" . 6089) ("setf" . 6892) (": cannot" . 2369) ("( null" . 609) ("( read" . 621) ("SKAction ." . 3854) ("view" . 7373) (", L2" . 1135) (". layout" . 1666) (", j" . 1192) ("Text_IO" . 3985) ("linux" . 6010) ("nl ." . 6273) ("} }" . 7722) ("': '" . 405) ("fmt \"" . 5401) ("), %" . 940) ("kill -" . 5922) (":= 1" . 2494) ("at (" . 4631) ("( $" . 431) ("excursion (" . 5293) ("-> UITableViewCell" . 1408) (", intent" . 1191) ("result" . 6727) ("block" . 4712) ("255 255" . 2135) (". cpp" . 1594) (",]" . 1237) ("= Vec" . 2791) ("AnyObject" . 3067) ("x64" . 7468) ("Error using" . 3311) ("Show (\"" . 3885) ("headers" . 5596) ("selector (" . 6852) ("False ;" . 3339) ("int argc" . 5818) ("ShowMessage" . 3887) ("'()" . 374) (")/" . 967) ("cross" . 4975) ("=[[" . 2932) ("($ 1" . 675) ("<< \"" . 2740) ("`, `" . 4410) ("i :" . 5657) ("/ juan" . 1839) ("\"; }" . 184) ("handler" . 5585) ("!= NULL" . 19) ("printf (\"" . 6538) (", 5L" . 1109) ("of a" . 6345) ("rust -" . 6783) ("EQ" . 3280) ("base" . 4681) ("DATE" . 3230) ("80" . 2248) ("| a" . 7639) ("\">>," . 197) ("); %" . 981) ("Int" . 3480) ("a ," . 4418) ("Private" . 3771) ("Controls ," . 3212) ("/ AndroidRuntime" . 1796) ("lua" . 6063) ("' Last" . 346) ("- border" . 1274) ("end" . 5211) ("CellIdentifier" . 3173) ("!$ OMP" . 9) (": complexType" . 2372) ("</ option" . 2722) ("( apply" . 508) (": TButton" . 2333) ("Node" . 3696) ("apply ." . 4578) ("[ info" . 4186) ("path /" . 6452) ("Rows ." . 3839) ("displayed" . 5094) ("5cm" . 2222) ("{ let" . 7571) ("F ," . 3324) ("2" . 2081) ("==" . 2902) ("} class" . 7690) ("= this" . 2840) ("link rel" . 6008) ("event ." . 5283) ("poolDictionaries" . 6510) ("\"},{" . 219) ("mkdir" . 6144) ("( defn" . 537) ("size (" . 6921) (">&" . 2964) ("it" . 5871) (". add" . 1557) ("css" . 4977) ("is --" . 5852) (". b" . 1571) ("IBOutlet" . 3432) ("precision" . 6519) ("00 \"," . 1933) ("H1" . 3407) ("{ println" . 7585) ("Printf (\"" . 3766) (", W" . 1156) ("A =" . 3033) ("( unit" . 650) ("}\"" . 7726) ("; end" . 2562) ("'())" . 376) ("fp" . 5449) ("thread" . 7189) (". 7" . 1457) ("* 8" . 1029) (". err" . 1618) ("end local" . 5228) ("make (" . 6083) (": 2" . 2293) ("^ super" . 4367) ("row ['" . 6763) ("]; //" . 4339) ("not (" . 6295) ("substr" . 7054) ("python2" . 6611) ("perror" . 6463) ("ets :" . 5277) ("null ," . 6312) ("action_dispatch /" . 4461) ("username" . 7321) ("parameter ::" . 6435) ("var /" . 7355) ("L )," . 3529) ("25" . 2132) ("sed -" . 6845) ("console" . 4926) ("MODULE" . 3572) ("# t" . 231) ("paper" . 6431) ("typename T" . 7268) ("phase ==" . 6470) ("TForm1" . 3951) ("( request" . 624) ("stdlib ." . 6991) ("$( this" . 278) ("Prelude >" . 3764) ("; 3" . 2540) ("THEN" . 3953) ("GetType" . 3394) (") sender" . 885) ("findViewById" . 5389) ("/ texmf" . 1873) ("( 8" . 446) ("radius" . 6632) ("= [" . 2793) ("('" . 685) ("eq ." . 5247) ("Public Class" . 3780) ("- patch" . 1344) ("([]" . 782) ("etc /" . 5275) ("signature" . 6915) ("Object subclass" . 3717) ("1 ])." . 2012) ("\" M" . 51) ("forKey :" . 5426) ("Content" . 3207) ("- 2" . 1259) ("use warnings" . 7310) (". Object" . 1516) (". Columns" . 1478) ("left ;" . 5964) ("time" . 7197) ("DIMENSION" . 3235) ("Fun" . 3373) ("str" . 6997) ("sun ." . 7066) (". get" . 1630) ("itemize" . 5876) ("NSInteger )" . 3650) ("2 )." . 2087) ("( true" . 649) ("sample (" . 6800) ("z" . 7505) ("then --" . 7178) ("A1" . 3036) ("Override protected" . 3733) ("request" . 6708) ("alloc" . 4518) ("Protected" . 3777) ("} ;" . 7678) (")) (" . 907) ("(~>" . 790) ("AS [" . 3046) (". begin" . 1574) ("HashMap <" . 3415) ("resp" . 6723) ("qualified Data" . 6615) (", parameter" . 1203) ("Msg" . 3609) ("( T" . 495) ("=\" true" . 2869) ("?. text" . 3005) ("use Ada" . 7307) ("Rows" . 3837) ("- image" . 1314) (", \"" . 1079) ("DelegatingMethodAccessorImpl" . 3254) ("onCreate (" . 6358) ("IO ()" . 3459) ("column [" . 4894) ("maze (" . 6120) ("- box" . 1276) ("\"#" . 106) ("), X" . 944) (", 0" . 1089) ("hadoop" . 5583) ("}); }" . 7735) ("Left" . 3547) ("scale" . 6814) ("Sub Public" . 3924) (". Click" . 1474) ("nil ];" . 6266) ("objects ." . 6340) ("rotate" . 6759) ("player ." . 6489) ("this ->" . 7187) (": text" . 2430) ("?." . 3004) ("! {" . 6) ("- z" . 1388) ("> </" . 2955) ("strcpy (" . 7005) ("get -" . 5513) ("func main" . 5476) ("b ->" . 4666) ("S1" . 3845) ("rw -" . 6788) ("elseif (" . 5200) ("RewriteRule" . 3835) ("' s" . 361) (". string" . 1729) ("INTEGER ," . 3453) ("%></" . 307) ("1 ]," . 2013) ("gradle" . 5552) ("( vector" . 654) ("Var ." . 4076) ("emacs" . 5202) ("reflect ." . 6682) (") at" . 851) ("integer ;" . 5828) ("dev /" . 5072) ("onCreate" . 6357) ("plugin" . 6494) ("_" . 4369) ("implicit none" . 5731) (", string" . 1210) ("bool" . 4718) ("):-" . 976) ("as !" . 4612) ("lst )" . 6060) ("( str" . 641) ("Object ," . 3716) ("url :" . 7302) ("; else" . 2561) ("https" . 5642) ("j =" . 5887) ("( 50" . 443) (": Name" . 2327) ("], \"" . 4327) ("padding -" . 6423) ("td class" . 7126) ("1 }" . 2021) ("Length (" . 3549) ("R ," . 3797) ("( inc" . 571) ("(*,*) '" . 742) (". io" . 1656) ("awk '{" . 4657) ("Message" . 3591) ("06 -" . 1958) ("Forms ." . 3367) ("structure" . 7035) ("pgf" . 6467) ("Put_Line" . 3787) ("to -" . 7211) ("( NULL" . 477) ("module" . 6155) ("Cell" . 3172) ("qualified" . 6614) (") Next" . 843) ("44" . 2191) ("getElementById (\"" . 5517) ("\\ newcommand" . 4254) (",[" . 1233) ("rustc" . 6784) ("VARCHAR (" . 4070) ("][ j" . 4352) ("size_t" . 6925) ("( IN" . 464) (". Transcript" . 1537) ("one" . 6359) ("\"]" . 203) ("derive (" . 5064) ("}{ 0" . 7756) ("))" . 906) ("Function (" . 3375) ("end else" . 5224) ("style ." . 7039) ("= if" . 2814) ("; open" . 2581) ("A \"" . 3028) ("struct" . 7032) (". physicsBody" . 1697) ("}," . 7737) ("When" . 4099) ("end )" . 5215) ("( AFn" . 449) ("argc" . 4585) ("begin for" . 4695) ("var i" . 7356) ("UIColor ." . 4024) ("); #" . 979) ("( range" . 620) (": as" . 2362) ("++ {" . 1071) ("none integer" . 6290) ("PRIMARY KEY" . 3744) ("= vec" . 2843) ("new File" . 6239) ("sh" . 6899) ("allocate" . 4522) (": No" . 2329) ("Add (" . 3057) ("\" (" . 29) ("models" . 6153) ("_ ," . 4373) ("new -" . 6234) ("db /" . 5022) ("{ tabular" . 7597) ("im1 ," . 5715) ("g" . 5491) (". swing" . 1733) (", error" . 1181) ("X )," . 4116) ("print (" . 6529) (". d" . 1598) (": type" . 2435) ("'..' 9" . 402) ("([ H" . 777) ("[]) {" . 4226) ("& _" . 320) ("viewDidLoad" . 7376) ("1000" . 2033) ("0" . 1899) ("defn -" . 5048) ("require" . 6711) ("soap" . 6931) ("class" . 4851) ("SELECT" . 3849) ("3 -" . 2150) ("\": 0" . 170) ("( cdr" . 518) ("println !(\"" . 6545) ("{ NSLog" . 7529) ("here" . 5605) ("[ UIImage" . 4174) ("edit" . 5183) ("in `<" . 5760) ("\" height" . 75) ("Chapter" . 3176) ("')->" . 382) ("exp )" . 5305) ("\\ draw" . 4244) ("scanf" . 6816) ("1L" . 2077) ("child" . 4843) ("a )" . 4417) ("27" . 2137) ("object sender" . 6334) ("err :=" . 5264) (")) ((" . 908) ("No" . 3694) ("< xsl" . 2688) ("' Range" . 347) ("true );" . 7244) ("WHEN" . 4091) ("\". to_string" . 161) ("format (\"" . 5440) ("help" . 5602) (". sql" . 1727) ("ads" . 4498) ("!," . 15) ("), nl" . 950) ("margin -" . 6099) ("( models" . 595) (". call" . 1577) ("000" . 1938) ("nl" . 6271) ("package :" . 6414) ("bin" . 4703) ("clj :" . 4863) ("done" . 5140) ("( sender" . 632) ("8 \"?>" . 2242) ("die \"" . 5080) ("State )" . 3903) ("cdr" . 4810) ("format" . 5439) ("H" . 3404) ("/>" . 1895) ("< xs" . 2686) ("alpine" . 4525) ("objectAtIndex :" . 6336) ("Public Property" . 3782) ("$ this" . 269) ("then" . 7176) ("IO" . 3458) ("@ interface" . 3019) ("catalina ." . 4804) ("</ LinearLayout" . 2708) (": 1px" . 2292) ("X =" . 4122) ("= models" . 2825) ("cl -" . 4850) ("male (" . 6087) ("). Value" . 960) ("'>" . 414) ("Memo1 ." . 3590) ("PARAMETER" . 3738) ("inc" . 5768) ("let mutable" . 5979) ("data ['" . 5014) ("n )" . 6191) ("Compiler" . 3201) (", const" . 1175) ("overflow :" . 6399) ("Vec ::" . 4080) ("r \\" . 6627) ("2 )," . 2086) ("Visible =" . 4086) ("tabular }{" . 7113) ("cdr lst" . 4813) ("val" . 7340) ("x" . 7449) ("dr" . 5145) ("first" . 5393) ("no" . 6276) ("NaN NaN" . 3674) ("tmp /" . 7208) (". 12" . 1448) ("t =" . 7094) ("integer ::" . 5827) ("/ ruby" . 1862) ("ets" . 5276) (". write" . 1752) ("=\" center" . 2857) ("List ." . 3557) ("[ ^" . 4177) (": super" . 2428) ("jquery" . 5899) ("if err" . 5703) ("import Data" . 5738) ("html" . 5632) (", 6" . 1110) ("id :" . 5679) (": insert" . 2397) (":/ Ruby200" . 2465) ("= let" . 2818) ("lock" . 6038) ("Excel" . 3316) ("newImage" . 6244) ("let [" . 5976) ("\"); printf" . 138) ("= CGRectMake" . 2773) ("'\\ 0" . 416) ("ID =\"" . 3436) (": public" . 2417) ("y ," . 7494) ("\"-" . 159) ("txt" . 7254) ("or die" . 6377) ("Smalltalk" . 3892) ("/ usr" . 1876) ("http" . 5637) ("REPORT" . 3806) ("ui" . 7279) ("< LinearLayout" . 2633) ("). -" . 959) (": \");" . 2261) ("list -" . 6020) ("c =" . 4776) ("( line" . 584) ("ardnew" . 4581) ("=\"@+" . 2887) ("catch" . 4805) ("close (" . 4871) ("?," . 3001) ("- x" . 1386) ("function scene" . 5487) ("1 &" . 1984) ("graphicx }" . 5559) ("property (" . 6573) ("///" . 1890) ("0 \"" . 1900) ("\"></ script" . 196) ("))))))" . 921) ("<! DOCTYPE" . 2690) ("=\" android" . 2855) ("sys ." . 7082) ("( stderr" . 640) ("shift" . 6907) ("7L" . 2239) ("isset ($" . 5870) ("X1" . 4125) ("core" . 4948) ("listen (" . 6023) ("0 /" . 1915) (":- write" . 2463) ("reference to" . 6680) ("types" . 7271) ("Convert" . 3213) ("]" . 4279) ("finally" . 5385) ("T ]," . 3940) ("in range" . 5766) ("02 :" . 1950) ("b )" . 4664) ("ebin" . 5169) (":(." . 2459) ("EventArgs" . 3313) ("NSArray" . 3636) ("pub" . 6578) ("minOccurs" . 6140) ("} };" . 7725) ("link" . 6007) ("/ rake" . 1858) ("2016" . 2123) ("$ value" . 271) ("ORM" . 3713) ("Forms ," . 3366) ("0 To" . 1924) ("Z )" . 4150) ("{ 0" . 7521) ("fun ()" . 5469) (", n" . 1197) ("( w" . 656) ("nonatomic" . 6284) ("open (" . 6364) ("8 ." . 2246) (", List" . 1136) ("; float" . 2564) (": ." . 2273) ("Cells" . 3174) ("Float" . 3354) ("Add (\"" . 3058) ("<!--" . 2691) ("display \"" . 5091) (", Int" . 1132) ("dolist" . 5139) ("theme" . 7175) ("- 01" . 1244) ("Add" . 3056) ("Protected Sub" . 3778) ("+=" . 1077) ("< tr" . 2683) ("42" . 2189) (". ." . 1435) ("R *." . 3796) ("temp |" . 7129) ("\\ n" . 4253) ("SetLength" . 3880) ("::<" . 2486) ("t" . 7085) ("awk -" . 4658) ("char" . 4832) ("timesRepeat" . 7202) ("curl_setopt" . 4980) ("vec ![" . 7362) ("( select" . 630) ("#=" . 244) ("\" ->" . 34) ("String ," . 3908) (")+" . 938) (".< anonymous" . 1774) ("2L" . 2140) ("future_impl" . 5489) ("i ++" . 5653) ("write ('" . 7443) ("! var" . 5) ("}." . 7741) ("\" $" . 26) ("code" . 4876) ("% \"" . 287) ("frame ." . 5457) ("NEW_LINE" . 3626) ("Int =" . 3485) ("GROUP BY" . 3389) ("dequeueReusableCellWithIdentifier (\"" . 5062) ("loop [" . 6051) ("likes (" . 5998) ("so ." . 6930) ("*," . 1055) ("']," . 422) ("Sub Private" . 3923) ("ByVal sender" . 3127) ("\") then" . 123) ("{$ R" . 7610) ("= structure" . 2838) ("=~ m" . 2937) (") ?" . 829) ("h1 >" . 5578) ("poolDictionaries :" . 6511) ("');" . 384) ("= member" . 2824) ("1 3" . 2003) (") const" . 854) (") ." . 812) ("] on" . 4303) ("Class" . 3182) ("com ." . 4896) ("blank" . 4710) ("scanf (\"%" . 6817) ("concat" . 4914) ("e" . 5154) ("'|'" . 428) ("define -" . 5042) ("- eq" . 1298) ("sub {" . 7044) (". backgroundColor" . 1572) ("X )." . 4117) (", `" . 1165) ("); //" . 985) ("no file" . 6278) ("( len" . 581) (": Natural" . 2328) ("import java" . 5742) ("DIMENSION (" . 3236) (". f" . 1622) (".`" . 1782) ("require (\"" . 6714) ("2 .," . 2094) (">" . 2939) ("( kind" . 579) ("('#" . 687) ("public static" . 6588) (">:" . 2975) ("ip" . 5850) ("ex ." . 5286) ("( unsigned" . 651) (". el" . 1613) ("S2" . 3846) ("return $" . 6733) ("each >" . 5162) ("most" . 6160) ("</ div" . 2713) ("Main >" . 3578) ("shell -" . 6906) (")); }" . 931) ("format ." . 5443) ("callsite" . 4787) ("df" . 5073) ("[ org" . 4188) (",'" . 1226) ("a '" . 4415) ("() let" . 713) (") ->" . 811) ("? (" . 2994) ("ardnew /" . 4582) ("S_" . 3863) (". foreach" . 1627) ("' django" . 354) ("Height =\"" . 3419) ("dart :" . 5005) ("android :" . 4538) ("); echo" . 995) ("f ," . 5325) ("- c" . 1279) ("tr >" . 7232) (": UIViewController" . 2339) ("!." . 16) ("ioutil" . 5849) ("goto" . 5548) ("most recent" . 6161) ("data ." . 5011) ("Distribution" . 3263) ("inherit" . 5786) ("=\" form" . 2861) ("2 ;" . 2101) (". AbstractCallSite" . 1462) ("- default" . 1290) (". invoke" . 1654) ("el" . 5185) ("texlive /" . 7146) ("atom" . 4644) ("pi :" . 6480) ("\"); end" . 136) ("/ XMLSchema" . 1800) ("a where" . 4433) ("07 -" . 1960) (":: endl" . 2479) ("getJSONObject" . 5519) ("sender ," . 6866) ("F" . 3323) ("{ console" . 7546) ("\\ latex" . 4250) ("selector" . 6851) ("b c" . 4670) ("MyBase ." . 3615) ("element >" . 5188) ("name )" . 6202) ("= display" . 2807) ("'<" . 413) ("int )" . 5814) ("origin ." . 6387) ("NSString" . 3659) ("[ UIColor" . 4173) ("num2str" . 6318) ("na" . 6198) (". 10" . 1446) ("/ gems" . 1831) ("go -" . 5540) ("[ X" . 4176) ("List ," . 3556) ("\":\"" . 177) ("tools" . 7220) (",< 0" . 1232) ("\"/" . 163) (", 4" . 1106) ("seq" . 6871) ("pairs (" . 6428) ("C -" . 3133) ("Of" . 3718) ("/ latex" . 1840) (". 0d0" . 1443) ("(\"\\" . 670) ("delegate =" . 5053) ("Enter" . 3302) ("ggplot (" . 5527) ("Y2" . 4144) ("align" . 4513) (": access" . 2352) ("18" . 2069) ("}\\" . 7749) ("' =" . 337) ("print (\"" . 6530) ("func ()" . 5474) ("that" . 7168) ("empty" . 5206) ("SB" . 3847) ("url" . 7301) (". graphics" . 1637) ("lifetime" . 5996) ("( fid" . 551) ("do j" . 5119) ("matrix" . 6111) ("a ->" . 4420) ("4 |" . 2186) (". execute" . 1621) ("member x" . 6127) ("=\" col" . 2858) ("CONSTRAINT" . 3152) (". Fatal" . 1490) ("</ tr" . 2733) ("on :" . 6356) ("i |" . 5669) ("Lines" . 3552) (". label" . 1663) ("; %" . 2531) ("0 -" . 1912) ("} struct" . 7714) ("comment" . 4901) ("Sender" . 3870) (". php" . 1696) (": angular" . 2358) ("( params" . 613) ("open" . 6363) ("?> <" . 3007) ("< script" . 2671) (". numeric" . 1683) ("]; NSString" . 4341) ("from" . 5462) ("Label" . 3544) ("( Show" . 492) ("0x0" . 1976) (": out" . 2414) (": url" . 2436) ("interface {})" . 5835) ("\" id" . 78) ("2014" . 2119) (". 168" . 1450) (">< td" . 2981) ("<< \"\\" . 2741) ("NSURL URLWithString" . 3666) ("countSeq" . 4958) ("[" . 4154) ("[ Int" . 4168) ("Text ." . 3975) ("New_Line ;" . 3690) ("' Recognized" . 348) ("babel" . 4672) ("gravity" . 5560) (") IBOutlet" . 840) ("TRUE ," . 3961) (":= \"" . 2489) ("=> 0" . 2918) ("np ." . 6301) ("ss :" . 6963) ("android" . 4535) ("string ;" . 7019) ("file or" . 5373) ("reflect" . 6681) ("- left" . 1320) ("8 ," . 2245) (") as" . 850) ("tableView (" . 7107) ("Option <" . 3727) (". springframework" . 1726) ("math" . 6109) (": (" . 2270) ("Xs" . 4134) ("id =" . 5680) ("; cr" . 2557) ("task body" . 7120) (". info" . 1650) ("UIKit" . 4030) ("Traceback (" . 4006) (".\\" . 1778) ("- 03" . 1246) ("{ 2" . 7523) ("Element" . 3287) ("NULL );" . 3669) (": [:" . 2343) ("process -" . 6563) (".*" . 1761) ("fig" . 5364) ("40" . 2187) ("util" . 7333) ("} if" . 7700) ("String ." . 3910) ("Ys" . 4148) ("E ," . 3270) ("$(\"." . 280) ("Foundation" . 3368) ("_ :=" . 4376) ("utf" . 7331) ("\"></ div" . 195) ("format t" . 5444) ("/ lua" . 1843) (")>>" . 1015) (") (+" . 805) ("]; int" . 4345) ("love" . 6053) ("lang" . 5940) (", Data" . 1126) (": YES" . 2341) ("redirect_to" . 6675) ("[ else" . 4182) ("private static" . 6555) ("\" &" . 28) ("2 }" . 2107) (". Name" . 1511) ("- F" . 1264) ("1 /" . 1999) ("frame (" . 5455) ("State" . 3902) (")>'" . 1014) ("segue ." . 6847) ("@ synthesize" . 3024) ("| {" . 7655) ("pgf @" . 6468) ("*." . 1058) ("dart \"" . 4998) ("%> <" . 302) ("ORDER BY" . 3712) ("+ (" . 1065) ("1px" . 2079) ("} func" . 7698) ("free (" . 5461) ("Is" . 3505) ("%{" . 310) ("=\" import" . 2863) ("; type" . 2604) ("invokeMethod (" . 5842) ("getElementById" . 5516) ("( Y" . 500) ("attr ('" . 4647) ("\"] =" . 204) ("value =\"" . 7347) (". run" . 1714) ("h >" . 5576) ("''" . 366) ("UITableView" . 4034) ("=> x" . 2928) (". IO" . 1499) ("{:" . 7615) ("D1" . 3229) ("fill_parent \"" . 5380) ("kbd" . 5915) ("* time" . 1042) ("UITableView *)" . 4035) ("label" . 5931) ("c" . 4768) ("``" . 4413) ("( size" . 636) ("PROGRAM" . 3747) ("( x" . 660) ("\" local" . 80) ("#!/" . 232) ("linux -" . 6011) ("others =>" . 6392) (". x" . 1753) ("% c" . 290) (": name" . 2410) ("\" Width" . 55) ("nil ;" . 6265) ("A )," . 3030) ("<" . 2628) ("buffer (" . 4749) ("();" . 731) ("IBOutlet var" . 3433) ("([]," . 784) (". adb" . 1556) ("><" . 2978) ("3 )" . 2145) ("fmt" . 5400) (">';" . 2965) ("wx" . 7447) ("varchar (" . 7358) ("( required" . 626) ("iostream >" . 5848) ("real ::" . 6664) (": 19" . 2291) ("puts \"" . 6605) ("ys" . 7504) ("printfn \"" . 6542) ("nvarchar" . 6326) ("core ." . 4951) ("23" . 2130) ("xsi :" . 7487) ("rel" . 6687) (",%" . 1224) ("); int" . 1000) ("| NULL" . 7633) ("blah" . 4708) (". apply" . 1568) ("callsite ." . 4788) ("End" . 3292) ("` block" . 4402) ("If End" . 3466) ("echo '<" . 5177) ("- a" . 1267) (". concurrent" . 1588) ("f ." . 5326) (". Add" . 1463) ("!(" . 10) ("django" . 5105) ("Select" . 3867) (") enddo" . 860) ("Else" . 3288) ("applyTo" . 4579) ("- buffer" . 1277) ("dll" . 5108) ("schemas" . 6824) ("p {" . 6410) ("f (" . 5323) ("1999" . 2075) ("FS" . 3333) ("- 4" . 1261) ("hello" . 5601) ("When '" . 4100) ("`(" . 4407) ("expected" . 5308) ("Next End" . 3692) ("Node (" . 3697) ("Tables" . 3965) ("Can" . 3163) ("z -" . 7506) ("n \"" . 6185) ("jpg" . 5898) ("(( eq" . 691) ("< head" . 2653) ("( get" . 561) ("\" 2015" . 40) ("ok" . 6349) ("required" . 6717) ("VALUES (" . 4068) ("def" . 5034) ("NativeMethodAccessorImpl ." . 3683) ("override" . 6401) ("l ))" . 5928) ("\") as" . 118) ("n -" . 6193) ("nav" . 6220) ("e As" . 5158) ("program test" . 6568) ("typesafe" . 7272) (". net" . 1678) (". pm" . 1700) ("memq" . 6128) ("@ user" . 3025) ("none ;" . 6289) (". ResponseWriter" . 1526) ("/ cross" . 1819) ("import javax" . 5743) ("` call" . 4403) ("File" . 3342) ("LOOP" . 3541) ("go /" . 5541) ("; padding" . 2584) ("( def" . 534) (">) {" . 2972) ("== \"" . 2903) ("\")." . 132) ("string }" . 7025) ("alt =\"" . 4528) ("id >" . 5683) (": variable" . 2440) ("Empty" . 3290) ("Load" . 3561) ("\\ def" . 4242) ("auto -" . 4652) ("value As" . 7349) ("grails" . 5554) ("} =" . 7680) (": aliased" . 2355) ("spring -" . 6951) ("y (" . 7492) ("E /" . 3271) ("bootstrap" . 4724) ("LinearLayout >" . 3551) ("[: each" . 4211) (": i32" . 2391) ("_ ]," . 4380) ("\", err" . 151) ("] ifFalse" . 4298) ("Expr" . 3322) ("} private" . 7708) (":=" . 2488) ("import qualified" . 5745) ("list )" . 6018) ("public String" . 6583) ("'); $" . 385) ("move" . 6164) ("private $" . 6551) ("libc" . 5993) ("Forms" . 3365) ("urn" . 7303) (". exe" . 1620) ("self ," . 6857) ("spec )\"" . 6948) ("and" . 4533) ("\" style" . 91) ("200" . 2110) ("> <%" . 2953) ("4 )" . 2179) ("execute (" . 5297) ("lib /" . 5991) ("NSString *)" . 3661) ("Unknown" . 4058) ("~ p" . 7768) ("< char" . 2647) ("UTF -" . 4051) ("; height" . 2569) ("/**" . 1884) ("In" . 3474) ("BufferedReader" . 3119) ("lein" . 5965) ("script type" . 6833) (":: io" . 2481) ("\" <<" . 43) ("tools ." . 7221) ("= x" . 2844) ("- read" . 1351) ("site" . 6918) ("/ System" . 1798) ("physics ." . 6476) ("put_line" . 6603) ("html ';" . 5634) ("pop" . 6512) ("2012" . 2115) ("name -" . 6204) ("} ?>" . 7681) ("T ](" . 3939) ("Y" . 4135) ("package body" . 6415) ("( make" . 589) (". Strings" . 1531) ("compile :" . 4905) ("procedure TForm1" . 6561) ("Handles" . 3413) ("1427" . 2060) ("/ null" . 1846) ("display :" . 5093) ("year" . 7499) ("Couldn" . 3218) ("findViewById (" . 5390) ("ii" . 5713) ("TextBox1" . 3981) ("39" . 2174) ("} @" . 7682) ("class =" . 4853) ("00 00" . 1935) ("at groovy" . 4638) ("']" . 418) ("Program" . 3773) ("progn (" . 6565) ("sys" . 7081) ("function '" . 5481) ("dylib" . 5153) ("Messages" . 3594) ("=\" 1" . 2851) ("Some (" . 3896) ("\"?> <" . 200) ("newcommand {\\" . 6248) ("Html" . 3421) ("( s" . 628) ("weak" . 7399) ("8" . 2241) ("(@\"" . 772) ("1 \\" . 2010) ("] ]" . 4295) (", b" . 1170) (".," . 1762) ("message \"" . 6132) (". FSharp" . 1489) ("next ;" . 6252) ("low" . 6055) ("Get Return" . 3393) ("String (" . 3906) ("chan" . 4829) ("\\ r" . 4256) ("pdf" . 6453) ("]}, {" . 4363) ("- 05" . 1248) (") --" . 809) ("f32" . 5331) ("handles" . 5586) ("Box" . 3115) ("*(" . 1044) ("objectForKey" . 6337) ("); -" . 982) ("i ]" . 5664) ("{ std" . 7592) ("state" . 6974) ("JSONException e" . 3518) ("[ width" . 4196) ("); for" . 998) ("super" . 7067) ("BOOL" . 3101) ("; $" . 2530) ("\"}," . 217) ("gems" . 5500) (")^ 2" . 1022) (":: new" . 2482) ("PRINT" . 3745) ("] ->" . 4283) ("Convert ." . 3214) ("> class" . 2959) ("-> next" . 1421) ("> @" . 2958) ("such file" . 7059) (":( UITableView" . 2457) ("><%=" . 2982) ("%> <%=" . 304) ("= size" . 2835) ("\" width" . 96) ("of `" . 6344) ("args )" . 4588) ("53" . 2213) (". ?-" . 1460) ("= TRUE" . 2786) ("= False" . 2775) ("usepackage {" . 7313) (": add" . 2353) ("\" log" . 81) ("def __init__" . 5036) ("text" . 7149) (">>" . 2987) ("relative ;" . 6690) ("h3" . 5580) ("Couldn '" . 3219) ("Collections ." . 3195) (") \"" . 793) ("g :" . 5492) ("it ." . 5872) ("[ A" . 4163) ("png \"," . 6502) ("); \\" . 991) (":" . 2259) ("= document" . 2809) ("actor" . 4473) ("origin" . 6386) ("collection ." . 4885) ("( Patient" . 483) ("tonumber" . 7219) ("* 0" . 1028) ("$$ iwC" . 275) (". _2" . 1554) ("100" . 2029) ("insert into" . 5806) ("clear" . 4858) ("{ render" . 7589) ("UILabel *" . 4033) ("([] byte" . 783) ("]))" . 4317) ("'; import" . 410) ("db" . 5019) ("perl" . 6457) ("!(\"{}\"," . 13) ("article }" . 4608) ("); });" . 1012) ("); return" . 1007) ("current_user" . 4984) ("return (" . 6734) ("springframework ." . 6953) ("\" ng" . 85) ("Qt4 ." . 3793) ("' classVariableNames" . 352) ("call (" . 4783) ("Integer Dim" . 3499) ("Clear ()" . 3186) ("']['" . 425) ("arg" . 4584) ("public function" . 6585) ("INTENT (" . 3456) ("\\ end" . 4245) ("name =\"" . 6207) ("() (" . 699) ("for {" . 5424) ("= split" . 2836) ("hpp" . 5625) (". put" . 1707) ("_SESSION ['" . 4393) ("NOT" . 3633) ("max_length" . 6117) ("\\ item" . 4248) (": float" . 2382) (". close" . 1584) ("addSubview :" . 4495) ("addBody (" . 4483) ("); [" . 990) ("proc_lib ," . 6559) ("setText" . 6891) ("(?" . 769) ("& mut" . 321) ("end program" . 5231) ("IMPLICIT NONE" . 3443) ("goto -" . 5549) ("\") val" . 124) ("LANGUAGE" . 3537) ("B" . 3095) ("| data" . 7643) ("()) {" . 723) ("codehaus" . 4877) ("_GET ['" . 4389) ("something" . 6936) ("() ->" . 701) ("printfn" . 6541) ("then if" . 7181) ("Clear ;" . 3187) (",\" src" . 1222) ("List (" . 3555) ("Color :=" . 3198) ("\")," . 131) (". ali" . 1561) ("; return" . 2592) ("jar :" . 5890) ("- window" . 1385) (": string" . 2426) ("find (" . 5387) ("GROUP" . 3388) ("{ [" . 7535) ("; {$" . 2615) ("count ];" . 4957) ("DataTable" . 3249) ("dictionary" . 5076) ("Dialogs" . 3258) ("' (" . 331) (": when" . 2441) ("5 ;" . 2205) (". Height" . 1497) ("Button" . 3120) ("#( 3" . 239) ("util ." . 7334) ("[ 3" . 4161) ("<>)" . 2747) ("enumerate" . 5243) ("( for" . 555) (", (" . 1085) ("( 9" . 447) ("10 -" . 2026) ("LOOP ;" . 3542) ("@ CustomTag" . 3010) (": size" . 2423) ("is new" . 5860) ("20px" . 2125) ("ifFalse :" . 5708) ("reloadData" . 6693) ("json ." . 5905) ("} #" . 7667) ("( package" . 612) ("$ row" . 266) ("extend" . 5314) ("section" . 6839) ("k )" . 5912) ("}; int" . 7745) ("schema" . 6822) ("start /" . 6972) ("labyrinth (" . 5936) ("perror (\"" . 6464) ("if [" . 5701) ("= class" . 2804) ("(= (" . 767) ("})." . 7733) ("i -" . 5656) ("- none" . 1339) ("group" . 5568) ("([" . 774) ("self ." . 6859) ("ierr )" . 5691) ("itemize }" . 5877) (": %" . 2264) ("recent" . 6668) ("uploader ." . 7300) ("'' category" . 367) ("4 /" . 2182) ("18 ." . 2070) ("vector -" . 7364) (":?" . 2514) ("http \"" . 5638) ("f x" . 5329) ("JSONException" . 3517) ("TForm" . 3949) ("factor (" . 5339) ("0 )" . 1906) ("+ 1" . 1068) ("-- --" . 1393) ("Graphics ," . 3398) ("( count" . 529) ("7 ," . 2234) ("Ord" . 3729) (":: IO" . 2473) ("argv" . 4594) ("is the" . 5864) ("System ." . 3929) ("sum" . 7061) (". Monad" . 1510) ("= map" . 2821) ("2010" . 2113) ("actionpack -" . 4464) ("Goal" . 3395) (")))))" . 919) ("=> a" . 2924) ("src /" . 6960) ("@ return" . 3023) ("LinearLayout" . 3550) ("fill_parent" . 5379) ("'); var" . 388) ("id =\"" . 5681) ("field" . 5363) ("such" . 7058) ("While" . 4102) ("Int32" . 3488) ("* @" . 1030) (": $" . 2263) ("renewcommand" . 6697) ("at sbt" . 4641) ("[ {" . 4198) ("\",&" . 156) ("'" . 328) ("/ active_support" . 1805) ("rubies" . 6770) ("NONE" . 3632) ("); try" . 1008) ("] (" . 4282) (". Windows" . 1544) ("37" . 2170) (". $" . 1432) (".." . 1764) ("f" . 5322) ("UNION" . 4043) ("{ System" . 7534) ("private void" . 6557) ("icon" . 5672) ("Imports" . 3472) ("- dist" . 1292) ("read" . 6653) ("exec" . 5295) ("webkit" . 7404) ("setmetatable" . 6896) ("=\" packages" . 2865) (",<" . 1231) ("a >" . 4426) ("col -" . 4880) ("Destroy" . 3256) ("\" github" . 74) ("; int" . 2574) ("next =" . 6253) ("zeros" . 7507) ("findall" . 5391) ("ToString" . 3998) ("] let" . 4301) ("NaN" . 3673) ("exit" . 5299) ("- 07" . 1250) ("} while" . 7719) ("form ." . 5437) ("split" . 6949) ("- item" . 1317) ("root >" . 6758) ("IEnumerable" . 3437) (":^(" . 2525) ("**" . 1051) ("map (" . 6092) ("Then '" . 3991) ("string );" . 7013) ("-> new" . 1420) (":@\"" . 2517) ("await" . 4654) ("java :" . 5893) ("return [" . 6738) ("= &" . 2758) ("( Me" . 474) (") #(" . 795) (") (" . 802) ("sleep" . 6928) ("iwC $$" . 5882) ("defun my" . 5050) ("apply $" . 4575) ("/ home" . 1834) ("plugins ." . 6496) ("1 2" . 2002) ("= self" . 2832) ("lisp" . 6013) ("; }" . 2616) ("I in" . 3428) ("( and" . 506) ("]. (" . 4333) (",-" . 1229) ("]}," . 4362) ("else :" . 5194) ("='" . 2897) ("( Function" . 460) ("N ," . 3619) ("{ margin" . 7574) ("($ data" . 678) ("'+" . 391) ("didReceiveMemoryWarning ()" . 5078) ("DataGridView1 ." . 3246) ("err" . 5260) ("Recognized [" . 3816) ("color :#" . 4892) ("o" . 6328) ("& operator" . 322) ("| cut" . 7642) ("adb :" . 4477) ("ifTrue :[" . 5711) (". EventArgs" . 1488) ("t (" . 7086) (". Numerics" . 1515) (":: i" . 2480) ("$ 2" . 251) ("[ C" . 4165) ("id =\"@+" . 5682) (", M" . 1137) ("text ," . 7152) ("color /" . 4890) ("background :" . 4675) ("( n" . 599) ("aes" . 4500) ("Setter" . 3882) ("an" . 4530) ("Math" . 3584) ("is ." . 5853) ("push" . 6592) ("Y )" . 4136) ("'\\" . 415) ("tostring" . 7227) ("put :" . 6600) ("}; class" . 7744) ("Tail ]," . 3968) ("import \"" . 5733) ("try" . 7251) ("} \\\\" . 7686) ("' actionpack" . 351) ("inherited" . 5787) ("meta" . 6133) ("< xsd" . 2687) ("UILabel" . 4031) ("summary" . 7063) ("; package" . 2583) ("torch /" . 7226) ("{ def" . 7548) ("created_at" . 4971) (") or" . 879) ("Foo" . 3357) ("== 1" . 2906) ("Gofer" . 3396) ("$." . 284) ("< NA" . 2634) (". hibernate" . 1642) ("-> let" . 1418) ("loop for" . 6052) ("- e" . 1293) ("fff" . 5358) ("; do" . 2559) ("Parser" . 3751) ("= true" . 2841) ("Canvas ." . 3166) (": io" . 2400) ("clojure" . 4865) ("private String" . 6554) ("absolute" . 4449) ("PolymerElement" . 3758) ("do (" . 5111) ("ali" . 4510) ("- 8" . 1262) (". d0" . 1599) ("\": true" . 175) ("`," . 4409) ("\"\\ n" . 202) ("FileName" . 3348) ("x -" . 7454) (". phase" . 1695) (", false" . 1183) ("tic toc" . 7194) (": hidden" . 2387) ("</ artifactId" . 2710) ("@" . 3008) ("]) (" . 4313) ("gem '" . 5499) (";}" . 2627) (". json" . 1662) ("> /" . 2945) ("(=" . 766) ("() |>" . 720) ("58" . 2218) ("grid" . 5563) (": block" . 2368) ("railties -" . 6637) ("file :" . 5372) ("</ title" . 2732) (">]" . 2990) ("ng" . 6256) ("ready (" . 6659) ("=\"#" . 2877) ("initialize ." . 5796) ("self" . 6853) ("& \"" . 313) ("Caption" . 3167) ("lib" . 5989) (", start" . 1208) (".^" . 1780) ("override def" . 6403) ("move (" . 6165) ("SUBROUTINE" . 3860) (") NOT" . 842) ("lst" . 6059) ("( hObject" . 564) ("layout_width" . 5958) ("[|" . 4234) ("3 \"," . 2144) ("xmpp" . 7478) ("( void" . 655) (". map" . 1674) ("#( 1" . 238) ("o -" . 6330) (", 10L" . 1097) (", ." . 1088) ("( 7" . 445) ("!= nil" . 20) ("awt ." . 4661) ("\"}, {" . 218) ("bounds" . 4735) (": n" . 2409) ("());" . 724) (") go" . 866) ("double" . 5142) ("i +" . 5652) ("public string" . 6589) ("\\\"" . 4267) ("fig :" . 5365) ("printNl" . 6533) ("=> '" . 2916) ("params [:" . 6438) ("SUM" . 3861) ("= %" . 2757) ("Double" . 3265) ("Model" . 3604) ("end if" . 5227) ("( point" . 614) ("- right" . 1356) ("expression :" . 5313) (") '" . 800) ("select" . 6848) ("For" . 3359) ("0 '..'" . 1904) ("angular ." . 4541) ("Y1" . 4143) ("label >" . 5933) ("\" done" . 66) ("eval" . 5278) ("; with" . 2612) ("};" . 7742) ("( _" . 503) ("\" Dim" . 49) ("( clojure" . 522) ("| format" . 7645) ("js" . 5900) ("(->" . 750) ("pi" . 6479) ("R ." . 3798) (". grails" . 1636) (". plugins" . 1699) ("{ color" . 7545) ("- alpine" . 1270) ("-> (" . 1402) ("\"},{ line" . 220) ("require ('" . 6715) ("09 :" . 1965) ("file" . 5368) ("Catch" . 3170) (", Socket" . 1149) ("request ," . 6709) ("RelativeLayout" . 3819) ("of -" . 6343) ("( J" . 468) ("= |" . 2848) (": copy" . 2374) ("01 s" . 1947) ("s (" . 6794) ("hold" . 5615) ("( sizeof" . 637) ("File =>" . 3347) ("; double" . 2560) ("7 ." . 2235) (". WriteLine" . 1546) ("toString ());" . 7215) ("< sys" . 2677) ("0L ," . 1967) ("03" . 1951) ("LazySeq" . 3546) ("Seq" . 3872) ("buf" . 4747) (") write" . 894) ("), member" . 949) (": &" . 2266) ("=> :" . 2920) ("nil }" . 6270) ("print \"\\" . 6527) ("%" . 286) ("node [" . 6282) ("in <" . 5758) ("35" . 2168) (". dll" . 1605) ("tableView ." . 7108) ("end def" . 5222) ("=> Return" . 2922) ("IBAction" . 3429) ("* error" . 1035) ("release" . 6691) ("; private" . 2588) ("Pid ," . 3756) ("12 ." . 2050) ("{ font" . 7560) ("hline" . 5613) ("void )" . 7382) ("rspec" . 6769) ("lua /" . 6064) ("{ fig" . 7555) (", f" . 1182) (")\"" . 900) (") extends" . 861) ("=> true" . 2927) ("template match" . 7135) ("!= 0" . 18) ("send :" . 6864) (", new" . 1198) ("th >" . 7167) ("strings ." . 7028) (":[[" . 2520) ("Net ::" . 3686) (": center" . 2370) ("zone ." . 7511) ("vec" . 7361) ("{ tikzpicture" . 7599) ("gnatmake" . 5538) ("= $" . 2755) ("super viewDidLoad" . 7070) ("warn ]" . 7395) ("UILabel !" . 4032) (") defining" . 856) ("( const" . 527) ("st :" . 6967) ("{ pub" . 7587) ("] <-" . 4287) ("wrap" . 7437) ("]{\\" . 4360) ("Click Dim" . 3189) ("YES ];" . 4147) ("match -" . 6104) (": start_link" . 2425) (":= http" . 2504) ("(:,:)" . 763) ("} function" . 7699) (": DWORD" . 2316) ("valueForKey :@\"" . 7351) ("noreply ," . 6292) ("\\ multicolumn" . 4252) ("action_controller" . 4459) ("< stdlib" . 2675) ("Imports System" . 3473) ("CType" . 3157) ("plt" . 6492) ("IFS" . 3441) ("s \\" . 6798) ("println (\"" . 6549) ("m" . 6068) ("New_Line" . 3689) ("df $" . 5074) ("0L" . 1966) ("{ String" . 7533) ("%> <%" . 303) ("ArrayList <" . 3078) ("')" . 377) ("'); end" . 387) (". api" . 1565) ("REPORT ====" . 3807) ("/ actionpack" . 1803) ("/ perl" . 1849) ("alert (\"" . 4509) (":= false" . 2502) ("{$" . 7609) ("{ @" . 7526) ("=${" . 2896) ("/ dev" . 1823) ("true" . 7241) ("](\"" . 4310) ("import '" . 5734) ("Ada ." . 3055) ("draw" . 5146) (", sizeof" . 1207) ("] [" . 4292) ("$('" . 281) ("NSInteger" . 3649) (", C" . 1123) ("user ." . 7315) ("sed" . 6844) ("lazy" . 5960) ("), dimension" . 946) ("Y |" . 4142) ("( newline" . 603) ("](" . 4309) ("nrow (" . 6305) ("True )" . 4012) ("): def" . 972) ("= append" . 2798) (": anObject" . 2356) ("hs :" . 5631) ("nsc" . 6307) ("id |" . 5685) (". ID" . 1498) ("p (" . 6407) ("storyboard ." . 6996) ("1 \"" . 1981) ("tar" . 7117) ("exception error" . 5291) ("text =\"" . 7157) ("or" . 6375) ("private ;" . 6553) ("Destroy ;" . 3257) ("'' poolDictionaries" . 368) ("| self" . 7651) ("; case" . 2552) ("UIImage imageNamed" . 4028) ("stylesheet" . 7042) ("/ python" . 1853) ("akka" . 4505) (")]," . 1019) ("< name" . 2665) ("ref" . 6677) ("[])" . 4225) ("= malloc" . 2820) ("/ application" . 1810) (". length" . 1668) ("15px" . 2063) ("Text :=" . 3976) ("Program Files" . 3774) ("namespace std" . 6217) ("{ print" . 7583) ("Scanner" . 3865) ("#!/ bin" . 233) ("select *" . 6849) ("}} <" . 7760) ("- current" . 1286) ("; property" . 2590) ("paste" . 6446) ("defer" . 5039) ("auto" . 4651) ("< class" . 2648) ("Char" . 3177) ("ch ," . 4828) ("x2" . 7467) ("spring" . 6950) ("love ." . 6054) ("contentHeight" . 4941) ("TODO" . 3955) (") where" . 893) ("j ," . 5885) ("($" . 673) ("() var" . 718) ("switch" . 7076) ("' );" . 332) ("N" . 3616) ("deriving (" . 5066) ("Private Sub" . 3772) ("admin" . 4497) (". new" . 1679) (". HandleFunc" . 1496) ("override func" . 6404) ("Box <" . 3117) ("', $" . 393) ("string ," . 7014) ("1 ))" . 1987) ("Vcl ." . 4078) ("\" net" . 84) ("echo \"" . 5171) ("{ verbatim" . 7602) ("; border" . 2551) ("td ><" . 7124) ("src =\"" . 6961) ("- syntax" . 1367) ("list ))" . 6019) ("doFilter (" . 5126) ("([ a" . 780) ("using (" . 7325) ("string {" . 7024) ("maven" . 6113) ("7L ," . 2240) ("10 )" . 2024) ("complexType" . 4909) (". invokeMethod" . 1655) ("{ '" . 7517) (", {" . 1219) ("( H" . 461) ("handles ." . 5587) (". jpg" . 1660) ("bounce" . 4733) ("300" . 2163) ("). %" . 958) ("assert" . 4624) ("; cout" . 2556) (". [" . 1547) (". Width" . 1543) ("-> {" . 1426) ("i )" . 5648) ("; let" . 2578) (": inline" . 2396) ("NF" . 3627) ("endif" . 5238) ("query" . 6616) ("90" . 2256) ("( 5" . 442) ("web /" . 7403) ("xmlns :" . 7475) ("= nil" . 2827) ("subsection" . 7053) (")\") }" . 902) ("9 :" . 2254) ("i32 ," . 5671) ("IntToStr" . 3490) ("Visible" . 4085) ("cgi" . 4826) ("png \")" . 6501) ("SKSpriteNode" . 3855) ("protected" . 6575) ("option value" . 6372) ("f |" . 5330) ("rvm" . 6785) ("- command" . 1285) ("#{" . 247) ("- match" . 1329) ("aStream" . 4441) ("( goto" . 563) ("except" . 5289) ("dll \"" . 5109) ("hook (" . 5621) ("request ." . 6710) (">\";" . 2963) (". Checked" . 1472) ("action_dispatch" . 4460) ("If Not" . 3469) ("funcall" . 5479) ("left :" . 5963) ("end @" . 5220) ("Id" . 3463) ("sceneGroup" . 6821) (") real" . 882) ("_ )," . 4371) ("Num" . 3703) ("NSData" . 3639) (". hs" . 1645) ("(); var" . 735) ("transparent" . 7238) ("\")) (" . 127) ("notice" . 6299) ("row" . 6761) ("put" . 6597) (": 21" . 2296) ("initWithFrame :" . 5794) ("float :" . 5397) ("imshow" . 5751) ("obj" . 6332) ("= new" . 2826) ("CallSiteArray ." . 3162) ("Text &" . 3973) ("ElseIf" . 3289) (", 112L" . 1098) ("weak var" . 7400) ("; this" . 2601) ("cross /" . 4976) ("Failed" . 3337) ("01" . 1943) ("bash :" . 4683) ("33" . 2166) ("true ;" . 7248) ("hook '" . 5620) ("s \"," . 6793) ("django /" . 5107) ("refer" . 6678) ("TeX" . 3970) ("CharField" . 3178) ("stdcall ;" . 6986) ("#" . 221) ("kernel" . 5917) ("ELSE" . 3272) ("5L" . 2220) ("beans ." . 4687) ("fa" . 5334) ("fn [" . 5404) ("\" name" . 83) ("[\"" . 4200) ("Rest" . 3826) (", line" . 1194) (". 8" . 1458) ("[]" . 4218) ("support ." . 7073) ("nil {" . 6269) ("%>%" . 306) ("{ border" . 7541) ("(){" . 738) ("Long" . 3564) ("And" . 3063) ("long" . 6047) ("{ :" . 7525) (": Integer" . 2321) (", d" . 1176) ("( m" . 587) ("# include" . 228) ("a :" . 4422) (", animated" . 1169) (") viewDidLoad" . 891) ("SizeOf" . 3890) ("))]" . 932) (")=" . 1013) ("{ return" . 7590) ("collections" . 4887) ("'];" . 423) ("UIColor" . 4023) ("script src" . 6832) ("result :=" . 6728) ("text +" . 7151) ("users" . 7322) ("return 1" . 6736) ("** kwargs" . 1053) ("None" . 3698) ("Application" . 3069) ("null ?" . 6314) ("S_ {" . 3864) ("rb" . 6647) ("google ." . 5546) ("fun (" . 5468) ("play ." . 6487) ("/ rust" . 1863) ("is begin" . 5859) ("}}" . 7759) ("()->" . 727) ("c (\"" . 4770) ("Enabled" . 3291) ("call last" . 4784) ("protected void" . 6576) ("!=" . 17) ("\\ t" . 4262) ("sender" . 6865) ("org -" . 6381) ("ali -" . 4511) (", ByVal" . 1122) ("X ," . 4120) ("- 16" . 1258) ("wc" . 7398) ("eq ?" . 5248) ("') class" . 378) ("controller" . 4946) ("= 10" . 2765) ("end %" . 5213) ("\" >" . 45) ("/ json" . 1838) ("0 }" . 1931) ("- function" . 1308) ("__construct" . 4394) ("Open" . 3724) ("printStackTrace" . 6534) ("k" . 5911) ("href" . 5626) (". getString" . 1633) ("canvas" . 4791) (": error" . 2379) (". Collections" . 1476) ("\": {" . 176) ("l )" . 5927) ("lynx" . 6066) ("#-}" . 241) ("nrow" . 6304) ("\": false" . 173) ("x =>" . 7463) ("std ::" . 6983) ("=~ s" . 2938) ("activesupport -" . 4472) ("car lst" . 4797) ("( Exception" . 458) ("numel (" . 6322) ("kill" . 5921) ("'/" . 403) ("lst ))" . 6061) ("1999 /" . 2076) ("Handle ," . 3411) ("}}</" . 7765) ("SNAPSHOT" . 3856) (". ]." . 1550) ("Override public" . 3734) ("): if" . 973) ("x ->" . 7455) ("dimen" . 5081) ("printf (\"\\" . 6540) ("activerecord" . 4470) (", A" . 1119) ("test" . 7139) ("? lst" . 2997) ("xsl" . 7488) ("setf (" . 6893) (": E" . 2317) ("t ," . 7091) ("transform :" . 7235) ("column" . 4893) ("SET" . 3851) ("= [];" . 2797) ("java" . 5891) ("alpha" . 4524) ("zeros (" . 7508) ("synthesize" . 7080) ("physics" . 6475) ("< TextView" . 2638) ("scene :" . 6820) ("[ web" . 4195) ("params ." . 6437) ("% \\" . 289) ("min -" . 6138) ("( struct" . 643) ("rails" . 6634) ("header" . 5595) ("let cell" . 5977) ("\\ usepackage" . 4266) ("right :" . 6750) ("page" . 6425) ("div class" . 5102) ("( fun" . 558) ("\"]=>" . 210) ("2 |" . 2106) ("- i" . 1313) ("URL" . 4045) ("a ]" . 4429) ("leiningen" . 5966) ("ItemTemplate" . 3510) ("none" . 6287) ("] \"" . 4280) ("red" . 6674) (":= OrderedCollection" . 2498) ("( 20" . 439) ("section :" . 6840) ("() local" . 714) ("** exception" . 1052) ("' Image" . 344) ("\" C" . 48) ("member this" . 6126) ("con" . 4913) ("< polymer" . 2669) ("WRITE (" . 4096) ("indexPath ." . 5781) ("mv" . 6176) ("Parameters" . 3748) ("( cadr" . 516) ("arm" . 4598) ("x )" . 7451) ("pm line" . 6498) (") |" . 897) ("id ])" . 5684) (": 00" . 2276) ("} int" . 7702) ("to :" . 7212) ("bundle /" . 4758) ("Data" . 3243) ("',[" . 399) ("\"); return" . 139) ("/*" . 1883) ("> #" . 2943) ("ViewController" . 4084) ("ssl" . 6965) (". listen" . 1669) (". Put" . 1522) ("add (" . 4479) ("application" . 4571) ("/> <" . 1896) (", 2L" . 1103) (". reflect" . 1711) ("= UIColor" . 2788) ("call '" . 4782) ("impl <" . 5726) ("@ observable" . 3021) ("juan /" . 5909) (". self" . 1719) ("class (" . 4852) ("< form" . 2650) (".=" . 1775) ("car l" . 4796) ("[ super" . 4191) ("= True" . 2787) (". CharField" . 1471) ("/ main" . 1844) ("omp" . 6352) ("padde" . 6420) ("0000" . 1939) ("align :" . 4514) ("- 11" . 1255) ("string ." . 7016) ("margin" . 6098) ("console >:" . 4928) (", y" . 1218) (". fs" . 1629) (". ]" . 1549) ("); String" . 988) (".\\ n" . 1779) ("String ]" . 3916) (". delegate" . 1602) (", B" . 1121) ("for -" . 5414) ("': u" . 406) (". Items" . 1503) ("( 3" . 440) ("[])." . 4227) ("version" . 7369) (", 100" . 1096) ("2015 -" . 2122) ("typename" . 7267) (") Handles" . 839) ("label :" . 5932) ("List <" . 3558) ("Name" . 3675) ("returns" . 6745) ("layout_height =\"" . 5955) (") ;;" . 823) ("pm" . 6497) ("50 )" . 2208) ("<< endl" . 2742) ("Unknown Unknown" . 4060) ("asp :" . 4623) ("_ )." . 4372) ("Request )" . 3821) ("/ android" . 1807) ("/ $" . 1784) ("father (" . 5352) ("tic" . 7193) ("int {" . 5822) ("- column" . 1284) (": end" . 2378) ("Each" . 3286) ("Close ()" . 3191) ("font" . 5408) ("=[" . 2931) ("~= nil" . 7771) ("b =" . 4669) ("}]},{" . 7754) ("begin (" . 4691) ("\\(" . 4270) ("resources" . 6721) ("If" . 3464) ("{
" . 7513) ("xxx" . 7490) ("end end" . 5225) ("07" . 1959) ("node *" . 6281) ("{ i" . 7565) (">)" . 2969) ("( match" . 591) ("OleDb" . 3722) ("; procedure" . 2589) ("nonatomic ," . 6286) ("' =>" . 338) ("rdd ." . 6651) ("value ;" . 7346) ("\")))" . 128) ("actionpack (" . 4463) ("!" . 1) ("UITableViewCell {" . 4038) ("test ." . 7141) (": left" . 2406) ("c |" . 4777) ("* sizeof" . 1040) ("Form1" . 3362) (", Z" . 1160) ("import System" . 5739) ("H ," . 3405) (".$" . 1759) ("--> [" . 1397) ("wait ." . 7393) ("argument of" . 4593) (". AFn" . 1461) (": for" . 2383) ("( k" . 577) ("; while" . 2610) (", T2" . 1154) ("5L ," . 2221) ("{ super" . 7595) ("[[" . 4214) ("figure" . 5366) ("GLIBC_2 ." . 3386) ("global" . 5534) ("INSERT INTO" . 3450) ("real" . 6660) ("' ->" . 334) ("\".." . 162) ("', function" . 397) ("Key" . 3526) ("String" . 3905) ("UIImage *" . 4027) (")) :-" . 911) ("min" . 6136) ("=\" fill_parent" . 2860) ("st >" . 6968) ("= (" . 2760) ("second" . 6838) ("gcc /" . 5497) (".. 10" . 1766) ("read -" . 6655) ("()); }" . 725) ("` core" . 4404) ("T :" . 3935) ("n ;" . 6195) ("space" . 6939) ("at android" . 4635) (") =" . 826) ("org /" . 6383) ("Intent" . 3503) ("- 14" . 1257) ("edge (" . 5182) ("WHERE" . 4092) ("func tableView" . 5477) ("\") End" . 117) ("True" . 4011) (") 2" . 817) ("OPEN" . 3709) (". eval" . 1619) ("0 ))" . 1907) ("on ('" . 6354) ("directory" . 5086) ("Tail" . 3966) ("; {" . 2614) ("SparkContext" . 3899) ("overlay" . 6400) ("2 );" . 2088) ("NA NA" . 3625) ("Seq_Float_IO ." . 3877) ("i" . 5647) ("*( x" . 1046) ("lists" . 6025) ("#[ derive" . 246) ("normal" . 6293) ("; finally" . 2563) (". ToString" . 1535) ("(*" . 739) ("variable" . 7359) ("); System" . 989) ("1 1" . 2001) ("): at" . 971) ("[ I" . 4167) ("\", function" . 152) ("05 -" . 1956) ("alpine -" . 4526) ("bind" . 4706) ("Name >" . 3679) ("Dialogs ," . 3259) ("np" . 6300) ("? MODULE" . 2995) ("(\"" . 663) ("): File" . 970) ("do :[:" . 5113) ("li >" . 5985) (": db" . 2375) ("does" . 5137) ("0 \"," . 1901) ("[ $" . 4156) ("string `" . 7023) ("=\"${" . 2880) ("push :" . 6594) ("Catch ex" . 3171) ("Public Function" . 3781) ("file ,\"" . 5369) (")))))) (" . 922) ("/ github" . 1832) ("shutdown" . 6913) ("rdd" . 6650) ("Button1Click (" . 3124) ("next" . 6251) (";
" . 2527) ("\"><" . 193) ("hidden" . 5609) ("$ i" . 261) (">) =" . 2971) ("[ T" . 4171) ("=> \"" . 2914) ("super new" . 7069) (": gravity" . 2386) ("c ," . 4772) ("Integer_Text_IO" . 3501) ("= require" . 2831) ("My" . 3612) ("=\"{{" . 2891) (". size" . 1723) ("11L" . 2047) ("instance" . 5809) ("append (" . 4569) ("minipage" . 6142) ("log ." . 6045) ("if @" . 5700) ("racket" . 6631) ("LEFT JOIN" . 3539) (". contentWidth" . 1590) ("case" . 4799) ("2 /" . 2095) (": element" . 2377) ("INTENT" . 3455) (": relative" . 2419) ("core $" . 4949) ("a [" . 4428) (": 5px" . 2301) (": Array" . 2310) ("required )>'" . 6718) ("=\" submit" . 2867) (": 02" . 2278) ("scala ." . 6811) ("groovy ." . 5566) ("export" . 5309) ("\" ]" . 57) ("Try" . 4015) ("width =" . 7422) ("DO" . 3237) ("iostream" . 5847) ("/ dist" . 1824) ("ans" . 4555) ("- o" . 1340) ("{ my" . 7576) ("has_many :" . 5590) ("( main" . 588) (". com" . 1587) ("0000000 *(" . 1942) ("ido" . 5687) ("/ bin" . 1813) ("< input" . 2656) ("/ 1999" . 1787) ("core ::" . 4953) ("; when" . 2609) ("Bar" . 3104) (". data" . 1601) ("@ implementation" . 3018) ("End Class" . 3294) ("mother" . 6162) ("= [[" . 2795) ("9 \\" . 2255) (". awt" . 1570) ("email" . 5205) ("= do" . 2808) ("Image" . 3470) ("/(" . 1882) (": auto" . 2365) ("grails ." . 5555) ("Compiler ." . 3202) ("tostring (" . 7228) ("0 then" . 1928) ("< _" . 2639) ("nil" . 6260) ("ShowMessage ('" . 3888) ("$ result" . 265) ("J" . 3513) ("U +" . 4020) ("t2" . 7098) ("->" . 1400) ("name =" . 6206) (". _" . 1552) ("database ." . 5016) ("addEventListener (\"" . 4488) ("py \"," . 6607) ("' 00" . 336) ("index :" . 5778) (": length" . 2407) ("runat" . 6778) ("OR" . 3710) ("is array" . 5858) ("f64" . 5332) ("layout_height" . 5954) ("( D" . 455) ("to" . 7210) ("string (" . 7011) ("count" . 4956) ("{ #" . 7515) (". all" . 1562) ("ByteString" . 3129) ("'() (" . 375) ("attribute name" . 4649) ("layout" . 5952) ("} let" . 7703) ("print \"$" . 6526) (". \"" . 1431) ("\\ includegraphics" . 4247) ("), (" . 941) ("\" nil" . 86) ("( 1" . 435) ("write (*,*)" . 7444) ("yes" . 7500) ("=\" false" . 2859) ("auto ;" . 4653) ("erl ," . 5256) ("= 3" . 2767) ("- linux" . 1323) ("error ," . 5269) ("ptr" . 6577) ("\"; #" . 180) ("Transcript show" . 4008) ("find -" . 5388) ("\\\\" . 4277) ("xs :" . 7482) ("1 ;" . 2005) ("IS" . 3462) ("-> printfn" . 1423) ("encoding" . 5209) ("doInvoke" . 5127) ("cond ((" . 4918) ("getJSONObject (" . 5520) ("Dumper" . 3268) ("Int ," . 3483) (":'" . 2452) ("= List" . 2776) ("share /" . 6904) (") echo" . 858) ("L )." . 3530) (": 20px" . 2295) ("say" . 6805) (", ok" . 1202) ("arm -" . 4599) ("{ alert" . 7537) ("operator" . 6367) (":] +" . 2524) (". http" . 1647) (": Option" . 2330) ("NSDate" . 3641) ("?>" . 3006) ("> <?" . 2956) ("Int {" . 3487) ("05" . 1955) ("{ display" . 7549) ("extend [" . 5315) ("-> IO" . 1404) ("servlet ." . 6881) ("0 1" . 1917) ("; text" . 2599) ("strings" . 7027) ("failwith" . 5344) ("node (" . 6280) ("collect" . 4883) (": String" . 2331) ("height :" . 5598) ("=\"@" . 2884) (". ads" . 1560) ("}]}," . 7752) ("6L ," . 2231) ("& str" . 323) ("last -" . 5944) ("position =" . 6516) ("/. rvm" . 1887) ("/" . 1783) ("note :" . 6298) ("let ((" . 5974) (", X" . 1157) ("( i" . 567) (": AnyObject" . 2309) ("r ," . 6624) ("TStringList" . 3962) ("as" . 4611) ("io ::" . 5846) ("= value" . 2842) ("ARGV" . 3043) ("NSArray *" . 3637) ("table >" . 7104) ("AsyncTask" . 3094) ("printf" . 6537) ("( L1" . 471) ("fail" . 5342) ("%; }" . 300) ("activesupport" . 4471) ("null ;" . 6313) ("backgroundColor" . 4677) (". Visible" . 1541) ("FILE" . 3327) ("dart -" . 5002) ("; using" . 2606) ("render" . 6696) ("hline \\" . 5614) ("return Boolean" . 6737) ("BOOL )" . 3102) ("stderr" . 6987) ("))) (" . 916) ("property" . 6572) ("( recur" . 622) ("UIImage (" . 4026) ("( quote" . 618) (". gradle" . 1635) ("at :" . 4633) ("linear" . 6004) ("1 -" . 1996) ("char >" . 4836) ("-> Void" . 1409) ("b1" . 4671) ("( lambda" . 580) ("[ this" . 4193) ("ORM \\" . 3714) ("[ 1" . 4159) (") FROM" . 837) ("map {" . 6094) ("package" . 6413) ("address" . 4496) ("0l0 ," . 1972) (". pas" . 1691) ("RewriteCond %{" . 3834) ("\" :" . 42) ("1 put" . 2018) ("- 12" . 1256) ("HttpRequest" . 3423) ("cadr" . 4780) ("active_record" . 4466) ("m2" . 6071) ("\" />" . 37) ("gcc -" . 5496) ("navigationController" . 6223) ("declarations }" . 5031) ("T1 ," . 3942) ("{ //" . 7520) ("observable" . 6341) ("{ frame" . 7562) ("RDD" . 3801) ("0 =" . 1921) ("' First" . 343) (") <-" . 824) (": \\(" . 2346) ("w" . 7385) ("Vec" . 4079) (". insert" . 1652) ("=/" . 2900) ("((" . 688) ("> :" . 2950) (") 0" . 815) ("CustomTag ('" . 3226) ("t1 ." . 7097) ("end #" . 5212) ("< 0" . 2629) ("ok ," . 6350) ("{ table" . 7596) (", err" . 1180) ("is tagged" . 5863) ("). unwrap" . 965) ("0 </" . 1920) ("| grep" . 7646) ("\" android" . 61) ("break" . 4741) (":: a" . 2477) ("function ($" . 5483) ("} [" . 7684) ("Array ." . 3074) (". hpp" . 1644) ("if let" . 5705) ("return }" . 6744) (", function" . 1186) ("<%=" . 2696) (", E" . 1127) ("} else" . 7693) ("'';" . 370) (". names" . 1677) (": return" . 2420) (": A" . 2308) (". t" . 1734) ("to_string" . 7216) ("tikzpicture" . 7195) ("08 :" . 1962) ("]." . 4332) (":= True" . 2499) ("[<" . 4213) ("Read" . 3813) ("c ." . 4774) ("</ form" . 2714) ("\"${" . 109) ("npm" . 6302) (": array" . 2361) ("with -" . 7429) ("\" =>" . 44) ("0x0 ," . 1977) ("}]}, {" . 7753) (") for" . 864) (";\"" . 2618) ("log (" . 6042) ("CustomTag" . 3225) ("Core" . 3215) ("extent" . 5318) ("config ." . 4921) ("chan int" . 4830) ("])) (" . 4318) ("{ val" . 7600) ("Exit" . 3319) ("defvar" . 5051) ("New System" . 3688) ("2 )" . 2083) ("nil nil" . 6267) ("false" . 5345) ("Boolean ;" . 3114) ("polymer" . 6506) (", 6L" . 1111) ("export ([" . 5310) ("end class" . 5221) ("indent -" . 5775) ("type `" . 7261) ("< meta" . 2663) ("(); //" . 733) ("len" . 5967) ("v \"," . 7336) ("( append" . 507) ("background" . 4673) (": background" . 2367) (":= new" . 2506) ("}{" . 7755) ("weight" . 7406) ("'); %" . 386) ("ThreadPoolExecutor" . 3996) ("BEGIN {" . 3100) ("t (:" . 7087) ("f :" . 5327) ("(`" . 787) (") x" . 895) ("($ line" . 679) ("ssh" . 6964) ("Natural" . 3684) ("- each" . 1295) ("echo '" . 5176) ("$ self" . 268) ("); let" . 1001) ("__init__ ." . 4397) ("= []" . 2796) ("]) {" . 4316) ("Date" . 3251) ("/." . 1886) ("span" . 6940) ("( df" . 540) ("50" . 2207) (") func" . 865) ("Ref" . 3818) (": 9" . 2305) ("Count" . 3220) ("cons (" . 4925) ("\\ node" . 4255) ("' from" . 356) ("- repeat" . 1355) ("center \">" . 4821) ("DataGridView1" . 3245) ("does not" . 5138) ("input" . 5799) ("& 1" . 317) ("main ." . 6078) ("git" . 5530) ("] ;" . 4286) ("true }" . 7250) ("printf (\"%" . 6539) ("addSubview" . 4493) ("} )" . 7671) ("M -" . 3569) ("doCall (" . 5124) (") As" . 832) ("overflow" . 6398) (". servlet" . 1720) (", }" . 1220) ("( B" . 451) (". py" . 1708) ("Right" . 3836) ("YES ;" . 4146) (". clone" . 1583) ("{ -" . 7519) ("d0" . 4996) ("Integer :=" . 3496) (")))) (" . 918) (". internal" . 1653) (". newText" . 1681) ("stop" . 6994) ("images" . 5721) (", &" . 1083) ("NSString *" . 3660) ("( name" . 600) ("); Put" . 987) ("= 1" . 2764) ("4 5" . 2184) ("Microsoft ." . 3603) (")%" . 903) ("rand (" . 6640) ("hyperref" . 5646) ("a |" . 4435) ("verbatim" . 7368) ("- animation" . 1271) ("</ td" . 2729) (". \\" . 1548) ("1000 ." . 2034) ("/ var" . 1877) ("my $" . 6178) ("- 0" . 1242) (": List" . 2323) ("ss" . 6962) ("in function" . 5762) (") [" . 847) ("Map" . 3579) (". dequeueReusableCellWithIdentifier" . 1603) ("' t" . 362) ("erlang" . 5258) ("fmt ." . 5402) ("- index" . 1316) ("'); }" . 389) ("Vcl" . 4077) ("=\" server" . 2866) ("$ 0" . 249) ("if ($" . 5695) ("377 \\" . 2172) ("( std" . 639) ("i32" . 5670) ("sudo" . 7060) ("hibernate ." . 5608) ("01 /" . 1945) ("log ('" . 6044) ("\" |" . 98) ("Data ." . 3244) ("-" . 1239) ("]()" . 4311) ("112L ," . 2046) ("array of" . 4606) ("Controls" . 3211) ("< th" . 2681) ("Grid" . 3399) ("self ->" . 6858) ("more" . 6159) ("public :" . 6582) ("true \"" . 7242) ("and (" . 4534) ("{ char" . 7544) ("library (" . 5995) ("( Native" . 478) ("Self" . 3868) ("Error :" . 3309) ("r ." . 6626) ("routes" . 6760) ("<<\"" . 2744) ("then return" . 7183) ("( int" . 573) ("List" . 3554) ("( equal" . 546) ("file2" . 5375) ("([ _" . 779) ("angular" . 4540) ("style" . 7038) ("display ." . 5092) ("while (" . 7414) ("repeat" . 6701) ("Item (" . 3507) ("Binding" . 3107) ("dart /" . 5004) ("Exit ;" . 3321) ("function [" . 5486) ("null" . 6310) ("[ tableView" . 4192) ("{-# LANGUAGE" . 7614) (", Name" . 1142) ("6 ," . 2226) ("^." . 4368) ("|> Seq" . 7661) ("- to" . 1373) ("border -" . 4726) ("check -" . 4842) ("; (" . 2532) ("public" . 6581) (", Pid" . 1144) (". Write" . 1545) ("gfortran -" . 5525) ("( Sender" . 491) ("5px" . 2223) ("codehaus ." . 4878) ("important ;" . 5748) ("\"> <%=" . 191) (". width" . 1751) (");" . 978) (". sty" . 1730) ("=\"#\">" . 2878) ("T >" . 3936) ("Put" . 3784) ("Grid ." . 3400) ("\" href" . 76) ("MiKTeX 2" . 3601) ("completion :" . 4908) ("self ()," . 6854) ("false ." . 5347) ("Boolean" . 3113) ("/ dart" . 1821) ("polymer ." . 6508) ("( R" . 485) ("- 10" . 1254) ("); finally" . 997) ("\\ setlength" . 4259) ("end module" . 5230) ("go" . 5539) ("USER >" . 4049) ("data =" . 5013) ("rvm /" . 6786) ("]; self" . 4347) ("As New" . 3086) ("FSharp" . 3334) ("character (" . 4839) ("t ." . 7092) ("} set" . 7713) ("u" . 7274) ("'));" . 379) ("NSIndexPath )" . 3647) ("(." . 751) ("> <" . 2951) ("initialize" . 5795) ("lambda (" . 5938) ("]}" . 4361) ("- theme" . 1372) ("h \"" . 5575) ("\")]" . 142) ("php $" . 6472) (". Var" . 1540) ("END LOOP" . 3276) (") :=" . 821) ("ok ." . 6351) ("cargo" . 4798) ("cr ." . 4966) ("constant" . 4933) ("at java" . 4639) ("user =>" . 7318) ("MessageBox ." . 3593) ("else if" . 5197) ("stk" . 6992) (". open" . 1686) ("li :" . 5984) ("2 0" . 2096) ("/ x86_64" . 1879) ("XSL /" . 4133) ("Property" . 3775) ("json =" . 5907) ("empty ?" . 5208) ("]):-" . 4323) ("Ok" . 3720) ("/ Users" . 1799) (". so" . 1724) ("hudson ." . 5645) ("5 6" . 2203) (";;" . 2624) ("= YES" . 2792) (". tex" . 1737) ("www ." . 7446) (". iter" . 1657) ("android \"" . 4536) ("[:" . 4210) (", Result" . 1146) ("L1 ," . 3534) ("function |" . 5488) ("Debug" . 3253) (":@" . 2515) ("\\ documentclass" . 4243) ("=\" yes" . 2875) ("1 ." . 1997) (".\" (" . 1758) ("lang ." . 5941) ("Inherits" . 3477) ("( car" . 517) ("rgba (" . 6748) ("} {" . 7720) ("= User" . 2790) ("png" . 6499) ("SysUtils" . 3926) ("2 +" . 2090) ("NULL" . 3667) ("window ." . 7427) ("ruby /" . 6774) ("begin if" . 4696) ("15" . 2062) ("/ XSL" . 1801) ("xml" . 7472) ("( named" . 601) ("[$ i" . 4203) ("dart" . 4997) ("ByVal e" . 3126) ("ease -" . 5168) ("T1" . 3941) ("(+ x" . 746) (": function" . 2385) ("a" . 4414) ("< img" . 2655) ("asParser" . 4618) ("begin" . 4690) ("{ string" . 7593) ("ada" . 4474) ("- s" . 1359) (". Integer_Text_IO" . 1501) ("Integer );" . 3495) ("Microsoft" . 3602) ("; task" . 2598) ("52" . 2212) ("Where" . 4101) ("Input" . 3479) ("Gtk ." . 3403) ("} }," . 7724) (": the" . 2433) ("while" . 7413) ("__init__ (" . 4396) ("- process" . 1347) ("began" . 4689) ("W /" . 4090) ("( string" . 642) ("make ([]" . 6084) ("real *" . 6662) ("time ." . 7198) ("( L" . 470) ("/ rvm" . 1864) ("\" End" . 50) ("option" . 6370) ("i in" . 5668) (") val" . 889) ("V" . 4066) ("main (" . 6076) ("10px" . 2037) ("{ cout" . 7547) ("type \":" . 7256) ("< artifactId" . 2642) ("bean" . 4685) ("-- (" . 1392) ("regexp" . 6683) ("; Result" . 2544) (": `" . 2347) ("WriteLine (" . 4111) ("/ src" . 1870) ("right" . 6749) (": print" . 2416) ("}{|" . 7758) ("padding :" . 6424) ("month" . 6158) (">] let" . 2991) ("build" . 4754) ("begin Result" . 4694) ("summary >" . 7064) ("import scala" . 5746) ("))+ 0" . 926) ("(( and" . 689) ("new List" . 6241) ("#(" . 237) ("( defvar" . 539) ("the" . 7169) ("); procedure" . 1006) (": integer" . 2399) ("egg" . 5184) ("net" . 6227) ("table" . 7101) ("some" . 6935) ("id ," . 5676) (", std" . 1209) ("inputenc" . 5802) ("INTO" . 3457) (", $" . 1081) ("from /" . 5463) ("Int (" . 3481) (":#" . 2450) ("() }" . 721) ("4 ;" . 2185) (". 01" . 1442) ("div style" . 5104) ("Base" . 3105) ("static void" . 6980) (") /" . 813) ("77" . 2238) ("panic (" . 6430) ("( global" . 562) ("Font ." . 3356) ("=\\" . 2933) ("/ 2001" . 1789) ("CType (" . 3158) ("you" . 7502) ("< module" . 2664) ("ifTrue :" . 5710) ("source" . 6937) ("' }" . 364) ("~ n" . 7767) ("1 \"," . 1982) ("cmd ." . 4875) ("repl" . 6702) ("}%" . 7727) ("| tempAnimal" . 7653) ("emacs ." . 5204) ("s \"" . 6792) ("(& mut" . 683) ("(' 0" . 686) (". Left" . 1504) ("09" . 1963) (", X2" . 1158) (". DataSource" . 1485) ("& \\" . 318) ("dired" . 5087) ("} ->" . 7674) ("- rails" . 1350) ("\\ 30" . 4236) ("Case" . 3169) ("11 -" . 2041) ("In the" . 3475) ("row ." . 6762) ("sender {" . 6869) ("L ," . 3531) ("+" . 1062) ("()," . 726) ("Property =\"" . 3776) ("} object" . 7704) ("eabi" . 5159) (">/" . 2974) ("json" . 5904) ("length" . 5969) ("application /" . 4573) ("Style" . 3920) ("i <=" . 5661) ("equation }" . 5253) ("_1" . 4383) (":: x" . 2485) ("Length" . 3548) ("namely `" . 6212) ("task" . 7119) ("format (\"~" . 5441) ("></ td" . 2985) (":: cout" . 2478) ("title" . 7203) ("@ end" . 3016) ("packages" . 6417) ("= \"" . 2753) ("to previous" . 7213) ("equal" . 5249) (") <<" . 825) ("( e" . 543) ("). parent" . 963) ("fi" . 5360) ("found :" . 5448) ("NULL ," . 3670) ("File_Type ;" . 3350) (". Create" . 1483) (". csv" . 1597) ("\" class" . 62) ("app /" . 4566) ("end loop" . 5229) ("None =>" . 3699) ("flex" . 5395) (". Data" . 1484) ("[{:" . 4233) ("C )," . 3131) (":= '" . 2491) ("center }" . 4823) (", allocatable" . 1168) (") implicit" . 869) ("col" . 4879) ("ghc -" . 5529) ("newImage (\"" . 6245) ("aliased" . 4512) ("=\" xs" . 2873) (". 0" . 1436) ("0 Then" . 1923) ("#'" . 236) (": 16" . 2288) ("This" . 3993) ("6 ." . 2227) ("_FILES" . 4385) ("returns [" . 6746) ("event" . 5281) ("NativeMethodAccessorImpl" . 3682) ("ring" . 6751) (". len" . 1667) ("() <<" . 704) ("Database" . 3250) ("bson ." . 4745) (". Println" . 1521) ("<? php" . 2749) ("Clear" . 3185) ("public void" . 6591) ("String >" . 3913) ("= SKAction" . 2783) ("L1" . 3533) ("textbf {" . 7164) ("false ," . 5346) ("13 ." . 2056) ("Body" . 3110) ("Native Method" . 3681) ("forall" . 5428) ("physicsBody" . 6477) ("role" . 6755) ("=\" match_parent" . 2864) ("unsigned" . 7292) ("( setf" . 634) ("segue" . 6846) ("fi done" . 5361) ("Rect" . 3817) ("textColor" . 7159) ("inline -" . 5798) ("1 0" . 2000) ("s" . 6791) ("- tab" . 1369) (": \\" . 2345) ("actionpack" . 4462) ("xs )" . 7481))))
(defconst language-detection-index-to-languages (language-detection-alist-to-hashmap '((0 . ada) (1 . awk) (2 . c) (3 . clojure) (4 . cpp) (5 . csharp) (6 . css) (7 . dart) (8 . delphi) (9 . emacslisp) (10 . erlang) (11 . fortran) (12 . fsharp) (13 . go) (14 . groovy) (15 . haskell) (16 . html) (17 . java) (18 . javascript) (19 . json) (20 . latex) (21 . lisp) (22 . lua) (23 . matlab) (24 . objc) (25 . perl) (26 . php) (27 . prolog) (28 . python) (29 . r) (30 . ruby) (31 . rust) (32 . scala) (33 . shell) (34 . smalltalk) (35 . sql) (36 . swift) (37 . visualbasic) (38 . xml))))
(defconst language-detection-forest '([2849 5.96 [3660 0.0956 [5402 0.516 [1239 17.5 [6404 0.152 [5034 0.156 [3716 0.0986 [6178 0.477 [5725 1.82 [3297 0.343 [1078 47.9 [5219 1.66 [5236 0.325 [4189 0.211 [3687 2.04 [6859 0.829 [4832 0.118 [2616 0.0932 [569 0.657 [3929 0.588 [6767 3.32 [1600 0.23 [980 0.198 [5261 0.157 [978 0.467 [7734 0.475 [5472 0.666 [5040 2.88 [5972 4.72 [5730 0.0441 [4682 0.402 [7514 0.128 [3052 0.0939 [4207 0.174 [2704 0.152 [5047 0.666 [1403 0.125 [1391 0.962 [6063 0.495 [2951 10.7 [6380 2.42 [784 0.922 [5539 6.3 [3016 0.95 [3712 1.2 [2470 2.15 [877 0.524 [6530 2.78 [2848 0.55 [2106 2.04 [4519 0.821 [819 0.235 [538 0.808 [3262 1.78 [6581 4.15 [6471 0.335 [3708 2.45 [2461 1.1 [6809 0.918 [489 0.13 [4867 0.517 [5757 0.494 [2517 1.11 [1980 4.21 [811 1.8 [5105 1.33 [968 1.14 [7034 0.891 [1888 1.93 [1722 1.97 [2752 3.33 [305 0.485 [2488 0.642 [4114 11.6 [5776 2.96 [5893 0.384 [1645 2.22 [5360 0.233 [3292 8.46 [2048 9.29 [3003 0.645 [6578 7.8 [5214 0.846 [5938 1.03 [3849 3.45 [5225 0.864 [4282 8.56 [2453 20.7 [7318 2.77 [7615 0.945 [5467 6.07 [3073 1.51 [5122 2.1 [5403 1.74 [7311 3.6 [7512 0.541 [5566 0.301 [906 5.65 [217 7.56 [7415 2.99 [1 12] [33 89]] [6199 41.2 [19 79] [19 50]]] [373 1.83 [7428 13 [21 32] [29 23]] [21 100]]] [6342 10.7 [14 100] [14 95]]] [2526 11.9 [3896 0.464 [328 3.05 [178 9.74 [14 14] [25 49]] [2929 5.52 [14 17] [25 85]]] [3698 17.9 [32 66] [31 33]]] [2259 50.1 [2526 74.8 [1025 6.85 [4 22] [2 62]] [2 59]] [6 70]]]] [20 98]] [11 4.76 [31 62] [31 100]]] [30 95]] [26 78]] [12 72]] [3 75]] [3 92]] [24 78]] [3 67]] [7169 1.11 [6230 4.13 [6743 3.7 [30 65] [22 100]] [30 100]] [30 97]]] [35 75]] [328 5.05 [21 95] [9 50]]] [6445 1.2 [5716 2.16 [30 98] [30 100]] [30 100]]] [31 93]] [27 100]] [3027 53.3 [2628 0.177 [1 32] [26 13]] [15 33]]] [3675 19 [37 81] [37 61]]] [5617 2.57 [1899 5.64 [33 88] [33 77]] [33 66]]] [2701 2.52 [15 98] [15 100]]] [7373 8.72 [7065 1.51 [1577 0.747 [3317 1.56 [1673 6.67 [3597 7.26 [1745 9.14 [4684 2.74 [2259 34 [17 62] [17 30]] [17 45]] [17 100]] [19 66]] [16 42]] [17 89]] [14 90]] [7189 3.88 [1773 1.74 [2259 26.2 [17 80] [17 100]] [17 83]] [32 46]]] [38 41]]] [7241 13.6 [5442 8.2 [6342 2.09 [7512 16.1 [6216 2.24 [663 14.7 [221 4.05 [30 21] [5211 1.79 [30 65] [30 97]]] [32 44]] [30 100]] [6 16]] [16 18]] [30 100]] [30 45]]] [1400 7.04 [1233 3.64 [27 38] [27 100]] [10 62]]] [2550 1.81 [7512 4.83 [407 8.65 [4008 1.67 [4414 18.8 [4162 0.863 [3125 11.2 [1496 4.95 [145 3.23 [1719 5.71 [6235 3.31 [3069 21.7 [7619 22.2 [685 9.61 [663 13.7 [4011 13.5 [8 38] [8 76]] [663 19.2 [13 72] [13 94]]] [8 91]] [13 100]] [8 100]] [34 100]] [34 100]] [13 100]] [13 100]] [37 90]] [34 100]] [13 69]] [34 100]] [8 87]] [13 92]] [2550 17.2 [1429 27.9 [0 60] [0 100]] [8 78]]]] [395 0.485 [30 98] [30 100]]] [5462 1.7 [7722 3.86 [5023 3.41 [6601 1.69 [452 0.907 [6524 1.38 [2331 1.63 [5122 2.03 [3233 3 [1167 0.734 [2444 2.44 [5809 2.45 [5011 0.527 [7340 3.53 [6713 0.821 [3959 0.49 [2813 1.14 [2526 3.82 [2705 0.938 [7690 3.94 [5753 3.62 [4122 9.44 [756 1.14 [3464 4.33 [4556 3.94 [3041 4.52 [5282 0.617 [826 1.86 [3676 0.131 [28 7] [8 44]] [7433 1.42 [12 35] [12 100]]] [22 88]] [3953 5.83 [35 78] [35 45]]] [23 97]] [4414 3.5 [1429 55.4 [37 59] [3288 2.49 [37 84] [37 100]]] [23 42]]] [429 24.7 [30 98] [30 30]]] [27 72]] [3308 3.99 [6644 1.98 [4569 1.55 [5994 1.07 [5655 2.04 [1652 3.98 [7297 0.258 [5439 6.21 [28 26] [28 28]] [30 37]] [22 100]] [22 84]] [29 88]] [28 97]] [28 96]] [29 52]]] [2752 43.3 [3905 15.3 [14 58] [14 100]] [14 41]]] [29 100]] [5130 0.435 [4286 27.1 [6265 6.49 [610 1.5 [2758 19.4 [5360 1.29 [4154 11.8 [2529 6.37 [2615 8.47 [5413 4.57 [384 2.59 [5 11] [23 42]] [17 16]] [8 100]] [25 61]] [1919 6.38 [7623 4.81 [7382 5.49 [24 24] [24 87]] [27 75]] [1073 5.15 [2 25] [5 24]]]] [33 100]] [4 59]] [5 93]] [24 100]] [27 100]] [18 42]]] [18 33]] [2813 0.544 [29 83] [29 100]]] [30 64]] [112 2 [3873 1.81 [5480 1.95 [6871 0.901 [567 10 [1783 4.93 [5871 4.2 [4669 3.27 [5412 10.1 [2913 3.07 [32 70] [2902 6.8 [2752 14.3 [32 90] [7449 37.5 [32 100] [32 85]]] [32 71]]] [4154 15 [32 90] [32 100]]] [32 100]] [12 100]] [32 63]] [32 44]] [12 81]] [18 41]] [32 90]] [695 15.2 [3895 2.67 [5732 2.79 [7340 10.4 [32 79] [4170 1.1 [5753 11.9 [1783 1.96 [32 96] [32 100]] [32 77]] [32 100]]] [32 80]] [32 100]] [32 66]]]] [1429 41.8 [6215 0.27 [126 0.826 [1913 0.847 [29 67] [29 100]] [29 100]] [939 2 [29 80] [29 100]]] [29 27]]] [15 85]] [15 95]] [29 100]] [35 86]] [6230 1.24 [3342 1.61 [30 93] [30 100]] [30 100]]] [32 61]] [7252 1.58 [4205 0.792 [1062 3.86 [6604 4 [6184 4.37 [4879 2.47 [377 2.74 [3278 4.24 [1899 3.3 [857 1.44 [80 2.68 [826 9.05 [7182 7.27 [6406 10.6 [2701 1.75 [2808 3.5 [22 37] [15 100]] [29 54]] [28 53]] [22 100]] [25 73]] [22 100]] [22 100]] [3333 1.08 [4279 7.62 [6457 1.73 [2259 14.3 [11 23] [7 41]] [25 100]] [7 27]] [1 100]]] [1 90]] [2830 2.37 [6031 3.7 [28 75] [22 100]] [28 83]]] [29 77]] [695 1.77 [6182 6.02 [25 65] [25 100]] [28 38]]] [30 100]] [145 1.45 [1429 8.28 [28 29] [7665 2.06 [28 80] [29 44]]] [28 37]]] [28 69]] [28 100]]] [37 100]] [15 100]] [35 75]] [4799 2.59 [6866 2.06 [204 7.6 [3917 1.98 [1899 1.13 [6959 10.2 [602 7.05 [957 5.12 [7739 3.65 [2526 2.39 [5692 5.66 [2752 8.62 [14 25] [6310 2.33 [14 63] [14 85]]] [5753 1.27 [7241 6.02 [899 2.99 [1239 2.99 [7354 3.4 [14 23] [18 33]] [24 45]] [14 60]] [14 54]] [896 2.39 [29 87] [14 35]]]] [14 18]] [14 50]] [18 53]] [7 55]] [14 88]] [23 4.09 [5692 9.5 [144 3.85 [32 14] [2 64]] [24 40]] [573 2.96 [4253 1.68 [14 28] [25 80]] [4 75]]]] [791 2.15 [6199 20.6 [14 80] [14 100]] [14 100]]] [22 69]] [5 100]] [23 32.2 [32 96] [32 80]]]] [5680 3.27 [6310 0.342 [7081 1.45 [3694 3.43 [1686 2.19 [3475 4.7 [2786 1.05 [850 1.77 [3041 2.58 [1676 6.38 [7301 1.49 [2760 4.07 [4158 1.25 [7411 3.21 [6848 3.18 [7255 5.86 [248 16.4 [7354 0.986 [5110 1.86 [7168 2.93 [3867 11.2 [2701 2.82 [2764 0.994 [774 1.02 [394 2.18 [2199 0.921 [2268 1.02 [5211 0.873 [28 55] [22 33]] [16 83]] [28 23]] [28 82]] [28 100]] [35 50]] [29 85]] [35 75]] [29 30]] [30 50]] [10 18]] [26 68]] [12 29]] [35 42]] [35 60]] [28 66]] [5 51]] [28 70]] [35 76]] [35 85]] [35 78]] [29 100]] [15 100]] [28 82]] [5412 10.3 [33 50] [15 100]]] [28 86]] [35 71]] [35 65]]]] [5447 1.09 [4154 33.5 [7330 14.7 [6791 0.998 [4663 10.3 [6830 22.3 [2892 1.82 [33 90] [33 100]] [33 83]] [33 66]] [33 66]] [33 63]] [33 70]] [33 97]]] [7382 2.49 [5480 1.8 [4799 2.77 [5260 2.39 [1627 2.65 [2493 1.33 [7325 4.79 [5812 7.25 [5961 2.62 [7287 0.743 [1674 1.75 [673 2.7 [2824 2.01 [5108 0.84 [7032 3.65 [2795 1.68 [3313 3.31 [6569 6.31 [2826 2.25 [7722 2.81 [312 13 [499 4.67 [4198 2.5 [7623 13 [7512 3.51 [4338 6.14 [2536 1.49 [2257 0.668 [5467 2.2 [3130 8.6 [3931 19.5 [32 9] [12 75]] [1 46]] [12 92]] [1 70]] [178 1.19 [8 28] [4 36]]] [24 69]] [1630 2.04 [1429 27.1 [4338 12.8 [286 3.46 [695 14.3 [145 14.5 [36 14] [13 33]] [13 27]] [2 33]] [24 84]] [7520 43 [362 2.94 [5316 1.77 [2939 4.12 [14 20] [5 50]] [32 88]] [25 42]] [36 60]]] [32 66]]] [12 39]] [19 83]] [27 100]] [4 41]] [7381 6.96 [7255 5.6 [906 5.71 [14 46] [5 57]] [18 50]] [14 32]]] [14 25]] [14 83]] [6866 14.4 [5 66] [5 100]]] [24 100]] [2 28]] [12 94]] [12 100]] [26 80]] [32 75]] [12 100]] [32 100]] [7381 22.9 [2 26] [4 87]]] [5 85]] [13 92]] [32 94]] [13 97]] [4369 1.54 [7076 3.18 [3095 1.99 [5851 6.25 [899 6.89 [32 77] [32 66]] [13 25]] [32 83]] [2 28]] [32 100]]] [6044 2.09 [1062 5.13 [5641 2.13 [6342 20 [7354 1.47 [18 38] [2259 5.71 [18 80] [18 54]]] [22 50]] [18 91]] [18 77]] [18 100]]] [5871 2.59 [791 9.04 [24 50] [24 83]] [24 85]]]] [7742 2.33 [2259 36.1 [888 0.891 [214 4.59 [7620 3.39 [4224 4.95 [7343 11.1 [13 95] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 85]] [2 100]]] [6681 0.296 [1471 2.24 [1084 0.473 [4895 0.32 [5333 1.65 [5686 2.76 [4719 2.76 [1400 4.19 [392 0.289 [5999 7.2 [6134 2.72 [7512 5.13 [6154 14.3 [695 1.06 [5824 4.59 [2316 9.52 [4235 18.3 [429 12.9 [7330 1.02 [5386 1.78 [11 21] [19 37]] [11 44]] [2259 7.58 [7665 1.19 [28 63] [28 40]] [2048 4.35 [8 24] [12 33]]]] [12 21]] [8 100]] [8 100]] [4012 1.06 [28 77] [28 62]]] [28 100]] [9 15]] [30 91]] [6027 1.55 [4784 1.73 [30 26] [28 100]] [28 100]]] [7428 6.13 [28 86] [28 55]]] [12 56]] [8 91]] [8 70]] [11 100]] [19 35]] [28 100]] [28 100]] [7084 0.547 [1256 14.7 [7210 0.754 [221 0.526 [19 50] [6074 1.28 [38 100] [38 77]]] [17 72]] [38 85]] [2137 0.312 [4639 2.66 [1239 16 [1659 9.91 [35 75] [4089 0.645 [1796 15 [6681 1.44 [19 66] [19 71]] [6358 0.291 [35 43] [17 62]]] [17 60]]] [19 72]] [17 85]] [19 62]]]]] [7301 0.498 [4013 0.206 [4205 1.57 [354 42.2 [1783 2.92 [28 98] [28 100]] [28 70]] [28 100]] [28 100]] [28 100]]] [3874 2.11 [663 0.522 [5441 1.08 [7480 0.528 [6857 3.88 [7452 2.82 [2267 2.51 [682 2.79 [4398 2.56 [7434 1.44 [4451 7.3 [248 3.95 [1407 3.95 [6621 0.963 [1888 3.27 [3902 5.88 [957 1.49 [1429 42.2 [6791 1.07 [1170 6.49 [350 3.6 [2637 9.71 [5225 1.54 [10 56] [10 100]] [31 100]] [12 87]] [31 73]] [10 50]] [18 27]] [2744 1.59 [1429 20 [2752 9.84 [10 51] [10 90]] [19 40]] [10 100]]] [10 100]] [36 53]] [10 66]] [31 100]] [15 41]] [12 100]] [12 100]] [15 63]] [31 100]] [31 100]] [31 70]] [31 100]] [15 100]] [10 100]] [4262 0.904 [4319 1.1 [5440 1.83 [4799 1.74 [131 1.23 [5211 1.37 [10 33] [10 90]] [10 71]] [10 75]] [10 100]] [10 100]] [10 100]]] [12 100]]] [6668 0.358 [3635 1.2 [7103 1.71 [3576 1.3 [1888 1.55 [4398 2.63 [7411 3.46 [5225 0.447 [2819 0.595 [2921 0.256 [4770 0.218 [5732 1.75 [2008 0.668 [6524 3.56 [2802 0.571 [2939 0.323 [2001 0.588 [2562 1.63 [3332 0.603 [906 13.5 [2764 0.361 [6899 2.31 [2488 5.22 [5482 2.61 [6506 0.64 [2913 2.19 [5170 1.73 [4280 4.42 [2706 1.17 [2701 4.98 [392 2.49 [2523 0.623 [6946 1.81 [4743 2.78 [155 19 [6124 2.07 [1 12] [12 82]] [19 43]] [1459 3.7 [7 81] [7 100]]] [10 93]] [24 56]] [5211 1.11 [1101 8.86 [2093 13.1 [248 1.63 [4067 0.0669 [28 24] [35 88]] [13 20]] [27 40]] [23 71]] [2241 2.37 [7169 0.885 [355 3.08 [2081 8.67 [22 35] [23 54]] [30 44]] [30 62]] [36 42]]]] [791 0.317 [248 4.13 [1068 7.36 [29 41] [1 33]] [29 83]] [4326 4.6 [6699 1.08 [29 74] [29 92]] [15 60]]]] [29 100]] [2011 2.35 [29 40] [29 98]]] [5170 31.9 [5174 13.5 [4663 3.61 [5368 19.1 [6653 1.39 [7640 4.95 [5176 14.9 [6184 0.497 [1062 1.12 [33 59] [33 100]] [33 90]] [26 66]] [1 80]] [6653 7.31 [33 90] [33 95]]] [33 50]] [33 100]] [26 50]] [33 87]]] [2919 2.15 [2925 2.85 [939 1.12 [2913 69.7 [2161 0.0805 [5480 8.35 [899 2.54 [1997 11.3 [1980 22.9 [4290 8.13 [32 20] [26 90]] [774 5.38 [3 54] [3 90]]] [30 62]] [32 88]] [32 55]] [30 80]] [26 51]] [32 72]] [26 95]] [26 47]]] [7 100]] [7062 2.09 [4154 12.2 [1186 1.63 [29 69] [29 100]] [29 90]] [29 100]]] [3424 3.7 [2093 3.07 [34 26] [2259 14.3 [32 94] [34 83]]] [8 100]]] [1769 1.42 [33 87] [10 28]]] [726 3.43 [5170 9.18 [844 0.137 [5247 0.494 [248 2.78 [6363 1.62 [1755 2.79 [1095 5.24 [6340 2.76 [3237 0.953 [2259 0.115 [2099 6.23 [7512 1.82 [5211 0.879 [6031 1.08 [23 20] [22 90]] [11 65]] [22 17]] [23 80]] [2004 1.77 [7287 6.02 [438 1.36 [2167 0.298 [22 10] [1 85]] [23 66]] [11 71]] [1192 4.71 [2275 13.7 [23 70] [1 66]] [11 71]]]] [11 100]] [28 100]] [22 62]] [22 95]] [1068 1.29 [377 1.81 [11 77] [11 100]] [11 62]]] [5753 3.47 [4611 1.24 [2143 7.16 [1 24] [25 50]] [29 90]] [1 81]]] [11 100]] [2039 0.176 [4095 0.471 [11 94] [11 100]] [11 100]]] [107 2.39 [5171 2.82 [33 75] [33 63]] [33 100]]] [29 88]]] [906 24.6 [5140 1.49 [5526 3.82 [567 2.56 [688 2.53 [21 25] [21 54]] [11 36]] [29 100]] [33 100]] [5647 21.7 [939 6.33 [21 61] [12 45]] [23 40]]]] [112 0.921 [2199 0.603 [3438 4.48 [3008 15.9 [1031 3.4 [35 69] [35 70]] [35 60]] [35 83]] [35 80]] [30 42]]] [1025 5.48 [23 68] [23 100]]] [1454 6.21 [2537 2.12 [1916 10.7 [5011 0.34 [5673 9.2 [2931 3.41 [4154 2.07 [7449 0.65 [3227 3.76 [3160 6.33 [2179 4.77 [221 17.7 [5568 2.26 [3027 5.88 [2153 6.89 [1 17] [29 52]] [29 44]] [29 100]] [1 42]] [21 83]] [27 100]] [29 83]] [29 62]] [23 41]] [23 100]] [35 56]] [29 100]] [23 37]] [23 100]] [29 42]]] [2002 2.56 [957 2.11 [1237 1.23 [4231 1.41 [4280 0.727 [5914 0.52 [3959 1.4 [4159 11.5 [2628 0.207 [2225 1.23 [728 3.55 [1068 0.982 [2081 36.2 [3794 2.82 [7171 2.79 [1062 6.82 [1078 14.6 [1846 1.61 [7627 1.17 [7314 10 [29 11] [3 90]] [35 85]] [33 70]] [4114 4.76 [2913 2.7 [2232 1.8 [29 20] [11 62]] [30 40]] [10 77]]] [29 36]] [29 86]] [29 81]] [2944 7.77 [29 22] [21 100]]] [5412 0.982 [11 29] [11 33]]] [10 80]] [7449 9.97 [2227 2.62 [4768 0.516 [1239 5.26 [29 63] [1783 1.81 [2232 0.392 [3 35] [29 71]] [15 22]]] [1 42]] [29 29]] [14 33]]] [144 4 [429 55.6 [5267 17 [1922 1.77 [222 0.898 [2726 0.273 [1400 4.54 [5056 0.69 [7472 4.91 [2132 0.975 [5692 0.792 [25 8] [33 28]] [35 30]] [38 90]] [7 100]] [12 75]] [18 54]] [11 53]] [10 75]] [15 50]] [23 72]] [1436 2.54 [30 35] [10 54]]]] [2225 1.3 [29 69] [29 90]]] [29 100]] [11 73]] [29 98]] [5917 0.445 [10 90] [10 100]]] [29 100]] [2913 4.67 [5412 3.45 [2764 3.23 [4279 1.64 [1094 2.81 [2143 0.363 [2939 16.3 [10 44] [10 89]] [10 96]] [10 66]] [1980 20.5 [10 100] [14 25]]] [10 33]] [20 33]] [10 35]]] [907 3.45 [1025 6.17 [2701 2.46 [2154 4.01 [21 39] [29 88]] [29 100]] [21 87]] [21 100]]]] [1913 3.46 [4326 0.597 [2806 0.78 [29 81] [29 100]] [29 54]] [29 95]]] [5121 8.17 [4704 3.61 [7528 1.08 [6532 1.87 [5692 4.85 [6182 1.36 [4158 5.78 [248 4.07 [3227 1.87 [4424 3.69 [915 4.68 [2764 7.35 [3931 1.94 [7683 2.2 [7251 0.544 [22 29] [28 100]] [1 90]] [1 71]] [22 56]] [21 55]] [22 68]] [29 50]] [1 60]] [1899 19.9 [28 66] [25 50]]] [25 100]] [6524 6.03 [5692 7.69 [1 100] [1 88]] [2796 3.11 [6949 7.65 [7640 1.24 [5413 2.86 [4533 1.79 [1906 1.11 [6189 3.07 [1 45] [25 100]] [1 40]] [28 62]] [1 70]] [1 58]] [1 80]] [28 100]]]] [11 100]] [4414 7.03 [1 100] [1 66]]] [791 2.02 [1 59] [791 13.9 [1 90] [1 61]]]] [22 76]]] [7169 0.901 [4592 0.978 [7139 4.13 [11 100] [11 90]] [11 100]] [11 71]]] [7251 4.29 [7340 3.98 [1101 8.38 [1106 0.846 [7210 11.4 [5574 0.797 [2232 4.63 [248 1.66 [435 10.9 [5753 4.5 [3130 6.53 [5967 4.07 [1783 19.1 [4611 12 [28 80] [28 40]] [28 63]] [28 50]] [28 75]] [4154 1.39 [6643 2.25 [429 24.8 [28 100] [28 83]] [28 75]] [28 100]]] [28 44]] [15 40]] [28 53]] [28 100]] [14 60]] [28 100]] [28 55]] [32 100]] [28 100]]] [2077 0.328 [221 1.97 [1094 1.08 [1913 2.27 [1986 2.79 [29 100] [29 90]] [29 100]] [29 100]] [29 100]] [29 100]]] [2064 0.821 [4279 60 [26 75] [26 95]] [26 100]]] [429 14.6 [28 37] [235 0.952 [5013 0.595 [939 0.728 [28 50] [29 96]] [29 100]] [29 80]]]] [6031 0.585 [2354 1.39 [7449 12.8 [5393 5.75 [6322 2.1 [5422 7.16 [4004 1.5 [2407 1.01 [1899 12.3 [5420 0.686 [1062 4.23 [939 2.16 [429 16 [756 1.35 [2752 31.2 [30 100] [8 33]] [30 100]] [1429 5.85 [22 62] [22 61]]] [10 60]] [5412 0.952 [5211 36.9 [22 89] [22 60]] [22 50]]] [864 2.26 [23 54] [23 90]]] [2562 1.33 [23 44] [23 100]]] [23 100]] [8 100]] [22 71]] [23 100]] [30 62]] [23 76]] [22 100]] [22 94]]] [5851 8.09 [4424 4.94 [23 3.27 [2759 1.13 [2004 3.4 [6883 2.28 [4218 1.51 [5673 10 [5812 3.37 [4533 5.43 [35 40] [35 70]] [35 85]] [6353 6.91 [35 92] [35 85]]] [15 66]] [35 95]] [15 50]] [35 90]] [15 24]] [15 88]] [11 53]]] [1710 0.531 [345 2.07 [4596 0.837 [7085 2.73 [2975 15.9 [1998 1.55 [2005 8.55 [5480 2.65 [2100 1.58 [4399 4.41 [33 23] [35 100]] [30 63]] [6342 3.06 [11 35] [11 75]]] [35 87]] [15 75]] [4549 17 [31 66] [31 100]]] [15 84]] [15 100]] [15 100]] [2253 0.39 [6636 1.34 [221 0.257 [435 0.837 [5500 9.02 [30 100] [30 83]] [30 100]] [30 100]] [30 75]] [30 100]]]] [2105 10.3 [2636 4.12 [1400 28.1 [3480 2.22 [791 9.93 [1981 1.31 [4768 4.31 [7722 7.6 [5480 3.14 [7340 1.59 [5274 2.33 [2763 4.22 [6205 2.11 [392 0.864 [7009 3.45 [248 7.12 [4 11] [26 73]] [5 75]] [18 38]] [18 33]] [7169 4.2 [2 40] [5 28]]] [2 55]] [32 87]] [2259 10.6 [18 52] [18 66]]] [14 21]] [25 45]] [14 52]] [906 3.63 [4424 5.49 [1429 23.7 [4338 9.81 [7381 10.5 [7210 11.5 [2 15] [8 37]] [7 44]] [2 66]] [2536 3.14 [32 30] [7 27]]] [13 33]] [435 1.66 [32 50] [32 100]]]] [32 73]] [12 54]] [14 63]] [14 63]]] [1452 9.53 [4291 0.921 [15 64] [15 100]] [15 53]]] [1783 1.25 [1078 35.1 [22 98] [22 85]] [22 66]]] [250 4.22 [6342 1.31 [5693 10.9 [248 11.9 [1 96] [1 100]] [1 88]] [1 55]] [1 90]]] [429 33.9 [2178 13 [4006 5.13 [6668 4.59 [28 100] [28 71]] [28 100]] [28 66]] [28 41]]]] [3659 1.71 [1240 2.85 [1701 1.11 [6338 2.71 [5698 17.2 [2902 3.45 [3026 39.5 [6333 3.31 [24 87] [24 95]] [19 60]] [24 100]] [24 62]] [24 58]] [24 100]] [24 100]] [24 77]]] [2004 0.424 [5480 6.13 [33 19] [0 50]] [2752 11.9 [29 100] [3325 0.212 [5693 5.61 [29 100] [29 83]] [29 100]]]]] [4312 1.32 [4968 0.284 [5673 0.678 [3 100] [3 87]] [3 100]] [3 100]]] [489 11.2 [791 2.27 [35 44] [35 78]] [4956 4.75 [3045 14.7 [429 26.8 [35 100] [35 97]] [35 93]] [35 77]]]] [3715 2.18 [7600 2.87 [6943 0.996 [6199 2.86 [6717 0.512 [2776 9.54 [32 100] [32 94]] [32 100]] [32 100]] [32 83]] [6811 1.93 [32 100] [32 91]]] [32 75]]] [7638 0.635 [2100 2.46 [2251 0.626 [4279 4.54 [1082 0.678 [5799 2.62 [5891 4.13 [7512 17.5 [7623 2.24 [6184 3.07 [7441 3.14 [27 77] [27 100]] [27 100]] [27 96]] [15 28]] [3 100]] [27 100]] [27 100]] [28 35]] [2 40]] [27 57]] [27 100]]] [333 9.13 [7665 5.62 [3505 1.61 [3538 9.59 [3849 2.1 [35 74] [328 9 [5680 8.48 [3095 21.9 [2770 8.69 [2526 3.2 [2199 0.501 [3045 30.1 [35 85] [35 55]] [35 100]] [35 100]] [35 55]] [35 62]] [35 85]] [333 0.556 [4154 1.6 [1429 84.4 [35 100] [35 80]] [35 80]] [35 100]]]] [2759 10.4 [328 15.9 [35 100] [35 66]] [35 80]]] [35 62]] [22 23]] [8 42]]] [7176 3.72 [5904 1.21 [248 8.34 [5641 15.2 [7301 4.3 [6749 0.204 [2248 2.33 [1445 0.84 [5898 2.82 [7329 13.8 [2963 4.98 [6471 3.91 [26 28] [5480 8.93 [4601 2.24 [2956 2.18 [3027 2.86 [6342 8.71 [6363 6.69 [2943 1.54 [1999 0.611 [3340 0.882 [2939 5.87 [5753 7.25 [26 79] [26 96]] [1576 4.27 [26 45] [26 100]]] [26 100]] [26 100]] [16 33]] [26 71]] [33 50]] [26 100]] [26 40]] [26 42]] [26 74]]] [16 66]] [26 62]] [19 37]] [26 33]] [2248 5.86 [26 42] [26 62]]] [16 40]] [16 26]] [26 25]] [208 12 [6727 3.09 [673 3.58 [7241 2.67 [26 90] [26 62]] [421 1.31 [7681 5.08 [26 97] [791 11.5 [26 86] [26 100]]] [26 100]]] [26 66]] [26 66]]] [19 71]] [33 70]]] [681 6.37 [6883 4.94 [5383 1.16 [2331 7.85 [6443 1.45 [673 2.54 [7270 6.38 [7187 2.94 [4602 0.524 [4200 3.87 [6554 2.79 [2793 3.07 [2398 2.09 [7682 2.54 [610 4.82 [7526 2.04 [5316 5.06 [1025 7.47 [3969 4.59 [2959 2.73 [5941 3.13 [6776 5.44 [3905 3.66 [2536 25.5 [695 7.92 [6572 2.11 [6980 1.44 [7411 2.16 [899 5.56 [7185 12.7 [7766 5.88 [6230 0.761 [4279 11.6 [7381 2.37 [7380 3.54 [7568 5.15 [221 9.56 [4851 14 [5 14] [7343 7.25 [5 30] [12 37]]] [30 38]] [4 66]] [4 71]] [791 38.5 [3095 6.49 [6550 3.5 [17 32] [17 71]] [4 57]] [5 56]]] [5 43]] [5 20]] [4 100]] [6581 13.7 [17 50] [5 54]]] [14 75]] [5 75]] [5 41]] [8 84]] [5480 24.9 [3437 3.7 [3476 4.59 [7535 3.98 [141 18.4 [5 34] [5 83]] [5 53]] [5 47]] [5 75]] [26 77]]] [4 55]] [163 6.51 [6230 21.6 [6584 4.72 [2628 7.55 [7214 6.02 [17 40] [17 57]] [5 21]] [17 51]] [6230 27.8 [17 78] [17 60]]] [19 66]]] [17 80]] [3 69]] [4 100]] [5 93]] [6581 13.2 [17 50] [4 76]]] [144 11.9 [17 58] [14 45]]] [2628 9.96 [1888 17.6 [2628 2.07 [17 76] [17 62]] [17 45]] [6581 20.2 [17 75] [19 64]]]] [6581 18.8 [5 100] [5 83]]] [17 83]] [178 2.89 [2536 2.09 [4 82] [4 88]] [4 66]]] [14 80]] [17 53]] [5 66]] [26 81]] [7722 16.9 [738 3.76 [6585 9.16 [26 77] [7590 2.26 [26 83] [26 100]]] [26 100]] [26 66]]] [5 79]] [4235 1.02 [791 1.89 [26 52] [26 96]] [26 91]]] [5 88]] [36 86]] [17 40]] [429 4.5 [5 65] [5 45]]] [7185 21.9 [26 100] [26 88]]]] [2694 0.901 [4895 4.68 [4770 2.17 [3691 0.622 [567 9.45 [3359 9.69 [7502 1.31 [3190 2.36 [312 44.1 [3602 5.17 [3724 3.64 [5851 10.3 [807 6.13 [3158 3.83 [3125 6.86 [3715 5.76 [49 8.95 [4369 9.38 [1783 0.463 [3159 2.01 [1546 4.61 [1485 2.51 [23 66.2 [2143 0.904 [116 2.92 [1899 18.5 [37 94] [37 90]] [37 100]] [37 100]] [37 88]] [37 100]] [37 100]] [37 83]] [37 100]] [37 100]] [3912 19.1 [37 88] [37 100]]] [37 73]] [37 83]] [37 86]] [37 60]] [37 88]] [37 46]] [37 80]] [37 80]] [3292 2.82 [37 60] [35 37]]] [37 83]] [37 50]] [37 60]] [1101 0.311 [4073 1.33 [3292 4.29 [939 0.928 [37 93] [37 100]] [37 82]] [16 77]] [37 50]]] [29 100]] [37 66]] [16 50]]] [2207 1.56 [5969 4.48 [2225 8.07 [743 37.2 [5480 4.73 [506 1.35 [7086 5.88 [688 7.39 [6132 6.17 [21 82] [9 100]] [21 100]] [21 100]] [21 100]] [21 60]] [9 100]] [21 100]] [21 68]] [21 62]]] [4125 4.78 [27 100] [27 87]]] [896 4.95 [4216 17.3 [4357 8.49 [1738 1.67 [4145 17.9 [774 9.82 [4571 4 [6294 1.31 [7301 7.01 [4279 12.7 [5753 0.544 [24 93] [24 100]] [2752 56.1 [24 98] [24 93]]] [24 85]] [24 100]] [24 90]] [24 87]] [24 77]] [24 100]] [24 57]] [24 90]] [1389 1.59 [1899 2.86 [7665 5.93 [24 57] [24 100]] [2902 2.66 [24 55] [24 66]]] [24 83]]]] [2206 28.3 [35 61] [16 21]]] [12 96]] [731 8.03 [7665 4.82 [968 1.39 [4530 0.59 [2259 3.69 [5227 1.29 [2902 24.7 [5121 7.23 [7210 12.5 [6529 1.01 [2081 6.96 [22 87] [22 85]] [112 8.64 [22 94] [22 83]]] [22 71]] [22 100]] [22 62]] [22 100]] [3302 6.43 [328 0.668 [5211 1.74 [28 45] [22 100]] [28 90]] [28 85]]] [28 62]] [28 100]] [125 2.16 [7731 4.24 [5005 3.7 [7 37] [7 100]] [7 36]] [36 76]]] [7 89]]] [5999 1.43 [5282 0.352 [2011 0.885 [6185 3.29 [22 100] [22 77]] [22 100]] [22 100]] [5692 5.26 [22 66] [22 100]]]] [2617 1.66 [3452 0.464 [4404 0.867 [4959 0.914 [2526 3.75 [6661 0.944 [3484 0.608 [4964 0.286 [4838 1.74 [2259 6.35 [4414 16.8 [1405 2.07 [5231 0.31 [4781 2.48 [5211 1.33 [3273 0.763 [4154 1.82 [248 6.85 [4521 2.42 [685 4.57 [7585 4.27 [112 6.41 [527 0.745 [1980 6.73 [6230 8.8 [2752 3.66 [15 23] [3304 1.43 [3586 2.82 [5065 1.58 [2470 34.9 [2753 7.75 [7451 8.68 [6068 8.83 [6732 7.6 [5732 2.46 [15 69] [15 100]] [15 91]] [15 100]] [15 100]] [15 62]] [15 68]] [15 100]] [15 100]] [15 100]]] [1429 15 [4 79] [30 65]]] [1025 6.17 [1062 9.03 [11 26] [15 66]] [15 61]]] [4 95]] [1980 5.62 [15 24] [11 55]]] [31 100]] [1899 0.743 [26 52] [25 85]]] [11 100]] [3243 2.15 [1081 0.921 [5198 1.51 [2473 2.67 [276 4.59 [3701 2.44 [6471 1.43 [7185 1.39 [5429 3.51 [2755 2.7 [719 4 [15 53] [26 100]] [26 100]] [26 100]] [26 82]] [26 72]] [15 100]] [15 100]] [15 100]] [26 100]] [26 87]] [15 100]]] [15 73]] [3139 2.48 [3860 0.763 [11 94] [11 100]] [11 100]]] [570 1.23 [3105 3.18 [6031 3.27 [5110 5.12 [11 71] [30 65]] [30 62]] [30 80]] [11 100]]] [1062 2.09 [11 75] [11 100]]] [11 100]] [15 100]] [7623 0.968 [5824 5.29 [1411 1.46 [1218 0.707 [15 88] [15 72]] [7512 1.47 [248 1.67 [4369 6.33 [4414 101 [15 100] [15 97]] [15 100]] [15 100]] [15 100]]] [11 100]] [7176 1.39 [2764 3.16 [1407 0.635 [4206 3.18 [2752 11.6 [15 83] [15 100]] [15 100]] [15 100]] [15 85]] [15 100]]]] [5254 1.12 [312 2.12 [6578 1.29 [5313 0.721 [5829 3.31 [3069 2.47 [2912 1.19 [5110 1.08 [4218 0.924 [2637 3.4 [6713 0.278 [1055 5.8 [2259 32.3 [504 1.44 [7381 4.09 [3905 5.12 [2394 1.25 [6230 3.23 [5447 8.13 [4398 27.6 [1795 0.149 [7742 6.07 [7451 7.56 [3308 0.843 [6566 6.68 [2199 1.33 [6103 5.15 [3703 5.38 [660 3.66 [7766 5.33 [5270 2.5 [5812 6.41 [7428 0.283 [820 0.756 [15 33] [11 80]] [7169 4.75 [26 28] [25 70]]] [4 55]] [24 27]] [10 75]] [15 76]] [15 100]] [32 66]] [30 38]] [11 100]] [29 30]] [15 90]] [4 100]] [25 100]] [31 57]] [31 94]] [663 3.31 [30 62] [30 77]]] [30 85]] [4279 14.9 [15 75] [15 54]]] [4 75]] [15 86]] [1710 2.33 [2128 0.374 [1078 5.71 [2074 3.24 [4414 18.4 [1025 38.1 [6582 5.52 [2132 8.24 [7314 2.97 [6276 0.438 [30 24] [25 50]] [3 50]] [33 50]] [4 100]] [7085 20 [15 72] [15 100]]] [15 88]] [1 66]] [30 54]] [24 27]] [30 100]]] [11 100]] [30 82]] [31 88]] [7451 0.967 [15 93] [15 100]]] [5345 1.59 [3811 1.25 [1429 7.98 [15 55] [30 77]] [30 100]] [30 100]]] [10 100]] [30 96]] [11 100]] [15 100]] [31 100]] [429 28 [31 69] [4 45]]] [10 100]]] [11 89]] [1640 1.91 [5812 1.88 [6342 0.544 [4 94] [4 66]] [4 100]] [4 81]]] [15 100]] [11 100]] [811 1.09 [6077 3.31 [4851 1.03 [2739 2.67 [6581 0.719 [5812 1.37 [695 2.2 [1813 2.59 [25 28] [25 100]] [2526 12.4 [31 38] [4 52]]] [7210 2.2 [4 90] [4 100]]] [4 66]] [4 100]] [4154 5.39 [4 56] [4 100]]] [2752 1.86 [31 88] [31 77]]] [688 1.09 [2966 2.26 [7722 6.44 [31 80] [15 75]] [31 100]] [31 100]]]] [1888 7.09 [4 100] [4 90]]] [31 100]] [5655 0.154 [6184 0.27 [3747 0.566 [392 0.697 [3456 0.576 [1911 0.464 [11 94] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]]] [4 98]]] [3850 3.14 [5753 1.37 [6184 7.19 [3332 1.91 [35 73] [3230 1.17 [112 2.26 [3571 0.396 [3708 1.88 [4768 10.9 [2081 5.74 [35 85] [35 63]] [35 81]] [4401 17.5 [3272 1.18 [3448 14.8 [5680 1.2 [35 97] [35 100]] [35 83]] [35 100]] [35 91]]] [35 100]] [3388 1.71 [30 57] [37 42]]] [35 100]]] [22 37]] [1025 1.41 [2526 2.65 [22 28] [35 72]] [35 80]]] [35 92]]] [2958 10.4 [5753 0.618 [5211 30.1 [3019 8.7 [24 99] [840 11.1 [24 100] [24 66]]] [5220 7.94 [24 92] [24 75]]] [24 100]] [6284 17.8 [24 93] [24 82]]]] [6621 2.15 [5833 1.88 [5309 1.69 [896 4 [1899 12.7 [2470 3.94 [2178 15.4 [6429 0.0514 [6077 1.25 [4895 0.832 [2488 25.9 [6960 2.21 [4557 6.3 [2232 1.11 [1634 1.63 [4663 1.98 [4851 4.5 [13 53] [17 44]] [27 33]] [5270 4.35 [13 99] [13 83]]] [13 66]] [13 41]] [13 100]] [13 55]] [4235 17 [13 90] [13 100]]] [13 100]] [13 100]] [13 62]] [15 66]] [13 29]] [5 44]] [13 100]] [13 100]] [15 66]]] [939 2.9 [811 3.39 [27 83] [10 92]] [27 97]]] [6938 0.155 [4877 0.767 [6681 0.475 [5824 2.72 [203 0.576 [1833 1.11 [2488 0.849 [4862 0.945 [4369 0.62 [6381 5.73 [1638 0.124 [7445 2.22 [3899 0.226 [1997 4.73 [4183 1.78 [4764 1.15 [3008 20.6 [1642 0.878 [6650 2.02 [5552 5.62 [1727 1.08 [695 6.96 [4639 0.224 [5564 0.356 [1662 1.09 [5180 20.1 [5270 6.02 [2846 8.21 [1429 66.5 [6775 1.56 [5544 2.23 [6342 5.86 [5509 5.08 [4063 1.68 [32 9] [28 42]] [3 50]] [7 38]] [13 100]] [30 100]] [6880 5.54 [5839 0.254 [2521 0.203 [4640 20 [4640 7.68 [17 22] [1673 0.184 [38 38] [17 60]]] [14 44]] [17 28]] [17 63]] [17 50]]] [14 72]] [32 68]] [17 91]] [19 95]] [14 92]] [2219 0.43 [4803 2.02 [5892 8.27 [2259 28.3 [19 55] [32 50]] [17 68]] [17 66]] [17 33]]] [6380 7.32 [14 73] [14 36]]] [32 81]] [4279 9.02 [2259 9.1 [14 100] [14 66]] [14 70]]] [32 90]] [14 59]] [17 84]] [1678 2.25 [6383 2.22 [17 64] [14 43]] [17 47]]] [32 100]] [5637 5.26 [6380 16.7 [32 43] [14 48]] [3 35]]] [4559 11.2 [32 85] [32 100]]] [4533 3.68 [6822 0.677 [2526 1.27 [2259 8.64 [25 26] [1980 11.3 [429 8.88 [15 20] [2 25]] [3 40]]] [38 53]] [38 30]] [1 30]]] [2169 0.136 [14 97] [14 100]]] [9 100]] [32 81]] [3 100]] [32 90]] [13 100]] [6495 1.31 [7301 2.88 [3 86] [3 100]] [3 100]]] [15 78]] [6076 4.02 [4552 0.232 [5637 0.544 [1512 0.677 [498 0.916 [1659 14.5 [32 44] [17 55]] [17 28]] [6953 0.593 [6681 5.15 [5839 2.13 [17 55] [17 62]] [17 52]] [17 100]]] [3683 1.59 [851 21.9 [17 100] [17 85]] [17 69]]] [32 76]] [1783 2.19 [32 83] [32 100]]]] [4968 0.672 [6113 4.03 [2062 0.872 [3193 3.77 [4154 3.45 [6091 2.44 [4781 7.33 [250 2.53 [14 100] [14 85]] [14 71]] [19 62]] [3008 0.945 [14 84] [14 72]]] [14 75]] [14 50]] [17 55]] [14 57]]] [6809 13.8 [32 62] [32 100]]]] [5110 0.813 [5593 0.55 [3421 11.8 [2652 0.883 [1980 0.116 [5983 19.1 [2717 5.08 [7020 16.8 [7665 0.775 [6758 1.09 [5851 7.15 [7241 18.8 [2667 1.67 [7489 10.8 [5100 1.77 [7763 1.95 [5999 2.51 [6445 1.27 [4740 2.2 [6159 11.3 [4414 49 [6959 0.548 [2232 3.84 [7343 50 [1078 6.81 [7104 1.05 [2947 3.13 [7206 54.1 [2644 6.67 [1899 0.998 [7122 8.47 [5130 0.96 [2691 12.8 [3227 6.64 [7169 1.01 [3287 31.6 [7348 5.65 [6371 5.62 [2707 16.3 [38 17] [2062 1.1 [7301 6.34 [2052 10.4 [38 69] [38 57]] [38 50]] [38 100]]] [16 57]] [38 93]] [38 100]] [14 20]] [38 81]] [38 50]] [38 93]] [2628 45.4 [26 37] [16 57]]] [38 28]] [1 41]] [16 60]] [38 89]] [16 44]] [38 38]] [38 92]] [38 90]] [14 18]] [4431 16.5 [4426 57 [14 55] [38 41]] [16 75]]] [16 28]] [16 42]] [16 25]] [1 77]] [7 50]] [16 30]] [38 100]] [5100 31.2 [6839 9.09 [16 34] [16 60]] [6 66]]] [36 61]] [16 37]] [38 87]] [23 3.79 [16 14] [26 50]]] [36 32]] [2689 16.5 [16 50] [16 100]]] [7281 23.8 [4426 3.32 [6 35] [16 66]] [16 46]]] [7231 2.16 [6409 6.71 [5102 0.99 [1436 2.3 [1445 11.1 [2048 4.04 [2661 9.68 [2650 1.08 [1254 0.116 [2178 9.32 [1262 0.0754 [1948 0.245 [4444 1.42 [429 9.07 [2881 7.63 [38 77] [38 37]] [35 23]] [38 100]] [38 100]] [5637 1.28 [38 100] [38 88]]] [38 47]] [38 100]] [16 50]] [6 42]] [17 33]] [14 35]] [2143 2.88 [38 48] [30 33]]] [6 30]] [16 34]] [16 49]]] [5564 0.816 [4754 1.68 [1459 1.37 [2199 3.29 [17 33] [17 88]] [14 33]] [2952 0.98 [5641 1.35 [17 88] [3 27]] [17 100]]] [14 100]]] [5 52]] [6833 0.81 [414 1.92 [16 47] [16 77]] [14 30]]] [2728 0.813 [5579 2.32 [5932 2.56 [2259 5.49 [2679 5.15 [15 25] [30 100]] [30 88]] [30 100]] [30 87]] [30 100]]]] [2004 0.389 [221 11.3 [663 2.11 [2069 0.127 [3773 0.773 [2225 0.808 [3565 1.24 [1724 3.44 [4154 1.29 [22 98] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 92]] [22 100]] [22 93]] [22 100]]] [6530 0.219 [6080 0.204 [6529 0.2 [1089 0.53 [4414 16 [5893 0.0939 [791 6.67 [1700 0.849 [5211 1.64 [3103 0.861 [4790 0.135 [2955 1.99 [248 2.77 [4044 1 [685 6.34 [5999 3.28 [4398 4.7 [5086 1.31 [1 3.85 [5374 4 [1451 11.1 [7203 2.87 [5071 0.948 [5564 2.22 [7461 3.83 [145 6.74 [1400 1.24 [5807 5.14 [5528 0.613 [5090 0.876 [4704 1.09 [5007 6.99 [1391 218 [5588 2.15 [2831 6.33 [204 2.42 [2274 0.634 [2178 13.5 [2069 1.7 [1696 1.71 [5605 20.2 [6848 2.39 [4092 3.8 [4154 5.16 [4235 36.7 [957 6.63 [7255 16.7 [1783 60.5 [5851 2.62 [22 15] [22 25]] [29 26]] [15 45]] [20 33]] [20 27]] [22 32]] [35 100]] [35 57]] [22 92]] [26 100]] [1 37]] [35 66]] [35 33]] [22 100]] [22 100]] [15 40]] [14 41]] [15 84]] [25 18]] [22 72]] [15 88]] [15 32]] [15 80]] [15 62]] [15 88]] [14 100]] [33 50]] [20 68]] [22 75]] [25 54]] [35 26]] [6353 0.678 [7 25] [30 62]]] [15 32]] [25 51]] [22 58]] [35 100]] [6732 7.84 [1429 55.2 [2470 0.904 [4414 0.632 [4533 2.98 [33 46] [15 38]] [33 75]] [15 73]] [15 32]] [15 100]]] [38 50]] [404 2.07 [30 33] [30 85]]] [35 100]] [6641 0.617 [22 69] [22 100]]] [25 100]] [4221 0.381 [4369 2.6 [7497 1.34 [5226 0.167 [811 0.606 [2470 2.85 [7255 9.81 [489 1.02 [842 1.09 [1118 0.234 [4775 0.924 [5211 1.43 [6761 3.77 [4774 2.73 [1391 11.5 [791 10.3 [35 17] [1986 3.98 [7449 4.82 [1391 3.02 [26 30] [15 23]] [15 58]] [32 40]]] [22 31]] [35 50]] [4 33]] [809 0.852 [5229 1.92 [7183 0.963 [2831 1.09 [5480 0.78 [5804 3.23 [435 0.78 [22 55] [22 57]] [22 100]] [7512 1.03 [22 93] [22 100]]] [22 100]] [22 100]] [0 70]] [859 0.435 [2029 1.2 [5368 9.12 [22 100] [22 75]] [22 100]] [22 100]]]] [2 75]] [35 57]] [35 95]] [35 100]] [15 51]] [847 0.276 [1899 0.42 [15 91] [15 65]] [15 75]]] [15 57]] [22 100]] [6294 0.316 [6476 0.618 [5281 0.84 [791 9.11 [22 87] [22 100]] [22 100]] [22 100]] [22 80]]] [1899 3.28 [5809 1.49 [1400 1.62 [22 85] [15 100]] [15 100]] [15 83]]] [15 100]]] [3 51]] [5211 3.36 [2178 5.27 [7169 13.4 [828 0.722 [6375 6.99 [7623 1.25 [811 1.01 [15 66] [15 100]] [15 100]] [15 50]] [15 100]] [15 64]] [15 37]] [22 88]]] [6499 0.46 [5732 0.895 [504 1.7 [36 0.662 [3281 0.808 [1755 0.347 [2207 0.458 [22 66] [22 57]] [22 100]] [2 60]] [22 100]] [15 87]] [15 80]] [22 100]]] [3424 3.09 [1104 3.11 [22 100] [22 85]] [22 80]]] [429 9 [5110 1.46 [15 92] [15 100]] [15 100]]] [2081 0.198 [7178 0.608 [6732 0.637 [5851 0.599 [23 26.8 [1995 1.1 [22 97] [22 100]] [22 83]] [22 100]] [22 100]] [22 100]] [22 100]]]] [2143 10.8 [4425 14.3 [1017 0.412 [3474 3.44 [915 0.249 [5412 4.14 [3486 1.73 [4429 0.809 [6622 1.47 [2470 0.96 [36 54] [15 99]] [15 100]] [15 100]] [15 100]] [15 66]] [15 100]] [15 100]] [15 100]] [15 75]] [15 75]]] [2143 8.15 [7009 0.903 [1017 0.732 [585 4.63 [7139 1.55 [429 13 [3 61] [3 100]] [3 100]] [3 87]] [3 100]] [3 100]] [3 94]]] [3959 0.911 [567 14 [1062 0.354 [4127 1.14 [540 8.52 [429 39.3 [5995 0.559 [29 97] [29 100]] [29 100]] [29 90]] [29 100]] [29 100]] [29 87]] [29 100]]] [5694 0.582 [695 8.4 [4159 12.5 [628 0.78 [6323 0.284 [2083 0.274 [1253 0.325 [4214 8.42 [695 0.581 [2128 0.792 [2407 0.548 [5753 0.69 [4319 2.53 [2003 1.57 [7061 1.17 [2251 1.58 [4159 0.739 [5011 0.73 [4764 1.89 [29 98] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [1218 0.301 [29 91] [29 100]]] [29 75]] [29 100]] [29 100]] [29 100]] [29 87]] [2143 4.27 [29 85] [29 100]]] [29 83]] [29 75]]] [756 0.425 [5753 0.241 [5716 5.08 [2927 0.795 [30 99] [30 100]] [30 100]] [30 100]] [30 100]]] [4369 0.555 [1764 1.75 [4799 1.78 [6241 3.36 [44 3.76 [4218 2.95 [4754 2.34 [2846 5.03 [83 8.71 [5753 6.95 [125 7.1 [4601 0.351 [5899 2.07 [6471 2.73 [429 9.44 [1660 0.103 [5363 9.64 [2752 25.6 [5534 1.67 [172 6.49 [4716 8.97 [1911 8.17 [2115 0.397 [1391 1.36 [144 34.8 [4279 6.63 [2191 0.128 [4154 7.81 [5673 0.613 [7738 19.7 [1899 7.69 [101 0.678 [4200 13.2 [7245 9.48 [2232 3.84 [6131 5.1 [6920 3.51 [99 2.28 [4061 0.0313 [2081 18.6 [19 54] [3 23]] [14 75]] [5346 2.89 [19 65] [19 69]]] [14 44]] [26 31]] [18 28]] [13 18]] [14 28]] [19 100]] [19 27]] [19 86]] [78 15.4 [1429 1.03 [19 58] [19 83]] [19 53]]] [42 54.7 [1429 22.5 [19 47] [13 40]] [14 25]]] [19 100]] [19 72]] [2023 1.11 [1079 21.6 [41 3.67 [177 0.381 [169 27.9 [19 42] [7722 8.6 [19 79] [145 43 [19 47] [19 100]]]] [19 88]] [19 50]] [19 40]] [19 53]]] [22 50]] [19 100]] [19 92]] [36 75]] [171 5.33 [1078 20.7 [7203 13.7 [4326 8.27 [19 74] [78 4.33 [57 5.49 [19 47] [19 85]] [19 80]]] [19 87]] [19 88]] [2081 8.21 [19 80] [19 75]]]] [13 60]] [24 54]] [14 37]] [1980 0.0477 [19 83] [2752 0.587 [19 100] [19 87]]]] [1997 2.5 [7335 6.11 [19 19] [1 100]] [14 44]]] [26 62]] [18 92]] [7738 2.7 [19 80] [19 100]]] [1 46]] [32 57]] [2245 1.15 [2260 4.89 [39 9.54 [19 75] [19 93]] [4279 7.34 [19 58] [19 77]]] [19 100]]] [22 46]] [22 57]] [19 30]] [1079 5.65 [30 69] [30 62]]] [5 100]] [32 64]] [22 89]] [32 48]]] [1239 4.63 [3635 5.29 [33 88] [1 100]] [4657 10.2 [5171 3 [2128 1.44 [5641 0.655 [6524 5.09 [232 1.34 [328 13.5 [33 72] [30 40]] [276 1.12 [5647 8.16 [5322 3.43 [1062 0.703 [5192 1.12 [3008 1.68 [33 96] [33 100]] [33 100]] [33 88]] [33 90]] [33 62]] [33 100]]] [1 72]] [19 30]] [33 66]] [7413 2.49 [33 100] [7415 2.74 [33 83] [33 100]]]] [1 64]]]] [5655 0.166 [5755 0.513 [1068 0.236 [1055 0.228 [7567 1.24 [5827 0.22 [791 19.8 [2470 3.34 [2628 0.803 [32 66] [32 82]] [7444 3.27 [6566 3 [11 82] [11 100]] [11 100]]] [5226 1.46 [820 2.51 [328 10.4 [11 52] [11 100]] [11 100]] [11 100]]] [11 100]] [32 95]] [11 100]] [11 100]] [11 100]] [11 100]]] [4369 0.162 [4270 0.686 [3554 1.86 [7571 3.6 [2426 0.404 [5978 1.24 [5198 1.39 [906 11.8 [4079 1.42 [4025 1.72 [4206 1.87 [110 0.423 [3606 1.61 [2990 0.634 [7354 1.67 [1404 1.08 [715 0.627 [537 1.49 [2482 0.624 [125 1.05 [5812 0.705 [16 0.971 [2260 1.33 [11 1.26 [3763 2.42 [323 6.02 [6542 1.33 [5211 11 [32 1.87 [6124 1.22 [5779 4.13 [248 0.894 [5065 2.46 [536 1.77 [3480 2.46 [4200 4.86 [2698 5.52 [6548 4.13 [4282 1.1 [7661 1.43 [6074 1.47 [5753 4.63 [5270 1.51 [1416 0.736 [1025 6.14 [3641 3.11 [3664 3.36 [5454 4.45 [751 7.09 [4615 7.69 [6977 20.7 [1391 3.07 [3067 5.26 [5980 0.963 [583 4.12 [392 2.37 [2331 13.4 [5918 4.59 [2766 1.15 [1078 12.8 [2540 1.49 [2048 9.35 [328 15.1 [2939 43.6 [5972 74.4 [5732 20 [3074 1.95 [5753 1.48 [4897 2.82 [6653 3.45 [2178 2.97 [12 77] [12 100]] [12 44]] [12 50]] [12 60]] [12 100]] [36 77]] [5972 99.4 [12 91] [12 100]]] [15 66]] [12 57]] [12 25]] [12 100]] [1899 6.58 [731 4.74 [5972 59.7 [12 65] [31 55]] [31 100]] [12 39]]] [12 33]] [12 30]] [36 84]] [15 18]] [3 47]] [7483 4.67 [12 96] [12 100]]] [36 100]] [15 77]] [36 66]] [36 100]] [3 62]] [36 81]] [36 100]] [36 100]] [7255 2.02 [2202 0.425 [12 72] [12 100]] [12 95]]] [12 100]] [31 80]] [6068 7.52 [6761 11 [2445 4.42 [871 2.67 [5509 2.79 [328 5.38 [5980 2.02 [12 55] [12 100]] [15 37]] [15 44]] [15 45]] [36 100]] [12 100]] [15 72]]] [15 58]] [12 100]] [3 97]] [36 86]] [4422 0.821 [7434 2.86 [12 95] [12 100]] [12 100]]] [36 65]] [15 66]] [3 69]] [15 100]] [1068 4.47 [1742 0.81 [4669 1.09 [4956 2.49 [7665 8.87 [1429 2.11 [15 74] [15 85]] [36 66]] [38 76]] [15 100]] [15 66]] [33 80]]] [36 100]] [12 100]] [15 100]] [5972 15.6 [30 100] [12 63]]] [7665 0.754 [1783 4.29 [6541 8.47 [12 81] [12 100]] [12 100]] [12 100]]] [31 100]] [2259 1.99 [15 90] [15 100]]] [31 100]] [728 1.33 [5007 2.51 [36 80] [36 85]] [36 100]]] [36 100]] [968 1.45 [6091 14.3 [6184 36.8 [705 8.88 [7657 1.32 [1078 44.4 [23 14.1 [2398 30.7 [5647 24.3 [12 96] [12 92]] [12 81]] [4991 1.62 [12 88] [12 80]]] [12 37]] [12 100]] [12 100]] [12 83]] [12 83]] [12 100]]] [36 96]] [31 100]] [3 100]] [15 93]] [15 97]] [2763 1.85 [5454 2.18 [7449 4.51 [36 89] [36 80]] [36 100]] [36 100]]] [12 100]] [15 100]] [802 0.423 [6103 1.39 [7149 3.76 [5647 26.9 [12 100] [12 95]] [12 57]] [12 100]] [12 100]]] [15 61]] [36 100]] [31 97]] [932 3.27 [7449 17.6 [518 6.35 [756 2.79 [1078 2.76 [621 7.46 [6091 3.76 [2752 3.76 [751 8.47 [3989 6.17 [6892 1.98 [21 55] [21 100]] [21 71]] [3 100]] [12 59]] [3 83]] [21 66]] [4956 3.76 [12 59] [36 85]]] [3 100]] [21 100]] [5980 6.02 [6091 5.92 [907 10 [21 31] [743 7.04 [21 87] [21 100]]] [12 40]] [12 100]]] [3 100]]] [2526 2.57 [429 28.2 [203 2.59 [23 1.5 [36 96] [36 100]] [36 100]] [36 71]] [31 85]]] [31 100]] [12 100]] [2259 20.1 [6544 1.89 [7693 1.89 [929 0.99 [7566 4.79 [4627 2.3 [728 5.62 [5467 2.4 [5412 8.6 [6230 14.4 [7449 13.5 [2259 11.5 [31 46] [31 51]] [12 80]] [31 100]] [31 62]] [12 100]] [31 89]] [12 100]] [36 100]] [31 100]] [6260 6.02 [5192 5.57 [31 50] [31 55]] [36 100]]] [5320 2.96 [5405 5.1 [31 81] [6983 3.65 [5879 5.75 [6545 13.9 [31 100] [31 88]] [31 100]] [31 100]]] [31 100]]] [2259 27.6 [31 64] [2259 71.5 [36 63] [36 100]]]]] [6015 22.6 [898 1.42 [2628 22.7 [5738 2.21 [1025 11.5 [504 4.85 [1776 1.36 [7085 0.673 [1253 2.22 [1400 1.25 [12 94] [12 100]] [12 88]] [12 100]] [12 100]] [12 75]] [12 80]] [15 100]] [12 66]] [12 100]] [12 84]]] [624 0.6 [36 96] [36 71]]] [5846 1.17 [4869 3.46 [7733 4.1 [1400 2.73 [131 17.4 [2526 6.7 [2913 3.72 [12 49] [2752 16.2 [31 83] [31 87]]] [1980 2.27 [31 78] [31 53]]] [31 100]] [7481 2.32 [1106 1.7 [7512 12.7 [3523 1.68 [7411 0.759 [203 1.7 [5980 0.335 [2628 0.586 [7434 0.813 [1025 1.27 [12 84] [12 100]] [12 100]] [7210 3.56 [12 100] [12 90]]] [7491 0.436 [7625 0.671 [5871 0.335 [1995 0.87 [12 100] [12 80]] [12 100]] [12 100]] [12 100]]] [12 68]] [15 59]] [15 100]] [12 51]] [12 62]] [12 56]]] [31 100]] [31 100]] [31 100]]]] [4895 0.176 [896 6.5 [6015 0.818 [4851 5.3 [7255 1.02 [5769 0.584 [747 1.28 [2763 1 [5812 2.79 [7352 1.47 [7414 0.15 [5225 1.79 [5040 69.4 [685 2.33 [1059 3.18 [583 1.41 [2752 1.47 [2993 3.37 [5238 3.45 [5322 4.08 [7185 2.3 [802 2.35 [21 57] [21 98]] [21 25]] [915 3.27 [21 97] [21 100]]] [2 51]] [4917 1.47 [429 61.5 [3 33] [21 94]] [21 98]]] [21 13]] [21 100]] [4 25]] [18 29]] [2 41]] [30 100]] [2 54]] [21 40]] [2 62]] [2 50]] [21 100]] [4 46]] [2 12]] [4 86]] [6249 0.409 [907 1.73 [21 95] [21 100]] [21 100]]] [30 30]] [1899 0.68 [30 72] [10 33]]]] [1025 1.16 [5814 1.28 [1400 1.28 [713 0.824 [24 1.23 [4851 0.597 [695 22.9 [73 2.98 [3008 1.09 [4829 1.27 [2847 0.975 [2637 2.62 [2793 1.46 [4663 3.21 [429 6.22 [13 48] [7012 1.34 [2434 0.539 [802 13.6 [3004 0.928 [5779 5.71 [5211 6.39 [4279 14.7 [782 1.83 [6081 1.83 [5640 4.35 [2760 3.75 [7585 1.55 [4907 0.818 [3908 6.53 [2260 1.02 [5609 9.95 [7076 7.39 [7520 5.08 [7712 1.83 [1980 7.36 [6015 9.51 [1239 2.09 [36 61] [2081 0.441 [36 83] [36 66]]] [13 33]] [5472 22.3 [13 65] [15 33]]] [13 100]] [36 73]] [13 85]] [36 100]] [36 92]] [38 54]] [36 100]] [36 100]] [36 55]] [13 100]] [13 100]] [13 100]] [13 41]] [1078 10.9 [22 60] [22 75]]] [36 100]] [36 100]] [21 71]] [36 100]] [13 100]]] [2488 4.95 [4154 1.33 [13 39] [23 27]] [13 100]]] [874 1.75 [36 93] [36 100]]] [36 100]] [22 75]] [5420 1.27 [5543 5.53 [13 100] [13 85]] [13 100]]] [2902 0.807 [2753 1.72 [36 97] [36 100]] [36 100]]] [13 81]] [702 1.17 [99 4.13 [30 4.76 [13 64] [13 100]] [13 77]] [13 90]]] [6717 1.98 [36 90] [36 60]]] [5476 1.85 [13 85] [13 100]]] [36 100]] [31 2.2 [7067 10 [4568 0.281 [7176 2.43 [5403 4.85 [2470 0.99 [3095 20.4 [874 8.77 [6853 15 [3905 0.489 [2342 13.5 [7601 0.739 [4851 0.967 [1603 0.864 [6091 0.559 [2270 1.52 [4814 5.23 [2526 0.8 [721 2.42 [36 97] [36 100]] [36 62]] [36 100]] [36 100]] [36 57]] [36 100]] [36 100]] [36 100]] [36 77]] [7428 2.8 [36 100] [36 75]]] [36 85]] [36 90]] [36 77]] [7343 2.49 [15 95] [15 60]]] [31 85]] [15 50]] [36 100]] [36 80]] [36 71]]] [13 98]] [4063 0.494 [5790 0.677 [7255 0.991 [2241 0.191 [6529 2.23 [2280 1.45 [7340 16.6 [4956 2.84 [6342 0.47 [6389 0.603 [5480 3.52 [1525 0.623 [7698 1.17 [3265 1.11 [5476 2.73 [7693 5.9 [7622 2.07 [1899 1.04 [4279 18.1 [13 95] [13 66]] [13 79]] [13 100]] [13 66]] [13 100]] [36 100]] [7512 15.5 [13 52] [1783 2.04 [1069 2.07 [13 94] [13 100]] [13 100]]]] [13 100]] [13 50]] [13 100]] [6342 4.08 [13 50] [1888 9.53 [13 72] [13 100]]]] [36 100]] [13 80]] [13 57]] [36 91]] [429 23.6 [13 44] [1995 0.362 [36 57] [11 55]]]] [6134 2.98 [1980 12.7 [5472 31.3 [24 0.493 [4373 5.49 [7722 1.17 [6416 1.86 [13 99] [13 100]] [13 100]] [13 75]] [13 100]] [13 66]] [13 90]] [13 87]]] [36 100]] [13 57]]]] [2968 1.52 [132 7.14 [3698 1.79 [7302 1.13 [5904 1.35 [353 1.71 [338 1.18 [7522 6.3 [6310 19.6 [2268 0.408 [5972 1.92 [3905 1.51 [6531 1.58 [6524 2.8 [1482 2.15 [1759 1.38 [397 0.282 [2764 0.409 [2793 10 [5812 1.43 [5482 2.21 [6591 8 [1669 2.51 [248 38.5 [7324 2.22 [277 7.69 [6230 4.12 [5485 7.56 [673 1.79 [168 9.25 [4565 1.09 [178 3.44 [7419 2.15 [18 45] [16 60]] [7 25]] [18 100]] [19 78]] [7516 4.98 [18 50] [18 100]]] [18 85]] [5 31]] [18 80]] [5 53]] [1429 6.85 [26 83] [25 50]]] [7 100]] [3732 12.2 [17 94] [17 66]]] [18 70]] [7 21]] [24 81]] [23 44]] [278 25.1 [4706 17.4 [267 5.57 [791 8.63 [18 57] [695 4.48 [18 74] [18 92]]] [18 96]] [18 66]] [16 66]]] [18 97]] [5 90]] [2259 3.76 [7 72] [7 85]]] [7 100]] [7526 4.68 [3008 4.59 [7 38] [7 85]] [17 66]]] [31 81]] [384 1.1 [248 1.49 [6658 4.02 [5011 3.87 [7735 2.12 [896 7.53 [18 68] [18 100]] [18 40]] [2259 59.9 [19 85] [19 100]]] [6 46]] [18 88]] [18 81]]] [7 60]] [23 100]] [685 1.24 [26 70] [2916 19 [26 71] [26 100]]]] [7 100]] [19 49]] [6757 0.645 [7259 3.04 [719 3.62 [18 60] [19 50]] [1181 2.01 [1587 3.49 [1262 3.33 [4571 8.4 [18 45] [19 100]] [2752 13.3 [19 100] [19 55]]] [18 45]] [19 70]]] [7512 21.1 [19 91] [19 75]]]] [31 61]] [4977 14.9 [7733 6.63 [5692 11.2 [5386 6.07 [4504 3.34 [2913 2.54 [5160 7.96 [5099 4.23 [5612 5.52 [7340 8.22 [4647 5.03 [392 4.66 [1429 4.73 [278 18.7 [7737 2.01 [18 58] [18 85]] [16 66]] [5154 9 [18 86] [18 57]]] [18 87]] [18 71]] [7512 16.9 [16 57] [18 75]]] [788 3.88 [18 60] [6 71]]] [18 50]] [16 50]] [18 50]] [5 38]] [18 100]] [5482 2.96 [18 92] [18 100]]] [5 25]] [6 53]]] [5 83]]] [4601 2.63 [2266 0.389 [719 0.22 [764 0.137 [1993 0.122 [6584 0.195 [3905 1.47 [6552 0.319 [384 0.593 [896 0.876 [1022 0.592 [1980 12.1 [2752 2.1 [2526 25.3 [2628 12.2 [6184 5.68 [5218 1.03 [3744 1.36 [2461 3.12 [2453 8.67 [3653 6.29 [7588 7.64 [7305 20.2 [1010 4.76 [7324 6.1 [7101 5.32 [4067 0.489 [1574 3.65 [7634 4.07 [5851 20.7 [4690 1.39 [6471 12.3 [7265 2.02 [3155 0.568 [1012 7.64 [261 1.29 [4951 2.88 [1429 26.9 [660 2.96 [4154 49.5 [3887 4.59 [4414 35.4 [560 15.8 [4764 0.308 [4398 11.6 [2165 0.294 [979 0.483 [7742 12.2 [727 3.18 [276 7.77 [4 16] [18 54]] [26 81]] [31 53]] [25 55]] [4 55]] [31 72]] [8 33]] [18 100]] [31 33]] [8 100]] [5 50]] [31 25]] [3993 0.593 [1077 5.75 [4991 22.1 [7305 0.932 [3222 8.42 [3056 19 [4927 3.76 [407 2.76 [1429 60 [6294 5.84 [8 19] [0 57]] [4479 7.25 [8 17] [17 85]]] [8 69]] [19 53]] [5 64]] [8 100]] [15 63]] [13 60]] [5 100]] [5 77]]] [3 71]] [33 90]] [6042 8.2 [18 36] [19 66]]] [978 21.9 [35 54] [35 82]]] [2 80]] [2749 6.49 [26 54] [26 100]]] [8 74]] [0 33]] [10 83]] [4 100]] [35 100]] [35 76]] [23 80]] [4 61]] [25 81]] [7512 28 [4 92] [4 55]]] [24 100]] [1240 1.99 [24 100] [24 88]]] [27 94]] [1980 0.986 [35 74] [35 100]]] [10 86]] [2 50]] [2707 7.69 [6230 15.2 [3931 31.2 [4851 0.136 [4 29] [4 92]] [7133 4.67 [5 48] [4 100]]] [4 50]] [26 33]]] [1025 13.6 [6620 3.86 [3273 0.324 [996 0.763 [2605 2.99 [3889 0.613 [8 57] [8 100]] [0 61]] [1764 1.17 [3988 1.39 [6670 1.53 [3054 1.89 [0 89] [0 100]] [0 100]] [0 100]] [0 100]]] [0 46]] [25 100]] [7742 4.42 [2 33] [2 35]]]] [2517 0.686 [3438 0.581 [3006 0.713 [2081 3.84 [6230 2.4 [1023 0.585 [6182 1.23 [3099 0.451 [2793 5.96 [701 0.928 [3652 1.31 [5972 7.47 [1013 2.6 [1701 2.99 [6342 1.83 [6187 3.28 [6189 4.99 [2562 3.66 [7382 0.364 [5366 1.44 [6179 2.37 [4092 6.82 [2759 6.15 [867 0.582 [2526 11.7 [5632 2.54 [4926 2.13 [7354 3.4 [5753 6.63 [6031 1.97 [398 13.3 [2178 8.27 [3457 3.66 [673 0.79 [429 59.5 [485 3.31 [7472 4.95 [5771 4.47 [4304 1.93 [5462 5.53 [5904 1.44 [3424 10.3 [5509 9.24 [2657 2.76 [939 19 [4154 9.73 [5211 14.2 [731 20.9 [5410 8.03 [435 0.778 [688 20.8 [1580 6.33 [3332 5.01 [695 1.92 [5170 11.7 [6977 10.5 [7009 10 [663 1.41 [5192 0.726 [6983 3.23 [7449 24.9 [2913 39.7 [5 14] [25 94]] [23 36]] [4 100]] [8 20]] [5 16]] [5 73]] [14 33]] [26 85]] [22 22]] [35 58]] [17 72]] [7 58]] [4 22]] [31 50]] [17 46]] [23 100]] [6920 2.44 [978 27.8 [24 25] [2752 30.4 [8 25] [2 58]]] [23 40]]] [10 70]] [4 86]] [17 72]] [23 71]] [19 59]] [35 46]] [19 83]] [4 70]] [38 100]] [38 58]] [23 36]] [26 75]] [35 85]] [23 46]] [23 92]] [22 77]] [3311 1.5 [23 31] [23 100]]] [1429 81.8 [2809 5.49 [685 1.78 [18 32] [18 47]] [16 55]] [5 58]]] [18 46]] [16 58]] [1081 2.54 [2742 2.46 [3492 2.65 [2804 4 [5969 10.2 [1141 1.28 [3113 7.13 [7363 1.87 [6582 1.56 [5132 4 [4109 1.66 [1671 4.29 [1429 23.8 [5170 6.02 [2 24] [26 38]] [5 21]] [18 70]] [5 50]] [18 88]] [4 100]] [4 96]] [8 71]] [4 66]] [18 32]] [8 92]] [8 100]] [4 100]] [26 62]]] [6031 2.01 [23 66] [22 100]]] [328 22.9 [16 37] [23 43]]] [35 78]] [25 100]] [23 100]] [24 72]] [5851 5.92 [23 72] [0 92]]] [25 65]] [5660 2.62 [2 73] [2 44]]] [999 1.1 [4253 1.96 [4684 0.852 [429 4.85 [26 70] [4663 4.67 [23 27] [23 66]]] [23 67]] [2 92]] [23 69]]] [5090 0.76 [22 38] [22 100]]] [23 82]] [2411 2.79 [11 7.46 [31 72] [31 100]] [36 100]]] [286 4.07 [7381 8.16 [24 88] [24 81]] [24 80]]] [558 0.43 [10 76] [10 100]]] [4349 3.27 [24 57] [24 100]]] [35 77]] [25 92]] [5431 1.68 [7302 1.27 [5851 6.22 [560 0.322 [1668 2.15 [324 0.405 [1919 2.38 [7491 1.7 [7169 0.668 [5647 12.4 [1400 4.44 [1911 2.35 [18 27] [2 33]] [7665 13.6 [2 33] [26 57]]] [2 54]] [2 38]] [2 66]] [4 74]] [7 55]] [18 87]] [6732 1.78 [18 45] [18 85]]] [2 50]] [19 50]] [26 100]]] [6233 1.54 [6173 1.71 [5904 0.971 [3563 2.73 [732 5.05 [1009 4.21 [3057 2.44 [7325 4.04 [1567 2.88 [1646 2.26 [2526 0.715 [2962 3.4 [3995 13 [7472 1.21 [3515 1.87 [2259 1.78 [3675 2.28 [673 27.4 [5389 7.39 [2628 7.35 [3798 2.43 [4414 13 [6243 5.3 [1062 15 [736 4.93 [624 3.76 [5641 4.02 [3519 5.71 [328 8.05 [1062 6.07 [1429 19.8 [5 24] [3503 2.33 [6725 3.55 [6199 5.49 [1587 5.96 [1011 3.07 [4851 16.1 [3190 2.46 [17 39] [5 83]] [19 64]] [17 70]] [5 44]] [4 20]] [19 62]] [17 93]]] [17 100]] [17 20]] [19 100]] [5 28]] [19 42]] [19 66]] [18 57]] [5 100]] [978 19.2 [5 40] [4 50]]] [38 56]] [19 32]] [38 77]] [26 100]] [5 77]] [5 24]] [19 42]] [429 20.1 [17 42] [38 80]]] [5 75]] [19 77]] [3312 4.47 [2526 2.73 [18 73] [1483 3.82 [3897 1.3 [5972 17.7 [2570 15.4 [1769 2.15 [5819 4.77 [5 28] [19 66]] [23 33]] [4 44]] [31 100]] [5 77]] [5 80]]] [38 90]]] [16 81]] [7 75]] [3972 1.69 [1429 51.8 [5 69] [5 84]] [5 91]]] [791 4 [5 92] [12 50]]] [695 1.18 [144 2.99 [7 35] [5 36]] [5 44]]] [26 94]] [19 87]] [663 1.3 [1078 1.67 [5 42] [19 68]] [1888 4.12 [19 86] [14 42]]]] [31 100]] [31 89]]] [4161 1.19 [2739 6.62 [5413 1.15 [3045 1.11 [1239 1.29 [2521 3.19 [5972 3.26 [2902 2.58 [178 0.87 [2207 1.15 [2466 1.39 [2241 0.838 [1783 27.6 [5799 1.53 [2232 0.677 [2033 2.24 [7522 2.96 [429 33.4 [2178 5.23 [4288 5.06 [2088 11.7 [7241 3.67 [23 26] [17 33]] [5 37]] [4 36]] [23 73]] [5412 0.924 [695 3.43 [5211 2.35 [23 62] [23 100]] [18 33]] [1980 9.94 [23 85] [23 100]]]] [23 62]] [23 58]] [23 60]] [23 75]] [16 22]] [23 76]] [16 26]] [2 50]] [25 35]] [22 50]] [31 81]] [23 42]] [688 0.514 [7665 0.327 [23 67] [18 28]] [23 81]]] [35 77]] [23 3.82 [791 1.17 [2 33] [2 53]] [1 50]]] [4 88]] [18 31]]] [7210 5.37 [26 94] [26 75]]] [3440 1.76 [35 73] [1078 3.09 [35 85] [35 100]]]] [1911 1.15 [3652 9.62 [24 86] [19 34]] [24 100]]]] [996 0.268 [673 1.59 [5654 1.83 [1239 1.14 [6538 2.09 [5225 3.21 [7507 0.654 [429 23.8 [2919 11 [134 1.54 [429 0.924 [2 22] [23 27]] [22 27]] [25 100]] [442 5.75 [5970 2.73 [4159 1.57 [985 1.9 [429 30.5 [23 44] [2259 1.08 [23 46] [4338 6.67 [4279 1.96 [6342 1.08 [2259 12.9 [23 100] [23 80]] [23 85]] [23 71]] [23 76]]]] [4 29]] [23 25]] [23 100]] [12 50]]] [23 100]] [23 93]] [2264 2.09 [2 75] [2 100]]] [2826 1.08 [1761 1.21 [1239 6.48 [1980 20.3 [2407 0.766 [23 65] [23 100]] [2259 1.89 [23 88] [23 100]]] [7246 1.47 [1911 1.09 [7512 3.51 [1211 2.15 [3616 0.928 [2178 3.1 [2752 15.2 [0 13] [2004 0.47 [23 67] [23 100]]] [1078 1.41 [23 83] [23 100]]] [23 100]] [23 100]] [23 18]] [24 30]] [10 100]]] [23 100]] [17 71]]] [1 35]] [5692 3.7 [2913 7.04 [26 75] [25 44]] [1 81]]] [2752 9.36 [0 85] [6114 7.45 [7061 2.3 [5225 0.46 [7491 2.28 [2752 40.7 [23 92] [23 100]] [23 70]] [23 100]] [23 100]] [23 77]]]]] [6184 6.07 [23 100] [23 83]]] [680 1.1 [6333 0.692 [4573 3.26 [4110 1.06 [7032 2.55 [3675 2.66 [4101 1.05 [3667 0.923 [673 4.75 [4342 0.516 [2453 2.15 [2385 0.406 [5904 0.818 [5007 4.61 [21 0.666 [6023 3.4 [3724 1.94 [2259 8.72 [3056 1.62 [3732 1.36 [666 1.42 [7583 2.64 [312 1.85 [5132 2.35 [1210 0.491 [3278 0.846 [6591 0.661 [7516 1.22 [4959 1.04 [6983 4.71 [3327 2.26 [7414 0.924 [4479 4.47 [5812 0.917 [515 0.424 [6022 2.73 [277 1.39 [3345 0.952 [3461 1.93 [3251 6.09 [5429 1.78 [5099 1.06 [2797 1 [6555 4.81 [2637 6.36 [6544 7.56 [560 5.61 [6042 1.23 [2081 9.37 [2629 3.98 [3794 20.7 [6581 1.11 [7279 6.9 [7734 1.3 [6883 1.44 [731 2.96 [2607 2.27 [2029 1.63 [4279 2.98 [6332 4.13 [978 4.42 [13 57] [6575 2.7 [4 21] [5 100]]] [18 45]] [24 60]] [4 44]] [16 42]] [5 19]] [29 37]] [6732 5.27 [1011 1.52 [18 39] [18 85]] [7 37]]] [4 60]] [5 41]] [38 100]] [2 58]] [2526 1.84 [4 77] [4 40]]] [18 55]] [18 72]] [14 50]] [5 100]] [5 90]] [18 87]] [18 81]] [5 68]] [18 90]] [1078 3.86 [17 50] [17 62]]] [5 100]] [18 81]] [7 100]] [18 43]] [1073 8.85 [2 22] [17 52]]] [7 51]] [7414 7.94 [17 42] [2 47]]] [2 100]] [4 100]] [4 100]] [1081 2.28 [248 23 [18 40] [26 55]] [25 33]]] [2939 5.58 [17 46] [5 72]]] [1 100]] [1429 32.2 [12 36] [5 95]]] [134 1.22 [18 60] [16 41]]] [4 59]] [7 66]] [2 87]] [2752 14.3 [485 9.37 [17 64] [17 40]] [38 54]]] [7381 1.09 [5019 3.36 [4805 0.911 [1980 1.47 [5 74] [5 92]] [5 100]] [35 36]] [731 1.09 [5 75] [5 91]]]] [5819 1.85 [7535 2.58 [6040 2.76 [2143 1.52 [4184 1.57 [6449 6.61 [2752 16.2 [18 14] [1980 1.55 [24 26] [24 57]]] [7 66]] [16 30]] [4 22]] [6724 3.55 [896 9.5 [18 80] [18 55]] [18 100]]] [24 100]] [24 31]]] [5 95]] [7 90]] [5 46]] [7546 13.8 [6040 0.485 [4478 4.67 [2826 6.32 [2764 0.739 [7441 1.5 [7381 0.945 [6732 5.8 [7734 2.22 [2 18] [5693 1.27 [19 43] [18 81]]] [429 39.8 [18 83] [18 50]]] [7 30]] [29 50]] [29 33]] [19 41]] [4 30]] [532 16.5 [2260 3.53 [18 72] [18 60]] [19 42]]] [18 80]]] [7354 2.48 [19 69] [19 50]]] [7700 0.982 [1587 3.5 [2797 1.22 [1696 3.5 [1980 6.95 [1023 7.03 [2526 4.43 [2259 13.3 [18 92] [19 54]] [7188 1.24 [18 78] [16 37]]] [18 91]] [7 50]] [19 55]] [18 100]] [19 80]] [18 100]]] [24 100]] [7057 1.22 [4344 1.16 [1025 12.1 [24 88] [24 100]] [24 100]] [19 40]]] [26 71]] [2 47]] [6230 7.07 [5 77] [5 60]]] [4200 4.69 [3676 6.95 [5 69] [19 66]] [5 50]]] [1906 2.82 [4338 0.864 [5812 13.2 [7520 4.31 [286 6.63 [2 50] [2 100]] [2 71]] [2 100]] [2 77]] [2 71]]] [2526 0.59 [3204 19.7 [4222 1.72 [5 81] [5 100]] [5 50]] [2826 11.7 [5412 1.16 [5 96] [5 100]] [5 75]]]] [896 4.81 [19 33] [7241 3.86 [7332 5.85 [19 77] [19 100]] [19 75]]]] [5 66]] [144 0.975 [18 86] [18 100]]]] [2531 0.16 [429 32.7 [386 0.281 [6044 0.932 [1429 30.5 [7185 1.15 [6184 5.29 [3130 0.57 [3155 1.04 [1 1.03 [429 6.55 [2259 6.21 [6471 0.967 [26 60] [7693 1.08 [26 82] [26 100]]] [26 52]] [2530 2.42 [2764 0.506 [23 28] [1429 13.5 [23 100] [23 66]]] [25 66]]] [26 90]] [685 2.8 [35 100] [35 88]]] [23 76]] [398 3.11 [23 63] [23 92]]] [5007 5.33 [23 7.29 [26 69] [16 33]] [1078 5.89 [18 55] [16 40]]]] [3972 5.4 [6040 0.778 [1980 7.45 [384 26.3 [2809 2.78 [6022 1.57 [560 0.617 [18 20] [18 67]] [5007 1.95 [7 78] [7 80]]] [18 51]] [8 43]] [23 60]] [18 79]] [8 100]]] [5267 5.73 [18 68] [18 45]]] [23 100]] [7009 3.89 [896 1.44 [957 8.35 [1429 40.3 [2143 2.16 [6375 0.75 [5753 12.5 [2207 6.2 [5211 1.27 [7139 3.65 [2081 4.49 [5647 2.53 [23 91] [23 76]] [23 100]] [23 44]] [5225 0.615 [798 1.61 [551 2.74 [1025 1.14 [23 97] [23 100]] [23 100]] [23 100]] [23 100]]] [23 57]] [23 57]] [23 55]] [23 100]] [1023 0.945 [978 40.1 [8 50] [23 33]] [18 88]]] [23 35]] [18 63]] [23 40]]] [23 100]]] [4 98]] [3562 0.475 [6441 5.28 [988 4.79 [6413 0.852 [6199 36.8 [6983 1.52 [3292 1.91 [5904 2.26 [1226 3.19 [1632 2.27 [4929 2.89 [2259 12.5 [1919 3.57 [4718 1.22 [3204 0.911 [7722 4.5 [6581 2.21 [5491 3.11 [5972 3.23 [7445 2.45 [3858 0.849 [896 13.6 [429 23.9 [2966 6.14 [2826 3.82 [7354 2.32 [7 18] [7 66]] [17 29]] [19 57]] [130 2.15 [2913 0.531 [2526 15.5 [999 1.99 [4478 2.93 [1740 3.95 [17 47] [19 46]] [2628 7.57 [17 100] [17 73]]] [7 40]] [7 44]] [38 35]] [14 25]]] [7 76]] [35 100]] [16 76]] [31 69]] [19 61]] [2902 3.58 [17 48] [5 25]]] [17 48]] [5 69]] [7 100]] [4338 2.79 [17 69] [5 40]]] [1998 0.701 [5211 2.58 [7255 3.73 [7 18] [5673 2.04 [2331 4.2 [18 54] [18 71]] [18 33]]] [8 31]] [0 100]]] [7 85]] [19 100]] [2752 1.57 [8 57] [2259 4.17 [23 100] [23 80]]]] [6313 1.23 [4571 2.41 [5413 0.971 [19 79] [19 100]] [19 50]] [19 100]]] [8 88]] [31 100]] [7 75]] [2550 0.852 [0 70] [0 100]]] [19 59]] [7 53]] [584 1.28 [6581 1.06 [7722 3.21 [2826 4.46 [19 68] [19 98]] [19 71]] [1079 3.08 [1703 1.57 [7215 0.797 [17 46] [19 71]] [19 85]] [38 50]]] [19 100]]]] [469 0.416 [5521 0.274 [5673 3.58 [4457 2.42 [4588 3.68 [4537 18.8 [3798 1.56 [7270 1.4 [2259 6.48 [3858 1.13 [7075 0.782 [7665 33.4 [3913 3.31 [1580 3.53 [7067 0.756 [4851 3.55 [5812 4.88 [731 0.446 [17 77] [7711 1.27 [6074 0.602 [17 100] [17 91]] [17 88]]] [17 72]] [6550 5.25 [3317 1.86 [6708 0.975 [17 62] [19 50]] [17 72]] [17 97]]] [17 97]] [17 70]] [6 22]] [5 27]] [17 100]] [35 66]] [19 38]] [5 75]] [731 5.8 [38 47] [17 72]]] [38 72]] [17 93]] [35 30]] [896 2.63 [38 70] [4851 7 [17 30] [5 50]]]] [19 57]] [19 100]]] [7431 0.41 [2562 0.239 [2259 1.35 [6732 0.486 [682 2.4 [3155 1.23 [6524 4.37 [4154 0.41 [3798 2.38 [4851 1.11 [3332 0.481 [2241 3.81 [1009 6.84 [6353 0.607 [6074 1.03 [1000 4.41 [724 0.891 [726 1.98 [4324 0.967 [1084 1.59 [6539 2.04 [23 31] [1 57]] [23 93]] [23 93]] [4 44]] [4 33]] [2 72]] [2 37]] [2081 2.7 [23 100] [23 81]]] [18 62]] [23 77]] [35 80]] [731 3.12 [7 33] [17 100]]] [16 33]] [4154 14.5 [688 0.516 [1226 0.885 [7491 1.88 [286 1.22 [23 50] [4158 0.41 [23 100] [23 77]]] [23 100]] [23 100]] [23 40]] [23 31]]] [25 36]] [35 100]] [2 70]] [7512 6.45 [26 17] [18 21]]] [383 1.58 [7381 0.204 [6729 0.463 [384 0.549 [1995 3.6 [4158 9.81 [1062 3.25 [1094 2.74 [7210 6.89 [2143 3.1 [144 1.18 [2259 10.8 [5211 2.97 [36 23] [10 42]] [23 57]] [19 28]] [929 0.502 [23 62] [23 100]]] [23 27]] [23 83]] [2081 2.89 [23 62] [4663 1.55 [660 3.37 [981 0.479 [23 90] [23 100]] [23 90]] [23 81]]]] [4 45]] [6184 1.26 [5651 0.935 [1909 1.64 [23 93] [23 60]] [23 100]] [23 73]]] [1783 10.6 [7210 3.44 [328 10 [23 100] [23 90]] [23 90]] [23 60]]] [12 41]] [5692 0.898 [2526 9.3 [17 41] [2 57]] [2 40]]] [17 27]]] [1170 0.398 [2628 3.91 [448 3.99 [6397 0.189 [688 1.92 [2793 0.39 [6791 2.45 [7494 0.661 [1913 1.16 [286 1.36 [23 73] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 87]] [23 50]] [567 0.15 [23 33] [23 100]]]] [0 100]]] [23 100]] [5771 0.478 [7665 7.66 [6524 2.12 [5405 0.467 [3008 0.482 [279 4.29 [5734 1.99 [2813 1.45 [7185 10.4 [5896 0.262 [2951 5.88 [7736 0.456 [7057 0.33 [5130 0.272 [6353 4.46 [6040 0.699 [1012 0.4 [7203 0.414 [2470 2.16 [6575 3.21 [4573 0.724 [7009 0.655 [5820 1.77 [4541 0.945 [434 3.2 [1911 1.16 [6077 2.22 [435 1.37 [719 12.2 [6591 2.66 [3913 1.13 [5480 0.354 [5851 0.552 [2259 0.884 [1429 19 [2 28] [5 41]] [38 50]] [5 61]] [18 50]] [17 50]] [17 50]] [18 42]] [29 33]] [7 77]] [2 35]] [5 52]] [18 100]] [2 56]] [5 56]] [19 77]] [5 90]] [4 62]] [2259 20.5 [18 40] [19 75]]] [397 1.6 [18 41] [18 76]]] [719 7.94 [144 9.72 [731 2.76 [18 100] [18 75]] [18 60]] [18 55]]] [18 63]] [6230 12.3 [2752 25.9 [532 1.36 [4338 2.58 [6027 0.981 [383 1.02 [2607 0.421 [16 51] [16 50]] [18 76]] [18 72]] [18 62]] [19 50]] [6 22]] [19 70]]] [6042 0.448 [978 6.86 [18 100] [18 72]] [18 100]]] [383 5.26 [18 46] [18 71]]] [6 62]] [17 100]] [5154 2.11 [23 4.83 [5161 8.2 [1062 10.4 [18 70] [16 66]] [18 100]] [5161 2.55 [19 28] [18 72]]] [18 80]]] [731 6.3 [896 8.47 [18 82] [1078 7.01 [18 87] [18 100]]] [18 58]]] [7 100]] [2756 2.24 [23 5.79 [18 71] [18 100]] [18 61]]] [5904 0.525 [5673 4.97 [695 6.17 [17 45] [18 35]] [4083 6.91 [19 53] [38 60]]] [1239 1.45 [5267 0.408 [567 0.561 [19 87] [19 100]] [19 62]] [19 100]]]] [31 100]] [688 1.11 [7 55] [7 100]]] [7067 0.271 [5383 0.121 [5972 2.98 [649 1.48 [7270 1.9 [269 1.89 [6442 0.864 [7526 0.44 [1669 1.31 [5732 3.94 [2809 1.73 [328 1.62 [4304 0.485 [3078 0.985 [7699 1.82 [6591 1.03 [6544 5.13 [276 1.89 [688 11.8 [3667 1.92 [5641 3.1 [7384 1.82 [7689 0.924 [1546 1.2 [7132 0.778 [2574 4 [1025 6.15 [4351 1.46 [6230 5.38 [6982 4.5 [7354 3.68 [4768 15.6 [5904 1.28 [5412 6.77 [5192 4.79 [7665 8.78 [18 54] [248 5.62 [4 18] [26 33]]] [5 35]] [4 76]] [19 53]] [2 22]] [4184 1.25 [4859 2.11 [1011 8.06 [18 44] [719 20 [18 75] [18 50]]] [18 100]] [18 87]]] [4 94]] [5 40]] [4 81]] [1980 9.01 [4 55] [4 33]]] [2 62]] [4 76]] [4110 10.1 [5 75] [5 100]]] [5155 2.53 [5 78] [19 43]]] [7381 5.52 [7 100] [791 13.1 [5812 15.2 [6077 16.2 [429 17.7 [4 57] [7 66]] [17 44]] [7 71]] [7 44]]]] [38 28]] [663 1.73 [2 52] [2 70]]] [7 100]] [4977 1.23 [18 54] [18 53]]] [2565 3.18 [31 80] [31 100]]] [7722 18 [1919 1.05 [7251 3.95 [7188 3.92 [17 47] [5 83]] [17 69]] [5 66]] [5 100]]] [2752 8.5 [18 100] [18 56]]] [19 55]] [5 74]] [2434 1.44 [392 1.53 [7301 1.75 [7742 1.43 [5482 3.36 [7 20] [18 71]] [328 9.78 [18 83] [7 44]]] [16 43]] [2260 2.51 [6732 0.596 [731 15.7 [7737 1.77 [18 40] [18 50]] [26 58]] [18 93]] [19 41]]] [18 40]]] [1073 1.04 [429 9.62 [16 50] [1631 4.74 [18 40] [18 100]]] [18 88]]] [688 5.54 [6524 3.51 [7590 0.898 [7 30] [16 45]] [7 100]] [7 100]]] [7 98]] [3971 1.79 [434 1 [2826 8.34 [17 35] [17 91]] [19 66]] [17 100]]] [5 90]] [1400 62.5 [26 90] [26 42]]] [5 86]] [4806 2.28 [647 0.986 [5693 2.99 [4478 2.82 [17 45] [17 100]] [5 44]] [17 62]] [17 76]]] [2081 3.65 [2939 6.67 [6199 13 [5753 3.61 [6546 0.705 [31 98] [31 100]] [31 100]] [31 85]] [5403 7.35 [31 66] [31 100]]] [31 100]]] [31 2.91 [728 6.58 [957 2.49 [2752 27.6 [5383 4.48 [17 66] [3008 8.36 [6977 7.86 [6230 10.1 [7 87] [7 50]] [17 42]] [19 70]]] [7 64]] [19 71]] [17 100]] [17 100]]] [3798 0.232 [5732 6.36 [733 0.77 [7 47] [17 54]] [17 88]] [7067 1.15 [5157 0.84 [19 55] [19 100]] [515 0.963 [2939 0.433 [7214 0.78 [1885 0.585 [5812 1.93 [17 33] [7381 7.87 [17 62] [17 87]]] [38 83]] [17 50]] [978 19.2 [19 64] [17 71]]] [38 60]]]]]] [2960 0.473 [4 48] [670 0.506 [2 66] [2 100]]]]] [5403 0.778 [31 61] [31 100]]] [3519 1.41 [7516 2.27 [1705 2.94 [6342 0.346 [772 2.24 [4573 0.821 [4338 1.02 [248 0.722 [26 18] [2178 7.13 [403 2.2 [6007 0.534 [719 5.99 [4602 0.978 [1023 1.41 [726 0.473 [26 81] [26 60]] [26 100]] [2259 3.87 [5431 5.12 [1995 6.34 [26 91] [26 100]] [26 77]] [26 100]]] [26 45]] [26 66]] [26 100]] [26 66]]] [2 23]] [19 77]] [24 85]] [4159 6.74 [1980 8.15 [3027 6.38 [2470 0.978 [7255 2.69 [985 2.95 [8 27] [26 35]] [0 75]] [26 50]] [0 91]] [5232 1.57 [1078 3.42 [0 68] [5412 0.68 [0 57] [567 2.55 [23 63] [23 90]]]] [0 100]]] [8 100]]] [18 71]] [1888 6.66 [407 3.07 [6727 1.74 [338 1.23 [26 75] [26 98]] [26 100]] [26 50]] [1400 14.2 [26 100] [26 75]]]] [19 100]]]] [719 0.157 [2526 13.6 [2504 0.664 [5039 0.699 [7572 0.701 [7321 1.81 [5007 8.55 [957 1.78 [13 100] [13 90]] [13 87]] [13 88]] [13 100]] [13 100]] [13 100]] [2 37]] [13 100]]] [221 2.78 [2755 3.47 [2753 2.08 [7187 2.29 [267 2.29 [5888 0.787 [5612 0.805 [7354 0.736 [2760 5.3 [6592 0.96 [5642 0.849 [7734 3.98 [5693 5.62 [178 14.2 [6524 1.09 [418 9.79 [663 19.9 [3008 6.78 [3006 0.198 [4956 0.73 [678 0.609 [431 6 [26 82] [26 90]] [35 53]] [26 100]] [5345 0.579 [26 98] [26 100]]] [25 60]] [25 57]] [16 50]] [25 81]] [25 55]] [26 75]] [26 66]] [994 1.56 [26 100] [26 77]]] [25 66]] [25 77]] [1078 11.7 [18 56] [16 72]]] [18 71]] [18 90]] [18 93]] [4394 1.26 [393 9.8 [6199 4.44 [26 86] [26 50]] [26 50]] [26 100]]] [2913 9.47 [1888 6.34 [26 85] [26 100]] [26 60]]] [388 0.728 [732 0.914 [1400 48.6 [725 0.442 [35 2.11 [384 0.353 [5412 8 [5170 1.01 [4389 2.44 [3850 2.16 [5851 0.316 [4338 1.42 [1078 22.9 [7722 1.05 [6708 3.02 [4235 6.81 [5429 6 [26 66] [26 100]] [26 100]] [26 100]] [26 100]] [26 100]] [2081 2.66 [26 46] [26 70]]] [26 100]] [26 77]] [26 83]] [4560 0.998 [26 93] [19 57]]] [25 55]] [2748 2.63 [4154 0.3 [429 14.8 [4613 0.353 [7693 0.826 [731 1.89 [980 7.89 [26 81] [26 100]] [26 100]] [26 100]] [26 100]] [26 66]] [26 100]] [2755 7.66 [26 85] [26 83]]]] [26 58]] [19 50]] [26 60]] [5173 1.69 [724 0.581 [5015 1.85 [7203 4.85 [6581 7.3 [5632 0.759 [3820 2.72 [5873 0.455 [791 8.42 [2259 0.49 [1980 4.19 [26 100] [26 80]] [26 100]] [26 66]] [26 100]] [26 60]] [26 100]] [35 50]] [26 83]] [26 75]] [26 100]] [26 71]]] [16 40]]] [385 1.98 [980 7.98 [25 52] [25 44]] [26 57]]]] [7 100]] [723 1.15 [2752 15.4 [2299 2.54 [4560 2.42 [132 2.25 [6184 0.734 [5211 4.55 [7118 6.62 [6717 2.58 [134 2.01 [3794 7.32 [7623 35.2 [328 19.8 [6406 10.4 [6732 7.26 [5270 0.556 [31 69] [31 100]] [31 80]] [31 75]] [31 60]] [31 63]] [31 57]] [31 73]] [31 100]] [31 62]] [0 28]] [31 57]] [31 50]] [19 60]] [31 100]] [248 0.752 [978 9.69 [5412 0.642 [31 29] [22 42]] [17 40]] [15 40]]] [17 55]]] [7176 0.784 [2526 2.7 [7384 0.134 [7449 3.92 [2473 0.392 [558 0.272 [5940 0.235 [2808 0.506 [7722 0.458 [3367 4.26 [5980 0.499 [978 3.11 [3718 0.399 [3473 1.12 [731 7.25 [1151 2.65 [3602 0.715 [6230 3.37 [4078 1.71 [5972 1 [2259 0.637 [3394 2.86 [3921 2.49 [1429 49.4 [7512 9.14 [12 27] [5 26]] [1089 2.11 [3912 4.22 [37 44] [37 100]] [37 100]]] [37 100]] [37 95]] [429 0.425 [3989 12.1 [248 3.74 [12 36] [12 81]] [12 90]] [5844 1.41 [31 2.46 [3685 4.34 [3079 2.86 [3929 14.3 [3929 3.31 [1239 3.31 [8 50] [15 60]] [12 25]] [4235 9.17 [4097 2.79 [5290 0.887 [7169 1.49 [4634 15.2 [12 37] [5 56]] [5 85]] [5 91]] [5 71]] [12 60]]] [37 100]] [5 70]] [17 36]] [38 50]]]] [12 96]] [8 100]] [6549 1.73 [12 81] [3 36]]] [4154 4.16 [3841 5.52 [2752 0.2 [3194 0.36 [3905 2.26 [695 5.58 [12 66] [37 44]] [12 60]] [12 100]] [6294 1.63 [12 89] [12 50]]] [5 75]] [1476 0.745 [12 88] [12 100]]]] [5 37]] [7534 8.35 [5 32] [17 100]]] [3113 2.04 [3295 1.01 [37 78] [37 87]] [37 85]]] [1429 57.5 [37 100] [37 88]]] [3345 7.54 [1025 4.06 [5812 6.13 [1584 1.48 [6548 2.65 [6724 1.11 [4681 3.55 [17 29] [5 72]] [19 38]] [6396 7.7 [7512 3.07 [17 100] [17 62]] [6544 16.6 [17 47] [17 73]]]] [17 94]] [2259 4.4 [17 83] [17 75]]] [12 33]] [5 25]]] [12 100]] [6866 2.15 [37 64] [5 100]]] [3315 1.26 [7009 3.41 [3424 5.28 [17 46] [17 85]] [5 94]] [5 100]]] [3244 1.11 [15 95] [15 100]]] [5904 0.0908 [17 41] [19 92]]] [12 100]] [15 100]] [5969 1.62 [6614 0.617 [7661 0.736 [4154 7.06 [6621 1.91 [1704 1.72 [2818 1.02 [4611 1.13 [3929 4.14 [15 40] [2752 31.4 [5471 2.65 [3929 6.46 [12 75] [12 92]] [12 100]] [12 69]]] [12 100]] [12 100]] [17 87]] [12 66]] [4154 12.5 [15 91] [15 77]]] [12 100]] [15 100]] [15 50]]] [5299 0.546 [17 69] [17 66]]] [5732 0.244 [3313 0.835 [898 0.642 [3335 0.301 [429 19 [4761 1.95 [1704 1.5 [4098 1.58 [2606 0.449 [4690 2.02 [2793 1.46 [4279 2.75 [5692 1.56 [3972 7.06 [5972 1.07 [7352 0.747 [2841 0.432 [5 40] [5 92]] [12 66]] [12 100]] [5 83]] [2752 28.3 [5 81] [5 100]]] [12 45]] [12 100]] [8 100]] [5 75]] [5 58]] [6980 4.4 [4851 1.33 [17 73] [17 93]] [17 57]]] [12 50]] [4000 0.539 [5413 0.363 [4806 2.22 [2784 0.495 [642 0.661 [4765 5.08 [3057 0.532 [2488 2.97 [7009 1.51 [2591 6.89 [7085 0.387 [7324 1.48 [1400 5.39 [6076 2.57 [2178 0.826 [1911 0.549 [17 57] [17 55]] [17 60]] [17 95]] [12 100]] [5 46]] [17 44]] [17 100]] [5693 4.36 [5 58] [5 40]]] [8 54]] [5 67]] [17 70]] [5 94]] [1078 9.34 [12 40] [5 75]]] [4045 1.42 [31 4.96 [6534 3.01 [6970 1.42 [3929 3.4 [17 60] [5285 1.49 [17 96] [17 92]]] [17 100]] [17 72]] [17 50]] [17 50]]] [2752 36.1 [7512 16.4 [1704 0.469 [17 52] [1429 47.8 [6920 0.879 [17 78] [17 100]] [3563 1.17 [7253 1.89 [3929 12.4 [17 64] [17 87]] [19 40]] [19 57]]]] [5157 2.46 [17 100] [17 70]]] [19 44]]] [5 92]]] [12 100]] [12 100]] [3313 2.7 [5 83] [5154 2.97 [5 80] [5 100]]]] [7333 10.9 [4895 7.35 [1587 2.27 [6311 3.41 [1023 0.283 [3308 1.39 [5753 0.506 [7334 2.85 [4588 1.46 [6732 0.79 [1899 0.493 [17 34] [17 100]] [17 57]] [2628 0.904 [1239 4.59 [17 89] [17 85]] [14 33]]] [17 100]] [1429 68.2 [17 100] [17 85]]] [15 60]] [17 100]] [17 66]] [17 60]] [17 46]] [14 83]]]] [5111 0.443 [7520 0.785 [4154 4.31 [713 0.249 [6541 0.397 [2818 1.05 [1888 1.67 [6363 1.33 [802 2.04 [328 1.61 [6732 1.51 [695 0.483 [12 48] [12 62]] [6080 2.14 [12 41] [15 100]]] [15 45]] [12 75]] [12 80]] [12 84]] [791 22.8 [12 100] [12 85]]] [12 100]] [12 100]] [22 50]] [5 44]] [15 100]]]] [537 0.885 [535 0.538 [6892 0.848 [4282 2.09 [248 1.14 [7009 3.98 [6310 0.692 [21 58] [21 89]] [12 62]] [15 32]] [3 95]] [21 100]] [6191 14.3 [907 24.6 [6061 15.6 [1239 0.571 [2081 1.46 [5248 2.62 [7465 1.71 [21 99] [21 100]] [21 100]] [21 100]] [21 100]] [21 87]] [21 95]] [535 24.2 [21 100] [21 76]]]] [3 100]]] [7363 0.46 [328 3.53 [5239 0.388 [2739 0.942 [3008 0.289 [6887 0.161 [4992 0.883 [1025 1.9 [5413 0.574 [4613 0.735 [6733 0.237 [2551 0.974 [7708 0.411 [6582 2.12 [560 0.589 [6982 0.404 [429 4.7 [6422 0.49 [4889 1.16 [7346 7.78 [7540 2.35 [7413 0.617 [6581 0.186 [7667 5.91 [5576 8.85 [5093 2.02 [6362 4.85 [695 0.818 [4450 9.56 [1429 27.8 [2526 104 [4651 3.82 [2530 0.4 [5099 7.94 [5597 7.6 [1445 3.36 [791 3.22 [2902 1.66 [7514 1.76 [25 11] [19 55]] [1 70]] [7559 5.62 [24 44] [31 100]]] [18 62]] [7421 11.8 [6 55] [16 64]]] [6 75]] [7668 1.73 [5192 0.393 [26 47] [26 66]] [25 44]]] [6 75]] [2564 6.85 [2 58] [2 100]]] [6 46]] [6515 25.1 [6 100] [6 73]]] [4 20]] [6 100]] [6 80]] [6184 15.6 [2 95] [2 80]]] [6 77]] [7711 20.8 [6413 0.0932 [978 2.92 [1919 1.07 [5769 1.63 [4394 2.33 [5 36] [26 100]] [26 100]] [4851 26.1 [17 41] [5 42]]] [26 55]] [17 50]] [5 75]]] [25 40]] [6 100]] [5 65]] [2275 9.06 [5624 3.7 [1783 0.582 [1078 3.7 [6 82] [6 100]] [6 90]] [6 100]] [6 85]]] [5962 13.6 [1283 0.418 [1899 4.19 [6 90] [6 100]] [6 50]] [6 64]]] [584 0.388 [1004 1 [980 0.16 [1919 5.77 [7324 1.19 [2591 0.105 [6173 1.01 [3905 0.553 [6550 0.104 [5770 0.8 [6260 0.938 [3659 1.37 [527 0.278 [6310 0.988 [896 2.26 [4146 2.3 [2398 2.49 [2607 0.438 [7583 1.1 [6184 3.32 [5515 5.82 [6883 6.12 [7343 0.273 [4369 3.47 [1240 3.4 [5480 3.07 [6729 2.87 [3895 2.2 [5820 2.44 [5812 8.99 [221 4.49 [6396 0.959 [1011 13.9 [6581 0.581 [2 11] [5 30]] [6 62]] [17 100]] [429 17 [4889 0.891 [4675 3.5 [25 50] [6 100]] [6 83]] [4 42]]] [2 25]] [4 100]] [31 75]] [19 37]] [2616 4.21 [19 50] [6230 3.07 [18 62] [18 44]]]] [24 90]] [31 81]] [1429 30.3 [19 31] [16 33]]] [7 81]] [5 88]] [2 46]] [25 66]] [18 50]] [12 90]] [24 100]] [5484 0.531 [6333 1.99 [1473 0.402 [286 0.318 [1190 2.77 [7414 12.4 [1546 1.15 [7032 1.95 [429 18.3 [392 3.4 [4279 0.364 [139 2.33 [6230 1.69 [2755 4.59 [6581 2.82 [18 13] [17 30]] [26 100]] [2628 1.57 [5 36] [5 50]]] [2 55]] [19 33]] [18 87]] [1023 2.13 [5753 1.21 [248 14.3 [7588 5.24 [1075 3.08 [4765 2.92 [1671 1.86 [1240 3.26 [929 3.29 [7700 3.79 [3667 2.99 [4718 5.51 [134 2.47 [5 26] [16 19]] [896 13.9 [5 67] [5 33]]] [4 53]] [5 37]] [929 7.82 [7 27] [7 45]]] [24 88]] [18 88]] [5 64]] [4 66]] [5 50]] [26 57]] [7248 1.44 [1239 2.37 [1429 11 [2 37] [1429 50.3 [5693 6.18 [5 95] [5 63]] [5 45]]] [5 100]] [5 50]]] [2841 3.11 [18 44] [17 46]]]] [4 45]] [5 100]] [2 70]] [2 29]] [2 47]] [5 100]] [5 74]] [18 57]]] [4507 0.126 [6294 0.707 [728 9.43 [5429 2.8 [5157 2.95 [7381 7.82 [7722 8.24 [7566 9.74 [1023 1.76 [2829 7.04 [5812 2.82 [6310 3.41 [2841 1.39 [5 28] [5 40]] [17 12.8 [5 62] [19 45]]] [5 68]] [17 41]] [17 23]] [17 54]] [5 65]] [17 31]] [7253 2.31 [5 85] [17 80]]] [5 100]] [17 88]] [5 69]] [18 72]]] [4 87]] [24 68]] [24 67]] [896 14.1 [4 94] [4 66]]] [5753 0.271 [1891 0.818 [1023 5.92 [1533 0.657 [1077 1.2 [5 58] [5 100]] [5 84]] [17 100]] [5 57]] [1429 54.4 [791 13.8 [5 66] [5 100]] [5 100]]]] [3910 3.65 [3519 0.492 [440 0.381 [3579 3.76 [7583 0.734 [1009 0.716 [6980 0.524 [2628 10.2 [695 14.3 [6206 4.92 [3928 2.55 [5510 1.04 [2029 1.16 [3905 36.7 [1703 2.42 [5799 0.739 [3113 0.498 [5412 2.07 [4806 2.66 [7188 5.77 [906 4.08 [1584 0.346 [7712 0.6 [1007 7.94 [17 45] [7 57]] [6581 8.13 [7 27] [17 80]]] [17 40]] [7 33]] [17 72]] [17 69]] [14 21]] [5 55]] [2 23]] [5297 4.19 [1980 2.57 [19 47] [17 66]] [26 37]]] [19 33]] [17 69]] [17 84]] [1703 0.526 [1690 6.44 [17 88] [17 83]] [17 100]]] [19 41]] [7 54]] [5 28]] [7689 0.28 [1899 2.98 [17 73] [17 100]] [7722 2.78 [17 80] [17 100]]]] [7 30]] [7 69]] [7590 1.83 [7 53] [7 95]]] [35 71]] [19 100]] [5 55]]] [31 100]] [4304 1.2 [7534 0.753 [2259 2.48 [695 12.1 [7598 11.5 [5345 6.37 [6883 7.95 [7413 0.379 [17 43] [17 70]] [6732 12.3 [5 100] [5 80]]] [5 90]] [2526 44.6 [1078 5.96 [17 88] [17 100]] [17 79]]] [19 43]] [5693 8.24 [5 58] [17 75]]] [17 100]] [5 54]]] [6587 0.965 [7006 10.1 [7255 1.47 [7317 0.464 [6657 5.68 [7722 1.3 [5 42] [5267 0.671 [7711 0.974 [2993 1.25 [7535 0.192 [5 68] [5 33]] [5 87]] [3928 2.23 [23 3.77 [5 85] [5 100]] [5 100]]] [5 100]]] [19 50]] [5 87]] [4 33]] [19 60]] [5 100]]] [2674 1.66 [7292 3.88 [7346 3.62 [6186 1.63 [1704 0.664 [6173 1.89 [6586 4.96 [2591 1.56 [7354 0.644 [429 52 [4338 6.6 [5192 3.07 [21 2.33 [7382 7.01 [4 23] [2 56]] [5 57]] [7700 1.1 [2 40] [17 50]]] [4154 10 [1 50] [4 50]]] [2 64]] [4154 1.93 [18 40] [5 62]]] [17 88]] [5 87]] [31 100]] [17 100]] [2 76]] [5 75]] [2 89]] [573 2.24 [2 95] [2 72]]]] [4394 0.16 [26 83] [26 100]]] [7449 2.44 [228 13 [2 92] [2 77]] [2 100]]] [570 2.33 [19 76] [19 46]]]] [2565 0.37 [4 79] [31 100]]] [2110 1 [2023 0.836 [1648 0.668 [7185 16.8 [791 22.7 [5348 10.2 [788 1.73 [5640 0.846 [5692 6.43 [5130 2.62 [5693 2.29 [18 93] [18 71]] [18 100]] [1239 1.26 [719 1.5 [18 92] [18 100]] [18 100]]] [18 100]] [18 93]] [18 84]] [18 81]] [18 62]] [18 100]] [18 50]] [18 66]]] [429 15.1 [4 95] [4 86]]] [5891 0.574 [3884 0.207 [736 0.136 [7016 3 [1063 0.205 [5 53] [5 70]] [12 60]] [6375 1.21 [4870 0.975 [6310 3.3 [573 1.97 [6732 1.66 [5 98] [5 83]] [5 71]] [5 70]] [14 33]] [5 58]]] [2760 0.364 [5 100] [5 94]]] [17 80]]] [5032 1.66 [2611 15.3 [4713 6.89 [6 94] [6 77]] [6 50]] [6 75]]] [2628 1.56 [5692 0.431 [26 80] [1919 0.357 [26 92] [26 100]]] [26 94]]] [23 2.7 [26 98] [2526 8.66 [2466 1.08 [7566 0.852 [26 72] [26 100]] [26 100]] [26 72]]]] [3315 0.194 [1668 0.106 [989 0.19 [4719 0.186 [1535 0.541 [5576 0.551 [7384 0.308 [3078 2.47 [3837 1.37 [2259 4.13 [249 0.592 [7528 0.357 [5660 4.53 [6581 1.47 [733 0.482 [731 2.48 [673 2.96 [4253 2.81 [5413 14.2 [1253 4.47 [2178 3.2 [7665 24.9 [2764 3.59 [2902 6.6 [5693 3.66 [4 26] [7665 15.2 [4 90] [4 40]]] [4 31]] [2 66]] [1 30]] [2 33]] [4 85]] [2 60]] [2 72]] [1 66]] [1073 2.75 [429 20.9 [5 36] [7 45]] [5887 1.42 [5 45] [5 62]]]] [16 37]] [2968 0.581 [567 2.85 [6591 1.12 [7677 1.67 [5 67] [5 33]] [17 83]] [17 45]] [5 93]]] [2 36]] [1 100]] [1 100]] [6544 0.705 [5383 6.83 [17 22] [17 100]] [17 76]]] [5 100]] [17 80]] [3302 0.487 [2081 0.81 [17 75] [17 100]] [17 44]]] [2 86]] [3213 0.541 [5 100] [5 85]]] [663 3.88 [1023 0.829 [1011 2.71 [17 63] [17 33]] [17 85]] [17 90]]] [5692 0.843 [17 72] [17 100]]] [494 0.106 [6534 0.624 [2628 9.66 [5753 1.18 [2628 8.87 [3928 0.546 [6042 1.17 [7601 1.4 [719 1.87 [19 36] [17 85]] [1069 2.38 [4507 0.891 [18 68] [18 90]] [18 75]]] [18 100]] [17 75]] [18 85]] [2628 5.71 [18 36] [7 40]]] [17 47]] [19 100]] [3414 1.4 [791 3.3 [17 47] [576 0.318 [5887 0.937 [3519 0.387 [2567 3.65 [724 2.23 [3492 0.693 [17 96] [17 100]] [17 87]] [17 80]] [19 80]] [17 71]] [17 100]]] [19 100]]]] [5 100]]] [6173 1.41 [4342 0.761 [7584 0.214 [642 0.949 [6926 0.314 [4025 1.74 [6982 0.464 [6252 4.81 [1048 1.48 [1690 0.404 [1400 0.191 [5844 0.122 [5815 1.23 [228 0.605 [4851 0.0691 [4214 0.978 [7356 0.0754 [7382 2.76 [1051 3.21 [602 0.623 [7516 1.04 [2753 1.44 [1899 38.1 [5812 1.08 [5142 10.6 [23 8.59 [719 9.01 [1906 5.31 [2902 6.51 [527 1.43 [939 0.309 [1007 1.78 [2745 1.53 [7266 8.91 [24 17] [2526 93.8 [2 80] [8 55]]] [17 28]] [4 62]] [17 40]] [4 75]] [24 45]] [24 58]] [4 59]] [2 73]] [2 80]] [731 0.686 [7594 10.3 [5914 0.249 [5413 5 [1429 5.81 [470 4.59 [6342 2.44 [2 56] [2 50]] [22 100]] [5 24]] [4 34]] [4 64]] [2 100]] [2760 2.58 [1072 4.08 [573 1.54 [4 36] [17 40]] [4 71]] [5 52]]]] [24 46]] [5 40]] [26 76]] [5 76]] [2 90]] [24 75]] [16 36]] [24 89]] [7188 0.0691 [4 50] [2753 0.207 [17 39] [5 66]]]] [6216 1.9 [23 15.6 [1888 2.16 [435 0.618 [2005 4.48 [6074 1.81 [2 77] [2 100]] [1640 5.89 [2 88] [2 75]]] [2 53]] [2616 8.72 [2960 1.03 [2259 0.688 [2 87] [2 66]] [2 50]] [4 53]]] [4 62]] [4 84]]] [2005 1.2 [655 2.16 [1078 5.35 [2 47] [6074 1.28 [2 60] [2 100]]] [2 100]] [4324 2.14 [2 92] [2 62]]]] [17 76]] [429 8.76 [26 41] [7168 0.682 [2976 0.179 [5575 3.47 [6230 2.24 [2 44] [2259 3.74 [2826 5.02 [4 75] [4 96]] [4 58]]] [4 100]] [4 100]] [2 50]]]] [7711 1.42 [17 64] [17 100]]] [24 95]] [5692 3.34 [1025 20.2 [4 53] [2 91]] [2628 1.44 [2 57] [2 80]]]] [4 94]] [24 100]] [5054 0.778 [4253 0.49 [6925 5.71 [3669 2.36 [6230 0.482 [6989 5.03 [6977 0.625 [6253 1.46 [1051 0.945 [2005 1.46 [2574 3.26 [1995 1.03 [2 78] [2 75]] [2 100]] [2 57]] [2 100]] [2 100]] [2 63]] [11 66]] [2 54]] [4 45]] [2 60]] [1059 3.36 [2 100] [2 71]]] [0 33]]] [5 70]] [7449 1.57 [4601 0.621 [7383 3.47 [939 1.54 [5654 0.596 [1640 0.502 [1239 0.838 [665 2.51 [6186 6.3 [2 100] [2 80]] [2 100]] [2 100]] [2 100]] [2 100]] [2 57]] [2 88]] [2 100]] [6988 1.77 [2 88] [15 44]]]] [2517 14.1 [3630 0.761 [2516 0.882 [24 95] [24 100]] [24 100]] [24 75]]] [31 100]]] [2906 2.84 [4349 2.2 [1072 1.61 [5192 6.77 [434 1.36 [5651 4.16 [5192 5.32 [7512 19.5 [1069 1.43 [5576 0.45 [2 93] [2 100]] [2 91]] [2 80]] [2 83]] [2 83]] [2 69]] [2 75]] [2 100]] [2 66]] [2 57]]] [2826 0.759 [1783 5.32 [7520 3.67 [6589 8.87 [5142 1.89 [6584 1.69 [5 65] [5 76]] [5 84]] [5673 4.35 [6443 5.05 [1078 0.734 [5 56] [19 56]] [5 57]] [19 54]]] [2616 22.5 [5 100] [5 87]]] [19 57]] [7593 0.991 [3972 0.437 [3204 0.911 [1899 1.39 [7269 0.635 [5 80] [5 45]] [6581 10.3 [5 100] [5 85]]] [5 100]] [7684 0.78 [5 66] [19 77]]] [19 66]]]] [5728 1.02 [2836 0.133 [5296 0.348 [6581 0.124 [6573 2.79 [2207 1.01 [5736 1.2 [3015 0.617 [1429 10.9 [7413 3.07 [5833 5.79 [2470 1.08 [25 33] [25 80]] [24 90]] [25 93]] [7210 0.119 [2005 0.606 [6550 1.17 [731 1.32 [4279 2.22 [6 30] [14 40]] [2259 3.99 [1633 0.949 [6230 6.55 [17 58] [5 25]] [19 83]] [5692 0.826 [7 100] [7 71]]]] [1769 3.14 [19 46] [17 71]]] [16 30]] [6575 0.357 [7381 0.911 [14 25] [7 71]] [2616 2.14 [19 88] [19 71]]]]] [25 100]] [24 77]] [6 88]] [24 95]] [3332 0.663 [5673 0.368 [6074 0.062 [3077 8.98 [2628 6.14 [6441 0.0562 [2530 0.238 [988 1.36 [2616 29.9 [1027 9.65 [7689 4.59 [1690 0.812 [5905 0.989 [3284 0.791 [7711 2.5 [4781 0.514 [6953 0.949 [7590 0.535 [7169 4.62 [978 17.7 [668 7.34 [5641 0.881 [5154 1.93 [7722 4.9 [3734 4.5 [2939 0.492 [17 30] [19 66]] [17 68]] [3732 6.05 [17 94] [17 64]]] [7722 3.98 [17 60] [17 91]]] [30 37]] [19 90]] [7248 0.228 [17 87] [17 60]]] [17 89]] [5896 0.356 [7067 2.91 [695 1.69 [17 47] [17 90]] [17 50]] [14 57]]] [17 100]] [35 28]] [7241 0.303 [5692 3.24 [2628 1.25 [1190 2.85 [17 52] [17 50]] [19 63]] [7566 0.978 [16 62] [17 75]]] [6550 5.78 [2536 0.332 [38 31] [19 37]] [17 81]]]] [35 83]] [19 77]] [6311 0.729 [2753 0.345 [17 92] [17 100]] [17 75]]] [1151 0.611 [2829 0.885 [17 50] [17 57]] [19 83]]] [26 66]] [19 77]] [17 46]] [26 100]] [19 77]] [7725 0.283 [5895 2.31 [2081 0.914 [7676 1.97 [1078 0.69 [17 58] [663 4.66 [1078 4.05 [19 83] [17 45]] [4479 0.695 [19 81] [19 66]]]] [17 80]] [17 100]] [17 50]] [3519 0.878 [19 60] [19 100]]]] [19 53]] [5891 1.69 [1666 1.29 [4338 2.07 [929 0.431 [17 82] [17 100]] [17 57]] [38 33]] [1745 2.22 [17 100] [17 57]]]] [6708 0.816 [7057 1.68 [3823 0.343 [6591 2.38 [6978 5 [5904 0.218 [5953 2.39 [5632 0.338 [3715 0.09 [3094 0.611 [6199 2.26 [791 14.1 [3983 4.52 [573 1.11 [4851 7.51 [6388 1.44 [728 4.4 [1746 0.528 [1885 0.701 [2826 1.97 [38 66] [17 80]] [17 50]] [38 72]] [17 62]] [17 77]] [19 66]] [7595 1.13 [17 89] [17 50]]] [19 35]] [5673 6.35 [17 44] [38 58]]] [600 0.661 [19 69] [17 65]]] [23 55]] [1023 0.662 [978 13.3 [4939 1.31 [19 87] [19 71]] [485 7.85 [38 38] [19 100]]] [19 50]]] [38 44]] [3983 4.82 [7588 0.608 [17 50] [38 80]] [35 50]]] [2536 0.224 [19 100] [19 62]]] [35 75]] [6586 2.51 [7068 4.71 [1750 0.343 [1060 0.74 [2628 4.99 [7185 3.3 [2753 0.742 [17 62] [19 55]] [6550 10.2 [429 35.3 [17 100] [17 63]] [17 33]]] [791 13.2 [17 58] [19 70]]] [19 88]] [7595 0.851 [17 53] [4851 2.02 [17 85] [17 91]]]] [17 100]] [19 73]]] [2939 2.53 [19 100] [19 75]]] [19 100]] [5819 0.148 [736 1.7 [19 40] [19 75]] [19 100]]]] [719 3.29 [6357 1.39 [35 100] [35 85]] [17 57]]]] [2108 0.835 [5904 1.37 [5741 7.36 [7244 1.27 [1899 5.18 [6591 3.65 [3008 2.27 [19 100] [1633 0.887 [2601 0.69 [5693 1.34 [19 69] [7188 0.542 [17 80] [19 75]]] [19 87]] [31 0.805 [3094 0.606 [19 60] [2636 2.18 [19 80] [19 100]]] [19 100]]]] [17 50]] [25 50]] [17 50]] [19 57]] [6977 2.32 [4158 1.1 [5316 0.75 [19 71] [5673 2.37 [19 100] [647 0.21 [19 100] [19 83]]]] [19 66]] [5905 0.404 [19 92] [19 100]]]] [17 71]]] [25 100]] [3102 0.55 [7381 7.64 [7590 3.57 [3636 1.1 [7512 16.6 [1640 1.65 [24 54] [24 100]] [24 100]] [24 100]] [24 42]] [24 100]] [24 100]]]] [5820 1.84 [224 1.65 [7712 1.32 [1911 1.95 [2684 0.377 [791 15.1 [4848 6.78 [978 4.22 [4 95] [6077 0.201 [5771 2.64 [2628 4.19 [4 96] [4 80]] [4 83]] [4 83]]] [4 75]] [4 76]] [4 100]] [4 62]] [695 2.41 [2 33] [4 90]]] [2 41]] [1101 2.01 [7449 19.5 [4 100] [4 66]] [4 62]]]] [993 10.8 [2536 13.2 [515 1.24 [25 4.53 [6727 5.39 [5662 14.5 [6727 0.369 [5647 1.25 [2567 0.229 [7665 13.4 [23 11.1 [4 100] [719 9.3 [2742 7.31 [4960 2.44 [4 60] [4 100]] [4 100]] [4 88]]] [4 100]] [4 100]] [4 100]] [4 90]] [4 85]] [4 60]] [6216 5.41 [4 66] [4 100]]] [4 90]] [4 85]] [4 90]]] [5869 0.0723 [3905 1.48 [681 0.767 [2748 0.306 [5484 0.192 [2915 0.898 [2739 0.916 [7301 0.701 [7734 0.622 [985 2.84 [6180 1.06 [1081 0.193 [1600 1.02 [5734 2.28 [4991 4.13 [5593 0.597 [7187 4.45 [5675 3.76 [248 14.1 [228 1.08 [5509 0.952 [2576 0.833 [4929 2.33 [2813 0.415 [5309 3.68 [1445 0.875 [7512 7.07 [896 3.13 [5662 0.15 [7 15] [38 27]] [2616 5.07 [5 57] [2 62]]] [6866 1.28 [3100 0.78 [731 5.13 [7697 0.316 [1400 14.5 [7414 2.61 [7419 2.16 [7 10] [6 66]] [18 66]] [31 50]] [31 100]] [5 33]] [1 100]] [5 100]]] [22 57]] [18 87]] [18 69]] [4 53]] [18 88]] [5 44]] [5647 5.07 [2752 2.26 [4 100] [2 84]] [2 100]]] [5480 1.46 [26 44] [5534 1.54 [26 79] [26 71]]]] [24 86]] [26 77]] [6 43]] [791 9.93 [1429 8.58 [1899 4.24 [2 40] [2 92]] [1 33]] [2 63]]] [7 100]] [7 100]] [23 4.01 [26 80] [26 55]]] [25 100]] [4414 2.98 [26 61] [26 45]]] [662 4.39 [5480 1.3 [2526 5.53 [5 46] [7 65]] [5716 0.637 [896 9.89 [18 61] [18 90]] [16 66]]] [24 44]]] [1668 0.973 [4571 0.458 [18 59] [19 57]] [19 57]]] [7327 1.3 [4 95] [2259 1.69 [4 100] [4 75]]]] [906 0.424 [418 0.313 [26 79] [26 100]] [26 100]]] [5904 0.729 [2091 0.109 [929 1.39 [4645 0.223 [6727 0.192 [7139 0.824 [5348 5.08 [5662 0.208 [1888 4.18 [18 84] [7169 5.32 [18 83] [18 71]]] [18 92]] [18 100]] [18 83]] [18 100]] [18 76]] [18 57]] [18 50]] [19 57]]] [663 10.1 [4876 0.747 [5851 5.11 [7185 0.487 [736 1.03 [26 97] [26 57]] [26 100]] [26 80]] [26 80]] [26 60]]] [7169 5.43 [26 96] [26 80]]] [828 0.293 [6575 1.08 [2591 0.356 [7 79] [17 75]] [17 87]] [7 100]]] [4991 0.289 [724 0.51 [5870 0.156 [26 62] [26 100]] [26 83]] [26 66]]]] [5665 4.03 [4684 1.37 [654 7.67 [4601 4 [827 1.22 [1000 1.12 [6193 0.556 [5198 4.57 [7742 0.269 [906 0.359 [7568 3.53 [2178 2.21 [7241 2.64 [4 100] [4 83]] [2739 1.54 [4 62] [4 100]]] [4 80]] [4 100]] [4279 1.08 [1007 2.51 [4 100] [4 90]] [2739 7.28 [4 85] [4 100]]]] [4 75]] [4 66]] [4 71]] [4 85]] [4 81]] [4 66]] [2259 0.709 [4 50] [2 42]]] [2 66]]]] [6187 0.459 [7020 0.127 [2976 0.252 [7544 1.52 [5233 0.747 [5732 0.187 [7324 0.399 [5847 0.0927 [3936 2.17 [2676 0.0648 [6088 0.0921 [2482 1.26 [4723 1.42 [6539 0.454 [3554 1.6 [5211 4.39 [2553 1.97 [6186 0.493 [736 0.382 [5969 1.35 [4851 1.42 [4959 0.897 [1919 2.25 [223 3.11 [2488 21.5 [2526 10.8 [2753 28.5 [2178 15.6 [789 1.09 [1011 5.81 [520 6.85 [2808 2.67 [1713 5.29 [2939 9.63 [7357 0.752 [5007 18.5 [685 0.876 [6359 1.47 [5462 5.96 [4159 1.79 [1078 16.4 [4832 26.2 [1986 3.31 [4369 1.86 [7329 0.967 [6997 2.85 [2 18] [22 30]] [35 30]] [12 90]] [4 45]] [2 27]] [5673 0.649 [1101 2.2 [2 31] [2 70]] [35 40]]] [2 60]] [4 56]] [29 50]] [23 32]] [2 100]] [35 88]] [4 51]] [31 100]] [15 100]] [23 12 [7665 12.2 [4768 5.63 [2 36] [2 66]] [2 81]] [36 37]]] [2 37]] [31 100]] [2 69]] [2 84]] [899 4.49 [3130 3.14 [2793 2.39 [1173 0.682 [1078 9.45 [429 2.95 [2 67] [2628 0.855 [2 44] [2939 5.03 [4 60] [2 40]]]] [4929 16.6 [2628 8.62 [2143 3.07 [1089 2.4 [2 48] [22 57]] [2 66]] [4 69]] [4 57]]] [2 89]] [24 77]] [4 46]] [31 62]]] [8 81]] [978 3.98 [2 100] [2 75]]] [5345 3.22 [7413 3.85 [2902 0.548 [7700 0.785 [7149 1.15 [228 1.34 [2 48] [2 80]] [4 44]] [2 85]] [1640 0.534 [2536 6.98 [1094 0.306 [2905 4.55 [2 71] [2 100]] [2 66]] [2 70]] [2905 0.357 [2 87] [2 90]]]] [4 37]] [4 69]]] [7512 10.6 [2753 0.474 [1062 0.81 [4 97] [4 100]] [4 100]] [1429 9.24 [4 100] [4 91]]]] [5267 5.12 [6552 0.956 [4 68] [4 100]] [4 88]]] [1668 0.575 [2 25] [1986 0.743 [6588 0.759 [17 50] [17 100]] [17 33]]]] [2752 18.2 [6074 0.797 [6581 1.76 [1089 1.03 [2 44] [4 100]] [5 33]] [4833 0.429 [4 61] [4 97]]] [724 1.34 [957 2.17 [7381 2.58 [4 31] [2 62]] [19 100]] [19 80]]]] [7185 1.66 [7255 0.426 [5812 18.2 [3667 0.748 [7413 0.313 [1033 3.22 [4768 3.14 [2 89] [2 80]] [2 100]] [2 100]] [2 100]] [2 92]] [2 85]] [2 42]]] [4351 9.35 [5299 1.23 [6363 2.26 [665 1.29 [1888 2.22 [4414 11.4 [978 19.2 [4776 3.67 [2 79] [4 66]] [978 23.1 [2 100] [2 87]]] [2 57]] [2 56]] [2 100]] [4 85]] [2 93]] [4 71]]] [6795 1.34 [5412 1.79 [2143 0.97 [22 25] [22 60]] [5812 2.25 [2526 1.76 [22 77] [23 90]] [2 44]]] [35 33]]] [12 74]] [5769 1.1 [5413 12.1 [2 99] [2 85]] [2 100]]] [4 100]] [31 100]] [978 17.1 [637 9.21 [736 1.05 [5211 0.77 [144 9.9 [4253 2.22 [2 100] [2 91]] [2 85]] [2 83]] [2 83]] [2 76]] [19 0.621 [1068 0.57 [178 2.82 [5812 0.647 [2 90] [1049 2.57 [2 91] [2 44]]] [2 50]] [2 100]] [2 100]]]] [2674 0.0934 [2 47] [1400 6.25 [1078 15.3 [2 100] [5659 0.266 [6791 2.48 [2 100] [2 88]] [2 100]]] [1400 13.7 [2 88] [2 100]]]]] [7665 5.4 [4 87] [4 100]]] [639 0.318 [6294 0.278 [6230 0.0927 [228 3.93 [4 80] [4 100]] [4 100]] [4 75]] [4 100]]] [2961 0.138 [4 48] [6217 0.213 [4 75] [6621 1.2 [4 100] [4 80]]]]] [6980 0.204 [1025 4.55 [896 1.3 [7411 0.963 [15 58] [15 100]] [17 45]] [1429 33.8 [24 96] [24 71]]] [17 100]]] [22 100]] [1690 1.05 [6088 0.773 [664 2.89 [2005 3.78 [5054 1.52 [5648 1.63 [43 1.44 [4414 24.7 [6982 1.36 [2 78] [7665 10.2 [4 76] [5771 6.86 [4 87] [4 100]]]] [2 100]] [4 100]] [2 42]] [4 100]] [4154 5.11 [2 77] [2 100]]] [2 100]] [4832 4.27 [2 85] [2616 13.8 [140 0.787 [2812 0.773 [4832 9.92 [2 93] [2 100]] [2 100]] [2 100]] [2 80]]]] [17 60]]] [4684 0.465 [429 13.7 [4154 1.88 [4 95] [4 88]] [4 100]] [4 100]]] [144 7.13 [725 0.291 [2628 26.9 [4 100] [4 80]] [4 66]] [2 57]]] [6989 0.099 [2740 0.381 [4841 6.03 [1640 1.84 [4533 2.92 [5673 4.64 [4338 3.98 [2939 3.69 [6184 2.36 [1075 0.117 [2081 0.367 [2 62] [4 44]] [2 55]] [5451 4.94 [2745 0.15 [1170 3.3 [5665 2.6 [2752 0.937 [2 85] [7742 9.11 [1141 5.25 [2764 2.67 [1011 3.69 [2 99] [7702 0.37 [2 100] [2 90]]] [2 61]] [2 77]] [2 83]]] [5662 5.56 [2 66] [2 100]]] [2 72]] [2 100]] [2 68]]] [5693 3.67 [15 50] [2 72]]] [7584 6.72 [1919 0.73 [7512 2.11 [4253 10.8 [2 55] [2 100]] [2 100]] [2 100]] [2 90]]] [2 69]] [4991 0.795 [2 52] [2 100]]] [1980 4.52 [4414 0.856 [4833 0.918 [4 90] [2 62]] [2 75]] [5574 4.68 [22 50] [2 76]]]] [2 54]] [4 100]] [7584 9.55 [4159 4.93 [6641 0.287 [5989 0.238 [2812 4.41 [6982 0.253 [7544 8.07 [2767 2.51 [5693 0.263 [6817 0.989 [2526 9.83 [2 86] [1062 0.64 [2574 3.61 [6077 1 [2 97] [2 100]] [2 88]] [2 100]]] [2 100]] [5838 1.73 [2947 0.9 [2 100] [223 1.49 [2 100] [2 83]]] [2 77]]] [2 71]] [2 78]] [4 81]] [2 77]] [2 71]] [2 77]] [5299 1.9 [1025 6.53 [4595 4.01 [2 100] [2 85]] [2 75]] [2 62]]] [2 64]]]]] [2525 0.928 [6711 0.161 [4214 1.56 [4907 0.21 [392 0.286 [6160 0.209 [5211 2.03 [20 0.417 [4611 0.178 [6231 0.365 [1406 0.255 [3004 0.662 [6524 1.32 [899 0.367 [968 3.86 [4154 9.76 [1708 3.89 [5270 0.649 [682 6.5 [2421 1.64 [2260 3.31 [731 12.3 [5472 0.453 [2259 12.1 [1769 18.4 [1429 33.6 [1011 5.38 [7428 1.08 [5753 0.997 [24 53] [24 70]] [12 90]] [24 100]] [717 2.59 [1078 0.766 [36 38] [663 2.61 [5480 8 [7722 1.43 [7374 7.01 [24 47] [24 90]] [24 90]] [18 77]] [36 50]]] [36 52]]] [36 55]] [36 70]] [7526 2.28 [3011 1.81 [5472 24.9 [791 23.2 [36 100] [6859 16.5 [36 100] [36 60]]] [36 92]] [36 100]] [36 100]]] [31 57]] [1746 1.43 [2273 3.8 [36 88] [36 100]] [36 100]]] [36 75]] [683 3.14 [31 95] [31 100]]] [3644 1.59 [6134 3.62 [1429 51.3 [31 95] [31 66]] [31 100]] [36 100]]] [2232 2.76 [28 93] [28 100]]] [144 10.5 [4545 3.81 [5267 5.67 [2548 0.838 [4815 2.86 [24 66] [24 100]] [24 100]] [5267 13.1 [31 88] [24 55]]] [24 100]] [36 68]]] [28 65]] [632 0.538 [7419 0.569 [631 4.72 [1913 0.715 [1783 2.06 [5692 6.61 [7693 3.62 [4154 0.942 [2832 4.44 [36 91] [36 50]] [36 100]] [36 71]] [36 100]] [36 66]] [36 100]] [1078 12.1 [36 83] [36 70]]] [36 100]] [36 100]]] [5732 5.6 [36 91] [36 66]]] [1089 0.373 [2421 0.894 [2029 3.19 [36 98] [36 100]] [36 100]] [36 100]]] [31 100]] [31 93]] [429 10.1 [1078 1.09 [2350 0.709 [36 62] [31 100]] [5270 1.44 [7712 0.364 [36 71] [36 84]] [31 100]]] [2470 2.79 [899 13.5 [3067 0.466 [2993 0.45 [7255 1.97 [1888 0.638 [7241 1.14 [4814 3.65 [2259 46.6 [1628 1.56 [36 82] [36 100]] [31 60]] [36 100]] [36 100]] [4296 0.213 [6205 0.677 [3647 0.327 [7169 0.892 [36 97] [36 100]] [36 100]] [36 100]] [36 100]]] [12 62]] [36 100]] [5705 3.1 [36 100] [1888 0.952 [36 100] [36 66]]]] [31 62]] [31 100]]]] [713 0.491 [7302 0.254 [2309 0.662 [721 0.512 [1239 0.675 [6261 11.5 [871 1.15 [532 0.891 [36 100] [36 80]] [36 100]] [24 50]] [36 100]] [7354 0.986 [1078 9.34 [36 100] [36 88]] [36 100]]] [36 100]] [36 77]] [36 100]]] [6820 0.455 [1391 0.2 [2453 2.33 [1899 20.8 [3052 2.42 [2846 0.304 [3841 0.734 [5092 1.75 [22 68] [22 100]] [22 100]] [22 100]] [30 100]] [36 54]] [24 100]] [22 100]] [22 100]]] [5086 0.415 [970 1.46 [1841 6.99 [4006 1.1 [1708 5.13 [31 55] [28 88]] [13 37]] [28 100]] [28 93]] [28 70]]] [731 0.94 [5480 2.36 [4011 1.59 [164 0.37 [28 84] [28 100]] [28 77]] [1219 0.43 [6859 8.53 [18 50] [16 37]] [22 77]]] [394 0.824 [5692 1.4 [18 72] [18 100]] [26 33]]]] [4338 4.68 [900 1.41 [7185 0.419 [4545 0.462 [902 1.8 [36 100] [36 62]] [36 100]] [36 100]] [36 66]] [24 100]]] [3663 6.29 [7026 2.25 [3905 1.04 [655 10.4 [7382 4.17 [655 3.76 [7722 6.09 [1746 7.88 [1628 1.05 [24 93] [24 100]] [24 91]] [24 75]] [24 72]] [24 100]] [24 60]] [36 100]] [24 75]] [19 50]]] [6499 0.31 [906 0.197 [6732 0.293 [22 86] [22 100]] [22 71]] [22 100]]] [208 5.01 [24 97] [24 75]]]] [6732 0.317 [5692 2.3 [7512 7.34 [6009 2.11 [6227 0.602 [5264 1.59 [5999 18.7 [248 4.19 [3056 0.936 [4154 7.1 [1788 1.05 [2081 15.5 [791 8.07 [3191 1.61 [7254 1.93 [1919 2.64 [1888 2.06 [978 0.312 [3492 4.52 [7168 0.785 [131 6.59 [3724 0.679 [5753 1.02 [3079 1.12 [1899 1.23 [37 43] [29 27]] [1079 3.46 [3905 12.4 [3879 3.23 [37 100] [37 71]] [37 96]] [37 83]]] [37 33]] [37 45]] [37 100]] [35 33]] [37 100]] [38 33]] [2752 5.81 [13 62] [17 38]]] [8 41]] [37 100]] [37 100]] [1079 6.89 [728 5.86 [3157 0.139 [1518 10.9 [3294 0.861 [3719 19.7 [668 13.1 [3262 0.649 [144 17.9 [1429 67.2 [144 4.53 [3374 3.51 [112 1.31 [1025 1.95 [37 73] [37 54]] [37 81]] [37 100]] [37 57]] [37 68]] [11 42]] [4011 6.75 [3831 17.8 [3301 13 [479 5.45 [2763 8 [7169 15.1 [3171 0.333 [3249 7.66 [3822 3.64 [832 0.423 [49 0.803 [791 19.5 [37 100] [2753 0.975 [3125 1.22 [1535 2.06 [37 97] [37 100]] [37 100]] [37 100]]] [37 100]] [37 100]] [37 80]] [37 80]] [37 100]] [37 85]] [37 94]] [37 84]] [37 85]] [37 60]] [37 90]]] [13 71]] [37 84]] [3294 9.62 [37 100] [3125 4.85 [37 96] [37 100]]]] [37 80]] [37 100]] [37 53]] [37 72]]] [29 38]] [38 50]] [2752 14 [2 18] [37 50]]] [1482 2.48 [978 0.858 [2161 3.3 [1545 2.76 [1463 0.534 [37 59] [3883 1.24 [1239 7.44 [1463 21.2 [3907 2.48 [3928 12.2 [3185 0.982 [3511 10.4 [3086 19.1 [429 5.57 [37 93] [37 100]] [37 81]] [37 90]] [37 100]] [37 89]] [37 96]] [37 90]] [37 91]] [37 100]]] [37 86]] [37 90]] [37 57]] [37 100]]] [38 20]] [33 63]] [13 100]] [5 33]] [30 100]] [7385 2.48 [6199 3.76 [2259 8.7 [7512 14.3 [3718 2.22 [7354 1.34 [37 51] [5 50]] [37 100]] [7698 2.42 [37 20] [13 100]]] [7512 15.7 [13 28] [19 29]]] [30 28]] [13 100]]] [6429 1.33 [3262 1.16 [5155 0.673 [7520 1.15 [6524 3.33 [1180 2.06 [7722 3.28 [33 20] [13 46]] [13 100]] [36 50]] [26 44]] [17 37]] [37 100]] [13 100]]] [134 0.671 [6333 4.22 [2752 16.5 [5472 1.13 [4611 0.605 [13 23] [4 37]] [6744 2.17 [13 100] [13 88]]] [22 24]] [22 40]] [2 39]]]] [1424 0.626 [6373 2.55 [5999 7.74 [3964 1.23 [4764 2.71 [407 3.02 [4920 1.2 [7341 1.4 [4338 0.686 [3644 5.51 [6853 17.4 [24 27] [2518 3.94 [24 55] [24 92]]] [24 75]] [7085 3.94 [5898 3.26 [5675 7.41 [3820 0.914 [7419 0.444 [1783 2.03 [3637 3.76 [5803 0.402 [328 9.33 [7070 2.59 [4339 9.95 [7057 7.24 [3018 0.188 [5412 4.65 [4677 8.93 [5866 3 [7623 6.96 [7425 12.7 [3663 14.6 [4339 0.317 [4342 0.419 [1911 0.699 [4146 1.37 [1020 1.43 [2526 13.5 [24 100] [24 99]] [24 100]] [24 100]] [24 100]] [24 100]] [24 100]] [24 90]] [24 91]] [24 83]] [6266 0.931 [24 89] [24 100]]] [24 87]] [5662 1.44 [24 93] [24 100]]] [24 100]] [24 77]] [4154 19.2 [24 80] [24 100]]] [24 94]] [24 71]] [24 75]] [896 2.9 [24 100] [1078 2.06 [24 63] [24 100]]]] [2616 2.02 [4347 3.78 [7566 1.98 [227 0.75 [4545 0.445 [24 94] [24 100]] [24 100]] [24 87]] [24 83]] [5675 0.352 [24 88] [24 59]]]] [24 100]] [24 60]] [24 86]] [24 83]] [24 80]]] [24 55]] [24 50]] [34 100]] [24 50]] [24 44]] [28 42]] [5267 1.31 [1899 2.76 [24 70] [24 100]] [19 90]]] [10 100]]] [6015 2.23 [2993 5.21 [1078 3.23 [23 9.84 [2526 9.45 [4690 2.15 [20 94] [7623 14.3 [2199 18.3 [4294 11.4 [1980 30.1 [7524 0.65 [7539 19.2 [20 100] [20 85]] [20 100]] [20 85]] [20 97]] [20 83]] [20 93]]] [20 71]] [20 78]] [2811 3.89 [2023 3.24 [1769 4.36 [799 0.821 [3027 10.4 [791 10.3 [5559 0.14 [4607 0.459 [4672 0.773 [7599 0.934 [7755 8.51 [20 100] [4699 11.8 [20 100] [20 60]]] [20 100]] [20 100]] [20 100]] [20 100]] [20 88]] [20 83]] [20 71]] [1769 14.3 [1 28] [20 100]]] [20 75]] [20 66]]] [20 78]] [20 77]]] [150 0.792 [7307 0.613 [873 1.96 [7032 7.59 [7246 1.12 [43 3.51 [23 1.79 [4684 8.53 [5007 17.2 [719 0.684 [462 10.6 [5914 1.16 [6449 4.07 [2913 4.1 [2534 1.52 [7245 4.12 [6791 37.5 [1400 14.3 [1095 8.25 [3008 23.5 [1883 2 [6603 2.02 [7094 1.24 [286 6.38 [663 4.1 [3931 15.9 [1429 6.95 [1998 8.02 [4991 1.95 [7512 9.85 [7424 0.425 [2526 25.2 [5693 4.52 [1764 0.431 [8 80] [8 100]] [8 100]] [7453 7.35 [1986 6.19 [429 1.12 [3911 3.82 [5833 6.85 [8 93] [8 100]] [8 100]] [1062 0.121 [5192 0.768 [2361 0.931 [1429 0.423 [2752 0.829 [4693 6.33 [2568 4.13 [5211 21.9 [7176 3.31 [8 97] [8 100]] [8 90]] [8 100]] [8 100]] [2555 1.1 [8 98] [8 100]]] [8 100]] [8 100]] [8 100]] [8 100]]] [8 77]] [8 66]]] [8 100]] [8 72]] [8 41]] [8 66]] [441 2.89 [4858 2.88 [5462 10.4 [1906 17 [6031 5.48 [7742 7.83 [2763 11.5 [1986 1.46 [7185 16.5 [978 0.39 [5851 16.4 [1078 19.5 [5412 1.35 [4935 1.78 [8 98] [8 100]] [8 100]] [2550 11.6 [2575 1.09 [2259 4.27 [8 81] [8 100]] [8 100]] [8 85]]] [8 64]] [7179 0.24 [2399 0.418 [2494 13.3 [6184 2.28 [3113 0.39 [5420 4.24 [3072 7.31 [434 4.63 [6251 1.33 [8 100] [8 87]] [6560 1.18 [8 96] [8 100]]] [8 60]] [3057 1.49 [8 97] [8 100]]] [8 100]] [8 66]] [8 81]] [8 100]] [8 100]]] [8 55]] [4158 0.311 [333 1.23 [5412 1.27 [8 100] [8 94]] [8 100]] [8 100]]] [8 81]] [8 75]] [8 50]] [8 62]] [8 66]] [8 77]] [8 66]]] [1062 0.986 [8 94] [8 77]]] [8 41]] [7512 0.479 [8 66] [2 42]]] [23 62]] [35 100]] [8 60]] [24 62]] [8 75]] [10 85]] [8 58]] [8 50]] [0 61]] [0 42]] [8 76]] [2143 0.695 [791 8.06 [8 50] [23 100]] [23 100]]] [0 33]] [2 55]] [8 58]] [8 55]] [5040 1.5 [6310 1.33 [896 2.77 [312 0.527 [2488 1.96 [8 40] [1436 0.126 [8 98] [8 100]]] [35 40]] [19 44]] [0 66]] [22 33]]] [4 100]] [10 100]] [2 76]] [4690 5.72 [0 50] [0 84]]] [0 100]] [10 100]]] [3003 0.177 [1235 0.325 [1300 0.452 [1192 0.333 [2630 1.85 [663 0.0287 [957 1.19 [7340 0.588 [6350 0.15 [5730 0.147 [499 0.623 [2807 0.356 [2550 0.146 [2004 0.241 [6125 1.29 [4690 1.8 [5082 1.41 [1125 0.982 [3667 0.423 [5455 0.196 [5063 5.37 [820 1.42 [3304 1.96 [791 0.513 [1161 1.33 [4326 11.1 [169 2 [7741 6.62 [3712 0.537 [5254 0.182 [4122 9.68 [2989 3.65 [685 1.1 [2913 1.69 [719 1.75 [939 11 [3926 4.13 [4331 11.1 [1955 12.5 [1150 16.7 [3435 2.91 [3156 2.2 [3480 1.47 [2007 2.76 [1980 15.8 [3849 3.73 [4832 2.67 [203 31.3 [2461 4.17 [4320 1.46 [2826 0.418 [2760 2.62 [217 2.37 [665 4.18 [6260 14.4 [4231 1.28 [434 3.46 [2276 5.02 [5670 12.2 [4663 25 [6031 7.43 [4079 6.49 [3931 31.3 [5676 14.5 [1078 129 [4802 1.64 [2657 15 [1400 2.7 [5962 2.03 [6982 12.2 [2130 0.998 [312 20 [4981 9.68 [99 0.516 [4235 11.6 [2752 30.9 [2343 11.1 [4630 12.6 [1925 7.6 [3531 23 [5589 6.8 [1206 3.03 [5462 2.44 [728 3.94 [6580 5.49 [1116 14.9 [1909 3.65 [1 9.43 [168 65.2 [1 9] [19 50]] [9 25]] [2 43]] [30 72]] [31 100]] [10 54]] [4611 3.7 [35 32] [35 53]]] [24 85]] [30 100]] [22 100]] [28 83]] [23 41]] [30 100]] [1084 2.24 [4601 5.38 [3095 16.2 [7742 16.7 [7449 8.86 [7665 1.16 [7512 10.5 [23 19] [22 63]] [22 37]] [1217 17 [29 42] [29 44]]] [2 35]] [978 8.47 [5 28] [23 100]]] [26 37]] [23 85]]] [1899 5.58 [20 75] [1 44]]] [19 60]] [26 100]] [2 53]] [1 25]] [4 100]] [20 41]] [2259 7.62 [10 26] [10 66]]] [4 88]] [33 42]] [4159 3.88 [2241 28.4 [7449 21.1 [2093 3.05 [2044 6.85 [2027 0.652 [978 0.104 [1108 4.49 [2212 0.244 [3227 8.74 [4279 0.261 [2232 18 [7428 1.4 [1587 8.2 [5156 18 [1953 2.84 [2023 0.914 [1228 31.6 [1 37] [28 57]] [1 60]] [1 77]] [33 44]] [12 40]] [1 55]] [32 37]] [28 17]] [25 31]] [10 28]] [1429 5.96 [1099 0.325 [1 34] [2201 10.5 [10 37] [1 20]]] [29 35]]] [1911 25.1 [0 20] [4 42]]] [1 90]] [1 78]] [28 30]] [23 50]] [3 21]] [23 36]]] [35 57]] [31 42]] [31 100]] [22 88]] [7665 4.95 [1 23] [4 26]]] [31 100]] [1 61]] [4 29]] [7512 21.3 [1980 6.13 [10 50] [18 60]] [10 89]]] [6260 32.3 [8 92] [8 50]]] [2 100]] [10 75]] [8 53]] [1911 9.62 [5 32] [17 26]]] [27 90]] [27 92]] [22 88]] [4594 8.38 [7665 15.8 [4 54] [2 77]] [24 66]]] [35 77]] [3616 13 [1909 6.07 [4332 5.75 [1123 26.3 [6732 13.6 [4011 7.46 [7514 1.3 [5393 10.9 [929 2.02 [2939 12.7 [5110 26.2 [1925 7.21 [4279 1.27 [5673 16.1 [2259 6.36 [4161 7.81 [4154 5.43 [2093 25.7 [1078 151 [1995 58 [1176 5.15 [2766 30.8 [1980 24 [1 18] [1089 39.7 [2763 7.46 [23 13] [23 33]] [28 40]]] [25 30]] [4 23]] [27 31]] [1 35]] [28 44]] [23 44]] [23 40]] [10 14]] [35 50]] [4154 7.69 [23 51] [429 21.5 [15 16] [29 33]]]] [15 30]] [11 100]] [15 42]] [23 66]] [4 30]] [19 51]] [15 66]] [22 57]] [1 85]] [27 30]] [4 83]] [23 90]]] [2091 19.8 [10 63] [10 100]]] [15 53]] [35 83]] [35 46]] [3609 20.9 [35 54] [35 89]]] [1 55]] [27 64]] [8 100]] [6927 3.23 [27 35] [8 38]]] [5972 2.86 [6230 5.35 [5812 2.86 [4 27] [2 50]] [17 38]] [31 100]]] [7241 4.58 [5110 5.05 [25 22] [30 82]] [30 63]]] [23 35]] [1101 6.33 [28 83] [28 66]]] [27 90]] [10 96]] [35 93]] [10 89]] [169 12.1 [19 63] [19 82]]] [27 28]] [1079 0.824 [1089 11.3 [4200 1.43 [144 1.61 [2055 6.19 [4198 5.26 [392 6.83 [7512 7.76 [27 52] [10 89]] [10 77]] [10 80]] [27 83]] [10 85]] [10 85]] [23 27]] [2178 1.28 [10 98] [10 87]]]] [3449 0.204 [896 0.197 [4288 2.29 [2752 16.6 [6665 1.2 [1219 1.52 [2764 1.48 [2701 1.23 [6848 1.67 [1426 3.55 [4114 13.8 [312 5.26 [4369 12.1 [7324 5.85 [3538 0.539 [2575 2.18 [3265 9.98 [4851 5.56 [3388 3.44 [5673 16.2 [3309 7.56 [3045 6.64 [2488 9.34 [836 1.87 [3273 0.732 [6529 6.11 [3829 16.3 [4006 0.414 [4154 1.04 [5284 8.2 [7101 1.9 [2178 19.6 [1121 3.33 [3944 1.2 [6491 4.67 [3452 2.37 [7428 7.17 [5851 12 [7657 5.38 [2411 1.17 [7445 0.53 [5403 2.54 [2628 14.4 [1402 11 [599 3.5 [802 36.6 [5692 7.7 [3444 6.03 [756 1.18 [2055 14.1 [5873 5.24 [2108 0.758 [328 11.6 [1233 5.46 [1400 13.6 [7512 14.3 [6294 0.807 [5824 10.2 [939 18.6 [6375 19.3 [3555 1.31 [852 3.36 [5211 0.497 [819 4.59 [939 10.4 [11 10] [4 41]] [27 100]] [22 56]] [11 100]] [32 91]] [8 62]] [27 44]] [27 53]] [2 38]] [13 27]] [10 68]] [27 100]] [1089 7.69 [11 27] [16 37]]] [429 8 [3 27] [35 50]]] [36 55]] [13 50]] [30 87]] [35 60]] [22 26]] [32 41]] [11 71]] [15 100]] [4 35]] [31 100]] [26 85]] [30 50]] [12 100]] [27 52]] [12 60]] [11 100]] [23 85]] [35 48]] [27 62]] [1108 8.99 [32 26] [32 50]]] [35 75]] [23 100]] [4159 10.6 [6074 1.79 [2048 1.84 [394 1.19 [4218 6.6 [939 9.2 [1980 24.6 [1436 3.07 [4414 1.9 [10 20] [429 16.5 [15 54] [32 30]]] [24 26]] [4159 4.07 [23 50] [7 33]]] [27 53]] [27 87]] [28 63]] [15 30]] [13 60]] [847 21.6 [15 49] [29 81]]]] [28 100]] [27 100]] [5121 4 [22 38] [22 100]]] [11 70]] [37 93]] [13 76]] [35 100]] [11 91]] [35 63]] [35 96]] [32 54]] [32 91]] [8 100]] [35 100]] [23 100]] [27 46]] [11 32]] [27 72]] [10 96]] [35 67]] [5007 0.33 [6017 2.26 [2180 8.73 [29 72] [29 96]] [29 80]] [29 100]]] [4781 0.316 [3273 0.451 [11 32] [11 100]] [11 100]]] [2259 0.917 [10 73] [10 100]]] [2752 11.8 [12 83] [12 100]]] [811 1.31 [6325 1.29 [6524 9.24 [3738 0.859 [7442 2.38 [2775 1.78 [3332 1.05 [2802 0.849 [2701 3.43 [7512 1.58 [6732 1.38 [3262 1.61 [3802 0.279 [6301 1.22 [7620 3.45 [4768 22 [835 1.37 [2470 3.37 [7491 24 [1217 4.42 [2005 1.68 [5972 3.03 [11 19] [12 60]] [23 100]] [23 78]] [23 50]] [429 41.3 [15 50] [11 46]]] [11 100]] [4418 25.8 [15 41] [12 62]]] [22 100]] [28 100]] [11 100]] [37 100]] [1078 61.9 [22 57] [22 100]]] [695 7.25 [286 2.78 [1062 7.43 [7665 19.3 [2752 39.6 [22 30] [2752 61.3 [22 71] [22 93]]] [15 29]] [10 37]] [10 66]] [10 29]]] [4769 3.6 [29 71] [29 100]]] [7453 3.14 [29 95] [29 100]]] [35 81]] [28 100]] [11 90]] [11 100]] [2149 7.59 [22 69] [22 63]]] [28 94]] [10 40]]] [1171 1.52 [7085 2.92 [4154 23.8 [23 65] [23 34]] [1078 63.8 [22 50] [23 45]]] [15 45]]] [6581 0.597 [994 7.02 [682 2.31 [1181 2.28 [5480 0.438 [5871 11.7 [899 0.977 [5820 2.04 [6524 2.07 [7032 5.73 [4218 1.05 [7381 1.63 [929 4.86 [791 31 [7665 0.855 [24 47] [5851 0.656 [5472 2.44 [4 22] [36 71]] [2 85]]] [14 36]] [4 34]] [2 31]] [1078 71.1 [13 50] [5 50]]] [2 100]] [25 54]] [2 100]] [36 41]] [14 85]] [1783 2.1 [5482 0.87 [695 0.998 [18 32] [16 44]] [29 53]] [18 28]]] [13 100]] [7512 13.2 [4 75] [4 66]]] [26 100]] [5 39]]] [3045 0.699 [35 79] [35 94]]]] [7665 17.8 [15 97] [15 55]]] [7052 0.709 [5753 1.16 [11 92] [11 100]] [11 100]]] [31 100]] [2055 0.942 [2704 0.32 [29 97] [29 100]] [29 100]]] [6074 0.846 [7566 0.639 [2225 8.2 [5023 2.94 [5999 4 [3669 0.548 [2024 0.963 [3152 1.56 [2902 5.84 [3041 0.741 [35 27] [35 100]] [2 85]] [35 100]] [35 100]] [2241 0.481 [4 53] [24 33]]] [19 30]] [35 100]] [35 90]] [4 50]] [2 81]]] [11 100]] [11 100]] [5236 2.2 [3871 1.03 [2178 1.89 [4852 1.54 [7176 2.99 [8 31] [8 100]] [8 100]] [4 71]] [8 100]] [20 100]]] [27 93]] [2704 0.775 [7051 2.86 [4338 1.03 [1104 26.8 [5412 1.57 [4288 1.75 [29 28] [23 100]] [2562 1.67 [2091 9.35 [23 78] [29 85]] [23 100]]] [15 36]] [23 96]] [23 100]] [29 100]]] [929 3.7 [5219 0.586 [8 75] [8 100]] [3829 1.52 [8 83] [8 100]]]] [22 100]] [4154 4.95 [4143 1.72 [949 0.75 [3619 3.78 [4120 7.29 [27 30] [5323 6.17 [4624 1.67 [27 71] [27 100]] [27 87]]] [27 100]] [27 100]] [27 100]] [27 45]]] [11 100]] [1106 0.524 [774 0.15 [144 2.49 [5216 1.81 [939 2.46 [1426 1.87 [2023 3.08 [10 79] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]]] [2149 12.2 [32 51] [32 96]]] [2103 1.06 [6658 0.48 [828 1.09 [1 7.58 [826 0.917 [5216 2.12 [1426 2.06 [2004 2.85 [5218 1.64 [7733 1.58 [2081 4.16 [1909 0.867 [3572 2.49 [2259 9.43 [5897 1.92 [6946 4.5 [7512 2.61 [4288 8.22 [1161 0.263 [4114 0.898 [434 16.1 [4611 1.86 [1068 0.417 [4768 12.7 [3324 21 [1995 25.1 [7453 24.9 [3533 1.54 [5970 1.04 [4320 0.662 [2463 1.12 [4478 8.89 [3843 2.99 [777 2.73 [7441 3.18 [2259 4.83 [941 1.08 [3556 17.1 [4326 6.14 [429 28.5 [27 87] [1131 5.23 [791 18.1 [3568 1.12 [1078 69.1 [1899 0.816 [27 94] [27 100]] [27 100]] [27 100]] [27 92]] [27 80]]] [7635 4.5 [2752 1.51 [4330 3.37 [429 13.6 [27 87] [27 100]] [27 100]] [27 100]] [27 100]]] [27 87]] [27 100]] [27 71]] [27 100]] [27 100]] [27 100]] [27 81]] [27 100]] [27 100]] [27 100]] [27 100]] [27 62]] [27 62]] [27 80]] [27 90]] [3621 2.41 [3940 2.11 [1980 19.5 [27 100] [27 90]] [27 100]] [27 100]]] [27 57]] [27 54]] [4151 0.554 [4369 7.62 [27 100] [4315 0.571 [3527 1.99 [4114 22.9 [27 98] [27 100]] [27 100]] [27 100]]] [27 100]]] [1133 0.294 [503 9.88 [286 0.154 [4279 2.39 [4114 1.24 [777 2.51 [3566 7.69 [2752 16.5 [27 100] [27 90]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 75]] [27 100]]] [27 80]] [18 26]] [10 100]] [27 80]] [5547 0.345 [23 7.66 [27 53] [10 88]] [13 100]]] [10 100]] [8 42]] [3480 6.45 [1099 3.84 [4279 12.7 [811 6.62 [392 5.99 [4517 1.76 [3097 0.735 [2939 11.7 [2251 4.06 [939 0.562 [27 89] [1161 0.555 [6271 1.23 [3554 0.633 [328 1.31 [1119 2.86 [27 99] [27 100]] [27 85]] [27 100]] [27 100]] [27 100]]] [27 73]] [27 83]] [27 100]] [27 50]] [27 73]] [10 50]] [27 68]] [27 45]] [32 100]]] [10 100]] [10 88]] [23 50]] [10 100]] [10 100]] [27 31]] [10 50]] [32 90]] [18 57]] [10 100]]] [1078 84 [2180 1.2 [5073 0.621 [1417 0.512 [1081 1.85 [2943 0.324 [2175 0.524 [2143 2.29 [5225 0.867 [811 1.7 [504 0.775 [7491 0.911 [2701 0.773 [877 2.02 [2526 5.01 [4116 0.275 [5845 2.46 [5260 8.01 [6524 3.65 [7737 1.3 [1681 4.94 [4895 0.96 [2802 0.628 [4326 0.698 [3489 2.86 [4991 2.46 [2128 1.31 [695 3.34 [6791 3.92 [7512 13.5 [144 13.3 [2091 7.05 [17 11] [4 57]] [12 20]] [19 30]] [22 44]] [22 25]] [15 33]] [32 55]] [5 66]] [1089 0.538 [27 83] [20 44]]] [29 100]] [37 43]] [22 100]] [10 50]] [22 70]] [13 87]] [10 100]] [27 100]] [2939 0.949 [7381 1.78 [4 36] [5 57]] [2 46]]] [22 100]] [29 96]] [22 51]] [22 66]] [10 93]] [22 100]] [429 6.92 [10 25] [2151 3.97 [2786 0.214 [2108 0.641 [1104 15.9 [2703 2.42 [29 46] [29 100]] [7 28]] [29 33]] [29 100]] [0 37]]]] [29 86]] [2526 10.5 [2 88] [2 57]]] [26 90]] [10 100]] [29 100]] [7665 1.88 [6015 0.987 [29 68] [29 100]] [22 34]]] [2753 0.0287 [23 1.35 [2091 1.73 [10 17] [29 71]] [1980 3.23 [4 25] [29 88]]] [4414 2.71 [48 0.208 [4769 0.94 [29 60] [29 100]] [29 100]] [29 87]]]]] [30 100]] [5420 0.763 [5731 0.14 [1919 0.775 [5827 0.494 [5154 2.84 [11 72] [5885 5.68 [4114 1.74 [18 33] [27 100]] [1 45]]] [11 100]] [2 42]] [11 100]] [1911 4.18 [23 75] [23 66]]]] [10 100]] [10 100]] [27 100]]] [4573 0.902 [820 0.514 [6027 0.863 [3061 0.653 [1094 3.41 [3079 0.255 [2081 1.73 [4895 0.543 [3374 10.8 [3561 0.846 [3511 2.05 [7210 1.55 [3610 2.76 [3700 13.1 [37 92] [37 81]] [429 8.96 [37 100] [37 87]]] [37 100]] [37 90]] [38 87]] [37 60]] [37 66]] [3990 12.3 [37 70] [37 100]]] [3036 1.54 [3507 6.28 [1539 13.1 [2469 1.38 [6347 6.65 [5918 6.35 [5447 10.9 [6503 0.851 [1908 1.07 [6007 0.775 [3812 0.615 [1063 4.91 [6767 5.22 [791 5.32 [313 1.99 [3702 6.01 [4102 0.194 [3997 0.879 [113 1.44 [7169 7.21 [3079 9.41 [3262 7.39 [37 100] [37 75]] [37 100]] [37 92]] [37 80]] [37 100]] [37 100]] [37 66]] [37 77]] [2087 0.616 [4369 4.12 [2753 3.54 [3879 16.2 [37 100] [37 83]] [24 3.15 [3262 4.26 [3587 1.68 [37 100] [37 80]] [37 100]] [37 90]]] [726 0.56 [3781 2.25 [3914 1.86 [37 100] [37 83]] [37 85]] [37 100]]] [37 83]]] [37 62]] [37 90]] [37 82]] [37 85]] [2081 0.357 [3466 1.96 [37 100] [37 75]] [37 100]]] [37 80]] [37 62]] [37 85]] [37 66]] [37 66]] [37 70]] [3997 2.52 [37 95] [37 66]]] [37 66]]] [37 71]] [2259 1.31 [37 61] [37 50]]] [23 10.8 [37 66] [38 85]]] [11 100]] [37 69]]] [4862 2.45 [6382 0.795 [1717 1.66 [684 0.471 [4630 8.5 [4426 0.644 [2628 2.37 [1783 62.1 [1980 2.19 [1400 1.01 [1429 56.7 [682 0.998 [31 90] [31 96]] [14 35]] [31 97]] [5692 1.2 [1062 1.52 [31 73] [31 100]] [3 50]]] [22 46]] [325 1.07 [7512 25.8 [10 1.22 [3524 4.25 [2259 5.33 [31 55] [3698 0.768 [5728 1.27 [728 1.23 [731 8.79 [2637 1.54 [31 96] [31 100]] [4 50]] [31 100]] [31 100]] [31 100]]] [31 100]] [31 100]] [31 100]] [31 100]]] [31 100]] [17 57]] [31 100]] [32 100]] [3065 0.463 [1579 1.31 [5840 0.414 [2039 0.677 [5753 2.18 [1715 1.12 [5744 2.55 [1577 0.199 [1621 0.328 [17 34] [17 88]] [19 62]] [17 50]] [14 83]] [33 27]] [14 52]] [6666 0.209 [17 60] [14 100]]] [17 77]] [19 76]]] [3 100]]] [1161 0.422 [7019 10.3 [2753 12.2 [1391 3.17 [5695 0.279 [736 9.01 [2199 16.3 [1754 4.07 [3327 24.4 [906 0.465 [201 8.11 [1785 1.55 [1927 0.222 [434 0.719 [2199 0.511 [392 0.395 [6233 0.861 [107 0.397 [4154 0.472 [328 0.745 [7715 1.23 [7512 19.5 [25 100] [4424 4.07 [25 100] [25 63]]] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]] [25 77]] [4253 1.41 [7085 1.18 [2755 5.19 [25 100] [25 85]] [25 100]] [25 100]]] [25 100]] [25 83]] [248 32.2 [25 100] [25 92]]] [25 81]] [25 87]] [25 100]] [1239 1.18 [25 92] [25 100]]] [2755 0.949 [4253 2.13 [182 2.28 [25 93] [25 100]] [25 100]] [25 100]]] [25 85]] [25 90]]] [6124 1.54 [851 0.521 [3597 2.39 [178 0.195 [2259 10.4 [480 3.29 [791 1 [3715 11.5 [1 44] [29 36]] [728 5.52 [6068 4.22 [978 0.829 [1981 0.513 [6276 2.97 [2826 0.134 [628 0.139 [3088 13.6 [3185 10.7 [3511 25.9 [939 13.5 [434 8.88 [1769 7.31 [4098 2.18 [4417 0.813 [1992 2.32 [3262 13.8 [37 100] [2752 27.6 [37 100] [1924 0.229 [37 98] [37 100]]]] [2780 1.08 [37 100] [37 87]]] [37 87]] [37 98]] [37 95]] [3299 4.67 [37 88] [37 100]]] [37 87]] [37 88]] [37 83]] [3921 2.82 [37 85] [37 100]]] [37 93]] [14 44]] [3772 2.45 [37 63] [37 100]]] [112 0.0986 [37 88] [37 100]]] [17 60]] [37 90]] [37 60]]] [27 70]] [37 33]] [37 50]] [19 50]] [14 37]] [37 42]]] [2470 1.01 [4168 0.335 [6711 0.705 [355 0.647 [2320 0.303 [5420 0.0505 [4057 1.19 [7381 0.945 [6859 0.986 [4210 1.56 [7665 1.31 [2752 3.54 [883 3.18 [4712 1.18 [5926 0.167 [5211 3.49 [968 0.0966 [1 0.227 [5194 2.09 [7314 0.701 [537 0.855 [2178 3.91 [6380 1.27 [2187 6.3 [791 1.43 [534 2.04 [5692 2.96 [6524 12.2 [2259 1.32 [1 26] [5034 19 [26 29] [14 36]]] [28 58]] [28 62]] [3 98]] [1429 4.96 [3 83] [6294 1.49 [5692 3.66 [7185 0.713 [7255 0.885 [3 54] [3 60]] [3 85]] [3 37]] [3 50]]]] [1 80]] [14 45]] [4663 2.62 [3 82] [3 100]]] [3 100]] [3 94]] [28 100]] [3 88]] [103 7.52 [28 82] [28 100]]] [867 5.99 [3008 14.7 [30 87] [30 100]] [30 80]]] [3424 0.251 [3 40] [20 100]]] [30 100]] [28 79]] [404 0.107 [6205 10.5 [2393 0.245 [6239 1 [4170 0.0904 [2259 23.2 [1611 2.3 [1888 3.14 [663 21.9 [6437 6.01 [968 0.556 [7512 9.11 [1101 17.2 [70 1.52 [392 1.34 [4568 0.949 [5345 4.28 [4154 31.4 [377 0.654 [312 17.1 [7512 5.2 [3071 3.18 [3008 12.1 [1899 0.22 [6525 1.85 [2052 11.3 [5211 4.5 [5753 0.787 [1078 4.84 [14 76] [3929 10.4 [14 40] [14 88]]] [28 61]] [30 85]] [33 50]] [28 78]] [2178 2.34 [859 1.03 [1911 0.22 [1239 6.4 [5692 1.25 [695 2.02 [30 25] [14 60]] [30 43]] [28 50]] [14 33]] [30 66]] [30 50]]] [4154 7.5 [30 90] [30 83]]] [30 100]] [30 50]] [30 85]] [2259 1.64 [14 38] [2752 19.9 [28 77] [28 56]]]] [32 39]] [30 69]] [28 95]] [6606 0.692 [7314 2.46 [429 1.16 [14 64] [28 58]] [14 57]] [28 100]]] [30 94]] [14 100]] [14 61]] [955 0.534 [5491 10.4 [5462 21.6 [6109 5.22 [585 4.25 [7491 34.4 [2178 12 [403 2 [4326 5.3 [4978 3.91 [6206 6.49 [6653 9.2 [6853 5.78 [7442 4.86 [5838 2.56 [5381 4.38 [2752 55.3 [695 24.2 [17 1.01 [3338 2.03 [168 2.3 [2143 0.321 [4159 9.95 [5510 0.952 [4154 9.49 [28 100] [28 90]] [28 100]] [28 75]] [28 100]] [28 95]] [5753 1.11 [28 100] [28 85]]] [17 3.01 [28 71] [28 100]]] [28 91]] [28 90]] [28 75]] [28 85]] [28 71]] [1206 6.85 [28 94] [28 75]]] [28 42]] [28 66]] [28 92]] [28 66]] [28 77]] [28 66]] [28 62]] [28 66]] [28 71]] [5462 27.5 [28 66] [28 81]]] [28 66]] [28 75]]] [14 87]] [14 75]] [6199 1.05 [728 2.09 [14 82] [14 100]] [14 100]]] [30 79]] [2913 3.23 [6380 2.42 [3905 10.2 [7251 2.74 [2846 2.89 [6230 5.31 [14 26] [14 77]] [32 63]] [28 100]] [32 94]] [14 100]] [32 67]]] [32 100]] [14 100]] [5732 0.495 [28 95] [28 100]]] [14 96]] [4312 2.68 [1646 0.724 [4011 2.24 [328 31.9 [6727 1.07 [7449 0.967 [6732 0.571 [28 84] [1078 1.66 [28 85] [28 100]]] [28 100]] [28 100]] [730 0.651 [14 71] [28 100]]] [28 80]] [6375 2.69 [28 100] [28 87]]] [28 77]]]] [5225 0.787 [7618 0.603 [394 1.18 [4806 1.1 [4154 5.21 [1552 0.555 [719 2.22 [889 0.502 [2846 2.03 [7717 0.924 [1676 0.821 [6333 5.1 [429 42.3 [2225 2.37 [6604 4.45 [7512 2.37 [1429 5.03 [3 57] [14 54]] [3095 8.21 [125 5 [7441 0.812 [7255 16.5 [3912 3.8 [6342 11.2 [3008 15.7 [7542 4.98 [7623 15.9 [1062 1.92 [2826 2.46 [2434 3.02 [968 0.77 [4369 3.27 [4414 45.1 [6882 7.64 [377 1.02 [14 78] [695 0.496 [2259 0.768 [14 82] [14 100]] [14 100]]] [14 57]] [32 50]] [14 30]] [32 55]] [14 40]] [3027 0.782 [4851 12 [1400 2.02 [5564 1.25 [5160 0.534 [728 1.32 [6732 1.61 [14 96] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [2826 13.2 [14 95] [14 85]]] [14 87]]] [2913 0.986 [14 98] [32 100]]] [14 35]] [32 90]] [14 43]] [32 53]] [32 100]] [32 83]] [14 100]] [14 61]] [32 67]]] [30 83]] [3 45]] [968 1.47 [14 50] [32 85]]] [32 89]] [7169 6.25 [2939 7.47 [14 87] [14 100]] [14 75]]] [32 93]] [1674 1.33 [6977 1.79 [5160 1.01 [5316 0.651 [1692 1.03 [5871 5.17 [6436 5.5 [6666 2.16 [906 1.61 [7518 1.85 [6403 2.44 [144 12.8 [3715 4.59 [7665 39.8 [2826 1.44 [6106 2.41 [125 2.54 [7449 4.45 [32 49] [32 100]] [32 87]] [32 100]] [6544 1.55 [14 64] [14 100]]] [14 73]] [14 100]] [14 95]] [32 100]] [32 100]] [32 83]] [32 91]] [695 0.386 [14 94] [14 100]]] [14 90]] [14 100]] [7704 0.326 [5673 3.5 [32 96] [32 100]] [32 100]]] [14 96]] [14 98]] [32 100]]] [32 100]] [6732 11.6 [7512 32.9 [7354 0.849 [4533 1.42 [6977 1.84 [4279 1.48 [7210 1.31 [695 12.4 [5564 0.816 [719 10.9 [14 83] [32 75]] [14 100]] [14 91]] [14 100]] [14 77]] [14 100]] [14 100]] [32 71]] [5729 2.44 [7343 16.4 [99 13.7 [14 94] [14 72]] [14 66]] [14 100]]] [14 77]]] [32 100]] [2793 0.592 [392 2.64 [6920 5.66 [7176 3.49 [4322 0.383 [7535 1.01 [7518 1.16 [4158 2.81 [6200 8.23 [5753 3.42 [4163 0.792 [4197 4.89 [5160 4.67 [883 2.58 [728 6.32 [203 1.55 [7615 8.38 [5673 26.7 [4876 8.79 [5871 7.48 [1648 3.5 [1062 11.4 [6732 6.51 [6437 5.35 [7514 5.81 [7334 2.26 [7600 0.756 [6436 3.23 [6310 1.73 [4414 5.03 [968 0.829 [2628 2.44 [5211 1.9 [99 2.07 [32 93] [32 100]] [32 44]] [32 66]] [6294 0.829 [32 99] [32 100]]] [32 98]] [32 85]] [14 75]] [32 100]] [32 100]] [19 40]] [14 88]] [14 41]] [32 76]] [34 5.35 [5675 2.79 [32 89] [14 57]] [32 75]]] [14 61]] [14 66]] [14 55]] [3 100]] [14 55]] [32 55]] [14 50]] [14 92]] [3 88]] [7085 8.63 [899 0.792 [32 97] [32 100]] [32 92]]] [5429 1.09 [4369 0.914 [7665 8.58 [14 53] [32 48]] [32 100]] [32 100]]] [3 71]] [4158 4.84 [14 85] [7512 10.8 [14 85] [14 100]]]] [32 100]] [14 75]] [2913 3.48 [4414 2.43 [6401 1.79 [32 100] [32 85]] [32 75]] [32 100]]] [14 85]] [14 68]] [3905 3.63 [7373 3.91 [6152 1.25 [1899 3.68 [14 100] [14 83]] [14 100]] [14 90]] [14 81]]] [2199 1.17 [5679 1.66 [14 95] [14 75]] [14 100]]]] [7185 3.61 [7210 1.94 [14 100] [14 71]] [14 77]]] [2759 1.87 [125 1.56 [7472 4.91 [3008 4.32 [14 96] [14 50]] [14 87]] [14 80]] [14 76]]] [20 100]] [328 2.62 [30 76] [30 100]]]] [2108 3.32 [7512 4.47 [6653 0.232 [6015 0.264 [791 3.67 [30 91] [5462 2.96 [429 26.5 [2993 2.42 [2790 1.38 [1679 1.88 [6199 1.29 [30 89] [30 60]] [5211 17.3 [30 87] [30 100]]] [30 100]] [6299 1.53 [30 96] [30 100]]] [906 1.1 [30 64] [3 91]]] [30 66]]] [30 64]] [30 57]] [2260 5.43 [30 97] [30 55]]] [30 44]]] [974 0.697 [6604 4.61 [7314 24.6 [1899 0.323 [5732 0.423 [791 36 [6732 1.31 [2913 2.73 [4569 1.03 [28 62] [2259 11.7 [28 83] [28 75]]] [30 86]] [2759 4.5 [429 18.6 [28 56] [4012 0.787 [5510 1.98 [1206 1.31 [28 84] [28 100]] [28 100]] [28 100]]] [28 50]]] [30 80]] [4395 0.557 [7139 1.15 [5028 1.24 [28 96] [28 83]] [28 100]] [28 100]]] [7185 0.088 [2904 3.42 [7512 1.63 [1025 5.4 [6131 0.0906 [6342 2.39 [1253 2.04 [6517 0.509 [2752 8.65 [28 54] [1429 78.6 [6920 0.412 [377 0.474 [28 98] [28 100]] [28 100]] [1911 1.01 [28 66] [28 88]]]] [28 83]] [28 75]] [28 75]] [28 100]] [28 61]] [28 54]] [28 62]] [28 100]]] [30 100]] [30 100]] [6732 27.2 [5034 22.7 [4533 2.87 [595 6.25 [28 100] [2787 5.76 [28 100] [2825 31.3 [28 100] [28 85]]]] [28 88]] [28 96]] [28 50]]]] [978 6.97 [2268 0.981 [6791 4.97 [6880 5.71 [5673 0.664 [14 98] [14 100]] [14 85]] [14 83]] [14 100]] [6230 14 [14 76] [14 40]]]] [32 100]] [6524 0.0933 [6644 5.72 [4159 2.37 [730 0.329 [968 0.467 [30 42] [631 8.51 [28 86] [28 62]]] [28 100]] [28 44]] [5655 0.445 [5967 7.13 [28 96] [28 83]] [28 100]]] [5655 4.48 [7497 0.362 [2764 0.0933 [4789 0.706 [4587 1.06 [1980 18.1 [5813 3.05 [2091 2.01 [1062 0.766 [28 97] [28 100]] [28 80]] [28 85]] [28 85]] [28 84]] [28 85]] [28 100]] [28 100]] [28 77]]]] [32 100]] [1980 1.47 [5753 0.647 [4332 8.08 [4061 4.85 [1239 1.78 [6299 2.01 [3008 6.06 [30 90] [30 100]] [30 100]] [30 100]] [30 100]] [30 85]] [30 100]] [30 100]]] [4154 7.16 [30 83] [3 78]]] [4369 4.85 [6175 7.06 [465 0.611 [112 0.428 [6342 0.62 [32 99] [32 100]] [32 100]] [32 100]] [32 88]] [7722 0.677 [7665 6.17 [32 64] [32 100]] [429 18.3 [32 83] [32 100]]]]] [7457 0.455 [1253 5.17 [4383 1.71 [7115 0.712 [3916 1.16 [4322 1.86 [7340 0.588 [2526 4.07 [6524 5.01 [7542 0.458 [4369 5.42 [1679 0.542 [1729 4.57 [3105 0.51 [663 1.38 [1429 13.3 [30 61] [7057 2.95 [30 91] [30 83]]] [30 45]] [30 100]] [30 100]] [685 8.26 [2920 7.81 [3686 4.26 [7341 1.28 [3008 9.29 [30 100] [1716 0.535 [4851 0.32 [30 75] [30 100]] [30 100]]] [30 87]] [30 90]] [30 88]] [30 80]]] [32 41]] [32 100]] [11 42]] [25 26]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]] [32 53]] [32 81]]]] [4895 4.95 [7106 8.6 [2093 2.65 [5776 5.81 [77 0.583 [695 0.119 [1753 0.578 [3432 1.38 [4615 4.65 [36 100] [2752 25 [36 100] [36 75]]] [36 100]] [36 100]] [36 100]] [14 0.989 [36 100] [36 87]]] [7400 3.13 [36 100] [36 70]]] [36 83]] [2753 1.89 [1405 1.5 [36 100] [6708 0.882 [36 100] [36 70]]] [23 7.35 [36 68] [36 100]]]] [7068 3.22 [36 100] [36 80]]]] [2037 0.0601 [1336 0.632 [4210 0.279 [518 1.37 [6515 0.57 [5409 1.31 [7512 5.4 [5629 0.147 [6897 0.926 [5938 1.97 [590 0.273 [5115 1.11 [5041 0.778 [5972 1.01 [4219 0.613 [2701 0.0285 [4282 1.37 [7318 0.308 [6015 3.11 [107 0.38 [537 2.13 [4682 1.42 [1623 0.454 [6148 6.22 [6471 1.28 [212 0.736 [5564 0.216 [5310 0.445 [6457 0.287 [6506 1.55 [7513 3.45 [996 0.259 [4867 0.536 [6810 0.372 [4714 0.0493 [5831 0.854 [5561 1.31 [6306 3.5 [1293 4.86 [5254 0.405 [7180 4.76 [535 1.63 [4896 0.462 [42 4.59 [6648 0.632 [5524 0.151 [1069 1.32 [426 1.09 [534 1.56 [2470 0.366 [5965 0.525 [1713 0.202 [5219 0.573 [3628 0.164 [6773 0.0541 [5046 1.93 [5170 4.47 [3262 0.412 [819 0.272 [695 0.0621 [1672 0.407 [6612 0.366 [1248 1.94 [2752 0.425 [502 3.95 [372 1.81 [5542 1.09 [7419 4.66 [7623 74.1 [429 20.3 [4768 2.84 [248 11.5 [5945 4.58 [6713 9.46 [2276 29.2 [1116 0.437 [200 0.204 [4778 0.366 [2122 29.4 [1817 0.929 [243 1.1 [3622 1.67 [2951 15 [6610 5.11 [6004 6.01 [168 0.0825 [5889 2.86 [5499 5.05 [2199 1.66 [3996 0.579 [6899 0.349 [5989 0.498 [7210 2.9 [4726 10.6 [5632 7.25 [3332 6.76 [1 14] [35 59]] [16 26]] [6 100]] [628 6.41 [6413 3.89 [5110 16.1 [33 8] [8 84]] [5 21]] [24 75]]] [754 4.18 [1841 1.55 [7 24] [1841 10.9 [22 12] [1997 11.2 [2 14] [10 50]]]] [18 75]]] [4920 1.95 [33 84] [14 23]]] [14 78]] [5343 3.7 [4207 7.25 [2174 4.56 [2050 4.02 [2274 2.61 [7354 1.46 [5989 0.398 [1 22] [22 20]] [4 30]] [1454 5.01 [10 46] [15 57]]] [2072 0.904 [1 60] [1 85]]] [28 29]] [29 100]] [31 45]]] [30 100]] [4154 4.08 [32 25] [17 40]]] [2259 65.1 [1838 8.04 [177 40.8 [99 2.37 [19 32] [19 44]] [19 71]] [36 33]] [10 62]]] [6 90]] [28 78]] [2093 0.96 [38 36] [17 70]]] [2127 0.635 [29 73] [29 100]]] [7210 0.255 [21 66] [21 83]]] [3 100]] [35 42]] [15 100]] [1262 1.29 [38 66] [38 100]]] [30 59]] [35 39]] [30 90]] [20 100]] [2530 3.76 [33 35] [6 70]]] [5299 0.175 [1576 3.34 [33 14] [4279 1.27 [2 55] [2 22]]] [2 53]]] [1285 0.885 [5034 5.97 [4049 4.09 [6406 4.65 [7085 3.88 [538 2.15 [5732 1.96 [562 7.25 [5203 1.69 [6085 0.884 [373 1.55 [2002 5.64 [1592 3.45 [1380 7.25 [1429 20.8 [4673 3.11 [1928 8.77 [1047 19.2 [5756 4.27 [5574 5.05 [4279 12.4 [3016 2.09 [5393 3.61 [5095 9.63 [1277 9.09 [5673 14 [21 22] [3 72]] [9 100]] [9 100]] [3 69]] [24 50]] [1239 53 [3 60] [1 36]]] [11 66]] [21 66]] [429 49.8 [24 100] [21 40]]] [22 85]] [6 92]] [4889 1.22 [2275 7.29 [4533 17.6 [1391 13 [21 8] [1899 24.3 [35 33] [31 100]]] [22 66]] [2 37]] [6 63]]] [21 93]] [3 100]] [21 50]] [21 100]] [21 76]] [9 100]] [9 100]] [24 52]] [1239 78.6 [621 6.49 [236 11.4 [743 14 [538 17.9 [802 17.5 [21 93] [21 64]] [21 95]] [21 66]] [21 83]] [21 100]] [21 54]]] [2081 11.1 [663 0.348 [429 39.8 [21 31] [5444 1.71 [21 65] [21 100]]] [9 85]] [21 45]]] [9 40]] [21 100]] [28 40]] [9 100]]] [2143 10.3 [1256 13.8 [1932 1.31 [35 43] [7628 0.675 [1 65] [35 75]]] [35 76]] [2106 3.31 [35 42] [35 90]]]] [23 5.81 [6116 2.54 [791 16 [6 73] [24 42]] [6 100]] [18 36]]] [13 97]] [21 95]] [26 85]] [1780 0.65 [3041 1.91 [2081 11.5 [596 0.299 [6524 1.83 [5056 17 [4092 13.4 [1684 4.81 [1611 4.5 [6921 1.06 [1436 0.0792 [5680 3.72 [3310 1.37 [6031 9.69 [5789 0.835 [2799 1.98 [5904 4.61 [1986 14.3 [5110 2.31 [1094 0.748 [1783 4.72 [4859 2.44 [1207 3.23 [2628 14 [4533 9.09 [7508 2.26 [957 1.52 [2802 0.328 [1400 14.8 [5211 2.63 [1576 10.6 [383 6.81 [23 13] [18 50]] [2 94]] [23 49]] [32 50]] [29 63]] [27 41]] [23 100]] [1078 4.07 [28 20] [35 55]]] [6 11]] [2 61]] [18 76]] [1447 2.73 [1600 2.39 [407 0.281 [6797 1.84 [7355 5.38 [5275 5.01 [3253 5.85 [4964 6.94 [2259 20.9 [7203 3.53 [276 7.49 [33 12] [11 46]] [29 40]] [13 16]] [4 88]] [24 75]] [25 50]] [33 66]] [33 50]] [25 40]] [7 100]] [1 71]]] [23 51]] [7623 3.53 [33 31] [30 100]]] [2763 6.67 [11 32] [15 88]]] [1239 66.9 [19 33] [19 93]]] [26 76]] [24 72]] [22 77]] [29 75]] [2955 8.03 [2752 33.2 [13 27] [24 33]] [7 100]]] [1051 1.09 [2298 0.672 [2073 2.49 [4876 1.54 [5294 2 [1576 1.65 [1025 9.85 [1951 5.1 [2628 2.91 [4898 2.22 [1959 2.27 [5299 0.407 [6199 4.42 [429 8.82 [1838 0.0792 [1783 5.32 [26 16] [2246 1.77 [3446 0.456 [4573 5.25 [1239 72.1 [1913 10.9 [16 22] [7 41]] [23 28]] [5632 4.22 [24 33] [4 33]]] [32 57]] [25 33]]] [1239 44.5 [19 75] [19 70]]] [2752 19 [17 16] [32 25]]] [32 62]] [24 55]] [17 50]] [7 30]] [7154 0.762 [1429 24 [38 62] [17 36]] [30 44]]] [10 54]] [33 57]] [2 77]] [2 40]] [15 38]] [22 40]] [16 42]] [17 42]]] [23 86]] [30 100]] [5480 0.518 [6905 3.08 [5991 0.87 [2081 0.614 [1429 62.4 [2 63] [11 57]] [13 38]] [11 54]] [2 100]] [2 100]]] [35 100]] [31 100]] [22 28]] [28 100]] [1916 10.5 [328 0.684 [4338 0.795 [4555 1.1 [4326 0.873 [3251 1.43 [6920 0.633 [1429 14.7 [1240 0.671 [2029 1.49 [2089 2.23 [23 31] [23 69]] [23 62]] [23 77]] [978 1.04 [1994 0.322 [22 13] [11 62]] [23 47]]] [23 100]] [25 44]] [27 57]] [23 100]] [5647 15 [23 95] [2 57]]] [30 19]] [23 83]]] [1429 1.15 [35 80] [35 95]]] [23 100]]] [1911 1.2 [3457 1.02 [1262 0.632 [2122 25.4 [1252 0.504 [3735 0.214 [3045 3.86 [2023 13.5 [2277 3.12 [1062 4.15 [2081 3.75 [1959 4.87 [2127 8.22 [1952 2.51 [2143 4.28 [35 13] [29 27]] [35 66]] [33 61]] [35 37]] [29 39]] [13 14]] [25 62]] [35 46]] [35 100]] [23 40]] [1913 8.43 [2064 9.83 [29 36] [1 90]] [29 93]]] [35 63]] [38 72]] [35 100]] [10 50]]] [1239 22.3 [28 66] [4768 2.76 [968 0.505 [1980 6.22 [28 100] [28 90]] [28 100]] [28 88]]]] [22 100]] [7354 2.17 [5097 2.76 [2164 1.37 [907 1.43 [398 1.27 [1365 4.45 [6607 3.24 [5034 0.248 [1453 2.94 [6389 2.55 [688 10.3 [5267 3.1 [1995 0.101 [5892 0.346 [2235 1.32 [7461 2.99 [2093 5.91 [1833 0.427 [1078 1.28 [5294 3.65 [802 2.51 [7255 5.86 [6732 0.879 [9 12] [35 42]] [12 62]] [1429 9.4 [429 50.8 [9 78] [21 63]] [21 57]]] [30 50]] [7009 0.515 [28 27] [28 33]]] [13 100]] [29 33]] [22 70]] [28 46]] [14 80]] [2259 21.8 [4 27] [19 66]]] [9 70]] [21 100]] [22 60]] [29 72]] [221 0.42 [14 61] [28 71]]] [28 86]] [9 87]] [28 66]] [21 61]] [29 57]] [28 100]] [18 38]]] [27 100]] [3262 2.15 [37 58] [37 80]]] [2755 0.599 [4802 0.334 [33 64] [33 100]] [26 77]]] [3 59]] [1447 0.453 [4754 1.58 [7329 0.994 [7335 0.606 [30 98] [30 100]] [30 100]] [30 58]] [30 100]]] [5753 1.06 [21 97] [21 100]]] [4851 1.28 [5412 20.8 [8 92] [8 75]] [8 100]]] [1338 4.8 [31 100] [31 60]]] [3 100]] [2752 32.5 [6959 0.173 [2526 0.575 [4964 0.726 [2912 2.18 [3694 9.82 [1957 6.52 [2752 8.72 [4764 2.47 [5769 2.58 [434 1.65 [2973 0.111 [3164 0.258 [5154 0.849 [222 0.268 [1242 5.13 [30 25] [4 42]] [30 50]] [25 40]] [25 75]] [30 33]] [25 71]] [30 69]] [21 70]] [11 29]] [30 100]] [30 95]] [10 100]] [4 66]] [724 0.38 [5753 0.502 [4414 0.44 [791 5.01 [1253 1.5 [248 0.609 [25 42] [25 72]] [23 28]] [21 33]] [25 50]] [21 61]] [4 81]]] [4064 0.994 [31 59] [31 62]]] [15 64]]] [907 2.46 [126 2.39 [3 99] [3 100]] [3 97]]] [1 76]] [6031 2.14 [6331 3.56 [6969 0.688 [1078 15.6 [1555 1.85 [6959 6.47 [2802 3.42 [4 51] [4 100]] [4 84]] [23 50]] [10 25]] [15 42]] [4 82]] [4 78]]] [3308 0.654 [328 1.7 [6929 3.33 [7429 10.2 [11 97] [11 87]] [11 77]] [11 60]] [11 100]]] [30 100]] [1980 6.14 [3 45] [4188 2.39 [3 88] [3 100]]]] [144 0.745 [2955 11.7 [3996 0.942 [1436 14.3 [5028 0.6 [5942 0.499 [2039 0.0617 [2011 0.647 [250 0.438 [17 17] [19 50]] [14 81]] [6383 0.809 [17 58] [17 28]]] [32 100]] [31 62]] [32 82]] [1980 0.669 [14 100] [14 37]]] [17 86]] [5643 0.472 [663 0.971 [32 89] [32 100]] [32 66]]]] [1367 3.28 [5042 6.18 [126 12.8 [21 98] [21 87]] [21 76]] [21 100]]] [2939 1.71 [178 2.42 [33 100] [33 83]] [33 100]]] [10 100]] [4895 6.86 [33 69] [33 57]]] [6751 2.99 [6342 1.25 [1899 10.3 [6678 2.33 [4948 2.09 [3 85] [3 100]] [3 100]] [3 66]] [3 71]] [3 100]]] [1452 1.84 [4988 3.68 [4802 7.02 [71 1.93 [5692 2.98 [2143 8.53 [2993 1.01 [1301 0.686 [4657 7.74 [6844 3.23 [6621 6.55 [1342 0.677 [5991 6.77 [1783 42.4 [1912 12.1 [33 60] [33 100]] [0 23]] [2 50]] [33 77]] [33 50]] [33 73]] [33 100]] [25 42]] [33 50]] [1 70]] [33 95]] [33 100]] [33 65]] [5692 5.97 [5174 11.9 [1 54] [33 70]] [33 57]]] [1 27]]] [6101 21.6 [594 18.8 [1277 14 [6375 2.15 [7085 17.9 [328 14.6 [7085 1.61 [5040 1.61 [1078 2.2 [5918 10.8 [5831 23.3 [9 93] [9 66]] [9 100]] [9 100]] [9 88]] [9 100]] [9 80]] [9 50]] [9 100]] [9 85]] [9 66]] [9 77]]] [1887 2.75 [4572 0.0344 [2241 0.111 [30 100] [30 87]] [30 100]] [30 100]]] [2539 1.58 [6382 13.9 [5843 0.12 [32 100] [19 50]] [32 77]] [32 80]]] [6134 0.111 [5941 0.972 [4292 1.54 [5889 3.45 [3 98] [3 100]] [3 100]] [3 100]] [3 100]]] [2029 0.518 [2764 0.673 [8 55] [23 100]] [23 100]]] [6 82]] [7 100]] [2470 0.611 [5641 0.764 [3994 2.24 [6342 0.322 [1783 13.9 [4235 4.67 [25 61] [25 92]] [6459 0.0479 [25 96] [25 100]]] [25 100]] [25 100]] [25 55]] [25 100]]] [10 100]] [4878 1.73 [14 100] [5568 1.1 [4684 0.103 [5637 3.03 [14 100] [14 84]] [14 100]] [14 100]]]] [7197 0.562 [1912 0.555 [4948 1.11 [3 92] [3 100]] [3 100]] [3 100]]] [7154 1.37 [5376 4.32 [6183 0.673 [6425 1.38 [5071 0.949 [23 21.7 [5170 10.6 [1436 16.6 [3527 8.88 [7301 1.41 [6032 2.59 [5622 0.265 [5753 4.32 [1391 8.82 [26 79] [26 62]] [26 71]] [26 85]] [26 91]] [16 44]] [26 100]] [1 71]] [26 50]] [9 36]] [26 100]] [26 100]] [26 77]] [26 100]] [1436 2.72 [1239 34.9 [26 75] [19 50]] [26 66]]]] [574 4.17 [5621 1.72 [5918 6.37 [6375 0.304 [7211 1.05 [6029 1.19 [9 59] [9 66]] [9 90]] [9 91]] [9 52]] [9 96]] [9 100]]] [11 98]] [5769 0.971 [5539 2.99 [5647 14.7 [5989 5.29 [1812 1.52 [1391 17.6 [2178 5.77 [1459 1.2 [2752 13 [2081 26.6 [2225 0.724 [7059 15.7 [6562 1.84 [2151 3.06 [33 75] [33 53]] [33 42]] [33 100]] [33 40]] [1 40]] [33 36]] [30 57]] [33 37]] [30 31]] [2879 0.982 [5561 4.88 [1783 8.96 [4703 5.72 [1 40] [33 90]] [233 45.5 [7208 7.18 [5573 3.31 [2081 21.2 [33 91] [33 63]] [33 100]] [33 66]] [33 66]]] [33 78]] [33 100]]] [25 43]] [33 100]] [13 100]] [2 44]]] [4851 1.17 [4197 7.94 [5393 2.16 [1239 39.6 [3 100] [1783 8.24 [3 100] [3 87]]] [3 100]] [3 100]] [3 100]]] [429 2.48 [7512 3.2 [427 11.2 [2987 8.74 [71 0.428 [5171 0.438 [2894 0.428 [2752 41.3 [4655 5.96 [6189 4.67 [1058 2.39 [4897 3.36 [5322 11.1 [4703 6.9 [2559 10.3 [1876 1.19 [1078 4.92 [5368 22.8 [4398 11.9 [5246 1.36 [4703 1.18 [6328 2.09 [33 88] [33 100]] [33 100]] [33 100]] [33 75]] [33 80]] [33 83]] [33 80]] [33 63]] [1239 35.4 [7329 1.45 [33 87] [10 50]] [33 100]]] [33 100]] [33 45]] [33 100]] [25 100]] [1 50]] [33 50]] [7254 0.428 [4214 1.96 [33 100] [33 80]] [33 100]]] [33 100]] [33 1.65 [33 96] [33 100]]] [33 71]] [33 54]] [5192 1.5 [33 50] [33 100]]] [6886 0.549 [1391 0.584 [178 4.29 [5171 1.64 [33 55] [33 100]] [25 60]] [33 100]] [30 28]]]] [5393 4.28 [688 2.52 [4048 13.5 [1239 70.9 [5562 5.98 [5807 0.825 [5007 0.745 [585 2.68 [1452 5.47 [7169 21.7 [4480 1.96 [21 25] [3 25]] [15 33]] [15 60]] [6082 1.56 [2083 1.85 [585 14.3 [1783 2.49 [429 68.7 [9 63] [21 88]] [21 88]] [21 95]] [21 71]] [21 97]]] [9 22]] [33 35]] [33 90]] [9 44]] [21 100]] [21 87]] [538 16.3 [21 87] [21 83]]]] [2526 3.82 [112 0.258 [3 97] [3 100]] [3 100]]] [5267 7.67 [757 0.711 [5047 0.907 [1239 51.3 [3 76] [3 94]] [3 100]] [3 100]] [32 62]]] [1101 0.994 [663 0.999 [5999 0.0749 [2280 0.432 [1957 1.09 [2793 2.46 [29 75] [15 76]] [29 100]] [29 100]] [9 27]] [5995 5.99 [29 100] [29 85]]] [29 100]]] [3 100]] [5047 0.259 [4751 0.675 [128 0.79 [3557 1.39 [826 0.505 [5972 8.91 [5999 23.7 [561 1.63 [6892 1.3 [622 0.863 [1062 7.47 [574 0.797 [5174 0.849 [7623 0.328 [4218 1.77 [523 1.62 [5388 0.502 [7363 1.19 [4480 1.2 [791 22.4 [221 2.24 [5439 1.44 [5918 3.04 [6791 2.9 [3 37] [21 66]] [21 62]] [21 78]] [3 41]] [916 1.95 [21 66] [1239 52.6 [21 100] [21 75]]]] [9 50]] [21 87]] [9 100]] [9 100]] [3 100]] [12 33]] [33 100]] [9 96]] [1899 6.85 [36 44] [12 38]]] [3 100]] [21 79]] [21 60]] [21 100]] [915 10.2 [429 30.9 [1 8.97 [5656 2.95 [695 5.41 [248 2.49 [1025 7.25 [12 43] [12 77]] [33 46]] [36 58]] [12 100]] [9 75]] [4218 2.89 [791 16.4 [3 76] [4407 2.7 [3 35] [9 57]]] [3 94]]] [5976 4.5 [5937 9.77 [7449 3.44 [21 55] [21 73]] [21 100]] [3 100]]]] [12 66]] [12 100]] [7085 0.74 [9 71] [9 100]]] [1373 4.09 [1277 8.31 [2624 1.56 [9 75] [9 83]] [9 100]] [9 77]]] [3 100]]] [917 0.431 [2752 2.37 [2624 1.85 [221 12.4 [2146 1.23 [2024 0.692 [4842 1.97 [553 0.963 [921 1.5 [816 8.73 [916 0.986 [4917 1.32 [21 96] [21 100]] [21 100]] [21 85]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 82]] [21 100]] [10 50]] [21 100]]] [7642 6.69 [5171 0.99 [5647 6.55 [2559 1.68 [33 95] [33 100]] [5174 4.35 [33 60] [33 100]]] [7241 1.98 [33 97] [33 100]]] [33 77]]] [1259 10.9 [5047 0.595 [6199 6.67 [5753 7.16 [5381 1.34 [1373 0.489 [4407 2.96 [2917 2.54 [2184 1.98 [7169 2.92 [1328 17.9 [791 21.9 [3 94] [3 75]] [3 63]] [3 100]] [3 66]] [3 100]] [3 100]] [21 60]] [21 60]] [3 42]] [3 100]] [3 100]] [15 100]]] [143 1.37 [5851 3.77 [112 6.37 [583 5.14 [508 8.52 [1239 57.8 [5693 6.29 [907 7.4 [517 1.9 [1980 1.01 [4716 5.19 [1325 1.95 [23 13.9 [429 120 [2993 19.6 [21 100] [21 90]] [21 91]] [21 57]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 93]] [21 78]] [21 60]] [1286 1.93 [569 1.41 [21 78] [21 100]] [9 50]]] [9 52]] [580 8.62 [9 57] [21 90]]] [9 100]]] [6727 0.717 [2464 4.52 [6150 3.65 [6711 6.88 [524 3.31 [7449 10.5 [918 3.59 [1325 18 [7428 9.72 [5084 11.2 [802 5.36 [4478 0.319 [6375 1.09 [6380 24.4 [5049 1.25 [9 82] [9 57]] [9 100]] [9 66]] [9 90]] [6294 8.13 [4516 0.947 [6136 1.96 [5851 0.0999 [6104 16.8 [1365 0.325 [2259 2.06 [6027 0.73 [6343 0.545 [6802 0.994 [4914 1.19 [9 92] [9 100]] [9 100]] [9 85]] [9 100]] [9 84]] [9 100]] [9 85]] [9 100]] [9 85]] [9 81]] [9 72]]] [9 70]] [9 69]] [21 72]] [5110 1.81 [1239 85.6 [9 100] [9 60]] [21 90]]] [9 60]] [21 88]] [9 46]] [5054 0.241 [371 4.63 [6802 0.376 [328 14 [9 90] [9 46]] [9 50]] [9 95]] [20 33]]] [21 53]] [621 0.358 [688 0.529 [9 50] [21 77]] [21 100]]]] [1242 0.632 [2526 3.6 [15 90] [15 66]] [15 100]]] [328 0.182 [2079 0.816 [1047 1.91 [107 1.68 [2579 0.773 [1240 7.08 [7419 3.27 [4198 0.252 [1333 1.66 [2259 24.3 [7675 2.37 [7665 2.06 [282 9.97 [18 16] [18 73]] [7381 0.69 [5962 5.07 [6524 2.21 [278 3.01 [1812 3.63 [5260 2.92 [5405 2.51 [4674 1.99 [4859 0.458 [915 6.63 [6544 2.49 [4506 4.59 [7514 5.5 [5693 1.17 [5254 1.79 [5480 7.83 [7043 1.34 [3878 2.04 [232 6.67 [6404 0.843 [4889 7.38 [285 11.1 [4266 1.25 [3008 19.4 [673 5.49 [2005 3.22 [3027 19.6 [2178 9.06 [6333 1.21 [3130 6.48 [1355 5.38 [1587 7.36 [1088 7.69 [23 7.53 [6181 5.38 [5170 9.34 [1087 17.9 [5211 1.51 [899 7.96 [2029 9.09 [6 11] [2 40]] [13 45]] [20 55]] [22 57]] [33 100]] [6 57]] [14 18]] [6 85]] [13 62]] [6 81]] [4 55]] [32 85]] [17 28]] [25 75]] [22 21]] [5429 3.11 [26 30] [38 57]]] [6 28]] [20 100]] [33 75]] [6 81]] [36 100]] [33 83]] [36 63]] [25 63]] [33 32]] [10 100]] [2 14]] [145 18.6 [7722 9.2 [19 23] [19 73]] [4308 0.917 [19 63] [19 100]]]] [32 100]] [14 38]] [3 94]] [18 70]] [6 88]] [31 100]] [13 84]] [33 100]] [2756 1.53 [18 70] [18 81]]] [7623 12.2 [324 9.01 [1813 1.85 [6178 1.81 [1 45] [25 100]] [1 90]] [1 100]] [1 41]]] [6 91]] [3759 5.05 [2616 4.68 [724 0.548 [5812 7.46 [7 28] [2 55]] [7 57]] [17 47]] [7 100]]]] [6 100]] [2119 2.15 [4948 0.986 [4673 2.92 [5904 2.76 [7149 15.9 [2023 0.732 [2526 13.7 [5346 2.22 [906 2.37 [1239 28.3 [169 5.19 [2178 1.12 [36 18] [10 42]] [19 83]] [184 23.9 [1079 11.8 [1888 12.1 [5412 3.27 [6 35] [21 66]] [6 71]] [5 33]] [6 100]]] [3 100]] [18 66]] [6167 17.1 [1888 3.31 [5748 2.2 [5609 16.4 [1239 20.1 [4 28] [6 87]] [6 100]] [6 80]] [6 42]] [6 62]]] [10 26]] [4465 2.13 [6 93] [6 87]]] [19 57]] [1 28.7 [2436 16.7 [4822 3.13 [4674 17.6 [6 97] [7416 22 [7405 6.54 [4674 25 [1078 2.65 [6 76] [16 44]] [6 92]] [6 84]] [6 66]]] [6 77]] [6 100]] [6 75]]] [3 40]] [10 17]]] [791 1.76 [1239 40.1 [10 100] [6 33]] [10 100]]] [4897 1.55 [1997 3.56 [2168 0.573 [171 2.73 [2115 4.67 [7739 12.9 [19 71] [18 43]] [18 35]] [2259 3.07 [19 100] [19 87]]] [19 92]] [26 33]] [19 77]]] [6406 2.35 [6829 10.9 [1883 4.1 [1335 2.7 [4154 4.85 [6116 17.6 [6 81] [6 100]] [6 54]] [6 100]] [6 100]] [2282 5.26 [1023 5.62 [6138 3.03 [6 94] [6 100]] [6 100]] [6 100]]] [6 57]]] [4189 2.92 [24 88] [24 100]]] [4651 14.3 [2294 1.23 [5722 11.7 [1320 4.35 [4731 1.59 [7419 15.6 [6 100] [6 87]] [6 100]] [7419 7.09 [6 69] [6 93]]] [6 62]] [6 100]] [6 71]]] [7210 1.74 [33 62] [33 46]]] [24 86]] [6287 9.88 [4939 7.01 [6116 0.793 [1429 12.9 [4891 8.88 [4675 6.14 [6 100] [6 88]] [6 60]] [7421 23.9 [6 100] [6 90]]] [6 100]] [6 70]] [6 81]]] [6413 1.21 [2936 1.6 [5482 0.492 [4656 1.93 [3323 4.36 [243 4.42 [3100 3.97 [4878 0.559 [6182 1.57 [7675 2.15 [1089 1.96 [364 2.23 [405 1.42 [5716 7.49 [5480 0.686 [4725 1.58 [4754 2.31 [6851 1.03 [7176 1.49 [4200 0.761 [5972 1.16 [1888 5.97 [896 2.81 [3251 1.05 [2039 6.04 [7517 7.35 [7729 1.78 [1980 4.89 [30 11] [719 2.18 [25 24] [33 62]]] [2260 4.42 [33 31] [14 40]]] [25 65]] [19 53]] [19 42]] [5429 2.68 [7 15] [26 54]]] [14 48]] [24 44]] [22 42]] [5701 1.49 [1 20] [33 83]]] [7 90]] [14 100]] [6 75]] [389 0.792 [283 4.75 [33 31] [18 100]] [6 33]]] [18 50]] [328 26.9 [18 77] [19 40]]] [6199 3.94 [14 32] [6 20]]] [10 87]] [6 92]] [25 100]] [14 100]] [1 89]] [21 100]] [1264 7.27 [1 60] [1 96]]] [328 12.8 [1 71] [1 95]]] [278 4.1 [7601 1.36 [788 2.81 [18 80] [18 43]] [18 88]] [18 100]]] [25 82]] [7 96]]]] [5202 1.64 [7009 0.154 [7057 3.14 [5439 8.77 [1364 1.94 [6830 0.998 [5983 1.64 [2566 2.62 [2616 2.57 [4727 0.198 [2259 29.6 [9 45] [6 76]] [6 60]] [6 94]] [6289 7.67 [3008 4.26 [6 85] [6 100]] [6 100]]] [6 93]] [16 44]] [5033 4.22 [6289 3.88 [7449 5.96 [1349 0.949 [3687 5.86 [6293 15.1 [4731 3.72 [226 1.3 [1997 7.22 [6 82] [6 100]] [6 100]] [6876 1.06 [6923 5.96 [6 91] [6 100]] [6 100]]] [6 37]] [6 55]] [2259 60.9 [6 100] [6 87]]] [6 62]] [7421 14.3 [6 50] [6 100]]] [6 97]]] [6 96]] [9 60]] [1239 76.1 [9 83] [9 100]]] [9 90]]] [4717 2.97 [435 1.14 [5988 5.87 [7679 2.32 [7314 2.6 [4939 2.07 [5093 16.5 [5776 16.9 [5753 12.7 [4653 1.5 [6701 0.631 [2259 25.6 [6 62] [6902 10.4 [7675 19.4 [1883 4.48 [2436 0.25 [2611 5.13 [5093 6.3 [2527 56.9 [5597 0.292 [4675 5.52 [5409 12.8 [1239 48 [6 72] [6 96]] [6 100]] [6 63]] [4450 4.88 [6422 8.02 [6 100] [6 90]] [1239 35.7 [6 83] [6 100]]]] [6 57]] [6 100]] [6 100]] [2585 0.5 [6 100] [6 60]]] [6 100]] [6 55]] [6 80]]] [2569 9.01 [6328 0.942 [6749 0.528 [2406 4.83 [5962 0.557 [5797 1.47 [6515 14.9 [6 100] [6 91]] [6 100]] [6 100]] [6 80]] [6 100]] [6 100]] [6 88]]] [6129 4.16 [6276 5.63 [2569 12.3 [7564 0.81 [5090 9.08 [6 89] [6 100]] [6 100]] [6 75]] [16 58]] [6 70]]] [6 50]] [6 66]] [6 60]] [7421 12.4 [6 100] [6514 12.7 [6 100] [6 77]]]] [7 40]] [6 60]] [6 64]] [1980 5.07 [6 75] [6 60]]] [6 57]]] [6792 1.82 [7413 1.5 [6897 3.89 [4154 0.574 [5041 0.18 [23 25.2 [1899 5.64 [1429 5.27 [23 7.28 [5999 0.39 [695 7.82 [4797 1.95 [4924 3.04 [583 2.19 [569 1.16 [21 95] [21 87]] [21 76]] [4924 16.7 [21 100] [21 83]]] [21 100]] [21 71]] [21 75]] [517 9.16 [21 53] [21 100]]] [429 57.6 [9 50] [9 70]]] [21 100]] [9 75]] [21 100]] [21 100]] [9 57]] [9 87]] [9 88]]] [6581 3.51 [2993 8.42 [5412 4.93 [1116 1.4 [2143 13.6 [6882 3.45 [6920 1.04 [5462 0.768 [4626 0.558 [906 0.533 [6136 0.378 [791 1.42 [3 87] [3 98]] [3 100]] [3 100]] [3 100]] [3 100]] [3 76]] [3 100]] [3 71]] [3 53]] [3 66]] [4282 2.64 [30 63] [3 100]]] [3 75]]] [1997 4.26 [2616 18.7 [4854 1.63 [7603 1.12 [5898 3.12 [4713 1.65 [5395 12 [5409 0.591 [6169 12.7 [4939 0.395 [6166 0.586 [6 88] [6 100]] [6 100]] [6 80]] [6 100]] [6 85]] [4675 0.715 [6 90] [6 85]]] [6 75]] [1283 0.882 [6 100] [6 66]]] [6 77]] [6 55]] [6 69]]] [731 0.101 [1948 0.0619 [4674 9.59 [6230 0.089 [5093 13.9 [5721 6.56 [2281 2.08 [2063 12 [6841 0.205 [7236 17.8 [6422 23.8 [2093 2.46 [4726 16.4 [1283 3.27 [2387 2.81 [1453 0.314 [5984 0.922 [5898 3.24 [7101 0.42 [7421 17.9 [1239 28.3 [6 90] [1364 1.76 [6994 1.28 [5624 1.85 [7505 0.0691 [1974 2.18 [6 100] [2584 1.5 [6 100] [6 75]]] [6 100]] [6 88]] [6 80]] [2035 1.35 [2300 0.199 [7255 0.263 [6 92] [6 83]] [6 100]] [6 66]]]] [6 87]] [4732 0.221 [6 83] [6 50]]] [6 66]] [7281 23.1 [6 100] [6 83]]] [6 62]] [6 96]] [7222 11.7 [7101 2.09 [2030 6.52 [6 100] [6 77]] [6 92]] [6 75]]] [6424 5.99 [2551 5.15 [6 69] [6 100]] [6 55]]] [6 55]] [6 57]] [6 72]] [6 50]] [6 78]] [6 50]] [6 64]] [7153 4.68 [6 66] [16 66]]] [6 50]] [4673 10.1 [16 75] [7512 13.2 [6515 4.98 [2262 10.1 [6 75] [6 41]] [6 83]] [6 90]]]] [6 50]] [6 50]]]] [7305 6.33 [2466 14.3 [604 9.09 [3691 1.08 [7623 4.91 [1394 2 [4218 0.248 [6859 5.69 [5142 4.55 [5476 26.3 [3687 0.411 [2763 6.63 [1490 0.606 [1069 8.07 [6083 0.364 [5260 1.19 [4312 1.04 [4417 1.07 [731 7.25 [13 100] [13 85]] [13 100]] [13 100]] [13 100]] [13 100]] [13 96]] [13 100]] [13 96]] [13 100]] [1429 29.4 [13 100] [13 90]]] [13 66]] [13 70]] [13 100]] [13 83]] [13 80]] [5812 1.17 [13 88] [13 100]]] [13 75]] [13 88]] [13 77]]] [5632 2.6 [3643 2.56 [3645 0.763 [6724 1.81 [6091 1.26 [6286 23.4 [7351 8.93 [6294 2.47 [4767 8.07 [6383 0.262 [208 13.7 [4564 2.81 [4929 11.4 [7156 6.81 [429 6.63 [5205 3.08 [5067 5.01 [2454 4.65 [4025 5.94 [6184 17.9 [1927 2.71 [7454 1.75 [1899 0.472 [6691 10.2 [4414 14.5 [3639 12.4 [24 94] [24 57]] [24 66]] [24 62]] [2909 0.173 [2526 4.7 [24 100] [7665 6.05 [24 100] [2793 6.33 [24 66] [24 75]]]] [24 100]]] [19 40]] [24 100]] [24 50]] [3660 7.19 [24 54] [24 100]]] [19 50]] [19 55]] [24 55]] [1078 32.7 [5838 0.71 [6692 2.73 [6853 30.3 [7031 19.2 [4030 7.81 [5447 1.96 [7197 2.07 [5427 4.85 [4414 7.45 [3662 1.23 [3694 0.786 [906 4.28 [3659 9.28 [7677 2.32 [4478 0.613 [2005 3.52 [2108 1.3 [24 100] [4495 2 [24 80] [24 100]]] [24 85]] [24 83]] [4339 1.81 [24 100] [24 90]]] [2771 11.9 [2515 0.829 [4519 9.53 [772 10.8 [3642 1.87 [6997 8.29 [24 100] [24 87]] [24 71]] [24 92]] [24 87]] [24 83]] [24 80]]] [24 87]] [24 75]] [24 100]] [24 85]] [24 71]] [24 88]] [24 75]] [24 88]] [24 75]] [24 78]] [2517 2.62 [24 100] [3026 0.647 [2259 14.7 [24 36] [24 77]] [24 100]]]] [2453 3.91 [24 100] [24 55]]] [2541 10.1 [1089 1.11 [24 88] [24 72]] [24 78]]]] [4518 6.98 [24 88] [19 50]]] [24 64]] [24 69]] [3660 11.9 [24 51] [23 7.52 [24 92] [24 100]]]] [24 50]] [36 42]] [3660 3.9 [19 63] [3652 6.75 [7381 2.23 [24 100] [24 75]] [24 42]]]] [24 43]] [24 64]] [24 69]] [24 59]] [6373 0.737 [2947 1.31 [5693 1.99 [4339 2.87 [896 6.33 [1980 0.867 [3660 17.4 [4349 2.97 [2525 0.709 [4342 1.44 [24 78] [19 41]] [24 100]] [24 100]] [24 42]] [7512 8.25 [24 88] [24 100]]] [2752 23.6 [24 71] [19 71]]] [24 100]] [2525 0.339 [2265 0.849 [24 88] [24 91]] [24 100]]] [24 54]] [24 62]]] [3308 1.77 [7672 2.79 [429 9.09 [7530 0.684 [3026 1.57 [1927 1.09 [2793 10.9 [3659 6.45 [19 77] [24 60]] [19 85]] [19 50]] [3637 1.58 [24 66] [19 85]]] [3637 0.937 [19 80] [19 92]]] [3644 0.876 [4279 6.71 [1899 1.52 [24 90] [24 100]] [24 88]] [19 50]]] [24 66]] [7529 2.93 [24 100] [24 77]]]] [16 44]]] [61 5.35 [7475 0.0526 [2649 0.237 [6778 1.83 [2680 1.04 [4501 0.719 [95 0.246 [7457 1.86 [2429 0.537 [6959 0.404 [2628 13 [631 1.77 [3905 4.41 [5130 1.3 [131 1.82 [429 6.18 [7329 8.83 [4703 0.551 [5626 0.174 [4655 1.66 [4840 6.33 [285 1.78 [4673 1.07 [6152 1.27 [5209 0.199 [6363 5.67 [301 1.78 [182 1.63 [985 1.12 [269 3.82 [5647 1.01 [7491 6.49 [978 0.6 [2752 17.8 [2559 1.16 [7665 16.6 [178 17.2 [7301 0.855 [6471 4.13 [7370 2.78 [5172 2.54 [7512 1.14 [194 1.18 [3582 2.47 [3342 2.49 [5110 3.37 [5241 0.949 [165 1.94 [1436 0.65 [78 2.51 [37 2.02 [248 0.678 [33 21] [33 77]] [16 38]] [38 42]] [6380 3.55 [8 25] [16 50]]] [17 22]] [38 66]] [33 75]] [18 66]] [5 100]] [16 33]] [5673 4.13 [18 28] [1 25]]] [33 100]] [38 76]] [26 76]] [2862 9.27 [6380 4.12 [16 13] [32 50]] [7 42]]] [25 43]] [6 42]] [33 100]] [3107 4.95 [3878 1.25 [4851 4.98 [4061 0.51 [2178 7.89 [33 17] [25 62]] [35 40]] [5 45]] [16 33]] [5 60]]] [5017 2.4 [26 53] [26 90]]] [7461 3.45 [38 54] [22 72]]] [33 57]] [26 90]] [26 100]] [25 93]] [30 47]] [7 50]] [23 11.6 [5637 2.75 [38 50] [19 75]] [38 57]]] [18 80]] [6 79]] [791 1.2 [2849 8.85 [33 72] [33 88]] [33 88]]] [16 78]] [7254 2.36 [1 76] [1 100]]] [6688 1.27 [6199 4.03 [4897 8.33 [91 0.657 [26 31] [26 75]] [25 28]] [28 50]] [6 47]]] [7665 10.8 [6406 4.71 [7305 5.26 [426 1.63 [4682 2.04 [33 69] [5561 2.56 [5617 2.33 [2892 4.64 [33 96] [33 83]] [33 100]] [33 100]]] [33 100]] [25 85]] [33 53]] [33 43]]] [4063 2.24 [5617 2.75 [1813 16.8 [6482 2.44 [25 33] [13 100]] [33 100]] [13 100]] [13 100]]] [3325 0.51 [1239 2.86 [1227 0.658 [3008 14.2 [4769 0.907 [978 0.898 [5480 1.03 [6153 2.26 [7288 2.56 [5413 1.62 [2706 1.87 [6924 2.7 [7369 0.707 [3687 3.14 [112 3.7 [1783 21 [673 0.785 [811 3.03 [29 12] [31 77]] [1 38]] [19 36]] [4768 12.9 [1630 1.14 [1601 1.89 [4851 3.7 [5211 11.2 [248 1.48 [1888 0.635 [1078 44.5 [7210 6.09 [2753 5.8 [221 14.1 [6207 3.4 [2259 5.85 [1899 6.14 [2939 2.73 [29 43] [29 87]] [38 33]] [28 42]] [11 25]] [29 100]] [37 38]] [28 50]] [29 92]] [12 57]] [2701 3.07 [29 84] [29 100]]] [11 100]] [28 23]] [29 90]] [28 100]] [29 87]]] [37 90]] [14 33]] [29 100]] [29 100]] [29 87]] [5368 6.5 [11 83] [11 100]]] [28 100]] [5211 1.03 [5013 2.12 [29 33] [29 85]] [22 100]]] [4926 2.76 [685 3.37 [282 2.96 [2259 13.2 [1023 1.15 [5 14] [2 41]] [791 4.77 [18 46] [19 55]]] [18 45]] [7186 0.493 [7354 4.67 [26 37] [18 75]] [18 83]]] [18 100]]] [29 100]] [1030 4 [112 5.33 [14 30] [17 72]] [429 10.5 [26 88] [26 100]]]] [11 100]] [6833 0.644 [2004 1.69 [7623 2.56 [2616 1.31 [7590 0.447 [7681 0.705 [1 1.01 [5099 3.09 [7038 3.99 [4050 0.813 [2849 12 [22 10] [29 20]] [8 28]] [18 42]] [18 60]] [26 50]] [26 87]] [18 70]] [2436 1.97 [16 25] [6 100]]] [1 34]] [29 91]] [18 76]]] [29 90]]] [1062 2.61 [155 1.09 [29 71] [131 6.91 [29 92] [29 100]]] [29 63]]] [7041 0.852 [4508 3.79 [2753 1.22 [184 3.23 [1696 3.81 [278 4.96 [18 46] [18 60]] [26 75]] [18 75]] [16 60]] [18 66]] [18 81]]] [7068 2.51 [6584 0.156 [37 18] [5673 0.624 [17 58] [2826 0.972 [881 1.43 [2849 11.3 [19 75] [19 42]] [17 77]] [19 63]]]] [38 50]]] [28 96]] [7344 2.62 [5210 0.0585 [2526 1.68 [4685 1.55 [4648 1.26 [5110 1.89 [5635 0.666 [2718 2.65 [6687 1.93 [6875 3.78 [78 5.67 [6382 1.04 [7154 9.69 [1429 17.7 [5595 4.89 [6406 20.6 [6372 13.8 [7231 3.39 [7282 0.797 [6940 5.71 [7260 7.52 [5692 0.832 [2069 6.83 [5983 3.31 [2650 7.82 [190 5.4 [5492 6.17 [2178 3.91 [4939 10.7 [2851 5.02 [7726 4.57 [4738 1.9 [4851 5.86 [6353 12.1 [5600 0.936 [7500 4.66 [38 52] [38 45]] [900 1.57 [16 37] [16 85]]] [7 57]] [16 38]] [16 69]] [5 53]] [1997 5.34 [7255 1.61 [38 68] [38 50]] [7472 12.3 [38 100] [38 92]]]] [16 79]] [38 86]] [14 75]] [4940 4.59 [2199 1.26 [2851 0.665 [5672 2.06 [3698 1.26 [2978 6.58 [5491 7.04 [6758 1.11 [23 21.9 [2869 1.35 [1395 6.42 [5681 22 [38 68] [38 30]] [14 30]] [38 42]] [190 11 [38 50] [2259 43.7 [38 42] [6 25]]]] [38 86]] [14 40]] [38 77]] [5 40]] [16 40]] [2849 74.7 [1429 4.1 [190 20.6 [1980 16.5 [38 88] [38 69]] [38 100]] [38 63]] [37 26]]] [38 76]] [16 81]]] [16 24]] [2661 32.7 [1429 8.31 [2640 3.31 [16 41] [6 28]] [16 78]] [6 72]]] [38 95]] [38 20]] [2859 2.78 [2377 6.08 [6830 5.13 [16 29] [18 75]] [2707 4.96 [26 37] [38 100]]] [5 23]]] [16 35]] [6 32]] [4859 2.96 [193 12.2 [16 49] [6 66]] [18 88]]] [1980 24.4 [2656 6.01 [16 52] [16 70]] [26 66]]] [16 39]] [6199 5.42 [6 41] [14 33]]] [2734 0.543 [7401 2.35 [7423 8.73 [2729 5.88 [7354 3.79 [1693 1.43 [7084 3.26 [2890 1.29 [3334 2.14 [3928 2.94 [63 21.7 [7476 13.7 [4859 0.982 [200 1.22 [5068 1.57 [5435 8.28 [2646 6.56 [5753 11 [2952 6.27 [6148 7.38 [7474 0.502 [6471 7.46 [2707 28.3 [7041 4.45 [6207 31.7 [978 3.32 [7231 2.82 [1980 31.7 [2628 26.3 [23 29.8 [6342 0.911 [5462 2.34 [16 25] [17 33]] [8 20]] [5673 2 [2081 1.12 [17 27] [5 33]] [38 52]]] [2753 2.65 [4895 3.09 [166 8.93 [17 22] [38 45]] [38 40]] [5 20]]] [38 75]] [26 29]] [18 44]] [17 85]] [16 71]] [5368 9.35 [5626 6.02 [1899 2.31 [2955 16.9 [38 51] [38 35]] [38 76]] [16 40]] [38 33]]] [26 53]] [7390 6.41 [165 4.35 [2469 1.71 [1899 4.09 [38 50] [5 33]] [38 91]] [17 33]] [6 28]]] [37 60]] [38 83]] [18 55]] [16 55]] [16 47]] [8 50]] [38 94]] [5753 2.65 [18 45] [18 72]]] [38 96]] [16 100]] [5 35]] [12 100]] [4074 3.89 [5 71] [5 100]]] [5 66]] [16 80]] [14 30]] [18 46]] [16 65]] [37 32]] [6 24]]] [18 36]] [17 42]] [1899 6.54 [5438 6.86 [7512 6.9 [78 25.9 [4154 1.27 [7038 6.79 [2666 8.81 [429 2.01 [16 42] [17 25]] [18 33]] [16 66]] [16 44]] [7 31]] [16 44]] [6134 10.3 [16 81] [16 60]]] [18 63]]] [2707 15.1 [7482 44.9 [38 100] [5 41]] [4909 10.9 [7482 48.9 [38 87] [38 100]] [2951 14 [166 4.68 [38 100] [38 81]] [38 70]]]]] [2682 0.543 [6 34] [16 57]]] [5345 3.98 [7241 4.34 [7369 0.855 [38 94] [38 66]] [38 80]] [38 80]]] [83 1.33 [7391 1.8 [2646 6.06 [2707 1.43 [16 100] [1646 9.73 [94 4.63 [6342 5.43 [328 4.46 [6688 1.96 [2749 7.54 [7166 5.46 [4854 7.21 [1899 1.68 [7231 5.08 [2653 10.2 [2682 0.649 [16 76] [16 94]] [14 42]] [16 83]] [16 43]] [13 27]] [16 60]] [26 100]] [6008 4.37 [6 66] [6687 8.95 [16 71] [16 58]]]] [6 25]] [38 50]] [6 45]] [18 45]]] [16 100]] [16 88]] [7260 6.87 [16 85] [5593 6.88 [16 37] [31 57]]]]] [30 68]] [38 86]] [17 62]] [6199 4.65 [76 0.458 [2939 27.8 [6923 4.11 [2663 1.1 [178 6.36 [6933 0.565 [302 0.549 [4891 2.87 [7491 2.56 [16 19] [6 55]] [16 42]] [16 62]] [6 52]] [2 70]] [16 78]] [16 82]] [1445 0.606 [6923 3.68 [2983 7.81 [6098 4.94 [2466 0.14 [4414 0.615 [7301 1.78 [187 7.69 [663 2.32 [7423 1.25 [16 37] [16 93]] [16 50]] [2526 19.5 [16 74] [6 85]]] [16 100]] [16 93]] [1783 5.07 [8 28] [1943 3.62 [16 53] [16 88]]]] [6 50]] [2868 2.35 [16 54] [17 30]]] [6 50]] [2 22]]] [2689 1.07 [6 64] [16 60]]] [6207 5.81 [26 28] [896 4.21 [4011 7.72 [3238 3.04 [7421 2.49 [16 27] [16 100]] [16 83]] [5 75]] [17 50]]]]] [69 3.45 [37 5.08 [7512 0.636 [429 2.89 [2689 1.88 [2648 0.807 [7154 0.474 [94 1.14 [38 81] [38 61]] [38 100]] [38 75]] [5918 31.8 [38 25] [24 30]]] [38 40]] [17 27]] [38 32]] [7476 5.44 [7210 1.85 [167 3.78 [7343 3.2 [4478 1.79 [1445 2.01 [2259 12 [1888 9.26 [2862 1.78 [4130 2.2 [5753 2.39 [38 80] [38 57]] [14 50]] [38 100]] [24 75]] [2939 45.9 [38 75] [38 100]]] [38 26]] [5 85]] [38 65]] [38 58]] [38 70]] [5641 7.28 [38 51] [38 76]]]]] [4648 2.86 [38 89] [38 100]]]] [5484 0.878 [2749 0.609 [7423 1.39 [5732 1.11 [2027 4.3 [5986 1.41 [7370 0.813 [2653 2.53 [282 0.447 [2940 12.9 [5623 0.803 [6417 2.48 [4991 3.89 [4987 0.955 [5900 1.41 [2469 3.25 [2709 12.8 [2939 9.18 [4279 2.22 [194 0.321 [94 5.26 [392 5.92 [2752 5.38 [2862 7.76 [791 7.17 [16 62] [5 28]] [18 38]] [5007 1.57 [16 31] [18 45]]] [18 33]] [16 100]] [16 62]] [29 45]] [4648 1.76 [4457 2.62 [2081 3.76 [1320 0.258 [5722 2.39 [3470 0.302 [7203 3.58 [1896 1.48 [165 7.89 [6833 5.33 [1980 4.73 [2951 6.96 [16 89] [16 69]] [33 50]] [18 62]] [16 64]] [16 33]] [16 100]] [38 50]] [6 39]] [16 85]] [16 52]] [16 92]] [38 100]]] [4527 6.67 [6 63] [16 81]]] [16 82]] [277 0.949 [1262 0.879 [2143 2.54 [2993 4.82 [7734 4.11 [5632 10 [6139 10.4 [5643 4.68 [7203 4.38 [6831 17.9 [5901 7.54 [1997 1.12 [16 47] [16 76]] [16 73]] [5901 16.8 [18 70] [18 40]]] [16 85]] [18 42]] [18 65]] [16 89]] [18 60]] [30 57]] [4504 7.38 [6136 6.1 [6 50] [18 56]] [6 66]]] [16 77]] [18 55]]] [18 64]] [18 25]] [7 95]] [6 75]] [2628 23.4 [19 50] [18 77]]] [18 72]] [1821 1.73 [7419 7.64 [2862 5.78 [2849 39.4 [1253 1.4 [7206 18.8 [2712 5.59 [2752 3.4 [90 2.37 [16 52] [18 75]] [5594 5.76 [18 50] [18 71]]] [16 60]] [18 40]] [2178 1.4 [18 42] [18 75]]] [16 52]] [1836 2.65 [16 57] [6 45]]] [16 57]] [7 100]]] [17 50]] [4851 3.27 [6 76] [6 33]]] [18 81]] [7 76]] [7332 0.273 [1997 3.04 [4414 17.3 [5898 9.08 [2752 6.06 [5716 3.64 [1981 0.627 [7281 0.651 [6937 1.49 [2951 18.8 [2640 4.02 [5632 2.19 [5753 0.964 [7419 4.33 [16 80] [16 93]] [16 83]] [16 75]] [16 77]] [1660 0.496 [16 53] [16 87]]] [16 92]] [16 60]] [16 55]] [2849 39.2 [14 28] [6 50]]] [16 63]] [16 96]] [6 63]] [38 32]] [16 45]]] [1400 1.19 [26 65] [26 100]]] [2732 2.42 [532 0.928 [2955 1.56 [1631 0.689 [7601 3.69 [2628 19.9 [5673 0.508 [1661 7.33 [18 87] [18 100]] [18 40]] [16 45]] [7 30]] [16 71]] [1895 2.07 [90 2.09 [18 50] [16 75]] [16 85]]] [18 77]] [16 75]]]] [673 5.97 [6346 16.7 [2364 2.85 [6279 7.34 [6393 5.68 [7231 1.23 [38 96] [38 100]] [38 90]] [38 86]] [38 100]] [187 5.93 [38 83] [16 50]]] [429 3.36 [38 75] [38 50]]]] [1980 3.16 [4004 5.38 [5 73] [2939 14.3 [37 62] [5 77]]] [5 56]]] [3849 0.273 [7370 0.127 [4097 3.26 [83 0.0346 [96 2.84 [7759 1.45 [4946 4.45 [2753 2.28 [190 1.49 [144 10.6 [7149 7.03 [2867 0.943 [7255 1.17 [6406 18.8 [14 18] [6 66]] [2939 10.8 [26 45] [16 37]]] [16 48]] [16 49]] [5 87]] [7402 0.891 [165 2.69 [5851 0.945 [1429 17.4 [7354 0.663 [6471 4.77 [2939 44.7 [16 52] [16 21]] [16 50]] [16 83]] [2469 0.72 [95 3.66 [16 46] [17 53]] [16 66]]] [14 22]] [6382 0.611 [16 20] [17 69]]] [17 72]]] [2753 7.67 [18 62] [5 45]]] [14 91]] [7611 3.49 [28 42] [28 100]]] [16 82]] [5438 0.104 [63 0.98 [2628 8.24 [23 13.4 [18 66] [26 34]] [2851 4.34 [6940 9.08 [2882 2.93 [2876 7.82 [5170 3.6 [2526 9.71 [62 2.01 [2732 0.785 [2939 43 [16 50] [1899 0.44 [16 90] [16 57]]] [18 50]] [16 37]] [6 50]] [26 33]] [2849 79.2 [5 25] [16 33]]] [7343 11.9 [18 57] [26 62]]] [18 75]] [2178 0.505 [16 76] [16 50]]]] [16 91]] [5588 0.239 [4392 1.18 [7423 2.59 [4738 14.7 [2716 0.566 [5869 1.93 [248 1.1 [2714 3.86 [2646 0.949 [6409 13.5 [4889 2.63 [78 7.04 [16 67] [16 52]] [16 100]] [16 92]] [16 44]] [7150 10.9 [16 48] [7347 8.85 [16 66] [4457 11.5 [16 95] [16 83]]]]] [26 42]] [26 94]] [978 1.84 [6133 0.577 [26 48] [17 57]] [16 41]]] [16 72]] [16 33]] [26 100]] [26 85]]]] [5 66]] [5210 8.36 [199 1.42 [5 21] [38 60]] [19 53]]] [5870 0.273 [7210 0.51 [26 70] [19 33]] [26 100]]]] [29 100]] [190 7.35 [4414 0.662 [4573 1.18 [7 59] [7 94]] [2526 4.06 [7 80] [7 85]]] [5627 4.07 [6961 1.64 [5753 3.82 [2680 6.56 [6 25] [7 75]] [7 100]] [7 100]] [7 100]]]] [3207 12.8 [2711 2.85 [2983 4.64 [6134 0.931 [2656 0.464 [134 0.169 [7391 0.236 [6199 5.12 [7241 5.29 [4515 3.48 [144 7.89 [3126 1.14 [3510 6.61 [37 54] [37 72]] [37 100]] [18 36]] [5 30]] [37 45]] [16 42]] [37 60]] [5 88]] [16 37]] [16 83]] [6778 11 [16 63] [5 33]]] [2102 0.117 [4154 4.09 [7343 3.5 [7210 0.418 [194 8.32 [6778 12.1 [2081 0.435 [429 1.98 [37 45] [37 78]] [2866 6.56 [37 84] [2849 53.3 [37 55] [5 36]]]] [5 39]] [37 90]] [37 91]] [18 25]] [2955 6.32 [37 83] [37 69]]] [5 60]]] [16 52]]] [2694 0.49 [5492 2.63 [4717 1.62 [5189 0.464 [1355 1.34 [5429 0.738 [2650 0.084 [2713 26.1 [300 0.519 [7512 0.947 [939 0.559 [4623 10.5 [7282 2.14 [6256 4.64 [60 18.4 [5326 3.86 [673 1.19 [6009 2.19 [2640 1.84 [4950 1.33 [7135 2.74 [6199 1.95 [4684 2.51 [4879 19.1 [1999 1.42 [5902 2.02 [301 7.88 [4854 26.6 [2275 7.57 [7132 2.55 [5894 1.84 [4939 27.7 [192 22.6 [2862 0.526 [2611 0.295 [2719 10.9 [7041 23.8 [6830 9.64 [2940 15.6 [2727 0.338 [7231 27.2 [7185 0.227 [4738 22.4 [2602 4.97 [6473 7.91 [7231 20.6 [2628 64.4 [1980 4.9 [187 25.4 [4870 1.36 [2679 8.45 [7665 9.83 [6074 4.01 [2866 5.03 [6877 1.12 [5723 5.76 [5642 0.741 [2979 5.11 [1239 49 [4937 2.87 [2370 0.454 [7347 0.394 [4939 11.9 [2143 2.31 [16 48] [5099 34.7 [16 28] [18 50]]] [6 57]] [16 35]] [16 66]] [6 45]] [2620 0.821 [16 36] [16 44]]] [6 62]] [16 90]] [1897 5.95 [2526 2.02 [1239 6.19 [16 60] [193 4.36 [5099 14.4 [6 70] [6 81]] [16 63]]] [16 42]] [6 61]]] [37 50]] [1895 5.83 [16 90] [16 71]]] [7 25]] [26 37]] [16 64]] [6 87]] [16 62]] [5605 3.18 [16 56] [16 71]]] [16 81]] [19 33]] [26 75]] [6 100]] [6 48]] [6 43]] [16 87]] [5672 0.442 [2951 18.9 [6923 0.971 [5103 15.7 [16 60] [16 80]] [16 66]] [16 50]] [16 84]]] [6 72]] [5901 3.23 [18 33] [6 44]]] [6 80]] [6 40]] [2127 0.238 [4675 1.9 [4727 8.67 [16 79] [16 53]] [6 50]] [16 83]]] [2707 21.4 [4854 1.66 [16 40] [7260 0.559 [5724 5.64 [4851 12 [6 50] [6 77]] [6 100]] [6 62]]] [2649 17.9 [2862 6.45 [16 54] [16 90]] [6 75]]]] [18 86]] [6 88]] [18 44]] [2649 12.7 [7 42] [19 23]]] [5637 1.93 [1919 5.99 [6 72] [6 54]] [6 90]]] [6342 1.65 [5436 7.02 [1783 13.1 [4851 50.5 [5090 0.466 [2713 4.48 [6 57] [2868 8.19 [2727 16.1 [4880 14.4 [2707 16.1 [6 38] [6941 12.5 [6 54] [16 47]]] [14 40]] [6 38]] [6 72]]] [16 55]] [6 81]] [6 100]] [16 46]] [6 90]]] [30 88]] [2143 0.959 [6 57] [6 90]]] [18 73]] [6 74]] [6 67]] [7343 16.2 [4728 1.1 [4854 2.72 [16 61] [2849 23.8 [6207 1.2 [38 28] [38 62]] [7049 1.01 [2939 28.1 [190 7.58 [2955 7.38 [6 33] [18 42]] [2876 2.69 [16 50] [18 33]]] [5673 4.22 [187 17.9 [6 50] [6 36]] [83 6.99 [23 20.3 [18 38] [18 80]] [6 63]]]] [16 66]]]] [16 91]] [5100 5.95 [16 72] [2628 41 [16 70] [16 100]]]]] [38 100]] [7 82]] [4870 2.06 [2951 23.4 [1983 1.82 [5238 2.19 [6129 0.905 [5101 7.41 [5673 3.12 [2951 12.1 [7419 7.7 [5641 14.6 [5577 2.09 [1239 50.5 [6961 13.4 [5721 0.668 [16 66] [16 87]] [6 62]] [16 37]] [16 100]] [16 100]] [16 100]] [5103 0.413 [5579 3.57 [2720 0.924 [5102 13.6 [1783 8.79 [6 39] [16 54]] [2709 4.3 [6 33] [16 89]]] [16 75]] [6 50]] [16 87]]] [2526 0.349 [1981 0.818 [2939 11.9 [18 77] [6942 4.03 [1895 2.65 [5641 4.16 [5799 3.72 [6439 1.17 [16 44] [6 60]] [6 63]] [18 42]] [2259 3.9 [18 55] [16 66]]] [16 61]]] [18 50]] [5408 0.698 [16 81] [16 71]]]] [76 0.555 [6 63] [6 63]]] [4939 0.267 [6 45] [6 36]]] [28 80]] [16 73]] [6 31]] [6 53]]] [30 100]] [26 57]] [30 90]] [6 100]] [2691 0.687 [18 68] [18 50]]] [978 0.26 [2877 2.21 [2691 3.25 [312 2.71 [4414 19.8 [5007 6.41 [2628 52.7 [2707 47.6 [6755 1.17 [2727 4.35 [5723 9.5 [6 45] [6 73]] [16 87]] [6 83]] [16 70]] [6 80]] [16 37]] [1253 1.41 [6961 0.547 [2619 0.73 [5595 1.59 [2178 2.09 [6 65] [6 45]] [6 94]] [6 91]] [1239 7.86 [6 100] [6 80]]] [16 57]]] [16 66]] [6 52]] [4762 1.23 [6 39] [16 54]]] [16 72]]] [37 25]] [26 66]] [2526 18.4 [4712 4.41 [5170 2.52 [2955 7.94 [7737 2.23 [2753 1.05 [64 0.35 [4891 2.86 [4725 0.27 [2618 1.1 [2707 9.05 [4738 3.41 [7421 0.24 [2951 9.47 [1078 4.3 [1899 2.15 [16 57] [16 44]] [19 52]] [6 57]] [18 70]] [30 71]] [2655 4.12 [6832 0.358 [4716 0.399 [7255 4.68 [2649 3.91 [18 33] [18 68]] [18 30]] [18 54]] [16 40]] [6 37]]] [16 71]] [1078 2.67 [16 66] [7038 1.74 [16 100] [18 85]]]] [6 53]] [1899 2.45 [190 3.61 [16 37] [7 37]] [16 83]]] [2861 4.4 [4717 0.344 [7153 0.254 [2955 1.6 [4854 7.6 [19 50] [16 33]] [178 2.06 [5 55] [16 85]]] [18 50]] [18 37]] [16 66]]] [1888 4.48 [719 1.98 [5102 3.35 [2752 5.61 [18 46] [18 33]] [30 66]] [2939 7.87 [18 100] [560 0.392 [19 50] [18 50]]]] [18 50]]] [7512 2.88 [5681 1.81 [18 33] [16 68]] [6833 0.351 [5484 1.98 [3421 8.78 [6422 1.32 [2667 1.9 [2727 4.07 [6 77] [6 53]] [6 91]] [16 28]] [2628 20.6 [6 37] [5 50]]] [18 55]] [18 75]]]] [2965 0.258 [6959 1.2 [26 75] [1429 6.37 [6 50] [16 42]]] [26 83]]] [16 83]] [2897 4.95 [5894 1.35 [6920 2.84 [2611 6.82 [7104 0.457 [6 80] [16 66]] [6 100]] [4514 2.44 [16 66] [6 100]]] [16 50]] [16 57]]]] [7038 3.67 [7260 1.23 [6 100] [6 66]] [1895 2.06 [6 61] [6 90]]]] [2178 8.59 [5099 98 [1888 6.19 [2656 14.5 [6 56] [18 54]] [6 82]] [6 78]] [6 100]]] [2867 0.109 [7445 0.21 [1820 0.966 [3742 1.39 [132 0.308 [6877 4.5 [3008 0.468 [7232 2.09 [1429 15 [5435 34.4 [3694 0.296 [6257 9.94 [16 52] [18 100]] [16 50]] [6 87]] [18 80]] [16 60]] [16 81]] [16 44]] [26 42]] [18 37]] [16 85]] [2682 0.191 [16 40] [37 37]]] [2876 7.24 [377 1.28 [2956 0.285 [2891 0.319 [5170 0.93 [4937 0.654 [2955 16 [60 0.31 [2876 1.74 [2654 0.497 [16 27] [896 0.304 [16 100] [16 33]]] [5102 8.38 [18 33] [18 44]]] [60 1.06 [16 88] [16 55]]] [16 72]] [2951 6.62 [16 54] [95 1.24 [16 50] [6 70]]]] [2861 0.561 [26 53] [26 45]]] [5753 0.525 [28 55] [28 57]]] [6199 2.6 [26 57] [6472 0.156 [26 88] [26 85]]]] [26 87]] [16 93]]]] [663 3.42 [7345 0.766 [1895 2.82 [4426 0.652 [6199 2.48 [1400 4.98 [16 25] [26 85]] [16 42]] [2709 0.992 [26 66] [26 84]]] [26 50]] [19 45]] [16 45]]] [7301 0.593 [6961 5.16 [18 73] [7 46]] [6 46]]] [6961 0.464 [2649 7.6 [7381 0.532 [7 36] [7 100]] [7 100]] [7 100]]] [7332 1.61 [3585 1.51 [6830 6.05 [4997 0.854 [4854 8.95 [2866 7.46 [2611 2.55 [69 0.763 [1660 1.03 [5412 1.75 [2579 4.36 [5100 30.1 [248 10.4 [5099 38.7 [284 0.465 [5170 0.629 [7169 3.08 [2672 0.444 [1919 2.73 [1701 2.41 [4717 11.1 [2661 11.7 [2867 1.83 [190 7.37 [4426 0.957 [16 89] [16 100]] [190 10.6 [2849 27 [6 66] [16 70]] [16 85]]] [16 38]] [16 50]] [2644 6.85 [6 27] [16 72]]] [6 33]] [6 63]] [1239 12 [16 44] [6 100]]] [2707 26.7 [18 50] [15 42]]] [6 42]] [19 54]] [5103 21.2 [6 66] [16 45]]] [26 85]] [6 63]] [16 90]] [2868 1.17 [18 70] [5593 1.77 [16 100] [26 53]]]] [1660 3.24 [16 100] [5635 3.16 [16 60] [16 100]]]] [38 85]] [7041 3.17 [6 78] [2644 2.54 [16 100] [6 50]]]] [2714 3.79 [1687 1.68 [37 50] [5 45]] [37 53]]] [6098 1.68 [2663 0.998 [5593 7.1 [1290 0.506 [7512 1.97 [6839 2.06 [2628 44.9 [62 0.904 [2048 0.805 [16 70] [6 50]] [5632 2.93 [6 75] [6 37]]] [6 70]] [6 90]] [6 84]] [16 44]] [16 46]] [2707 22.4 [6 55] [16 100]]] [6 94]]] [7 100]] [663 1.71 [4935 2.01 [7423 1.49 [2268 1.13 [1429 19.1 [5733 4.6 [7421 0.778 [5593 9.81 [6959 1.08 [1783 7.76 [7 50] [18 50]] [6832 2.11 [16 45] [18 55]]] [18 100]] [18 41]] [7 100]] [5902 8.45 [2654 3.46 [2667 1.02 [4946 0.617 [6831 7.96 [2081 0.444 [1997 0.476 [18 71] [2717 1.18 [19 55] [26 50]]] [6007 3.41 [5100 2.69 [16 57] [16 81]] [18 60]]] [5593 3.79 [16 42] [18 85]]] [18 100]] [16 76]] [5103 3.65 [16 87] [16 54]]] [18 58]]] [16 50]] [16 84]] [7 100]] [5642 1.99 [5626 2.15 [7354 1.77 [16 100] [16 47]] [16 42]] [18 57]]]] [18 100]] [6008 1.8 [2764 3.06 [2712 1.98 [16 76] [2870 0.998 [16 50] [2707 23.4 [18 55] [7 44]]]] [7 66]] [1997 1.95 [5003 0.914 [7 37] [7 100]] [1429 24.2 [7 80] [16 22]]]]]] [14 78]] [2711 0.582 [7512 8.67 [5198 0.183 [5597 2.43 [7644 0.345 [2667 2.08 [6207 0.957 [6941 2.57 [7289 0.861 [7665 2.29 [2695 0.736 [5 40] [1648 1.67 [5673 1.14 [30 90] [30 100]] [30 90]]] [30 100]] [30 100]] [18 37]] [18 33]] [30 95]] [4879 2.64 [30 100] [30 85]]] [6 50]] [16 33]] [16 50]] [37 50]]]] [4687 0.301 [1748 0.0526 [2631 0.433 [2890 0.855 [6757 10.3 [5130 1.55 [7141 3.27 [1687 1.76 [2869 3.47 [5637 1.64 [4050 2.85 [38 80] [38 64]] [5632 1.29 [2468 0.824 [7445 2.19 [4051 2.86 [38 52] [38 80]] [1980 0.551 [38 78] [38 93]]] [2862 14.7 [4535 7.16 [5 35] [38 100]] [12 44]]] [18 40]]] [38 100]] [2691 6.14 [7476 1.63 [6824 8.66 [2469 4.65 [38 36] [14 58]] [38 88]] [5637 7.55 [38 70] [3400 1.4 [38 35] [5 100]]]] [14 37]]] [28 33]] [38 80]] [2849 24.5 [38 84] [38 100]]] [2890 3.62 [5 87] [5 35]]] [3418 0.997 [17 28] [1089 7 [3207 2.09 [5 62] [5 100]] [3972 0.974 [5 55] [37 76]]]]] [3069 1.87 [95 1.15 [4840 0.807 [6953 1.31 [7489 11.1 [94 2.45 [1104 0.323 [7512 0.166 [7301 2.04 [6920 1.29 [4131 0.829 [5593 1.9 [1078 7.7 [2628 32.4 [2939 19.4 [2955 2.25 [7391 7.8 [38 62] [23 37.4 [38 72] [16 50]]] [1687 8.24 [16 22] [14 42]]] [2862 8.35 [7445 2.28 [38 70] [38 100]] [4897 0.084 [38 55] [38 45]]]] [38 96]] [16 60]] [24 2.45 [17 33] [16 100]]] [6494 2.13 [2715 1.3 [7474 4.76 [2102 0.15 [7260 1.18 [38 86] [2868 0.726 [23 24.3 [38 100] [38 85]] [38 100]]] [38 100]] [1961 1.98 [4496 2.13 [1748 4.62 [7304 5.82 [7476 2.02 [7475 8.64 [38 75] [187 3.37 [38 75] [17 45]]] [2870 0.724 [199 3.49 [6931 0.688 [1687 3.68 [17 37] [38 76]] [8 72]] [38 88]] [12 28]]] [38 42]] [38 72]] [38 57]] [5 25]]] [17 60]] [17 42]]] [16 50]] [1900 2.52 [17 37] [16 52]]] [5597 0.879 [6 71] [16 73]]] [6 85]] [5891 0.44 [5363 1.76 [2526 1.36 [2628 17.6 [38 62] [7446 0.777 [38 60] [38 92]]] [38 44]] [38 93]] [38 50]]] [4712 1.15 [2469 5.38 [2430 18.3 [2093 0.886 [7423 1.4 [2750 3.85 [89 1.6 [38 100] [4009 1.64 [5164 2.55 [38 100] [38 80]] [38 100]]] [5210 1.96 [38 71] [38 96]]] [38 83]] [38 100]] [38 85]] [1748 6.31 [38 70] [2374 1.23 [38 86] [38 100]]]] [38 72]]] [166 0.565 [17 72] [19 40]]] [16 38]] [4851 1.54 [5412 0.383 [5626 1.49 [7476 1.31 [38 50] [17 61]] [38 81]] [16 80]] [2259 12.8 [4896 0.282 [17 88] [17 100]] [17 66]]]] [17 40]]] [2707 10.2 [17 100] [17 88]]]] [6384 0.709 [6199 3.69 [5678 7.8 [4676 9.27 [2403 5.65 [2033 1.47 [7475 0.314 [38 85] [2628 15.2 [7009 6.38 [7242 0.627 [2259 35.7 [38 87] [5210 4.71 [38 100] [38 93]]] [38 80]] [38 63]] [2877 14.8 [4889 12.1 [38 100] [38 90]] [38 62]]]] [38 100]] [23 67.6 [37 4.67 [2864 17.2 [2259 63.8 [2242 6.17 [7417 4.48 [2392 5.62 [2468 6.87 [4538 49.2 [38 100] [38 75]] [6719 7 [38 41] [38 87]]] [17 46]] [2403 8.25 [38 100] [38 80]]] [38 100]] [38 100]] [38 100]] [38 91]] [38 44]]] [38 66]] [2939 12.5 [7222 0.404 [2633 0.0902 [38 62] [7331 0.579 [4889 0.645 [38 90] [38 100]] [38 88]]] [38 91]] [2955 8.2 [3983 3.32 [1808 1.58 [38 90] [38 87]] [38 100]] [38 60]]]] [38 57]] [2663 0.852 [4939 2.73 [5148 0.147 [5637 5.96 [5380 14.6 [6108 2.68 [2887 0.672 [38 66] [38 92]] [2857 2.36 [2633 1.96 [2951 1.64 [38 78] [2405 11.6 [38 72] [38 45]]] [38 81]] [17 26]]] [38 100]] [3121 0.715 [2955 0.404 [1807 6.11 [38 55] [6107 6.54 [38 56] [38 62]]] [17 40]] [38 88]]] [38 90]] [38 57]] [38 35]]]]] [2849 3.39 [7701 0.372 [4518 0.154 [3079 2.28 [3768 0.297 [7434 0.162 [4832 0.307 [2470 1.21 [6230 1.28 [976 0.184 [5211 2.03 [7665 1.11 [5360 1.55 [518 0.989 [5041 1.74 [4867 0.164 [4005 0.0926 [3708 0.988 [384 0.549 [3103 1.41 [4315 0.0453 [907 1.22 [6772 0.212 [819 0.22 [2488 8.99 [6178 0.271 [2939 84.1 [2526 5.34 [583 1.11 [3480 0.362 [5567 0.205 [2701 0.0734 [248 8.77 [6524 0.0933 [5049 1.34 [5047 0.463 [1078 46.4 [5034 0.0966 [4865 2.16 [6541 0.443 [1672 0.121 [6471 0.505 [429 0.297 [6413 0.338 [5056 1.55 [695 2.02 [1429 4.19 [4682 2.44 [1944 3.64 [2106 1.02 [3219 3.36 [2951 2.24 [7606 7.04 [2793 0.341 [2154 2.55 [7588 7.46 [5673 1.56 [5539 4.65 [4231 0.0639 [4556 5.49 [1032 2.2 [3045 3.65 [5007 25 [7255 6.28 [5170 0.555 [1025 0.543 [6713 42.9 [2759 1 [2011 0.107 [3003 6.33 [2259 0.262 [4369 101 [2023 0.759 [5072 10.4 [7233 8.2 [5110 7.26 [1783 5.18 [6848 4.5 [4846 13.5 [5809 11.8 [3304 9.8 [1888 1.9 [1917 17.9 [2752 1.1 [3182 5.62 [2241 2.36 [6310 14 [2069 17.4 [7169 0.586 [2033 29.6 [7320 4 [6581 9.43 [107 6.49 [6082 78.5 [7656 18.5 [2696 24.4 [7505 17.2 [5601 88.9 [1255 3.74 [2099 28.4 [1 23] [1 24]] [35 77]] [33 31]] [29 35]] [30 100]] [35 20]] [4 38]] [33 89]] [17 25]] [35 81]] [35 59]] [6838 8.56 [33 9] [23 71]]] [35 60]] [35 55]] [4161 4.9 [2002 6.38 [3435 15.2 [5154 1.51 [1 30] [3 60]] [35 90]] [1899 46.8 [29 21] [23 33]]] [2 44]]] [37 41]] [2143 46.8 [2787 3.14 [4044 1.3 [1769 38.9 [144 81.5 [731 7.69 [2814 8.5 [5383 2.99 [1062 52 [4799 3.55 [12 9] [15 62]] [12 29]] [35 75]] [12 87]] [4 16]] [29 35]] [15 29]] [35 100]] [5 28]] [23 50]]] [3130 0.805 [23 30] [29 36]]] [4680 9.09 [12 23] [4 28]]] [15 100]] [15 82]] [1 85]] [35 57]] [5275 3.7 [1877 26.8 [3273 3.4 [5926 1.93 [6797 4.5 [4154 48.7 [2132 1.67 [5732 20.1 [1915 27.8 [6569 31.2 [1999 25.8 [144 9.8 [2628 4.85 [791 28.8 [4704 14.8 [7623 93.8 [7449 21.7 [2236 4.5 [6621 7.69 [1813 25 [1959 9.57 [33 18] [1 40]] [13 50]] [15 50]] [28 50]] [25 33]] [35 31]] [33 30]] [30 57]] [16 28]] [10 50]] [35 31]] [13 87]] [1 87]] [6 100]] [1980 25.1 [35 70] [29 70]]] [16 36]] [33 69]] [33 66]] [13 40]] [1 54]] [33 45]]] [33 32]] [32 96]] [1783 109 [33 93] [33 81]]] [5574 0.894 [2055 31.3 [1255 8.62 [5851 19.8 [1955 6.27 [1 23] [35 57]] [3 20]] [35 40]] [23 44]] [1 80]]] [27 73]] [2278 5.61 [7340 3.76 [148 8.85 [5345 8.93 [5368 1.54 [7046 7.46 [4611 5.68 [5589 11.1 [5254 6.85 [4198 6.95 [5972 8.29 [1980 13.4 [3652 6.67 [1961 3.85 [6809 11.1 [5086 32.1 [5019 19.1 [392 5.06 [2048 14.7 [276 28.1 [5593 2.74 [7154 0.191 [7038 10.5 [7101 21.1 [4342 9.8 [7766 30.2 [216 3.7 [7354 11.9 [6296 6.02 [1 9] [33 43]] [36 67]] [3 70]] [10 72]] [24 100]] [22 84]] [6 81]] [14 38]] [16 61]] [11 37]] [2028 13.3 [1 30] [1 50]]] [28 14]] [30 100]] [26 61]] [32 100]] [1962 45.7 [2241 0.503 [1 28] [29 42]] [1 100]]] [24 100]] [2752 10.4 [3095 10.9 [2043 0.678 [2281 1.21 [7615 5.15 [1078 9.28 [3008 7.56 [7101 5.38 [1965 15.6 [2305 4.01 [7428 9.09 [2099 9.45 [2299 6.47 [2192 3.68 [3251 1.41 [1783 27.3 [2143 1.2 [1 16] [29 16]] [33 30]] [35 83]] [29 37]] [2225 2.72 [1 28] [1 45]]] [29 27]] [13 25]] [13 35]] [1 66]] [22 77]] [1 55]] [2280 17.9 [28 28] [21 37]]] [3 100]] [1 30]] [2225 2.2 [35 56] [5 28]]] [29 33]] [23 19]]] [36 26]] [19 87]] [10 100]] [30 100]] [30 33]] [34 85]] [33 30]] [7 16]] [30 60]] [12 66]] [1959 12.1 [1 51] [1 100]]]] [27 95]] [23 52.7 [29 28] [29 83]]] [35 37]] [30 85]] [5851 45.6 [1031 2.62 [1239 49 [4430 7.25 [3642 0.543 [1980 19.2 [24 11] [15 16]] [24 66]] [12 55]] [9 27]] [1025 50.1 [35 81] [35 100]]] [37 37]]] [5110 2.54 [5170 14.7 [11 27] [33 77]] [33 89]]] [94 10.5 [12 52] [19 76]]] [15 48]] [35 80]] [15 100]] [23 100]] [19 47]] [221 10.2 [13 77] [13 42]]] [2259 1.66 [1980 24.1 [35 38] [35 63]] [148 7.25 [30 17] [30 63]]]] [2417 7.46 [4 75] [4 100]]] [1248 4.35 [29 28] [35 50]]] [24 32]] [2241 0.355 [19 48] [19 66]]] [7344 2.37 [2259 44.4 [4851 0.522 [2678 1.08 [6842 4 [7763 2.67 [5647 8.58 [2709 22.1 [2649 2.07 [38 35] [2955 20 [16 43] [7 22]]] [16 32]] [18 30]] [7 66]] [16 44]] [16 57]] [6 45]] [1980 0.818 [38 53] [38 86]]] [38 85]]] [7255 22.6 [15 77] [15 100]]] [7623 130 [2259 45.4 [35 22] [35 100]] [35 72]]] [2041 1.66 [2131 4.82 [2294 6.15 [35 54] [14 87]] [29 63]] [29 71]]] [1391 6.67 [33 85] [33 100]]] [1585 0.769 [5333 0.53 [1576 2.33 [756 1.75 [2199 1.07 [3636 3.23 [1722 0.478 [1594 0.639 [4145 7.78 [1116 0.914 [5996 0.931 [5540 2.79 [232 1.46 [1713 0.202 [6331 0.475 [1913 38.8 [4279 7.58 [2793 8.11 [1640 6.81 [1708 0.699 [4213 0.189 [7247 6.36 [6485 1.5 [5498 6.33 [5254 1.2 [1638 0.332 [3297 1.23 [1870 2.58 [7142 1.83 [7272 2.65 [5171 4.63 [6610 3.36 [5542 4.35 [1645 1.75 [5904 2.66 [1600 0.588 [5531 16.1 [392 9.62 [3244 2.39 [2707 0.393 [6943 8.67 [6484 0.241 [5564 1.04 [7324 11.1 [3811 3.53 [6811 5.38 [5375 4.67 [7512 0.236 [5972 12.5 [7255 12.6 [6388 20.8 [6031 18.8 [5941 1.13 [1 11] [14 32]] [22 47]] [5732 11.6 [28 45] [28 100]]] [7409 0.994 [6103 6.77 [4790 2.89 [12 33] [37 50]] [12 94]] [12 100]]] [12 62]] [1899 22.1 [5067 0.236 [4673 14.4 [19 16] [6 100]] [19 73]] [10 45]]] [1 54]] [32 100]] [30 93]] [23 63]] [14 100]] [25 58]] [32 100]] [6844 2.11 [187 18.7 [7401 1 [5160 23.2 [2730 5.88 [5753 7.1 [2130 0.768 [185 3.19 [6935 0.441 [3435 2.17 [1671 8.61 [1262 1.68 [3604 1.18 [16 16] [5 50]] [7473 2.69 [38 36] [38 75]]] [26 70]] [38 77]] [15 28]] [16 50]] [38 60]] [28 36]] [7 94]] [19 33]] [17 75]] [5626 13.5 [16 80] [16 84]]] [6 62]]] [15 60]] [1646 6.15 [18 24] [18 76]]] [13 51]] [7 100]] [2081 1.49 [7274 2.39 [3548 0.797 [4017 11 [4684 0.838 [5637 5.42 [19 39] [19 30]] [19 60]] [19 81]] [14 66]] [19 33]] [19 64]]] [15 100]] [13 100]] [1429 81.9 [28 95] [28 75]]] [328 6.18 [33 92] [33 80]]] [32 100]] [20 92]] [5542 5.18 [1851 3.86 [13 28] [13 92]] [13 100]]] [1899 3.62 [37 98] [37 71]]] [14 100]] [10 100]] [30 100]] [25 100]] [27 87]] [12 83]] [1772 10.4 [1854 0.539 [2143 14 [28 72] [28 54]] [28 100]] [28 46]]] [3130 12.2 [2 28] [13 71]]] [2993 2.54 [24 66] [24 87]]] [1783 14.9 [2518 3.45 [1957 14.4 [2517 4.27 [6809 3.4 [5152 2.26 [6859 11.7 [5972 9.09 [2189 1.62 [2294 2.73 [4210 12.2 [57 2.32 [1932 11.9 [4312 3.82 [1961 8.67 [2118 14.2 [3849 4.42 [4292 34.6 [4198 4.35 [5308 4.07 [32 9] [32 30]] [19 80]] [23 52]] [35 66]] [24 100]] [24 50]] [15 50]] [24 40]] [14 76]] [30 80]] [14 30]] [1 30]] [12 61]] [24 71]] [5151 7.05 [36 63] [24 41]]] [32 100]] [24 76]] [24 52]] [24 57]] [4063 6.32 [6168 4.52 [403 4.56 [2166 5.6 [2275 3.39 [1772 0.813 [2048 5.25 [2178 9.07 [33 12] [10 45]] [1 58]] [13 66]] [24 33]] [32 75]] [4 44]] [6 57]] [32 31]]]] [3931 7.37 [328 68.2 [1437 0.613 [1439 9.47 [1066 22.3 [3027 7.27 [2275 3.76 [2939 14.5 [2225 18 [1948 40.5 [2048 0.213 [1961 1.68 [2246 24.5 [3622 1.41 [1 21] [29 85]] [3 33]] [1 72]] [2072 0.213 [29 38] [28 44]]] [1 75]] [1 52]] [33 27]] [15 20]] [1 57]] [11 63]] [23 88]] [29 29]] [23 42]] [2081 15.9 [1 93] [23 57]]]] [1340 9.34 [11 77] [1684 18 [2 75] [2 33]]]] [31 96]] [6964 4.59 [5412 4.59 [33 70] [33 100]] [33 100]]] [4895 3.19 [13 90] [13 100]]] [31 100]] [2752 14.9 [30 57] [30 94]]] [24 88]] [4 70]] [1772 13.3 [7141 12.4 [163 3.76 [1876 0.739 [1722 4.83 [33 46] [2048 4.73 [6757 4.13 [2058 3.3 [1313 3.23 [33 78] [33 100]] [33 80]] [33 100]] [33 100]]] [33 61]] [33 95]] [33 100]] [33 93]]] [24 96]] [6458 1.87 [6461 2.39 [7629 2.19 [1742 3.8 [4338 0.763 [2153 1.06 [2139 0.748 [2204 3.51 [2225 3.55 [4114 27.5 [6031 4.17 [2235 10.4 [2151 16.7 [2274 5.61 [6056 0.357 [2119 24.1 [7190 4.07 [7210 2.25 [2073 0.596 [2284 4.9 [2379 1.56 [1660 62.3 [2048 6.03 [2143 3.2 [1436 0.533 [1 14] [2117 2.53 [1 9] [15 40]]] [2132 11.7 [23 32.3 [2248 0.269 [1795 3.5 [2168 2.54 [2275 3.76 [2181 6.49 [29 21] [23 20]] [28 33]] [29 75]] [26 37]] [29 66]] [10 16]] [35 54]]] [1 34]] [22 54]] [0 45]] [1 54]] [1 73]] [14 10]] [13 66]] [35 83]] [33 61]] [28 40]] [1 34]] [1 37]] [6369 1.64 [22 40] [22 33]]] [27 75]] [1391 13.7 [2108 11 [5153 3.23 [1429 97.3 [1429 75.8 [2032 0.109 [2215 1.06 [2764 1.91 [4991 2.79 [2202 9.32 [2055 5.62 [1456 14.8 [1913 26 [2002 2.74 [29 12] [29 44]] [1 30]] [13 50]] [35 50]] [23 44]] [29 50]] [11 33]] [29 57]] [11 25]] [1254 1.92 [29 41] [23 50]]] [1 28]] [24 45]] [1 25]] [33 36]]] [4898 2.44 [29 17] [33 69]]] [2276 0.417 [2056 0.0889 [2169 1.37 [29 36] [2170 2.15 [29 63] [23 60]]] [2190 1.35 [2108 0.356 [13 40] [1 88]] [28 40]]] [29 66]]] [2108 4.33 [2194 0.773 [2132 2.72 [29 47] [1 37]] [12 40]] [29 33]]] [23 61]] [1454 1.92 [33 52] [33 60]]] [7623 192 [35 31] [35 83]]] [25 100]] [25 100]]] [30 83]] [7428 1.45 [5991 4.22 [5373 4.62 [6883 5.64 [5495 13.8 [808 2.39 [2 51] [2 95]] [2 92]] [6 84]] [2 25]] [2 53]] [28 60]]] [7207 0.53 [11 97] [11 100]]] [14 97]]] [5892 2.56 [7377 8.7 [3205 5.62 [3922 3.82 [6124 3.55 [5843 9.89 [7295 4.13 [2752 21.9 [3929 8.75 [3772 6.67 [1592 17.2 [1400 22.5 [5270 5.96 [1391 10.7 [152 2.37 [663 18.3 [7736 1.46 [5732 3.87 [7168 15.6 [2902 4.71 [7287 6.77 [3464 6.17 [1783 24.8 [685 5.88 [3027 19.6 [1899 10.2 [5154 1.31 [2466 3.25 [4218 11.1 [5999 7.48 [6732 5.75 [14 10] [18 40]] [12 33]] [14 91]] [18 77]] [28 27]] [28 32]] [4 53]] [18 54]] [4704 3.21 [13 25] [33 50]]] [37 66]] [12 100]] [28 46]] [14 45]] [28 76]] [18 80]] [37 27]] [18 78]] [22 55]] [31 62]] [10 48]] [28 85]] [37 91]] [37 72]] [3292 1.78 [7085 18.6 [1489 3.11 [2753 9.74 [12 28] [36 40]] [12 100]] [12 57]] [37 94]]] [31 100]] [22 68]] [12 98]] [37 100]] [12 88]] [36 100]] [14 100]]] [2986 1.66 [2275 2.96 [2232 0.525 [7401 1.48 [23 41.3 [4895 3.72 [7 45] [7 72]] [31 71]] [7 100]] [1436 17 [15 27] [7 55]]] [7 100]] [15 62]]] [2259 30.8 [1253 0.147 [3764 3.6 [1692 7.94 [5999 8.85 [5629 0.0578 [4997 1.41 [2794 4.27 [2235 7.71 [23 55.1 [7060 2.27 [6082 0.747 [1769 10.1 [13 27] [7 25]] [12 28]] [17 36]] [31 65]] [15 100]] [31 100]] [7 100]] [15 100]] [6485 5.99 [25 60] [25 100]]] [22 100]] [15 100]] [15 83]] [7 49]]] [3667 0.682 [1708 1.5 [5566 0.0796 [3439 0.535 [5106 1.33 [1659 0.898 [5484 0.512 [6848 1.23 [1833 0.811 [2917 7.75 [802 9.07 [893 4.07 [3311 0.349 [978 1.49 [499 8.93 [558 1.01 [3929 0.575 [5629 0.316 [7354 1.02 [3475 2.43 [6809 0.846 [5254 0.549 [5011 0.477 [5310 0.888 [4338 2.33 [6648 1.26 [3072 2.49 [2398 0.852 [6031 10.9 [1509 0.994 [3045 0.205 [4279 12.3 [1609 0.974 [560 4.49 [6767 0.879 [4554 0.529 [3288 0.162 [392 3.13 [2259 5 [7623 6.39 [6148 10.9 [6300 1.51 [5732 0.162 [6859 4.95 [372 3.56 [3850 8.9 [27 4.16 [580 0.444 [3292 0.604 [2987 5.13 [2802 2.68 [3003 1.03 [5192 0.221 [2780 4.13 [3273 0.77 [489 6.03 [306 1.05 [21 7] [29 100]] [35 98]] [3273 31.2 [11 73] [11 50]]] [23 2.7 [37 93] [37 100]]] [12 25]] [27 100]] [155 2.33 [29 80] [29 100]]] [23 66]] [1062 1.48 [2143 8.41 [3781 1.9 [2782 1.43 [5692 4.19 [3837 3.37 [5851 0.38 [1783 13 [37 90] [11 37]] [37 60]] [37 100]] [37 66]] [112 2.92 [37 80] [38 50]]] [37 61]] [12 33]] [37 59]]] [739 2.99 [917 5.23 [5937 23.5 [21 67] [21 100]] [9 60]] [21 100]]] [145 1.74 [32 80] [32 100]]] [35 83]] [1899 8.45 [21 85] [21 50]]] [434 6.64 [28 45] [36 100]]] [5745 3.55 [1980 2.63 [1899 2.86 [870 8.77 [28 60] [15 60]] [28 92]] [906 2.31 [1454 0.851 [28 90] [28 75]] [15 28]]] [15 85]]] [6301 0.703 [28 52] [28 86]]] [9 82]] [4374 3.94 [6393 2.07 [2225 5.46 [7635 8.47 [27 19] [27 92]] [35 70]] [15 100]] [12 100]]] [6560 0.341 [7241 1.69 [2699 2.13 [1661 0.155 [826 3.05 [2993 23 [6457 1.53 [1684 2.54 [4049 0.16 [1600 2.56 [6859 1.26 [1429 13.7 [5845 1.08 [5291 4.02 [3907 1.52 [143 2.74 [2444 3.27 [2752 5.32 [3 11] [12 14]] [15 88]] [9 87]] [32 81]] [10 100]] [10 100]] [4630 8.38 [6899 4.48 [631 1.34 [377 2.19 [1980 0.0516 [756 6.91 [36 11] [3 81]] [827 3.17 [28 6] [2 67]]] [1584 2.26 [28 46] [28 73]]] [36 80]] [33 76]] [4530 0.894 [5574 0.752 [2068 4.8 [4059 5.49 [2752 24.4 [11 49] [2 53]] [17 90]] [11 100]] [4 41]] [37 55]]]] [1429 54.3 [7512 9.28 [36 57] [36 54]] [36 92]]] [7 100]] [21 100]] [5393 0.503 [1429 43.2 [11 57] [6791 0.204 [22 25] [36 50]]] [2 58]]] [25 88]] [27 62]] [7428 6.85 [7623 8.02 [1025 2.82 [939 4.78 [7480 9.71 [7009 3.65 [6294 3.87 [12 64] [11 50]] [12 97]] [15 100]] [11 77]] [12 70]] [15 64]] [7449 2.53 [12 87] [12 100]]]] [6027 7.08 [3317 0.624 [1600 4.57 [6449 0.21 [6353 0.384 [6228 0.279 [18 66] [18 92]] [18 100]] [18 88]] [7 100]] [7 75]] [7 100]]] [12 100]] [2259 75.3 [631 1.12 [2233 0.281 [1460 2.77 [7243 23.6 [4414 0.393 [2939 15.1 [5457 3.07 [6223 5.05 [2260 6.37 [4907 4.2 [23 7.47 [36 35] [695 1.33 [3 28] [36 71]]] [36 100]] [36 82]] [36 100]] [36 100]] [10 100]] [2752 0.444 [3 17] [30 30]]] [32 69]] [27 100]] [7 42]] [36 100]] [14 28]]] [791 2.29 [21 40] [27 48]]]] [2232 2.96 [2925 2.85 [695 3.3 [1023 8.53 [4288 3.02 [6621 2.56 [7358 2.22 [4320 12.4 [2752 9.02 [6851 3.6 [2225 4.63 [328 68.8 [1913 1.91 [397 2.56 [6205 9.25 [5776 7.59 [7168 0.657 [429 37.2 [3424 1.97 [28 13] [23 62]] [27 31]] [23 40]] [36 33]] [7 63]] [18 55]] [30 33]] [26 41]] [35 60]] [24 75]] [1239 20.6 [394 19 [7441 7.73 [4061 1.66 [4011 5.47 [1429 21.4 [23 23] [7461 0.928 [2081 9.35 [5412 8.89 [791 27.7 [28 48] [14 36]] [28 100]] [23 50]] [28 87]]] [28 100]] [28 88]] [11 66]] [28 94]] [25 39]]] [27 100]] [35 90]] [685 13.6 [28 67] [28 40]]] [3 33]] [18 93]] [2787 1.59 [1986 4.53 [4533 4.7 [28 65] [28 50]] [28 100]] [20 71]]] [4601 25.4 [26 41] [2925 36.4 [26 84] [19 50]]]] [28 60]]] [7343 0.21 [37 86] [38 57]]] [7 100]] [5602 0.866 [1997 1.04 [6782 0.307 [31 77] [31 100]] [31 100]] [31 100]]] [18 57]] [1783 35.2 [7428 0.628 [2216 0.485 [1428 5.07 [2081 0.719 [19 44] [24 63]] [1062 49 [24 68] [24 90]]] [24 100]] [2143 2.62 [2169 0.345 [1899 0.678 [24 80] [36 70]] [24 80]] [24 100]]] [1980 7.69 [24 41] [4 33]]]] [5046 2.42 [4568 2.18 [1451 3.38 [23 86.3 [4159 9.47 [4799 9.12 [5785 2 [607 1.81 [2029 16.4 [3715 1.66 [2130 15.2 [766 2.86 [5809 9.76 [4602 0.888 [2041 9.8 [7625 2.02 [4612 6.33 [5271 19 [5373 2.33 [6438 10.2 [1980 42.7 [2796 5.38 [5673 4.41 [1547 13.5 [5967 3.74 [3 18] [28 81]] [11 73]] [3 64]] [15 85]] [23 54]] [30 100]] [11 40]] [32 86]] [36 100]] [34 85]] [24 90]] [26 100]] [15 100]] [3 100]] [24 81]] [26 40]] [29 57]] [3 100]] [32 88]] [32 85]] [2178 12.8 [6091 11.3 [2752 54.4 [7449 1.17 [2241 1.75 [29 51] [29 75]] [29 42]] [22 22]] [3 75]] [2241 20 [4292 9.09 [4312 7.19 [29 40] [3 87]] [3 100]] [29 55]]]] [29 79]] [29 54]] [28 85]] [6015 2.42 [3 98] [3 100]]]] [35 77]] [28 94]] [6294 0.47 [22 75] [10 15]]] [7188 1.27 [4663 2.86 [5267 5.1 [12 93] [12 83]] [12 100]] [12 100]]] [2048 0.752 [1078 7.62 [26 81] [32 36]] [26 100]]] [30 98]] [24 57]] [10 100]] [435 0.254 [2081 2.12 [1677 0.266 [5368 0.524 [906 5.03 [1899 14.3 [1078 17.2 [429 30.9 [2259 6.85 [112 1.89 [19 20] [29 66]] [29 62]] [29 57]] [28 33]] [29 66]] [29 89]] [28 29]] [29 100]] [794 0.724 [29 89] [29 80]]] [2259 0.254 [429 39.2 [29 100] [23 40]] [29 100]]]] [10 100]] [1 0.223 [4533 2.87 [286 17.5 [5891 4.28 [32 100] [32 92]] [32 88]] [32 85]] [32 80]]] [4414 5.72 [3475 7.52 [15 63] [15 96]] [15 100]]] [1980 3.84 [850 2.89 [3663 0.99 [4859 3.14 [7734 0.156 [4024 0.894 [112 4.02 [4926 1.23 [5322 10.1 [4611 3.26 [36 41] [36 96]] [1 30]] [10 36]] [36 71]] [36 100]] [7169 3.3 [134 0.157 [1888 2.37 [18 45] [18 50]] [19 40]] [18 77]]] [18 80]] [36 100]] [36 91]] [248 2.59 [5299 1 [2011 1.3 [1452 2.43 [1783 6.41 [939 2.56 [2260 0.986 [429 59.8 [6859 2.86 [36 22] [36 100]] [32 40]] [36 100]] [29 33]] [3 26]] [10 27]] [24 25]] [11 33]] [29 33]]]] [6329 1.33 [15 97] [15 100]]] [3554 6.9 [2969 1.8 [3831 1.74 [7662 4.35 [1905 6.4 [3292 3.25 [7169 1.39 [1980 9.78 [1429 83.7 [826 2.44 [6342 2.57 [968 0.878 [4154 9.21 [3008 0.352 [12 54] [12 81]] [12 53]] [1899 1.22 [17 33] [8 33]]] [5 93]] [12 100]] [3901 0.292 [7210 0.743 [5 28] [5 60]] [12 80]]] [12 86]] [2151 1.13 [6027 1.35 [6866 0.206 [4761 1.09 [3929 11.9 [37 29] [429 14.4 [12 58] [5 54]]] [5 50]] [37 57]] [5 57]] [12 37]]] [37 63]] [5 40]] [12 100]] [37 87]] [12 100]] [12 90]]] [5470 0.743 [3971 4.4 [1 12.5 [429 23.8 [7456 2.49 [12 94] [12 100]] [1764 1.36 [5879 3.14 [509 1.22 [4417 2.65 [324 1.82 [12 99] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]]] [12 88]] [12 88]] [12 100]]] [4122 8.04 [23 1.79 [7512 2.67 [4124 7.65 [5647 5.62 [7442 3.14 [27 67] [27 77]] [23 33]] [27 92]] [27 55]] [27 71]] [27 96]]] [5581 2.46 [6042 2.06 [6768 6.64 [7061 1.81 [276 1.82 [4068 1.72 [6921 1.25 [6859 3.98 [392 0.273 [7512 1.6 [3525 2.74 [286 2.42 [7133 1.57 [7354 7.49 [7491 5 [774 0.8 [5769 1.74 [5970 4 [7098 9.21 [4338 3.77 [6544 6 [23 4.34 [1580 5.75 [3332 12.9 [3928 7.84 [485 9.14 [6619 11.6 [3033 0.855 [470 22.8 [5812 2.35 [5999 5.85 [1400 8.79 [7508 1.41 [438 0.773 [4279 18.1 [1980 9.24 [663 2.79 [655 32.2 [7381 25 [5509 4.07 [1783 32.2 [5 14] [17 43]] [1630 6.02 [8 33] [17 90]]] [4 71]] [2 71]] [17 20]] [23 32]] [791 7.97 [8 35] [26 50]]] [23 54]] [23 100]] [4 37]] [23 60]] [791 23.3 [12 22] [2 50]]] [22 83]] [23 88]] [25 100]] [38 51]] [5 77]] [35 100]] [17 52]] [5 11]] [17 52]] [24 56]] [35 87]] [23 100]] [2 54]] [23 48]] [23 50]] [2259 13.4 [978 38.5 [5130 10.7 [5 36] [16 66]] [19 60]] [978 21.4 [36 44] [19 50]]]] [4 100]] [23 46]] [35 80]] [4 21]] [23 38]] [24 57]] [23 97]] [35 100]] [18 60]] [23 66]] [31 100]] [3515 4.59 [2752 27.8 [132 4.35 [18 63] [18 50]] [19 40]] [16 20]]] [23 100]]] [23 100]] [7412 6.17 [15 92] [15 100]]] [2752 4.26 [6150 2.94 [616 2.79 [429 69.3 [3008 0.65 [435 6.94 [4478 1.67 [4279 2.67 [1318 5.38 [1451 7.11 [1391 6.06 [2259 64.8 [5040 1.47 [2944 4.67 [6015 7.2 [6380 4.76 [21 32] [9 100]] [21 90]] [21 66]] [21 86]] [21 80]] [9 50]] [9 36]] [9 100]] [3 51]] [9 56]] [1429 7.65 [688 6.55 [21 83] [21 66]] [21 76]]] [10 42]] [2270 5.49 [1239 75.8 [5412 10.2 [6184 30.6 [6791 10.2 [5937 1.93 [5403 5.05 [1986 1.52 [1985 3.12 [6306 6.49 [4663 7.09 [2099 3.64 [21 54] [21 91]] [21 77]] [3 100]] [21 100]] [21 65]] [3 100]] [918 1.93 [5323 2.37 [21 92] [21 100]] [21 100]]] [3 50]] [802 31.3 [21 100] [21 93]]] [3 66]] [9 54]] [21 45]]] [3 92]] [23 19.8 [1429 2.16 [9 50] [9 100]] [791 27 [9 100] [9 83]]]] [5007 2.94 [5972 5.41 [2179 0.313 [906 2.39 [15 54] [15 73]] [11 33]] [695 3.53 [12 95] [12 100]]] [15 100]]]] [2752 1.59 [802 8.73 [915 20.7 [906 6.94 [23 4.57 [3 69] [3 88]] [1980 49.2 [3 97] [3 60]]] [3 100]] [3 57]] [7512 0.797 [32 52] [32 100]]]] [13 100]] [4645 2.99 [3675 0.545 [132 3.69 [1226 4.42 [2978 0.444 [850 0.8 [5480 2.18 [112 1.48 [7149 8.32 [904 1.13 [6981 0.257 [1437 0.675 [6376 2.02 [957 0.711 [35 67] [5 30]] [35 100]] [35 100]] [35 61]] [38 71]] [14 50]] [32 20]] [18 37]] [1980 9.53 [35 97] [35 75]]] [38 60]] [35 100]] [32 42]] [14 27]] [1187 0.761 [18 37] [18 77]]]] [168 19.7 [7007 1.27 [397 10.1 [5888 2.77 [276 36.1 [964 17.2 [1062 5.47 [6199 0.354 [6732 10 [5516 0.96 [7513 15.7 [2939 26.1 [695 38.1 [4926 7.12 [7186 22.6 [4859 2.53 [4205 1.99 [896 10.4 [18 66] [16 37]] [6 42]] [18 96]] [18 72]] [18 100]] [18 58]] [16 66]] [6 46]] [16 50]] [18 100]] [18 81]] [731 6.44 [18 53] [37 42]]] [18 100]] [18 36]] [18 52]] [16 42]] [18 100]] [19 57]]] [4083 0.523 [1796 0.269 [3899 0.226 [3969 1.36 [4200 0.201 [3683 5.44 [1948 1.1 [7374 2.23 [2272 0.266 [6822 1.45 [2039 7.23 [4090 2.92 [4551 0.53 [2139 0.227 [1662 0.334 [3598 4.78 [4279 21 [3576 7.19 [6943 7.04 [4505 0.593 [7189 1.28 [1573 0.331 [5941 1.3 [7185 2.63 [6780 0.402 [1654 1.46 [6879 1.6 [1078 10.1 [4456 0.503 [1656 0.195 [1436 0.211 [3897 3.48 [17 49] [17 100]] [17 45]] [17 82]] [17 100]] [38 50]] [17 92]] [1711 2.35 [1607 0.213 [17 84] [17 100]] [17 66]]] [10 40]] [1 33]] [1565 1.08 [6809 1.47 [4637 1.95 [17 62] [6777 1.94 [17 52] [1592 2.25 [6380 0.965 [17 87] [17 60]] [17 37]]]] [32 78]] [14 40]]] [1899 0.137 [17 94] [17 100]]] [2048 0.732 [5412 1.73 [17 87] [17 77]] [17 71]]] [32 87]] [32 100]] [17 90]] [14 54]] [4537 5.78 [32 57] [35 75]]] [19 71]] [17 31]] [32 100]] [19 81]] [32 58]] [38 55]] [20 29]] [38 72]] [19 39]] [32 50]] [19 85]] [32 70]] [32 100]] [4558 0.167 [5999 0.639 [4414 1.08 [7374 2.14 [4781 0.165 [2130 0.346 [6049 0.546 [17 65] [1750 0.618 [2257 0.822 [1563 1.35 [19 50] [17 53]] [17 75]] [19 60]]] [19 31]] [19 75]] [35 41]] [19 77]] [38 80]] [5296 0.622 [19 83] [19 100]]]] [1714 0.348 [7210 0.273 [38 75] [38 91]] [3680 0.765 [19 73] [17 34]]]]] [28 100]] [1995 1.75 [1062 0.241 [1769 2.42 [2143 1.65 [1986 6.49 [11 66] [35 50]] [11 100]] [11 83]] [3130 0.391 [11 93] [11 100]]] [1986 5.79 [844 0.867 [11 90] [11 100]] [11 85]]]] [1239 0.373 [3905 14.2 [1516 1.66 [14 98] [14 100]] [14 85]] [14 100]]] [6388 6.6 [5989 0.994 [2093 1.15 [28 88] [28 100]] [28 100]] [28 60]]] [2779 1.42 [6766 0.247 [6342 1.44 [1239 7.85 [2993 3.92 [7203 1.71 [2108 15.5 [2208 0.885 [35 61] [429 27.7 [35 75] [35 87]]] [35 42]] [35 90]] [21 44]] [35 25]] [29 33]] [35 100]] [29 62]]]] [7038 3.09 [2139 0.306 [896 2.06 [5099 6.68 [5509 2.49 [663 7.49 [5270 0.994 [414 1.57 [5480 7.8 [2749 4.25 [1429 32.5 [2259 32.9 [4235 11.6 [7449 5.31 [26 80] [26 42]] [6333 0.121 [26 94] [26 100]]] [26 61]] [6425 6.17 [221 6.31 [1742 1.2 [7301 1.41 [2143 1.52 [26 73] [26 54]] [26 40]] [33 66]] [16 44]] [26 54]]] [26 81]] [26 57]] [16 100]] [26 93]] [26 48]] [26 35]] [6 44]] [19 40]] [1 35]] [16 85]]] [5412 0.207 [22 100] [22 94]]] [898 1.5 [23 20.6 [3929 15.9 [12 100] [12 88]] [12 100]] [12 100]]] [3 100]] [4517 0.521 [5420 0.248 [23 15.6 [826 8.71 [1239 14.7 [5692 0.0966 [5732 1.39 [2759 1.5 [2917 6.02 [6859 1.74 [1717 1.93 [5296 3.66 [7340 3.39 [631 2.46 [2099 5.23 [3726 2.76 [1429 19.5 [5472 20.5 [28 25] [28 50]] [5632 1.51 [5891 22.4 [5753 1.29 [685 2.49 [14 45] [6732 1.98 [14 81] [28 71]]] [28 66]] [17 57]] [28 43]]] [32 100]] [3 81]] [28 93]] [32 100]] [14 100]] [32 100]] [28 90]] [3 100]] [1646 2.24 [28 55] [28 100]]] [5851 0.763 [1077 3.95 [6859 1.66 [1980 5.12 [28 71] [28 86]] [957 1.78 [28 93] [28 100]]] [28 75]] [28 100]]] [802 2.22 [4943 7.92 [5999 9.31 [1925 3.81 [6342 7.44 [7298 4.81 [7501 0.894 [2905 1.41 [5192 16.2 [4565 2.87 [28 92] [28 88]] [28 50]] [28 44]] [28 75]] [28 71]] [28 62]] [429 23.4 [28 100] [28 52]]] [1 37]] [28 62]] [3 70]]] [663 1.81 [236 3.36 [248 0.131 [4154 10 [3 57] [4197 9.36 [2143 3.03 [6091 2.01 [3 78] [3 100]] [3 100]] [3 80]]] [2 33]] [3 100]] [14 57]]] [32 100]] [7731 5.15 [5871 6.31 [377 1.42 [695 3.03 [802 1.14 [5632 6.24 [5403 1.36 [5732 1.21 [3 52] [28 43]] [3 100]] [28 57]] [3 97]] [14 56]] [28 77]] [14 63]] [3 100]]] [968 0.963 [28 66] [28 93]]] [6439 2.92 [6856 6.69 [7203 0.557 [1429 3.47 [3 77] [1084 0.778 [3381 4.64 [5194 0.431 [28 89] [28 100]] [28 85]] [28 84]]] [28 100]] [28 75]] [28 100]]]] [3273 0.858 [939 11 [1161 0.508 [7036 0.042 [7752 0.6 [4332 0.525 [6853 7.14 [4154 3.82 [1429 6.63 [3003 0.829 [4114 27 [5884 0.698 [7740 2.6 [4323 1.69 [3902 4.23 [2147 0.434 [429 59.5 [7411 4.71 [5647 15.5 [392 4.78 [4444 14 [3449 12.8 [4968 1.89 [2939 0.122 [3670 28.8 [1909 7.67 [3944 4.01 [2931 10.5 [7320 8.47 [7739 5.36 [4331 5.55 [3964 7.3 [5320 4.5 [7203 10.1 [1783 33.3 [3667 6.35 [818 8.2 [5673 11.8 [4781 8.19 [2108 7.52 [2241 5.59 [802 2.92 [2802 4.07 [2752 0.462 [3849 1.81 [2002 25.4 [1233 2.01 [7623 94.5 [3554 5.06 [1127 11.2 [1943 26.3 [1300 4.95 [2437 12.2 [6732 11.7 [6349 3.94 [1190 4.42 [5568 4.59 [5267 1.87 [774 2.79 [2052 2.37 [1219 5.71 [4418 83.9 [2049 1.6 [1 28] [1 66]] [1 100]] [10 73]] [1 54]] [27 48]] [10 30]] [35 81]] [2 68]] [10 80]] [15 30]] [30 100]] [10 100]] [32 44]] [22 75]] [32 83]] [35 57]] [27 77]] [23 58]] [35 95]] [2752 76.8 [23 13] [11 15]]] [29 77]] [12 38]] [1101 34.2 [2241 9.9 [1 73] [1 22]] [12 30]]] [1 44]] [5690 4.95 [11 72] [11 100]]] [35 32]] [29 63]] [2 31]] [2149 3.4 [1 54] [35 31]]] [30 43]] [2 41]] [35 100]] [27 78]] [10 61]] [35 50]] [23 52]] [35 71]] [2 45]] [35 59]] [10 25]] [35 66]] [35 88]] [1 79]] [392 58 [429 14.1 [2752 20.7 [19 22] [18 42]] [11 29]] [27 71]]] [11 44]] [35 71]] [2225 22.6 [2259 3.58 [2029 1.64 [27 54] [27 36]] [1094 1.72 [10 28] [12 27]]] [32 33]]] [27 94]] [10 60]] [27 100]] [10 87]] [11 100]] [27 69]] [27 100]] [3554 1.04 [5629 1.06 [567 12.1 [5092 3.68 [5972 2.86 [4326 17.6 [6325 0.0591 [4320 8.4 [4092 5.28 [4571 0.225 [3959 3.46 [5454 0.222 [5640 0.435 [5994 3.88 [7606 2.06 [5290 4.79 [1078 126 [730 0.291 [599 7.58 [377 2.85 [5345 1.28 [1218 1.83 [2787 5.45 [1235 3.45 [791 0.293 [7737 10 [2213 1.21 [1963 2.6 [1150 10.3 [2178 2.8 [1094 11.3 [1932 36.9 [1159 4.5 [2173 0.639 [27 12] [16 45]] [27 88]] [12 38]] [2259 3.82 [1 28] [6 38]]] [2202 0.53 [23 14] [1456 8.28 [2091 0.53 [11 33] [1 40]] [23 50]]]] [35 100]] [1 37]] [1078 99.9 [8 44] [1 71]]] [10 68]] [6031 3.51 [4611 11.2 [3155 1.58 [2199 0.437 [1078 46.7 [37 57] [4663 22.5 [2280 1.1 [1888 15.2 [3003 4.67 [1783 2.79 [1116 6.69 [1995 18.5 [3929 13.3 [2259 53.8 [2760 0.664 [5732 5.43 [7169 10.8 [11 11] [35 40]] [28 81]] [28 33]] [36 40]] [35 36]] [22 21]] [30 50]] [11 26]] [27 100]] [32 66]] [11 23]] [18 28]]] [1911 9.39 [11 13] [12 33]]] [19 60]] [35 71]] [13 61]]] [10 100]] [28 100]] [7505 8.47 [28 56] [28 46]]] [27 40]] [1094 9.77 [28 34] [22 44]]] [2 45]] [28 90]] [1456 1.03 [1099 1.7 [3130 6.71 [1 39] [1 71]] [2023 4.76 [1 61] [1 42]]] [25 27]]] [10 93]] [10 88]] [29 61]] [13 100]] [29 62]] [29 88]] [10 66]] [791 3.76 [35 77] [35 87]]] [27 100]] [28 100]] [27 89]] [12 47]] [22 96]] [11 70]] [15 100]] [32 56]]] [1078 82 [4337 13.9 [4601 0.342 [7512 0.766 [2199 6.67 [3310 12.8 [1239 9.62 [168 7.46 [2993 7.31 [7411 3.82 [4158 0.952 [1210 3.7 [928 2.65 [5366 3.5 [4323 4.07 [1123 3.55 [3849 1.23 [1239 4.51 [2133 3.55 [27 12] [35 42]] [28 50]] [35 85]] [27 70]] [27 100]] [23 100]] [27 100]] [5 40]] [2143 10.2 [28 51] [30 23]]] [15 56]] [27 66]] [19 58]] [23 36]] [23 100]] [15 31]] [10 38]] [1429 5.89 [1980 22.6 [22 33] [1 28]] [1101 0.609 [28 80] [28 100]]]] [28 86]] [3794 3.14 [939 0.177 [2752 5.35 [2180 11 [3576 6.49 [2234 22.2 [2178 41.7 [27 27] [15 54]] [15 61]] [15 100]] [2199 14.2 [2226 1.99 [27 50] [15 76]] [15 27]]] [2259 9.84 [4329 4.95 [1114 2.46 [978 15.4 [4288 4.59 [2072 7.13 [27 47] [27 28]] [4 22]] [18 50]] [3003 3.03 [23 20] [27 100]]] [27 100]] [28 23]]] [27 88]] [27 100]]]] [28 48]] [1239 2.96 [2013 2.73 [27 82] [27 100]] [27 66]]] [10 100]] [29 100]] [788 1.02 [1617 0.611 [7436 2.51 [2178 3.19 [1079 6.42 [1219 2.05 [4200 4 [5154 4.67 [4320 18.9 [3634 2.22 [1166 1.73 [27 36] [27 100]] [35 50]] [4120 4.2 [27 85] [27 100]]] [27 100]] [10 85]] [10 100]] [10 100]] [429 38.2 [27 78] [27 66]]] [10 100]] [10 100]] [5309 0.452 [10 88] [10 100]]]] [6660 1.47 [1121 0.898 [64 0.885 [6350 3.76 [4117 1.58 [3555 2.62 [5883 12.5 [1899 7.88 [941 31.4 [7441 2.67 [4279 5.72 [4373 1.87 [1108 4.11 [6465 9.43 [3531 7.94 [27 50] [27 100]] [27 100]] [1078 107 [29 18] [27 85]]] [27 97]] [2091 4.67 [27 60] [23 33]]] [27 100]] [15 29]] [392 7.79 [1138 1.93 [1980 4.1 [2752 14.2 [939 27.2 [27 33] [27 61]] [10 30]] [1239 9.83 [27 24] [28 58]]] [27 100]] [28 57]]] [11 100]] [32 81]] [27 100]] [10 100]] [29 100]] [27 93]] [11 92]]] [3746 0.699 [1138 0.0693 [2024 0.472 [3099 1.69 [1980 13.6 [11 80] [844 0.578 [11 91] [11 100]]] [35 66]] [11 77]] [11 100]] [35 70]]]] [7451 1.93 [2225 2.89 [2362 1.66 [4219 13.2 [3 100] [3 98]] [3 100]] [3 88]] [3 100]]] [29 0.362 [3628 4.35 [1757 4.59 [201 2.18 [5803 1.88 [6031 2.01 [5446 6.02 [6260 11.9 [1338 4.07 [7006 6.9 [5410 40.4 [516 3.5 [4588 5.15 [2251 1.33 [586 2.22 [806 15 [143 2.51 [660 12.2 [21 69] [21 100]] [9 100]] [21 100]] [21 100]] [9 100]] [21 100]] [21 100]] [9 88]] [21 100]] [9 100]] [21 94]] [9 100]] [9 90]] [9 100]] [9 100]] [9 90]] [21 100]] [1279 1.45 [9 78] [9 100]]]] [5192 0.0906 [427 0.233 [6024 0.275 [5844 4.53 [1055 0.254 [695 0.341 [6301 0.401 [674 1.56 [340 1.34 [7461 0.928 [688 12.7 [1888 1.12 [2793 1.27 [685 0.654 [2753 5.6 [5732 0.504 [1849 3.65 [426 3.45 [16 4.27 [7305 3.4 [4655 1.48 [2823 3.47 [4865 0.337 [5753 2.86 [6184 1.49 [4282 1.67 [2831 1.29 [1454 5.49 [7251 3.3 [2766 11.1 [6080 1.14 [916 0.861 [2944 5.05 [5034 2.71 [5509 0.855 [2039 2.08 [4279 6.04 [1906 2.26 [2993 0.29 [1104 6.88 [22 39] [27 40]] [36 35]] [22 37]] [28 36]] [28 33]] [3 50]] [4414 3.65 [28 89] [28 100]]] [21 71]] [21 100]] [15 100]] [7 55]] [28 100]] [22 80]] [22 100]] [3 100]] [5851 7.05 [25 22] [25 36]]] [791 26.9 [2180 3.14 [973 3.32 [4337 6.78 [4741 2.09 [968 20.7 [221 5.61 [28 66] [28 68]] [28 35]] [28 83]] [28 57]] [28 77]] [28 69]] [28 53]]] [3 100]] [22 100]] [1 81]] [5809 4.76 [3 22] [15 100]]] [36 100]] [1 100]] [25 100]] [2628 1 [6080 3.14 [1980 9.71 [2241 1.4 [5509 2.5 [906 9.48 [429 1.6 [28 87] [28 100]] [28 80]] [28 85]] [28 87]] [1911 6.67 [28 76] [28 50]]] [15 100]] [28 50]]] [22 65]] [2764 4.59 [3008 6.15 [28 80] [28 50]] [28 42]]] [4279 13.1 [28 91] [28 36]]] [1078 16.3 [7 28] [2259 10.6 [7 25] [12 44]]]] [7 47]] [28 72]] [1 100]] [1 100]] [2259 3.82 [28 100] [28 88]]] [6653 15.9 [6380 2.65 [5601 8.58 [1429 5.86 [5753 1.4 [28 44] [1239 0.526 [28 92] [28 62]]] [6644 0.0933 [7445 4.2 [6530 10.8 [2787 7.82 [144 9.14 [2947 1.29 [6524 42.1 [7373 0.15 [6529 9.69 [3302 2.84 [5326 7.96 [168 7.26 [5013 4.07 [6606 0.692 [1429 92 [7168 1.84 [4011 0.232 [5968 0.382 [1783 25.8 [2149 3.34 [7441 0.686 [112 13.6 [3269 3.31 [7493 1.27 [7198 3.64 [5267 5.74 [5034 28.1 [5937 1.87 [4396 0.513 [6856 0.832 [392 1.31 [7251 0.773 [6998 2.2 [5753 0.79 [28 91] [28 98]] [28 100]] [28 100]] [28 100]] [28 100]] [28 100]] [28 90]] [28 85]] [28 71]] [28 88]] [28 85]] [28 71]] [28 57]] [392 1.85 [28 66] [28 87]]] [28 60]] [28 46]] [28 100]] [3995 1.03 [1239 2.35 [28 100] [28 83]] [28 100]]] [28 71]] [14 40]] [28 75]] [28 86]] [28 66]] [28 57]] [28 71]] [28 63]] [28 54]] [28 63]] [28 71]] [2259 11.4 [145 2.54 [28 90] [28 85]] [791 7.05 [28 63] [36 66]]]] [28 70]] [22 50]] [28 100]] [794 0.17 [5812 0.267 [4158 2.63 [28 100] [28 85]] [28 100]] [28 100]]]] [9 37]] [14 50]] [9 50]]] [11 100]] [663 2.86 [22 75] [22 100]]] [7 100]] [1 67]] [2180 0.502 [4312 0.13 [4741 8.69 [3698 3.52 [5632 1.78 [4011 0.273 [328 39.6 [4704 0.724 [5192 16.7 [4781 0.356 [726 2.98 [6529 7.03 [1079 5.42 [6531 1.77 [864 1.19 [5191 8.49 [362 0.724 [6525 21.5 [1221 0.688 [4991 1.65 [1429 56.7 [28 100] [28 80]] [28 87]] [28 100]] [28 87]] [28 100]] [28 85]] [28 100]] [28 100]] [28 71]] [28 64]] [28 85]] [11 66]] [28 33]] [28 62]] [28 53]] [28 100]] [28 75]] [28 71]] [28 45]] [2081 0.283 [28 96] [28 100]]] [12 50]]]] [6777 0.165 [851 5.65 [6844 1.16 [269 1.55 [4658 8.83 [791 0.253 [2081 11 [5532 10.6 [23 5.25 [3006 0.574 [5254 5.05 [4390 1.65 [135 0.805 [1429 20.3 [939 3.88 [1084 2.49 [1239 5.7 [5574 3.55 [4655 7.25 [6342 19.2 [4704 17.3 [5753 9.09 [2755 2.49 [2752 1.65 [5480 6.67 [3739 7.04 [33 31] [28 42]] [33 44]] [2628 11.2 [26 50] [26 69]]] [731 15.3 [26 55] [26 81]]] [33 60]] [33 90]] [25 56]] [1 92]] [20 50]] [2755 1.28 [6621 4.5 [6959 5.78 [7335 9.35 [4682 7.99 [7769 3.03 [5999 7.52 [6294 3.31 [5072 3.4 [33 49] [33 50]] [33 76]] [2 40]] [21 37]] [5447 11.1 [33 100] [13 33]]] [26 37]] [13 30]] [33 81]] [25 75]]] [26 70]] [26 60]] [1622 1.63 [5965 2.86 [6827 9.09 [5539 4.38 [978 2.65 [1623 3.03 [1581 2.58 [400 0.192 [248 24.2 [5641 10.4 [7151 3.18 [1932 26.4 [2059 2.54 [1696 6.02 [232 4.95 [1698 0.606 [2408 2.73 [1445 22.3 [2127 1.18 [1783 81.1 [3993 4.85 [1913 20.5 [33 12] [30 26]] [33 50]] [33 37]] [13 21]] [22 37]] [33 100]] [25 100]] [33 85]] [26 83]] [33 66]] [1 66]] [4 42]] [7 55]] [3694 6.85 [1437 25.9 [33 26] [26 50]] [33 50]]] [14 55]] [3 100]] [11 100]] [26 55]] [13 94]] [18 100]] [3 100]] [11 83]]] [978 9.9 [26 44] [26 76]]] [26 84]] [10 100]] [1696 12.3 [673 2.37 [26 83] [663 1.72 [26 92] [26 87]]] [26 83]]] [1239 12.2 [44 3.45 [4682 1.23 [216 2.62 [5353 3.94 [5140 5.05 [6525 2.2 [5205 2.33 [4601 1.14 [181 1.39 [5851 25.5 [6616 4.64 [4611 6.52 [1078 0.761 [7314 2.46 [6791 15.4 [33 35] [26 30]] [33 82]] [1 15]] [15 41]] [26 75]] [25 62]] [26 51]] [26 74]] [26 88]] [25 90]] [33 95]] [26 85]] [1 37]] [33 92]] [26 80]] [2081 5.69 [3404 3.4 [178 9.53 [5110 5.83 [5154 10.9 [1313 2.07 [4809 1.96 [4530 1.93 [33 41] [33 100]] [10 70]] [33 100]] [25 57]] [33 93]] [26 50]] [33 57]] [33 84]]]] [13 76]] [5170 11.6 [980 3.07 [4114 4.76 [7335 5.2 [1 24] [33 72]] [15 44]] [26 85]] [33 70]]] [6482 2.35 [4297 4.32 [4602 0.6 [7116 7.98 [7411 3.03 [5562 1.22 [6413 1.69 [5539 11.9 [6811 1.17 [6080 2.67 [7254 2.1 [392 3.62 [267 3.5 [5564 1.59 [5007 0.93 [7729 6.19 [1912 5.42 [7497 3.5 [6883 6.49 [5528 1.64 [896 10.4 [2011 11.5 [4593 1.86 [5140 2.01 [249 1.59 [5299 0.838 [5429 7.75 [794 9.33 [7314 17.2 [6342 0.253 [2048 7.69 [4533 11.9 [802 12.1 [6395 4.98 [4851 4.09 [6180 3.94 [1301 8.41 [4414 30.4 [7255 9.43 [3130 3.49 [233 2.65 [673 6.05 [2755 2.04 [4781 2.42 [33 18] [2 28]] [35 20]] [26 34]] [33 90]] [22 44]] [32 62]] [15 52]] [33 100]] [25 100]] [3 41]] [2 75]] [11 31]] [15 33]] [29 35]] [29 19]] [3 60]] [33 85]] [26 87]] [7335 0.838 [33 54] [24 66]]] [7 46]] [864 3.65 [6653 2.01 [33 82] [33 100]] [33 100]]] [15 100]] [1429 35.3 [29 89] [29 62]]] [18 37]] [15 100]] [33 69]] [29 100]] [31 90]] [1 100]] [2081 7.16 [1601 1.58 [6998 0.709 [1239 28.1 [29 50] [10 30]] [29 100]] [29 66]] [2001 2.96 [29 91] [29 100]]]] [14 100]] [18 85]] [18 48]] [978 2.59 [33 51] [26 90]]] [15 100]] [32 100]] [13 100]] [13 91]] [33 91]] [6791 6.29 [15 79] [15 100]]] [15 93]] [26 78]] [32 100]] [13 100]]] [7415 1.39 [1899 6.67 [1 86] [1 100]] [33 60]]] [929 3.03 [26 71] [26 69]]] [1888 3.97 [426 9.72 [1078 20.7 [33 81] [1 90]] [1 75]] [33 88]]] [4059 1.89 [4576 0.886 [4639 3.79 [5941 1.02 [12 27] [32 82]] [17 62]] [32 98]] [17 44]]] [6092 0.0792 [2178 0.684 [1239 3.88 [2259 22.5 [4639 0.111 [3 55] [17 73]] [6159 1.16 [4642 0.975 [1568 2.27 [17 36] [32 75]] [32 87]] [17 50]]] [32 44]] [32 92]] [32 100]]]] [258 2.24 [1467 1.87 [802 2.28 [774 0.939 [1400 0.382 [3928 1.03 [2808 1.73 [7343 24.9 [5814 1.62 [7411 10.3 [6732 13.2 [286 13.7 [2628 3.1 [2772 1.23 [2398 0.404 [6155 4.45 [6375 6.9 [3130 2.21 [7456 9.59 [1776 5.62 [6809 2.94 [4114 33.5 [4071 13.7 [897 4.49 [1925 5.73 [1094 0.143 [5339 0.497 [4154 59.3 [2818 0.99 [5413 8.8 [4769 1.24 [328 9.12 [5007 0.183 [4414 4.3 [1764 2.67 [5605 2.46 [2128 0.0749 [4197 1.95 [1068 18.8 [7460 18.5 [1995 17.6 [1429 57 [5994 0.364 [2752 0.826 [7169 19.5 [7101 5.88 [2702 3.23 [29 78] [29 100]] [29 87]] [29 50]] [5412 0.488 [2178 0.826 [29 86] [29 100]] [29 60]]] [29 100]] [29 56]] [29 53]] [15 50]] [12 50]] [15 80]] [29 75]] [15 37]] [15 71]] [6015 2.3 [29 85] [29 100]]] [6068 0.801 [660 1.25 [2068 0.715 [29 97] [29 100]] [29 100]] [29 100]]] [29 91]] [5454 0.0734 [2093 5.57 [29 100] [29 72]] [29 100]]] [32 70]] [12 100]] [15 40]] [29 100]] [1095 10.1 [1899 18.3 [6883 0.419 [1104 2.2 [29 100] [5680 0.891 [2753 1.16 [2704 0.586 [906 0.263 [23 2.27 [2225 7.7 [29 91] [29 90]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]]] [29 100]] [2149 0.32 [4154 21.5 [7453 1.17 [939 0.719 [5007 2.77 [29 100] [29 66]] [29 100]] [29 100]] [29 85]] [29 100]]] [29 84]]] [15 45]] [15 100]] [29 57]] [10 37]] [32 100]] [12 100]] [29 46]] [29 100]] [1078 17.8 [12 55] [29 50]]] [12 100]] [12 64]] [12 100]] [435 1.98 [248 1.79 [12 48] [29 100]] [29 100]]] [4768 1.59 [29 47] [29 100]]] [15 71]] [15 60]] [12 76]] [12 63]] [15 97]] [1899 8.48 [15 61] [12 83]]] [1391 5.49 [2701 17.6 [1400 19.4 [12 71] [15 48]] [15 63]] [15 83]]] [10 48]] [7210 1.45 [15 50] [12 60]]] [15 100]] [15 100]]] [4684 0.185 [5844 0.208 [2219 0.163 [7333 2.3 [1452 5.47 [5892 0.066 [7210 1.12 [1621 1.47 [14 98] [14 100]] [14 100]] [14 100]] [14 85]] [14 93]] [14 100]] [14 100]] [14 86]]] [6211 1.58 [3884 0.935 [3559 2.15 [6813 0.653 [2628 10.6 [3244 1.36 [4283 0.921 [4206 10.5 [4163 2.59 [1400 10.3 [1987 5.56 [7461 2.49 [2320 1.85 [7210 1.31 [3111 2.7 [3908 3.06 [4288 5.44 [7480 7.69 [939 0.673 [2753 2.16 [7255 24.3 [1078 24.4 [15 50] [32 30]] [15 71]] [32 57]] [32 33]] [15 100]] [32 92]] [32 90]] [15 66]] [32 63]] [5323 3.69 [5972 5.49 [660 4.27 [4851 7.95 [32 64] [32 100]] [32 92]] [36 100]] [32 100]]] [32 57]] [32 100]] [15 76]] [32 100]] [15 58]] [15 100]] [15 100]] [36 83]] [32 100]] [503 7.1 [32 100] [32 75]]] [15 100]] [15 100]]] [429 114 [536 10.6 [6883 8.78 [1017 0.722 [5831 2.84 [371 3.1 [4210 0.62 [4978 3.95 [554 1.46 [5972 3.85 [4154 2.44 [5693 0.717 [9 55] [21 71]] [3 63]] [1783 7.58 [6397 3.27 [791 12.3 [590 2.11 [4282 1.95 [3 46] [3 100]] [3 100]] [688 1.99 [6547 3.6 [1986 6.04 [3 82] [3 100]] [3 100]] [21 66]]] [21 57]] [3 82]]] [3 100]] [3 100]] [3 100]] [21 50]] [9 97]] [3 100]] [21 39]] [21 66]] [688 4.35 [21 54] [688 13.2 [21 66] [21 100]]]]] [2793 0.32 [6827 4.07 [3003 0.852 [6923 0.328 [3849 3.12 [6490 0.467 [5734 2.7 [7413 5 [6767 2.86 [537 0.615 [6848 5.25 [1025 2.82 [4213 2.79 [2539 2.27 [6471 4.78 [2684 1.45 [892 0.931 [2605 6.05 [2559 1.97 [2845 1.16 [7657 0.838 [980 0.357 [3743 1.33 [2379 3.92 [7381 1.68 [535 1.31 [4122 38.1 [4992 3.64 [5480 1.84 [2569 1.17 [4997 1.31 [2081 7.13 [23 3.11 [5174 8.48 [6582 2.28 [2931 1.98 [7241 2.84 [6927 1.25 [286 5.76 [5950 2.74 [5397 13 [2321 2.16 [6809 1.63 [6182 2.44 [7663 3.88 [1335 0.843 [4959 3.23 [811 19 [7365 5.05 [5858 1.86 [7176 16.1 [4703 9.18 [5904 2.94 [5448 3.46 [6382 0.144 [6342 33.1 [7633 4.59 [2530 4.83 [3659 0.765 [6537 12.1 [4145 3.82 [7292 4.06 [4302 0.293 [4655 1.17 [4732 3.36 [5140 3.91 [4338 6.74 [3928 8.91 [5366 0.202 [1932 2.15 [6189 5.88 [5686 16.1 [8 8] [21 82]] [25 100]] [1 36]] [23 90]] [5 45]] [2 25]] [33 77]] [6 83]] [1 90]] [8 85]] [2 55]] [24 94]] [6537 24.9 [2 100] [2 53]]] [24 92]] [673 17.9 [25 45] [26 91]]] [35 95]] [8 67]] [4063 0.427 [2241 0.397 [17 47] [14 33]] [17 28]]] [2259 34.5 [32 100] [32 85]]] [19 81]] [33 50]] [8 76]] [0 100]] [4 100]] [10 95]] [4 90]] [6 93]] [12 100]] [25 100]] [32 100]] [8 76]] [6 95]] [1062 8.91 [434 2.38 [24 83] [24 100]] [24 75]]] [2143 3.24 [978 3.51 [23 24] [929 6.88 [663 8.1 [23 75] [2 90]] [23 57]]] [23 31]]] [1141 9.78 [2 66] [4 75]]] [328 21.7 [5 17] [26 88]]] [429 1.01 [23 89] [23 100]]] [791 3.23 [6582 14.4 [4 68] [4 91]] [4 100]]] [33 42]] [5831 0.463 [6524 5.5 [56 3.15 [7623 3.58 [4704 1.61 [600 3.03 [1429 74.8 [4948 1.22 [7009 13.1 [5769 14.9 [750 3.4 [2466 2.94 [6550 9.75 [896 0.381 [2739 30.3 [5732 5.3 [7241 10.3 [2530 5.52 [5115 7.04 [179 0.471 [7314 17.2 [6260 7.7 [3897 7 [2023 7.96 [1888 1.61 [2763 0.69 [3008 18.7 [3054 3.76 [6413 0.47 [33 10] [21 44]] [0 100]] [25 54]] [4 20]] [7169 1.61 [978 3.94 [2 35] [2 36]] [12 66]]] [22 33]] [37 60]] [36 50]] [3 73]] [12 40]] [33 100]] [25 43]] [7241 15.2 [3 77] [3 71]]] [24 50]] [4 93]] [5 25]] [17 75]] [7731 0.982 [19 20] [24 57]]] [3 100]] [1640 15.2 [4 75] [4 91]]] [4 42]] [3 93]] [5 40]] [17 73]] [33 60]] [5140 0.858 [33 52] [33 100]]] [3 72]] [1742 18.9 [4870 2.06 [25 48] [25 100]] [1 75]]] [9 100]]] [1899 70 [4658 2.7 [2530 17.4 [2145 18.7 [6621 3.34 [3100 3.23 [1899 37.3 [248 3.88 [1094 2.66 [1106 6.91 [2218 0.952 [534 4.5 [2143 7.94 [4184 3.7 [1764 7.87 [1253 4.92 [906 18 [4571 5.96 [2752 12.1 [25 9] [7461 7.81 [4279 17.8 [5412 2.97 [178 4.59 [23 31] [17 28]] [2 33]] [18 22]] [18 33]]] [19 45]] [21 100]] [2526 23.7 [23 70] [23 30]]] [8 70]] [1 28]] [2081 53.7 [1 13] [23 61]]] [3 100]] [1 100]] [23 38]] [23 47]] [33 29]] [2763 3.7 [2178 7.97 [3 57] [3 42]] [25 28]]] [1 100]] [23 44]] [21 86]] [26 70]] [1 80]] [23 87]]] [7 96]] [4736 0.948 [4675 0.657 [6 75] [6 100]] [6 60]]] [6732 1.87 [6560 0.507 [7285 1.57 [560 1.33 [6199 13.2 [4279 6.29 [2426 6.41 [3113 17.2 [695 3.29 [791 2.47 [6986 0.931 [5692 4.07 [8 30] [18 40]] [8 100]] [23 27]] [18 50]] [8 100]] [8 100]] [23 46]] [8 75]] [279 6.85 [18 69] [18 37]]] [21 100]] [8 100]] [2752 5.75 [0 32] [18 62]]]] [5647 7.75 [663 4.89 [2 68] [2 88]] [2 100]]] [27 90]] [21 92]] [655 2.34 [6550 1.27 [4 54] [4 96]] [4 35]]] [32 80]] [3743 10.6 [35 80] [2178 3.03 [35 95] [35 100]]]] [134 0.238 [980 7.14 [26 90] [23 3.7 [2752 23.6 [25 66] [26 60]] [26 87]]] [26 100]]] [5972 2.65 [12 87] [12 100]]] [23 100]] [33 83]] [25 83]] [10 93]] [4 100]] [5641 2.58 [26 83] [26 52]]] [2101 1.39 [23 27] [12 55]]] [12 84]] [7742 1.14 [1995 0.336 [939 1.75 [5480 0.401 [605 9.33 [4991 8.71 [6537 1.23 [1200 25.6 [6859 1.44 [2764 3.99 [6260 8.34 [435 1.39 [1943 1.47 [112 1.38 [1980 6.94 [5396 10.9 [7411 1.51 [3328 5.26 [3008 6.57 [5753 5.29 [4663 27.3 [6917 3.56 [221 27.8 [978 20.5 [7461 8.35 [7751 1.11 [2 18] [24 83]] [12 80]] [2 46]] [2 85]] [23 62]] [4 35]] [2 34]] [1429 13.5 [24 36] [24 57]]] [2 66]] [30 30]] [4 69]] [4684 5.77 [23 29] [4 25]]] [21 80]] [23 64]] [23 53]] [24 80]] [23 50]] [24 80]] [24 100]] [2 87]] [4992 14.9 [2 100] [2 75]]] [24 90]] [5486 0.401 [23 58] [23 100]]] [23 60]] [435 0.419 [12 23] [1253 0.419 [23 56] [23 100]]]] [4 52]]] [1980 1.68 [35 53] [35 75]]] [3 100]] [1239 2.7 [6074 2.86 [31 93] [31 100]] [31 100]]] [7185 5.15 [2892 3.07 [33 57] [33 100]] [33 75]]] [1888 7.38 [7 94] [7 87]]] [4663 2.07 [1025 6.8 [23 80] [23 100]] [23 100]]] [3462 7.19 [740 4.62 [1919 5.59 [3438 0.861 [695 1.92 [35 70] [35 57]] [35 100]] [35 100]] [35 71]] [35 100]]] [6959 0.379 [6515 2.31 [7224 0.246 [1382 2.9 [6 74] [6 100]] [16 42]] [6 100]] [16 66]]] [27 100]] [2259 3.65 [2806 3.45 [18 85] [18 64]] [18 100]]] [4326 1.36 [286 1.78 [1425 2.26 [4768 14.6 [2099 1.81 [4301 2.16 [2232 1.18 [7657 4.26 [1025 3.61 [1429 41.9 [3003 1.23 [23 55] [27 100]] [429 9.56 [24 49] [23 50]]] [2548 1.08 [1429 7.2 [3659 9.64 [23 40] [7026 1.72 [24 87] [24 100]]] [7491 0.752 [2259 3.9 [24 70] [2536 1.96 [209 1.41 [2395 2.67 [3659 13.4 [2526 17 [24 80] [24 100]] [24 60]] [24 100]] [24 100]] [24 100]]] [24 71]]] [3660 7.54 [24 91] [24 71]]]] [12 100]] [1094 7.61 [23 81] [23 71]]] [12 100]] [2232 13.2 [23 100] [23 78]]] [27 66]] [12 100]] [2531 0.467 [5972 4.89 [2143 11.4 [23 91] [23 50]] [12 100]] [23 94]]] [4331 5.43 [27 75] [27 100]]]]] [7472 0.273 [5896 0.117 [5100 0.568 [2689 0.191 [5298 0.776 [6131 18.7 [2939 118 [5566 2.7 [2733 1.44 [2665 2.42 [414 2.2 [2766 5.03 [2276 0.205 [2897 4.95 [2685 1.75 [5058 6.18 [2947 1.38 [2642 4 [2944 10.6 [1587 4.36 [6199 17.8 [1897 3.65 [6406 22 [1259 2.9 [2712 27.8 [6371 16.1 [1436 2.6 [1932 0.956 [5983 37 [38 30] [16 77]] [38 100]] [10 27]] [6 33]] [14 50]] [38 75]] [16 40]] [38 90]] [17 30]] [38 100]] [3 50]] [17 72]] [36 22]] [2093 2.71 [2178 0.802 [4610 27 [19 40] [14 58]] [17 69]] [2951 50.3 [14 30] [14 58]]]] [16 34]] [7 62]] [38 75]] [38 100]] [10 30]] [2628 56.8 [38 55] [38 100]]] [16 38]] [14 100]] [4717 9.16 [5577 3.75 [4496 3.92 [7371 4.74 [4130 0.49 [7123 23.8 [3130 2.66 [2628 16.1 [1 36] [6074 2.95 [1920 2.44 [3895 10.9 [6406 51 [2659 1.68 [5918 2.58 [4768 40.7 [2691 2.71 [5150 25 [1587 7.16 [38 70] [38 46]] [16 100]] [38 53]] [38 40]] [36 47]] [2707 68.6 [38 100] [38 90]]] [16 52]] [6 42]] [2949 3.02 [38 92] [38 62]]] [38 40]]] [38 93]] [16 53]] [38 91]] [17 51]] [38 100]] [16 37]] [16 52]]] [38 100]] [1395 1.25 [14 52] [14 62]]] [16 70]] [7101 15.4 [1239 17.2 [16 43] [6 50]] [6 62]]] [2246 0.117 [17 37] [17 100]]] [1265 0.428 [2849 0.469 [38 59] [38 92]] [17 45]]]] [6449 11.8 [2753 12.1 [6524 21.2 [4154 0.271 [6907 3.95 [663 1.86 [1980 25.9 [25 100] [25 88]] [25 100]] [25 100]] [25 100]] [25 98]] [181 6.02 [25 93] [25 100]]] [25 76]]] [1900 1.14 [7340 1.48 [3541 2.81 [3972 2.35 [791 12.5 [2752 10.9 [6732 1.75 [685 4.86 [6853 7.84 [168 14.4 [4332 6.77 [296 2.37 [1587 9.46 [407 10 [3008 0.808 [4663 9.95 [4369 2.54 [6353 6.14 [3687 5.68 [5110 1.02 [1980 3.92 [3054 12.7 [144 3.27 [3369 0.414 [978 3.55 [429 29.7 [2488 22.7 [328 24 [13 29] [34 90]] [4154 7.25 [8 62] [8 41]]] [8 95]] [1078 76 [392 2.22 [5692 14 [8 91] [8 71]] [8 100]] [8 55]]] [8 100]] [13 66]] [0 100]] [8 41]] [1239 10.4 [5647 4.76 [8 89] [8 85]] [8 75]]] [13 100]] [34 37]] [13 56]] [13 71]] [1980 4.95 [8 90] [8 62]]] [8 96]] [2259 14.5 [13 85] [13 37]]] [32 100]] [8 65]] [13 100]] [34 80]] [383 5.26 [8 96] [8 100]]] [38 44]] [8 32]] [6147 3.03 [13 56] [2 66]]] [8 98]] [1764 1.41 [0 77] [0 60]]] [2760 1.48 [32 50] [32 100]]] [32 97]]] [504 0.647 [4414 0.362 [448 0.813 [1129 0.613 [3130 1.42 [3554 1.56 [2199 0.585 [4120 0.581 [4116 3.86 [27 100] [3934 3.5 [27 97] [27 100]]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]]] [5991 2.89 [3337 0.215 [4064 9.85 [2246 0.399 [6883 4 [1862 0.879 [3811 0.377 [2199 6.83 [1997 12.2 [30 62] [30 100]] [30 57]] [30 100]] [23 1.16 [30 97] [30 100]]] [33 42]] [30 100]] [30 50]] [30 100]] [4337 7.54 [2191 0.335 [4712 3.91 [30 100] [30 88]] [30 83]] [30 90]]]] [660 0.383 [4480 0.603 [7464 0.649 [1365 0.246 [6544 0.482 [4591 0.816 [6085 1.32 [538 0.463 [7197 0.615 [1592 1.07 [5937 2.01 [1361 1.09 [5697 1.11 [7298 0.885 [554 0.642 [5047 0.599 [6267 0.911 [1018 2.09 [5139 8.95 [5892 3.07 [6132 4.85 [751 6.17 [5040 1.34 [373 1.55 [4282 5.47 [4048 3.6 [4564 2.39 [1400 1.82 [2993 13.3 [4210 2.16 [5851 1.06 [1373 3.5 [4214 0.876 [2917 4.2 [4218 4.79 [536 16.2 [534 1.03 [2156 12 [802 7.35 [21 56] [6883 4.26 [21 72] [9 60]]] [21 88]] [3 96]] [9 44]] [3 92]] [3 71]] [3 85]] [9 38]] [21 81]] [3 100]] [21 88]] [15 38]] [3 100]] [21 100]] [1783 5.26 [3 96] [3 100]]] [21 94]] [114 1.45 [583 3.03 [23 24.9 [21 100] [21 90]] [21 100]] [21 100]]] [3 100]] [9 100]] [3 100]] [9 61]] [3 100]] [9 80]] [6621 2.35 [5732 1.9 [1429 0.975 [3 98] [3 100]] [3 100]] [3 100]]] [4219 1.03 [3 98] [3 100]]] [3 100]] [3 91]] [5047 1.51 [1239 66.2 [3 100] [3 50]] [3 100]]] [2156 1.04 [1783 12.1 [21 92] [21 75]] [21 100]]] [3 100]] [3 83]] [4748 3.02 [545 0.48 [1322 4.64 [5393 0.99 [5046 2.33 [21 74] [21 90]] [21 95]] [9 52]] [21 90]] [9 97]]] [6897 3.55 [21 86] [21 52]]] [3 100]] [3008 0.835 [586 0.452 [917 1.02 [5047 1.2 [3 94] [3 100]] [3 100]] [3 100]] [3 100]]] [793 0.781 [5799 1.75 [6199 1.41 [9 41] [9 84]] [21 87]] [7428 0.491 [9 92] [9 77]]]] [3 100]] [7009 2.83 [7615 1.61 [3008 1.75 [4663 0.778 [580 0.209 [5295 1.05 [5049 7.76 [7211 7.05 [5535 0.608 [538 0.739 [3 65] [429 43.2 [3 33] [9 80]]] [9 83]] [906 8.32 [9 75] [9 100]]] [21 47]] [10 37]] [9 88]] [3 40]] [3 100]] [3 100]] [9 90]]] [5322 15.1 [818 0.121 [6260 2.57 [645 0.635 [5937 8.81 [21 75] [21 100]] [21 100]] [21 62]] [21 62]] [747 4.42 [21 45] [21 75]]]]] [27 100]] [6613 2.11 [4851 1 [339 1.27 [3045 7.23 [3849 14.7 [3336 0.938 [5897 1.26 [3389 0.518 [5692 0.605 [35 68] [28 42]] [35 88]] [35 100]] [35 75]] [3234 20.8 [3862 31 [1085 2.49 [35 94] [35 100]] [35 70]] [35 72]]] [35 92]] [35 96]] [4 40]] [15 50]]] [1025 4.85 [6491 0.482 [2815 0.448 [719 1.23 [1483 0.957 [5812 1.18 [5366 0.272 [2004 0.376 [282 0.555 [5411 4.34 [6155 2.7 [3059 1.13 [269 1.64 [4690 1.16 [5838 26.6 [2752 10.4 [7736 2.42 [5409 2.92 [6732 8.79 [2251 0.261 [4414 19.6 [3450 1.47 [7169 11.4 [1391 2.07 [6177 2.51 [3308 20 [2939 17.8 [6040 0.952 [2488 2.49 [1436 1.54 [398 2.67 [7354 4.39 [6719 12.7 [144 4.22 [26 25] [7 50]] [18 100]] [18 77]] [23 65]] [26 100]] [8 81]] [18 76]] [26 33]] [23 100]] [25 90]] [35 83]] [23 44]] [939 1.37 [35 97] [35 100]]] [26 60]] [35 47]] [18 82]] [6 100]] [18 76]] [663 0.84 [4205 6.27 [6177 10.5 [687 10.7 [6719 1 [5170 5.72 [1454 0.65 [398 0.813 [4288 3.44 [3332 3.96 [1081 3.57 [1078 5.65 [2831 14.3 [281 2.44 [7354 5.26 [23 43] [18 34]] [18 71]] [18 81]] [23 58]] [26 77]] [35 88]] [23 98]] [385 2.56 [7354 5.24 [23 90] [18 62]] [26 90]]] [23 91]] [26 88]] [18 94]] [7 100]] [25 71]] [26 65]] [2753 4.39 [26 37] [18 50]]]] [35 100]] [8 100]] [2755 4.73 [5174 14.1 [26 60] [18 44]] [26 90]]] [8 100]] [18 92]] [23 86]] [7185 0.555 [384 33.7 [18 56] [16 50]] [6 42]]] [2225 0.418 [2023 0.562 [23 84] [23 100]] [23 100]]] [23 100]] [35 64]] [8 100]] [532 4.79 [6044 2.46 [6831 3.05 [283 8.41 [248 26.9 [731 8.18 [6353 0.873 [379 1.45 [2752 31.3 [18 62] [7 50]] [18 83]] [18 100]] [18 87]] [18 88]] [18 60]] [16 50]] [18 100]] [18 100]]] [23 100]] [23 100]] [2628 1.81 [7101 0.456 [2793 0.409 [978 1.28 [1078 2.44 [35 44] [23 71]] [1911 0.325 [4954 0.516 [5749 0.354 [6791 1.31 [23 77] [23 100]] [23 100]] [23 100]] [23 100]]] [23 100]] [23 40]] [23 33]]]] [2217 0.917 [4309 7.14 [2939 24.8 [787 15.8 [6294 4.56 [1676 25 [312 3.75 [145 1.44 [1943 8.96 [6616 3.14 [5491 2.17 [6353 10.4 [1919 5.47 [5812 1.51 [5588 0.861 [6955 0.583 [3514 1.94 [1783 6.44 [3711 2.48 [2081 6.66 [35 82] [1078 19.7 [1 27] [35 75]]] [35 100]] [35 68]] [1064 0.504 [6621 28.9 [1429 105 [1025 17.6 [3448 11.9 [2199 7.88 [3273 1.76 [429 15.9 [3435 22.4 [4663 34 [1648 21.5 [1078 12.4 [35 86] [2023 0.48 [685 1.59 [35 95] [35 100]] [35 100]]] [3667 2 [35 98] [35 100]]] [35 80]] [35 77]] [1429 69.2 [23 5.75 [2628 0.797 [35 96] [35 100]] [35 66]] [35 100]]] [3953 17.2 [35 100] [35 90]]] [35 50]] [35 100]] [35 86]] [35 80]] [35 68]] [35 55]]] [35 64]] [35 62]] [3152 1.56 [3045 7.03 [35 61] [35 80]] [35 100]]] [35 50]] [35 75]] [35 68]] [35 50]] [35 78]] [35 55]] [37 42]] [35 66]] [4 27]] [35 63]] [35 36]] [35 40]] [35 44]]] [2055 7.09 [4781 0.0926 [6606 0.99 [29 53] [28 100]] [5154 1.43 [5904 4.21 [5943 2 [1343 1.1 [3790 0.0926 [7329 8.23 [1429 26.4 [28 100] [28 62]] [28 45]] [28 87]] [968 2.77 [1343 12.9 [28 98] [28 80]] [28 80]]] [6406 1.14 [3136 14.8 [2226 3.06 [5942 17.9 [5472 1.09 [6353 1.35 [906 1 [838 1.04 [5943 2.6 [28 80] [28 100]] [28 100]] [28 100]] [28 100]] [28 100]] [28 85]] [28 83]] [28 83]] [28 75]]] [28 54]] [28 69]]] [28 75]]] [4949 0.311 [1899 5.99 [3 100] [4684 1.46 [1913 2.28 [3 91] [3 100]] [3 100]]] [3 100]]] [5441 0.822 [1400 7.71 [6353 7.88 [376 0.35 [2232 12.4 [4794 13 [603 3.93 [1916 5.99 [4182 0.465 [5090 1.04 [5187 7.71 [823 0.446 [6279 2.67 [7363 4.07 [21 99] [21 100]] [21 100]] [21 100]] [21 76]] [21 100]] [21 100]] [21 87]] [114 0.682 [21 100] [21 75]]] [4925 2.82 [21 97] [21 100]]] [21 80]] [21 100]] [21 77]] [7737 1.18 [21 83] [10 100]]] [10 100]]] [535 0.538 [4626 3.27 [328 2.04 [373 2.28 [29 8.71 [6017 0.629 [569 7.66 [791 13 [688 2.79 [21 53] [9 57]] [906 16.9 [806 4.76 [5692 4.44 [7449 11.5 [5972 1.14 [21 97] [21 81]] [21 100]] [802 14.1 [21 83] [21 66]]] [21 84]] [6897 2.65 [21 100] [21 85]]]] [21 100]] [21 98]] [9 60]] [21 71]] [23 1.47 [21 93] [328 6.73 [9 85] [9 100]]]] [9 60]] [6251 3.12 [126 0.204 [1429 14.1 [21 100] [2178 0.161 [21 71] [21 100]]] [21 100]] [21 93]]]] [7139 13.4 [5246 7.46 [2280 0.823 [429 7.91 [5141 8.51 [221 28.1 [3464 2.27 [5175 1.18 [6068 10.5 [234 2.96 [5267 10.1 [4988 4.7 [5753 8.77 [5084 14.8 [5776 1.24 [5196 0.596 [1388 1.74 [1812 3.14 [6294 10.2 [6845 2.92 [6176 0.787 [4235 18.7 [7085 4.52 [1899 1.18 [33 95] [33 100]] [33 91]] [33 72]] [33 87]] [33 87]] [33 83]] [4704 6.85 [33 100] [33 97]]] [33 93]] [33 100]] [33 88]] [33 72]] [33 100]] [5170 11.2 [33 63] [33 100]]] [33 81]] [33 83]] [33 72]] [33 62]] [33 90]] [5170 1.18 [33 64] [33 100]]] [33 66]] [33 33]] [33 50]] [33 84]] [33 76]]] [5597 1.31 [5472 0.216 [4189 0.211 [3905 0.758 [2574 0.133 [673 3.31 [5769 0.631 [5962 2.7 [5034 1.92 [5405 1.05 [7737 1.52 [3659 0.491 [232 0.496 [1390 1.12 [5753 0.854 [978 0.705 [3019 2.2 [144 21.2 [2398 0.711 [6100 0.169 [5349 1.62 [5734 1.29 [4851 1.79 [221 12.6 [4349 3.1 [4655 0.494 [5705 1.93 [3020 0.813 [6178 1.08 [3313 1.38 [7382 2.17 [5777 3.48 [6422 2.47 [2701 1.64 [384 1.91 [3100 0.659 [326 1.47 [7255 17.5 [7755 0.792 [7340 0.853 [7721 1.72 [6855 1.57 [896 5.17 [5260 3.03 [6167 0.982 [6578 2.8 [7038 7.24 [6287 4.77 [4266 0.416 [6871 3.25 [4877 0.711 [248 4.52 [4235 33.7 [4868 0.599 [42 0.907 [4799 7.58 [328 27.6 [6031 4.28 [2752 4.08 [5093 3.65 [5976 0.595 [7615 1.09 [7563 8.64 [168 1.5 [1783 1.08 [2453 4.76 [2616 2.29 [560 3.45 [2007 1.38 [5872 4.59 [2509 1.44 [731 1.95 [772 10.8 [5623 3.5 [1078 13.2 [7009 6.96 [5171 22.1 [2143 22.6 [5403 3.18 [3727 10.2 [1888 11.6 [5409 4.35 [6940 18.5 [3357 10.6 [1239 27.2 [1429 57.6 [4663 22 [2009 9.78 [14 10] [26 100]] [3 69]] [14 23]] [6 39]] [31 78]] [6 77]] [6 100]] [14 16]] [31 100]] [31 94]] [3 50]] [33 90]] [695 1.98 [13 78] [4 33]]] [5205 2.39 [811 4.35 [2149 15.2 [5671 7.52 [4680 14.1 [7276 1.27 [2488 6.73 [2969 1.86 [1220 29.4 [5673 2.81 [6997 4.76 [1059 6.67 [5346 5.88 [31 12] [18 70]] [6 53]] [31 100]] [13 20]] [31 95]] [2939 5.89 [31 44] [31 100]]] [13 93]] [31 100]] [3 50]] [31 100]] [27 40]] [31 88]] [13 100]]] [6 100]] [24 100]] [6732 38.1 [17 19] [17 46]]] [13 96]] [14 100]] [3008 4.74 [10 91] [10 100]]] [18 64]] [6735 6.33 [2450 3.18 [7265 4.07 [4 5.85 [4889 1.22 [2178 5.05 [688 3.44 [2388 6.17 [5673 3.34 [1078 15.9 [3101 7.46 [6740 5.88 [4414 53.2 [7032 12.8 [4725 2.56 [6 50] [6 76]] [2 50]] [25 33]] [17 33]] [24 100]] [6 60]] [17 50]] [6 100]] [4 57]] [6 45]] [2275 2.43 [6 91] [6 100]]] [6 96]] [2 81]] [6 100]] [2 62]]] [24 96]] [6383 6.5 [1899 12 [4820 1.64 [7672 4.04 [4904 4.69 [6653 2.18 [5838 0.27 [4566 7.35 [4573 0.531 [99 6.26 [2081 6.52 [377 11.4 [5891 7.57 [663 4.2 [2436 7.94 [2039 1.53 [2058 0.918 [4704 2.46 [2274 1.36 [4939 0.902 [5322 4.25 [33 16] [16 50]] [38 44]] [26 85]] [33 63]] [13 42]] [13 40]] [6 75]] [6 41]] [32 66]] [14 50]] [10 27]] [18 34]] [19 55]] [30 66]] [14 90]] [3 70]] [32 50]] [26 81]] [6 90]] [1899 19.6 [33 50] [6 23]]] [14 57]]] [1429 49.1 [1932 3.44 [173 3.03 [174 11.8 [1783 42.9 [1783 15.3 [19 56] [19 42]] [13 28]] [19 75]] [26 33]] [19 57]] [19 32]]] [5 57]] [3 93]] [3 100]] [6 80]] [5403 1.51 [1919 6.03 [1164 0.237 [7251 1.15 [6732 4.76 [6350 0.531 [7354 3.22 [7512 5.88 [6266 1.77 [2818 1.27 [7332 3.88 [6791 7.57 [5410 23.9 [4754 1.75 [939 2.96 [6853 3.53 [4288 17 [17 8] [4 42]] [36 53]] [29 32]] [14 33]] [33 33]] [28 41]] [19 85]] [12 100]] [24 75]] [558 1.13 [2990 1.84 [4569 4.13 [2832 3.07 [2752 54.7 [3092 3.11 [1330 1.99 [4154 14 [7525 3.23 [2846 18.7 [3207 2.7 [663 22.7 [4200 10.9 [7381 1.56 [7028 3.18 [7522 6.52 [4883 2.11 [5160 5.55 [2434 6.31 [2902 5.31 [6260 9.35 [14 10] [13 75]] [36 54]] [36 72]] [14 73]] [14 100]] [23 47]] [13 85]] [3008 5.62 [5 26] [7 42]]] [14 70]] [16 22]] [36 37]] [14 39]] [30 100]] [6581 9.01 [23 22] [5 63]]] [32 100]] [12 100]] [22 27]] [36 100]] [13 100]] [12 100]] [12 100]]] [738 1.72 [2005 10 [1899 3.01 [1888 30.6 [36 27] [18 29]] [5413 1.85 [5972 1.74 [36 47] [36 100]] [16 37]]] [7 37]] [4860 1.92 [18 65] [18 100]]]] [10 100]] [2526 8.28 [5110 9.53 [4414 13 [5693 2.76 [12 45] [5 37]] [18 70]] [12 100]] [6550 9.56 [2616 35.4 [1025 2.59 [18 20] [24 60]] [5 65]] [7346 16.7 [5 81] [5 90]]]]] [2436 1.19 [899 2.39 [36 48] [36 100]] [36 100]]] [6156 0.237 [2752 14.8 [13 85] [10 63]] [10 100]]] [6548 2.18 [4154 13.2 [5819 7.87 [2 20] [17 29]] [7561 4.22 [5654 4.05 [4332 4.59 [2526 48.4 [2 50] [2 88]] [18 46]] [2 29]] [4 33]]] [17 73]]] [312 1.51 [31 97] [31 100]]]] [22 75]] [377 6.94 [1453 5.82 [3008 21.7 [2259 57 [6382 4.99 [99 3.91 [5568 0.846 [2752 40.4 [14 22] [14 50]] [14 58]] [14 76]] [14 95]] [19 20]] [10 37]] [14 88]] [14 61]]] [429 13.8 [36 43] [6094 2.37 [32 63] [32 100]]]] [3 34]] [3 100]] [5322 6.49 [20 65] [21 37]]] [5154 3.63 [6524 3.86 [7187 11.9 [788 7.87 [6031 10.9 [1587 0.752 [7720 2.89 [3008 30.1 [3835 4.93 [5360 1.53 [2929 3.82 [6184 7.64 [250 15.3 [267 4.59 [695 6.83 [429 7.12 [731 1.53 [2029 0.398 [1436 3.99 [33 28] [33 50]] [16 40]] [26 37]] [7665 27.8 [2755 1.64 [26 14] [26 61]] [25 54]]] [33 42]] [18 100]] [33 56]] [33 60]] [25 81]] [33 93]] [6471 2.46 [26 50] [26 100]]] [25 93]] [3 33]] [26 18]] [33 100]] [18 83]] [26 100]] [2969 2.28 [25 45] [25 91]]] [33 62]]] [14 100]] [12 91]] [20 100]] [6 77]] [6 59]] [791 1.39 [31 98] [31 100]]] [6 94]] [5039 1 [2259 24.3 [2488 1.44 [13 56] [13 100]] [13 37]] [13 100]]] [4200 8.99 [5480 2.3 [6337 7.75 [1429 12 [5815 7.08 [6069 4.07 [1783 20.3 [772 2.89 [19 2.73 [3667 1.68 [4235 1.96 [5429 3.88 [7742 0.879 [4602 2.6 [2739 13.8 [7568 5.13 [6866 15.2 [2259 3.14 [5654 6.85 [4929 5.75 [5198 7.68 [4664 7.07 [6406 4.76 [663 34.5 [6588 3.94 [6732 2.65 [4288 7.77 [7185 13.4 [5693 29.4 [7032 4 [4 15] [2 75]] [896 54.9 [791 49.2 [7520 16.1 [25 12] [24 30]] [17 46]] [2902 28.6 [2 27] [1 60]]]] [4 40]] [4 45]] [429 56.1 [4 30] [19 50]]] [5 56]] [7 55]] [2 50]] [2 68]] [1078 2.99 [26 25] [5 22]]] [4 80]] [2 100]] [5198 0.952 [5972 8.97 [24 20] [31 72]] [4 15]]] [5 88]] [2 43]] [4 90]] [26 100]] [2616 2.73 [4 77] [4 50]]] [25 100]] [2259 4.76 [178 3.94 [2 79] [25 100]] [25 50]]] [2 90]] [2 82]] [24 94]] [5692 8.36 [19 22] [25 84]]] [2 85]] [2 94]] [2591 8.81 [7254 5.49 [2616 4.67 [5871 12.1 [6261 4.86 [6576 2.33 [6977 5.3 [4896 1.39 [5564 3.07 [328 34.2 [429 16.3 [17 7.82 [7 18] [4 25]] [7566 11.9 [7214 5.26 [5647 4.42 [5 23] [2570 8.5 [18 50] [13 30]]] [7 50]] [7 39]]] [14 90]] [14 100]] [14 50]] [5 58]] [5 100]] [36 90]] [14 73]] [4799 21.3 [7598 3.65 [5 41] [17 55]] [7 69]]] [25 50]] [17 87]]] [24 66]] [2911 1.62 [957 11.4 [1073 6.68 [6581 3.7 [2259 51.9 [5267 1.42 [6826 3.14 [5480 23.6 [7520 12.7 [7665 32.2 [5482 17.9 [2813 8.93 [1980 6.29 [5480 14.3 [18 57] [18 67]] [5480 7.55 [1 55] [18 50]]] [18 50]] [29 54]] [18 35]] [18 41]] [18 78]] [18 100]] [18 70]] [6 33]] [26 100]] [19 58]] [5130 9.9 [18 86] [18 77]]] [18 100]]] [2023 0.963 [2199 1.9 [26 48] [26 86]] [26 89]]]] [2698 2.46 [31 82] [31 100]]] [3 100]] [660 16.5 [5403 3.7 [5632 4.42 [7693 1.12 [5345 3.01 [1899 0.952 [503 1.53 [125 13.2 [132 8.71 [1429 7.56 [1769 4.95 [429 15.6 [32 65] [896 16.7 [32 50] [2 28]]] [32 100]] [32 85]] [18 50]] [32 70]] [32 100]] [5812 1.25 [32 69] [2 44]]] [18 36]] [18 40]] [18 42]] [31 70]] [2 54]]] [5931 0.0985 [4533 2.99 [4277 0.96 [6895 1.77 [20 76] [20 100]] [20 92]] [20 71]] [20 100]]] [2939 4.13 [177 4.67 [899 24 [7023 6.49 [7615 5.15 [13 64] [3 100]] [13 100]] [13 50]] [19 77]] [12 45]]] [31 100]] [2251 1.25 [3627 2.67 [7683 1.68 [1 90] [1 100]] [1 100]] [1 100]]] [132 1.34 [719 21.9 [688 3.07 [7723 0.754 [6585 2.2 [6920 2.96 [738 8.34 [6199 7.94 [2813 3.45 [1023 1.98 [663 1.09 [18 29] [18 68]] [14 25]] [18 77]] [18 71]] [18 76]] [6 87]] [26 88]] [276 3.7 [18 73] [5130 1.25 [18 87] [18 100]]]] [7 66]] [6732 6.17 [18 45] [26 85]]] [18 75]]] [6732 0.241 [145 1.18 [4768 3.37 [1648 3.27 [5154 1.67 [429 38.1 [4611 0.885 [6342 4.02 [434 1.02 [32 31] [32 50]] [15 55]] [29 83]] [7449 3.27 [2764 0.756 [29 49] [29 100]] [906 7.77 [2259 2.33 [29 92] [29 87]] [29 83]]]] [15 50]] [32 100]] [29 81]] [2705 0.588 [29 73] [29 100]]] [883 0.688 [4159 1.11 [29 75] [29 100]] [29 100]]]] [6 84]] [7623 13.6 [2951 1.99 [26 62] [26 87]] [26 81]]] [2517 3.07 [6076 3.03 [1429 2.59 [1240 1.22 [2 52] [24 96]] [4154 19.4 [24 96] [24 75]]] [2 68]] [24 100]]] [662 1.07 [7169 3.88 [5198 3.92 [5 87] [5 60]] [5 80]] [5 88]]] [4663 17.7 [25 100] [25 71]]] [4517 0.813 [6 95] [6 100]]] [4611 2.79 [36 88] [36 100]]] [2745 0.982 [5692 13 [23 1.85 [1742 30.3 [2232 2.96 [1 95] [1 100]] [1 71]] [1 80]] [1 70]] [1 97]]] [5819 7.64 [24 64] [7449 5.88 [4 41] [4 33]]]] [899 0.647 [5701 1.47 [2436 0.861 [791 1.43 [7169 2.39 [6936 14.9 [4279 0.726 [6524 21.3 [6 65] [25 58]] [26 41]] [25 90]] [25 38]] [6 19]] [6 100]] [33 100]] [2705 0.406 [25 28] [29 100]]]] [384 3.42 [5316 2.25 [2627 23 [2648 0.978 [6074 21.8 [6550 11.7 [6851 5.11 [7132 5.47 [7009 0.904 [7588 4.21 [7742 1.83 [2541 1.73 [2339 3.14 [6205 3.23 [163 1.89 [968 3.41 [5564 1.12 [1565 3.27 [5514 3.55 [6581 3.98 [6382 1.42 [7400 2.76 [6046 6 [2707 11.6 [1899 4.96 [6310 0.199 [896 13.6 [14 25] [2616 7.04 [32 36] [7 66]]] [32 41]] [4154 8.46 [36 56] [429 9.69 [19 42] [32 57]]]] [16 53]] [26 84]] [36 100]] [14 83]] [1017 1.06 [144 11.7 [2573 4.44 [2950 4.67 [17 35] [5 100]] [17 37]] [38 62]] [5 100]]] [7665 41.5 [5 77] [5 45]]] [14 100]] [14 100]] [28 100]] [17 57]] [6199 14 [26 85] [14 50]]] [36 100]] [17 75]] [4 93]] [5110 11.1 [6549 4.2 [7512 34.3 [4154 9.9 [5 38] [5 40]] [7590 9.53 [5 64] [5 42]]] [17 81]] [26 50]]] [6589 9.2 [3576 2.96 [23 26.8 [1017 9.4 [5 68] [5 33]] [26 50]] [5 100]] [5 52]]] [4 100]] [5309 2.67 [7 85] [16 66]]] [3554 14.9 [17 32] [32 42]]] [14 84]] [4 100]] [5 82]] [4061 6.67 [7340 1.74 [3027 41.7 [6576 5.63 [5851 1.6 [248 2.65 [6591 6.75 [7 26] [17 75]] [7588 2.86 [26 75] [26 100]]] [17 50]] [17 57]] [32 66]] [32 100]] [26 63]]] [26 72]]] [2259 9.46 [7 83] [4851 2.04 [328 36.7 [7 100] [7 76]] [7 100]]]] [23 5.41 [4513 11 [7682 0.722 [6 88] [6 100]] [6 75]] [6 72]]] [2566 6.99 [221 14 [1980 0.924 [4653 2.18 [6289 8.3 [2527 14.5 [5099 0.808 [429 7.25 [2259 91.1 [6 91] [6 58]] [6 100]] [6 100]] [6 66]] [6 100]] [6 52]] [7560 0.0846 [6 78] [6 100]]] [7574 2.11 [7545 0.985 [6 97] [6 100]] [6 100]]] [6 76]]] [12 77]] [2846 5.89 [5931 12.6 [99 5.16 [17 2.16 [1451 4.03 [132 6.12 [6581 22.3 [7693 5.84 [163 13.9 [176 0.678 [1025 2.76 [112 0.65 [1936 7.93 [2445 19.1 [6937 12.9 [6920 3.05 [19 38] [5 33]] [22 57]] [19 55]] [19 66]] [32 23]] [24 50]] [5637 0.678 [19 64] [19 76]]] [13 57]] [36 37]] [14 36]] [18 62]] [13 44]] [13 92]] [23 81.6 [13 18] [3675 3.4 [5007 2.22 [172 12.4 [2127 0.592 [144 22.9 [17 36] [5673 2.73 [19 61] [19 81]]] [19 71]] [19 88]] [19 91]] [19 92]]]] [32 66]] [6373 4.59 [99 21.7 [22 44] [14 25]] [22 100]]]] [3658 2.73 [429 32.3 [227 5.62 [24 85] [24 100]] [14 33]] [24 100]]] [685 0.694 [2436 0.624 [6529 7.39 [6187 1.96 [3057 0.273 [6524 1.59 [7413 1.36 [2275 0.241 [6557 0.965 [6089 0.568 [1083 1.94 [7529 1.46 [321 1.51 [4718 3.37 [3732 1.25 [6042 0.369 [5403 3.27 [7405 2.74 [682 1.43 [7723 0.766 [5480 0.476 [1180 2.54 [3008 1.81 [7601 2.94 [6581 1.75 [6538 2.83 [1190 1.09 [2526 11.8 [1632 0.733 [2628 19.1 [3972 6.08 [3652 2.65 [2081 11.9 [6747 5.51 [828 4.61 [7381 3.11 [7590 6.91 [4533 1.01 [4205 0.754 [567 9.1 [434 15.9 [7244 1.89 [1011 1.58 [5368 0.98 [791 26.1 [899 0.96 [1769 17.2 [5673 6.42 [1391 3.45 [144 14.8 [7512 1.58 [23 30] [5 10]] [38 37]] [22 37]] [16 33]] [2 60]] [18 25]] [13 72]] [10 60]] [7253 4.85 [4158 7.04 [2752 10.7 [17 20] [17 23]] [2 40]] [17 47]]] [38 33]] [2 73]] [17 88]] [26 55]] [791 3.35 [20 33] [31 20]]] [1078 28.9 [5 37] [2 57]]] [1011 22.3 [7384 2.54 [1128 1.61 [6310 3.88 [2 25] [5 100]] [5 88]] [7 62]] [17 28]]] [31 48]] [6 100]] [978 11.9 [23 71] [2 38]]] [772 9.92 [773 7.98 [24 100] [24 80]] [24 66]]] [5 100]] [3936 5.88 [4 46] [4 71]]] [19 100]] [3667 1.92 [5971 2.79 [7568 1.7 [7365 0.79 [2453 1.67 [1026 7.68 [4160 1.93 [1546 2.85 [4673 7.38 [6184 1.14 [1993 15.4 [6920 11.7 [2488 3.63 [7343 2.53 [6514 7.57 [2913 4.42 [1587 1.83 [731 8.02 [731 6.3 [4959 5.8 [5007 9.1 [688 2.94 [1073 12.6 [1429 10.6 [2763 1.82 [719 1.62 [1089 4.95 [2 24] [2 88]] [0 37]] [2 51]] [1025 14.6 [2763 10.6 [5969 2.92 [573 9.09 [4 25] [4 33]] [17 42]] [5 50]] [24 44]]] [4 37]] [2 56]] [7 37]] [4 100]] [2 50]] [896 8.48 [4 27] [1899 8.18 [7 46] [2 42]]]] [5 58]] [7 36]] [5 55]] [7 56]] [13 53]] [17 58]] [4 33]] [4 56]] [6 87]] [5 100]] [2 63]] [12 58]] [24 93]] [4 100]] [7566 1.33 [2 56] [2 58]]] [18 52]] [2 64]]] [2 53]] [7381 2.33 [2 85] [2 93]]] [7192 7.32 [6582 1.12 [5732 0.431 [6548 1.42 [6883 3.84 [5316 0.27 [4851 5.05 [4154 27.3 [610 1.51 [1557 2.37 [5 42] [17 100]] [5 85]] [19 93]] [5 61]] [17 80]] [6584 10.8 [5514 11.8 [5 95] [5 66]] [7563 12.8 [12 37] [5 57]]]] [1011 12.2 [17 100] [17 70]]] [17 72]] [4 100]] [17 93]]] [6584 1.77 [1899 6.99 [5 51] [7 33]] [5 54]]] [7409 3.92 [7534 0.501 [7722 6.99 [25 34] [17 39]] [17 63]] [6 100]]] [13 100]] [7700 3.63 [2466 0.403 [5130 0.498 [429 46.9 [896 7.21 [5413 6.1 [328 13.7 [2752 14.8 [5192 1.29 [2628 2.88 [18 30] [4 42]] [18 60]] [2813 1.04 [18 53] [18 80]]] [26 84]] [18 78]] [18 45]] [660 3.39 [5480 9.62 [22 33] [18 43]] [29 60]]] [5692 5.68 [978 7.06 [16 62] [896 1.88 [18 66] [6658 1.39 [18 80] [18 100]]]] [16 46]]] [19 51]] [18 84]]] [4573 0.548 [279 1.57 [1186 4.27 [7512 23.5 [18 73] [2752 7.45 [18 100] [18 80]]] [18 46]] [18 44]] [5 42]]] [2 41]] [6 87]] [31 95]] [5969 0.369 [4805 4.35 [736 2.71 [18 59] [7 37]] [5 27]] [1078 7.21 [695 1.42 [18 66] [18 55]] [18 100]]]] [5729 3.17 [6581 0.37 [19 46] [6804 1.02 [429 33.3 [1690 3.84 [4851 1.09 [17 100] [17 66]] [17 75]] [5692 8.54 [19 37] [17 88]]] [2760 2.96 [4535 3 [38 81] [17 50]] [5389 6.72 [17 60] [38 45]]]]] [2526 13.8 [17 100] [17 90]]]] [5 48]] [31 100]] [24 87]] [6735 1.83 [435 0.451 [5692 11.6 [2 46] [4 60]] [4 78]] [2 80]]] [985 1.96 [5647 19.2 [2 100] [2 95]] [2 87]]] [458 1.29 [5 79] [17 72]]] [4726 1.96 [6168 0.724 [5412 2.04 [4040 2.13 [6 57] [24 100]] [24 44]] [6 100]] [6 71]]] [21 1.66 [7248 1.5 [649 11.9 [4991 1.77 [3008 2.65 [6184 1.01 [1078 32.6 [6068 4.75 [7009 8.18 [929 1.46 [3928 2.13 [2610 7.13 [5110 1.05 [5693 3.48 [7169 4.42 [1062 1.72 [1899 2.33 [2616 10.1 [2 28] [17 28]] [4 71]] [4 70]] [2 40]] [1025 4.11 [18 26] [2 40]]] [2 62]] [896 14.9 [2 50] [2 68]]] [5 66]] [2 60]] [4 92]] [22 42]] [2610 2.83 [1993 1.2 [896 4.98 [7414 5.63 [4 50] [2 55]] [2 90]] [2 100]] [4 60]]] [6196 0.671 [2 76] [2 88]]] [25 57]] [2 79]] [5 66]] [38 35]] [5 45]]] [665 2.28 [5080 0.682 [719 2.14 [3929 3.19 [7512 34.5 [178 2.5 [1 34] [25 100]] [1 83]] [17 100]] [663 8.3 [7 30] [7 75]]] [25 100]] [1 50]]] [3057 14.3 [5 86] [5 61]]] [6538 1.72 [312 0.699 [5692 12.5 [2763 6.55 [2 70] [1 54]] [2 50]] [2 60]] [6735 5.73 [2023 0.634 [5851 4.86 [2628 7.06 [5396 3.1 [2 82] [2 71]] [2 63]] [2 100]] [2 100]] [2 62]]]] [896 24.9 [7 84] [7 69]]] [4673 1.4 [6 62] [1364 0.99 [4725 0.624 [6 96] [6 100]] [6 100]]]] [7723 0.0791 [719 7.3 [7187 1.55 [4791 1.86 [7139 6.02 [4645 0.505 [5641 1.55 [338 4.79 [5729 1.92 [7699 7.39 [1065 0.894 [1064 0.855 [2809 2.15 [7526 1.3 [5484 1.8 [7665 3.85 [6 20] [5732 9.08 [5485 1.85 [431 2.39 [18 38] [26 68]] [18 100]] [7 90]]] [18 100]] [7 88]] [18 73]] [18 92]] [18 100]] [16 80]] [7 100]] [26 100]] [1587 1.11 [18 42] [18 83]]] [18 75]] [23 37]] [16 78]] [26 94]] [688 1.41 [1239 7.84 [429 11.9 [26 51] [18 54]] [5484 2.16 [7 84] [18 66]]] [7 100]]] [7259 0.8 [5267 11.9 [1009 2.34 [964 2.91 [5637 0.722 [685 11.1 [7566 1.74 [18 100] [719 2.94 [18 80] [18 66]]] [18 69]] [18 92]] [16 40]] [18 53]] [18 50]] [1023 3.17 [19 53] [18 85]]]]]] [5757 0.728 [7583 1.95 [5467 2.13 [1409 1.12 [1535 0.469 [5171 0.441 [5744 0.943 [1617 1.32 [221 0.179 [6768 1.53 [5264 1.53 [429 30.5 [6173 1.02 [7683 1.11 [7311 1.4 [3652 1.79 [285 3.36 [6546 3.82 [5130 0.22 [4270 1.36 [7021 2.37 [5110 3.4 [1463 0.935 [6581 4.01 [5972 3.77 [2752 5.11 [1089 0.693 [2913 0.763 [978 0.134 [7755 5.88 [4218 0.131 [774 2.6 [1883 7.69 [7405 1.69 [7566 3.88 [4655 2.54 [392 0.293 [5429 6.17 [4279 3.53 [99 9.9 [5647 7.67 [5056 1.28 [36 14] [17 40]] [7512 17.7 [29 50] [31 44]]] [13 60]] [5753 4.72 [3 57] [29 34]]] [5 28]] [4154 0.446 [328 25.1 [7 25] [8 20]] [17 42]]] [1 66]] [29 37]] [6 60]] [2 50]] [24 90]] [13 72]] [20 87]] [17 23]] [32 46]] [6 53]] [6178 2.49 [6977 6.69 [7665 9.84 [968 0.612 [392 15.7 [5668 2.65 [1769 1.07 [7149 0.353 [145 0.528 [7512 3.04 [29 24] [2813 1.47 [5480 0.479 [2616 0.589 [38 15] [5412 2.78 [2 50] [24 50]]] [18 45]] [18 100]]] [32 43]] [18 36]] [18 54]] [29 53]] [28 81]] [28 63]] [383 2.59 [4154 22.7 [7566 3.5 [2143 14.7 [5430 1.37 [3667 1.35 [2939 18.4 [392 2.51 [6853 8.49 [2199 10.2 [1888 8.65 [31 2.17 [36 17] [18 66]] [791 4.73 [7 34] [4 37]]] [2 57]] [36 80]] [18 41]] [10 36]] [2 50]] [5 69]] [36 55]] [23 3.81 [2752 13.4 [5 60] [36 76]] [5 54]]] [24 62]] [14 45]]] [14 84]] [25 100]]] [1011 1.66 [7535 2.62 [1253 1.98 [36 65] [12 85]] [36 100]] [31 62]]] [5 50]] [5 85]] [4071 3.92 [1429 20.7 [6871 2.89 [719 2.96 [5412 8.41 [15 26] [33 56]] [33 90]] [12 88]] [5110 20.7 [1239 12.7 [7176 1.56 [2526 2.56 [12 82] [5412 3.71 [5 25] [12 70]]] [12 100]] [33 57]] [12 96]]] [12 100]]] [5 100]] [36 100]] [407 0.3 [392 1.13 [18 39] [16 35]] [18 90]]] [31 100]] [33 82]] [24 91]] [20 100]] [1 100]] [5879 2.99 [31 97] [31 100]]] [554 0.768 [4214 0.617 [2813 0.813 [1883 2.36 [1995 0.854 [567 2.26 [6260 1.99 [3872 2.7 [6927 1.47 [4312 2.95 [7665 10.9 [5994 1.27 [2763 1.19 [5 23] [17 37]] [29 100]] [906 5.88 [1023 1.47 [1078 14.9 [6311 1.6 [939 3.55 [2903 2.51 [7512 32 [5 52] [5 34]] [5 50]] [5 44]] [5 83]] [36 30]] [6732 1.47 [7 19] [18 55]]] [5 64]]] [36 50]] [2 100]] [32 92]] [36 80]] [29 79]] [29 61]] [7169 2.16 [2 44] [2 64]]] [18 81]] [29 88]] [3 80]]] [13 100]] [31 100]] [663 1.56 [2559 1.11 [2259 28.1 [2526 3.29 [2262 0.979 [5668 1.43 [5693 1.25 [328 9.41 [33 30] [7428 0.332 [25 42] [28 40]]] [7667 0.359 [29 50] [29 100]]] [29 92]] [26 75]] [25 35]] [5756 1.11 [6 51] [6 100]]] [33 100]] [4184 0.975 [7169 5 [4768 0.494 [29 39] [29 94]] [25 50]] [29 89]]]] [10 100]] [1078 4.62 [4369 6.72 [14 33] [32 100]] [32 91]]] [4841 0.264 [33 100] [33 85]]] [5 87]] [36 100]] [1899 0.885 [12 74] [12 89]]] [1181 1.35 [2081 1.55 [1888 3.89 [6853 3.86 [5267 3.14 [184 0.695 [2939 1.33 [2526 6.71 [36 29] [1 50]] [5693 2.51 [2526 4.33 [1 90] [1 71]] [1 100]]] [25 100]] [36 100]] [36 100]] [36 76]] [7512 11.5 [1 37] [1 83]]] [36 100]]] [4312 0.468 [5757 19.2 [29 90] [29 39]] [6732 1.98 [7512 18.9 [29 100] [29 87]] [29 83]]]]] [3026 9.51 [4332 2.25 [5783 1.15 [7529 10.8 [1389 44.8 [24 100] [24 85]] [7382 18.7 [24 66] [24 100]]] [24 100]] [24 100]] [24 88]]] [7665 10.2 [2969 0.295 [6182 2.58 [5491 3.73 [1239 6.25 [5753 2.51 [2081 0.312 [25 81] [1 33]] [33 83]] [7207 0.637 [1722 1.64 [5302 1.53 [328 4.73 [7329 1.29 [2624 4.82 [1757 1.23 [33 92] [33 100]] [33 71]] [25 50]] [33 100]] [33 100]] [33 62]] [7176 0.637 [33 71] [33 60]]]] [13 44]] [25 100]] [25 100]] [5307 9.98 [5322 3.33 [232 4.74 [253 0.307 [4154 3.25 [25 80] [33 45]] [25 100]] [978 2.79 [3100 5.31 [7310 2.56 [5115 2.99 [5110 2.46 [5174 2.59 [33 64] [33 100]] [248 26.6 [33 96] [33 83]]] [33 100]] [25 100]] [1 90]] [25 96]]] [7583 4.71 [1 50] [1 100]]] [33 94]]]] [726 2.37 [2526 4.73 [663 3.82 [1888 16 [4895 4.83 [7379 1.18 [3661 24 [3026 12.1 [6859 1.18 [7381 1.12 [3663 1.55 [429 12.4 [2793 6.77 [24 75] [19 46]] [24 81]] [24 86]] [5692 1.78 [24 94] [24 100]]] [24 53]] [24 81]] [38 55]] [24 71]] [24 55]] [24 56]] [36 78]] [5814 7.95 [4583 1.06 [3662 4.3 [774 10.7 [5693 11.5 [2827 3.97 [4146 2.83 [1050 14 [5673 2.47 [5833 19.3 [6260 0.6 [7512 4.72 [36 62] [1389 9.62 [5753 1.41 [134 0.723 [1239 2.46 [24 94] [24 100]] [24 87]] [24 100]] [24 71]]] [23 0.6 [4214 2.77 [24 86] [24 100]] [24 100]]] [24 75]] [24 100]] [24 75]] [24 100]] [24 60]] [24 66]] [24 72]] [24 100]] [24 50]] [24 80]]] [36 44]]] [685 0.959 [3573 0.383 [100 4.92 [560 1.02 [2580 0.577 [2831 0.249 [83 1.88 [95 1.75 [5718 1.12 [6103 2.83 [328 121 [64 4.17 [774 0.516 [4504 0.821 [2490 3.13 [791 5.94 [4154 0.354 [957 7.15 [719 0.57 [2935 0.391 [7354 4.77 [1911 12.2 [7255 1.43 [1116 3.67 [2385 1.27 [5680 15.6 [2764 10.8 [1948 4.09 [404 3.76 [5673 4.15 [3878 0.846 [221 1.57 [1429 34.8 [1888 5.52 [2929 10.3 [1079 6.94 [4200 24.6 [2846 15.4 [19 28] [22 50]] [22 100]] [19 50]] [25 50]] [20 25]] [22 21]] [10 50]] [10 44]] [19 45]] [392 22.3 [28 66] [28 33]]] [19 75]] [22 63]] [22 80]] [18 100]] [3 50]] [77 1.26 [19 55] [19 62]]] [22 53]] [18 44]] [20 46]] [18 62]] [18 80]] [791 4.6 [4308 1.34 [1961 0.522 [7038 0.242 [2232 5.46 [1078 46.6 [23 81 [4279 17 [19 27] [22 56]] [19 59]] [10 31]] [13 28]] [18 50]] [19 87]] [19 59]] [19 90]]] [383 1.68 [5480 3.95 [248 15.6 [10 15] [25 100]] [5007 1.79 [5480 7.76 [18 93] [18 55]] [5692 1.59 [18 45] [19 50]]]] [18 83]]] [13 100]] [4840 2.49 [2385 6.76 [18 82] [1011 3.99 [18 43] [19 58]]] [19 65]]] [10 75]] [4154 2.56 [19 83] [19 94]]] [25 90]] [31 38]] [24 63]] [95 12 [19 84] [19 70]]] [203 2.24 [23 166 [2199 6.15 [4414 1.06 [1995 0.463 [168 42.3 [19 86] [19 64]] [2180 2.47 [19 91] [19 80]]] [19 42]] [18 71]] [14 33]] [18 50]]] [22 83]] [25 100]] [7734 6.18 [7731 1.31 [1911 1.5 [2570 2.88 [18 79] [18 100]] [18 62]] [18 90]] [5888 4.47 [2813 1.81 [5130 3.13 [791 7.66 [18 66] [18 92]] [663 3.54 [19 62] [16 50]]] [18 55]] [19 66]]]] [1453 0.615 [2628 3.57 [6310 11.2 [1899 4.26 [6342 0.405 [23 88 [1587 4.15 [3008 2.65 [19 42] [14 28]] [19 89]] [5776 4.11 [2091 9.93 [2846 2.04 [2257 1.38 [2196 2.05 [3675 20.2 [175 9.14 [2225 4.06 [7009 18.7 [176 23.4 [64 6.43 [2259 72.4 [171 3.12 [2149 1.15 [2192 1.27 [19 87] [19 100]] [19 66]] [19 80]] [18 50]] [4308 2.44 [19 53] [19 100]]] [78 1.85 [19 66] [19 86]]] [19 57]] [19 63]] [19 69]] [19 33]] [19 50]] [19 100]] [19 25]] [18 40]] [19 42]]] [19 92]] [4308 2.83 [100 18.4 [169 37.6 [19 40] [23 134 [19 71] [19 100]]] [14 45]] [19 57]]] [18 54]] [4 22]] [18 37]]] [10 100]] [5480 2.58 [1429 33.8 [6 27] [19 61]] [7251 2.19 [7546 1.16 [6658 1.8 [7517 3.31 [4574 3.34 [5509 1.96 [1068 0.428 [5007 1.89 [394 1.37 [549 0.778 [2752 10.7 [2385 0.87 [18 72] [392 7.34 [18 85] [18 100]]] [2526 2.06 [18 33] [1899 1 [18 100] [18 63]]]] [18 100]] [19 33]] [7255 4.15 [7566 3.38 [6155 0.507 [18 38] [18 100]] [19 53]] [18 62]]] [18 100]] [392 10.2 [7512 6.7 [18 66] [18 86]] [18 100]]] [19 66]] [19 57]] [277 3.51 [19 29] [19 58]]] [4926 4.76 [18 75] [18 93]]] [19 66]]]]] [1101 6.85 [2758 2.92 [4929 1.95 [31 100] [31 77]] [31 100]] [2081 13.6 [31 100] [2081 18.2 [31 71] [31 100]]]]] [1611 1.89 [4219 0.592 [537 1.09 [914 0.62 [5307 1.55 [1663 3.23 [4395 1.4 [2913 0.68 [4011 0.364 [6549 20.2 [429 27.1 [4939 0.938 [4171 2.44 [6809 1.25 [2738 3.03 [3358 5.88 [3485 1.38 [1931 1.01 [6487 4.44 [7722 0.0817 [404 0.99 [6045 6.08 [3559 3.55 [4991 1.73 [4218 1.68 [7520 11.3 [4309 3.7 [7721 3.6 [1995 1.15 [2225 5.12 [7579 1.87 [4418 4.35 [791 33.7 [7512 16.7 [2902 2.37 [14 68] [14 100]] [5386 3.88 [7409 8.77 [4451 4.76 [14 62] [32 100]] [14 100]] [14 83]]] [32 66]] [14 100]] [32 100]] [14 83]] [28 38]] [3 100]] [32 100]] [32 57]] [695 3.11 [14 92] [14 100]]] [4279 0.477 [14 40] [3 44]]] [32 100]] [14 81]] [28 96]] [791 28.9 [4799 6.42 [3515 1.31 [6333 4.76 [3928 16.1 [6696 10.2 [169 0.478 [2259 48.7 [791 18.6 [1783 0.881 [4680 1.68 [5034 50.9 [721 21.7 [328 1.22 [1429 14.1 [14 75] [14 88]] [14 100]] [14 57]] [14 37]] [14 100]] [14 97]] [14 76]] [14 37]] [14 50]] [14 63]] [14 50]] [32 100]] [14 100]] [32 66]] [32 57]]] [32 100]] [3 70]] [32 100]] [32 66]] [32 100]] [32 100]] [32 100]] [14 93]] [1096 2.18 [1685 1.05 [5034 21.4 [6544 10.4 [1062 1.23 [4322 1.31 [2260 3.39 [5034 5.85 [3 57] [1239 10.4 [7214 0.904 [791 28.6 [5753 9.09 [7428 9.31 [7501 2.3 [328 5.12 [7693 7.22 [4168 2.54 [6920 3.36 [896 11 [1078 19 [32 77] [32 65]] [14 60]] [14 55]] [32 100]] [14 60]] [14 100]] [32 100]] [32 77]] [32 71]] [7566 1.75 [899 12.8 [32 92] [899 17.2 [32 66] [32 84]]] [32 91]]] [32 70]] [3 40]]] [14 100]] [32 100]] [32 77]] [957 3.45 [14 62] [14 100]]] [14 54]] [28 100]] [14 90]]] [32 94]] [28 93]] [3483 0.971 [1 1.14 [4943 1.66 [5410 16.8 [1740 0.963 [5730 1.09 [4364 6.03 [6342 3.29 [1239 18.4 [1995 8.26 [7449 13.5 [4801 1.27 [1648 2.96 [3034 2.28 [7722 2.05 [899 1.24 [7233 5.75 [1769 3.18 [32 83] [32 100]] [32 100]] [32 100]] [32 100]] [7512 14.7 [32 80] [32 100]]] [32 83]] [32 100]] [32 100]] [3 50]] [32 60]] [32 87]] [32 75]] [32 99]] [32 100]] [32 50]] [32 80]] [32 100]] [32 100]]] [28 100]] [14 86]] [14 100]] [32 88]] [3 100]] [3 100]] [1676 6.43 [2570 1.99 [14 100] [14 85]] [14 80]]]] [6279 1.36 [957 0.541 [2841 1.49 [7413 0.978 [7566 0.83 [383 1.55 [5693 0.813 [5753 6.18 [695 1.25 [4731 2.01 [2616 1.36 [6749 16.7 [2125 0.904 [6 53] [6 100]] [32 35]] [5624 5.62 [6020 2.61 [4851 3.12 [7301 3.25 [2224 12.2 [2275 8.46 [1974 26.2 [5748 0.139 [5624 0.901 [2282 5.2 [4891 1.36 [7222 9.1 [6 94] [6515 2.37 [6 69] [6 100]]] [6 100]] [6 76]] [6 100]] [6 62]] [6 81]] [4514 4.17 [6933 3.81 [7224 5.07 [1239 6.98 [6 75] [6515 1.12 [6 94] [6 100]]] [6 66]] [6 70]] [6 45]]] [6 50]] [6 100]] [6 40]] [7040 3.44 [6 41] [6 100]]] [16 45]]] [7224 16.3 [7513 6.17 [2584 14.2 [1980 4.93 [4726 31.6 [1701 1.05 [7505 6.36 [2558 0.504 [7404 5.78 [5396 0.227 [7512 12.1 [4673 0.584 [6 92] [6 100]] [6 100]] [6 100]] [6 93]] [6 100]] [6 88]] [6 77]] [6 83]] [6 85]] [6 75]] [6 84]] [16 55]]] [4 37]] [6 29]] [2 18]] [18 60]] [2 44]] [2 80]] [20 50]] [6354 1.72 [7520 1.37 [5345 2.56 [1062 1.71 [5131 1.08 [18 60] [18 90]] [18 62]] [19 33]] [6 50]] [18 57]]] [7381 4.63 [2 37] [2 60]]]] [228 0.484 [6036 4.56 [2091 0.731 [4235 3.08 [7419 5.35 [6155 0.609 [285 11 [5770 2.12 [6481 3.6 [4517 5.49 [7259 2.25 [7168 1.91 [2298 0.609 [14 16] [17 60]] [3 30]] [14 71]] [6 66]] [30 87]] [22 37]] [4 66]] [10 54]] [6 100]] [3008 0.462 [6074 1.32 [20 28] [4 60]] [2 50]]] [10 85]] [26 65]] [48 1.15 [7745 2.71 [999 3.2 [6196 3.95 [4964 0.11 [2556 0.121 [6367 0.245 [144 0.245 [3667 1.69 [2675 0.754 [5576 2.47 [5192 0.318 [2752 15.8 [1640 25.5 [5267 0.956 [228 7.05 [4959 1.58 [2 35] [4 100]] [5812 22.4 [4960 2.67 [4 87] [4 100]] [4 77]]] [4 44]] [2 81]] [2 39]] [2 61]] [2 73]] [2 95]] [2 81]] [5576 0.593 [2 50] [7665 2.79 [2 50] [7451 0.464 [663 0.53 [999 0.834 [2846 3.16 [1025 19.6 [695 8.64 [6184 0.427 [2 95] [2763 0.427 [4418 3.03 [2 97] [2 100]] [2 100]]] [2 86]] [2 54]] [2 80]] [4 57]] [7032 14.3 [4253 0.894 [5851 0.688 [2628 7.61 [2 100] [2 86]] [2 100]] [1004 7.23 [7566 0.882 [286 0.593 [2 96] [2 100]] [2 100]] [2 95]]] [2 71]]] [2 71]]]]] [4 100]] [4 100]] [4 86]] [2 100]] [2 92]] [1980 2.37 [2961 3.7 [4 44] [4 100]] [2 45]]] [13 32]]]] [7330 0.125 [5246 1.05 [6791 3.61 [5170 0.319 [5999 6.41 [5920 2.34 [253 0.673 [2268 1.43 [7715 0.509 [4377 0.797 [7694 1.04 [6177 1.46 [828 2.42 [560 1.52 [4611 1.29 [1077 3.61 [7561 1.08 [2799 0.434 [7682 1.06 [6527 2.35 [1239 10.5 [1980 12.2 [2259 14.1 [4507 2.04 [4946 2.14 [249 1.63 [2936 1.67 [3327 6.85 [2178 3.04 [7298 3.7 [4205 1.95 [168 1.18 [719 8.41 [6155 1.98 [7583 0.611 [4927 2.22 [5659 2.16 [6551 5.63 [7185 0.275 [6251 3.51 [5353 1.42 [673 28.5 [26 60] [407 0.334 [6581 4.85 [26 83] [26 100]] [26 100]]] [26 100]] [25 36]] [7373 4 [26 76] [26 100]]] [26 100]] [25 42]] [18 100]] [25 50]] [18 88]] [26 92]] [26 57]] [736 6.27 [5595 5.62 [3008 0.435 [7373 1.01 [722 0.79 [5716 1.48 [5694 3.61 [255 0.99 [7566 0.405 [695 6.63 [26 88] [26 100]] [26 100]] [26 100]] [26 84]] [26 100]] [26 88]] [16 57]] [26 100]] [26 80]] [26 50]]] [18 75]] [7665 17.1 [25 38] [1 57]]] [25 100]] [25 90]] [1 100]] [18 82]] [18 87]] [1078 6.13 [26 42] [7742 0.482 [18 76] [18 80]]]] [1 42]] [685 1.32 [26 29] [26 50]]] [25 100]] [6 100]] [7512 17.1 [791 12.2 [2925 0.608 [5693 7.2 [1899 0.537 [2752 23.5 [26 100] [4205 5.41 [26 76] [26 100]]] [26 100]] [26 80]] [26 75]] [26 83]] [26 82]]] [7566 11.5 [5661 1.81 [7055 0.592 [3331 3.31 [1 59] [1 100]] [1 100]] [1 100]] [25 57]]] [1 83]] [431 2.4 [4351 4.53 [7352 3.58 [6449 2.13 [4851 0.524 [7413 1.73 [134 7.64 [2759 0.695 [221 1.42 [328 7.61 [4613 0.602 [26 81] [2947 0.355 [731 14.4 [5647 17.5 [6199 12.4 [1911 1.62 [1783 5.22 [26 99] [26 90]] [26 100]] [26 85]] [26 85]] [26 87]] [26 100]]] [1400 29.3 [26 100] [26 62]]] [12 44]] [26 100]] [26 71]] [26 66]] [26 100]] [26 85]] [26 71]] [26 66]] [731 0.479 [26 100] [26 54]]]] [719 11.1 [5596 0.244 [4927 0.766 [560 5.58 [18 80] [18 96]] [18 100]] [18 100]] [18 77]]] [31 100]] [5647 0.88 [6907 2.54 [6732 5.71 [5695 1.31 [5429 6.51 [1429 2.71 [1899 10.2 [25 100] [25 91]] [25 100]] [25 94]] [25 100]] [25 90]] [25 100]] [25 86]]] [25 100]] [25 100]] [25 100]] [2526 3.73 [978 5.39 [6733 2.25 [18 90] [18 57]] [5482 3.7 [26 55] [18 100]]] [248 15.8 [18 83] [18 76]]]] [7668 1.06 [25 92] [25 100]]] [25 91]] [673 16.3 [6184 6.2 [2530 1.39 [25 75] [25 100]] [25 100]] [25 58]]] [6955 14.9 [2178 8.12 [6131 9.9 [4601 7.33 [312 5.94 [7623 3.92 [5079 4.15 [5693 0.306 [6724 7.78 [1400 48 [5904 3.84 [5176 8 [5007 13.6 [4398 4.83 [812 0.393 [7251 1.54 [5873 0.998 [6406 16.9 [4611 24.2 [7413 4.17 [1011 0.561 [2913 1.12 [5692 5.15 [6733 3.11 [1078 2.7 [26 87] [7665 7.99 [929 0.348 [1400 1.96 [26 100] [19 40]] [26 100]] [26 100]]] [26 100]] [2755 3.81 [26 79] [26 100]]] [26 100]] [26 100]] [26 100]] [26 75]] [26 80]] [26 71]] [26 66]] [26 100]] [26 70]] [26 66]] [26 100]] [19 71]] [26 68]] [26 57]] [1072 0.258 [3006 0.158 [1223 0.612 [4388 3.37 [995 2.37 [26 93] [26 85]] [26 100]] [26 100]] [26 100]] [26 66]]] [26 82]] [26 40]] [26 52]] [2748 3.98 [7512 2.34 [26 100] [1078 3.72 [19 60] [392 1.65 [26 77] [26 75]]]] [26 100]]] [26 58]] [1 50]] [26 55]]] [6525 3.42 [7677 1.08 [980 4.04 [328 8.7 [679 1.41 [7054 7.61 [2580 1.75 [3008 0.719 [1783 4.17 [6178 3.67 [978 6.55 [6524 16.7 [25 41] [25 87]] [26 90]] [25 100]] [1 50]] [25 89]] [25 100]] [1 75]] [25 100]] [26 39]] [26 77]] [26 73]] [25 100]]] [7255 2.07 [5462 1.01 [2755 1.23 [6276 2.37 [2769 1.56 [221 8.39 [6178 2.89 [25 92] [25 100]] [25 75]] [25 100]] [25 87]] [25 100]] [25 66]] [25 83]]] [2936 0.431 [3100 1.08 [6353 0.947 [5201 1.06 [6185 3.23 [685 3.1 [202 0.555 [6457 0.293 [5692 5.49 [26 52] [1 87]] [25 100]] [221 0.937 [25 100] [25 87]]] [25 100]] [25 63]] [25 100]] [25 55]] [1 100]] [4338 3.63 [25 100] [25 86]]]]] [2587 0.151 [1047 1.04 [5817 1.06 [6988 0.0445 [3204 2.51 [791 6.89 [5239 1.13 [286 3.22 [221 0.625 [2764 4.68 [312 7.29 [6088 0.734 [2 39] [2 92]] [2 90]] [5 27]] [7009 1.29 [7491 1.56 [4 79] [4 100]] [2658 4.99 [4 83] [4 100]]]] [2 83]] [4 100]] [4929 3.95 [2961 0.785 [6538 1.02 [6582 2.79 [4235 2.99 [2571 2.45 [3027 1.62 [5819 4.95 [178 0.68 [1429 31.8 [1980 3.75 [2081 0.217 [7742 1.2 [4338 3.86 [2 35] [2 37]] [2 69]] [2 70]] [5692 5.21 [2 46] [312 5.02 [2 73] [2 100]]]] [17 61]] [4 54]] [17 40]] [2 45]] [4 39]] [999 0.437 [2 88] [2 100]]] [4 80]] [5819 2.32 [2 93] [2 80]]] [2902 0.417 [4 87] [4 100]]] [4 81]]] [5 100]] [2766 0.874 [2 91] [2 50]]] [7363 8.32 [4 81] [4 100]]] [1253 0.836 [6251 1.57 [2 66] [2 100]] [2 100]]] [4601 0.22 [5654 4.54 [3303 1.6 [2939 14.1 [4663 16.6 [2264 3.75 [2 100] [2 85]] [2 66]] [2 66]] [2 71]] [2 62]] [2 100]]]] [4970 0.418 [7533 1.4 [3483 0.283 [7526 0.25 [3726 0.585 [968 1.36 [4087 1.12 [2342 5.18 [900 0.647 [6094 0.81 [4369 1.87 [2913 1.85 [6977 1.05 [4270 1.07 [6395 0.612 [2340 1.95 [731 0.559 [3734 0.77 [4200 0.883 [5005 2.89 [2846 2.44 [7185 1.99 [5692 1.86 [939 16.8 [6853 2.28 [6547 8.76 [721 0.246 [7588 2.06 [5316 3.52 [5412 12.2 [5730 6.02 [5242 22.3 [4587 6.93 [3912 4.13 [7601 10.3 [978 8.08 [1062 20.2 [7665 50.2 [5064 2.92 [899 7.11 [3742 5.05 [7512 39.6 [6342 6.11 [5403 1.48 [7711 11.1 [1769 6.99 [6550 9.31 [14 26] [429 4.67 [17 42] [19 40]]] [17 58]] [19 46]] [31 83]] [19 54]] [6583 9.29 [19 36] [19 40]]] [17 35]] [32 37]] [31 100]] [14 55]] [14 41]] [7 31]] [7354 25 [36 57] [36 91]]] [36 78]] [32 86]] [36 92]] [32 90]] [429 38 [17 35] [7 45]]] [4414 3.28 [32 68] [32 92]]] [695 15.9 [5 27] [14 44]]] [14 75]] [14 100]] [36 86]] [31 93]] [6529 3.23 [6732 8.33 [3929 0.243 [5345 4.45 [5160 2.46 [2260 8.12 [4478 0.142 [7381 1.69 [36 43] [7 44]] [1 33]] [36 100]] [14 90]] [31 21]] [12 44]] [14 51]] [36 72]]] [6203 9.92 [144 6.85 [5851 5.21 [6202 0.864 [2331 3.82 [7722 14.5 [663 2.65 [7214 2.28 [17 39] [14 57]] [14 40]] [7 31]] [32 90]] [791 16.9 [19 58] [14 66]]] [5851 12.3 [36 57] [36 72]]] [17 75]] [14 68]]] [32 59]] [7 100]] [7583 1.28 [2526 2.76 [7571 1.06 [5705 1.14 [899 2.42 [4768 0.64 [7512 14.1 [36 62] [14 90]] [14 62]] [36 77]] [36 100]] [36 100]] [7 41]] [36 100]]] [3732 7.53 [17 50] [17 77]]] [3972 0.618 [4712 1.95 [791 5.45 [663 11.2 [2939 8.42 [6583 2.11 [4533 0.438 [957 2.93 [494 0.413 [14 21] [17 80]] [7 50]] [17 42]] [17 72]] [17 88]] [19 73]] [2570 1.32 [1980 1.11 [3910 1.04 [7381 4.61 [17 35] [7381 7.43 [2616 1.64 [19 44] [19 71]] [7 26]]] [19 50]] [17 40]] [17 33]]] [32 30]] [5 63]]] [31 100]] [4913 1.61 [2752 4.16 [3929 4.62 [16 44] [494 10.2 [1 28] [17 42]]] [6709 1.23 [5192 0.751 [5316 0.483 [5851 3.23 [896 5.25 [17 56] [7381 1.08 [17 64] [17 100]]] [17 50]] [17 50]] [663 7.53 [17 87] [17 72]]] [17 66]]] [35 42]]] [36 96]] [4061 5.66 [99 1.19 [1062 0.569 [3733 0.447 [978 0.59 [7241 4.05 [6977 4.74 [19 61] [5412 2.39 [7214 2.89 [6977 8 [14 38] [2628 5.75 [5034 6.17 [17 40] [14 70]] [14 40]]] [14 87]] [14 69]]] [14 74]] [17 58]] [19 61]] [17 56]] [14 100]] [3905 30.6 [2259 29.8 [14 87] [14 100]] [14 71]]]] [3912 1.93 [791 13.6 [685 3.31 [7340 2.72 [32 40] [32 100]] [7 100]] [32 75]] [32 75]]] [3905 27.2 [7688 0.499 [2320 0.96 [939 5.21 [5746 0.393 [3008 1.45 [3579 4.78 [112 14.2 [6413 1.27 [32 71] [32 100]] [32 100]] [32 100]] [32 50]] [32 100]] [31 42]] [32 100]] [32 100]] [32 50]]] [5692 0.81 [32 88] [32 100]]] [36 92]] [36 90]] [36 92]] [7241 2.41 [3872 1.11 [6074 4.04 [1151 6.36 [6175 0.741 [2752 5.73 [32 72] [5034 3.17 [3 25] [7512 5.41 [32 88] [7185 8.86 [32 100] [32 83]]]]] [32 75]] [32 62]] [32 50]] [32 100]] [32 78]]] [3378 2.16 [4800 0.766 [5673 1.17 [32 86] [5679 3.58 [32 100] [32 88]]] [32 100]] [32 100]]] [6851 1.67 [2616 0.845 [2752 2.07 [36 44] [17 27]] [663 6.35 [7526 3.16 [17 78] [6583 5.74 [17 46] [19 75]]] [19 66]]] [7 100]]] [4799 0.898 [32 65] [6074 0.283 [6401 0.956 [32 98] [32 100]] [32 100]]]] [141 0.406 [7588 5.94 [1783 0.437 [2793 4.53 [4710 5.59 [1062 2.55 [3928 2.74 [791 2.79 [14 64] [14 45]] [896 5.14 [17 90] [17 50]]] [2902 0.501 [17 44] [17 73]]] [14 100]] [2259 49.1 [14 100] [14 91]]] [17 36]] [17 50]] [7169 0.739 [17 40] [17 37]]]] [7 100]]] [7057 1.65 [1065 3.94 [2451 1.19 [939 4.16 [631 5.3 [773 4.82 [144 5.47 [7301 5.68 [3642 7.95 [2029 6.64 [7722 15.1 [906 1.49 [2548 4.45 [4762 3.96 [4338 42.7 [2777 4.09 [5267 2.24 [3652 0.73 [2771 0.986 [6839 7.77 [1436 1.37 [4169 0.724 [7255 4.4 [24 100] [24 88]] [24 100]] [24 100]] [24 80]] [24 100]] [24 100]] [24 97]] [4342 2.54 [24 83] [24 100]]] [24 90]] [24 85]] [24 100]] [24 90]] [24 71]] [24 63]] [24 75]] [24 84]] [6184 1.38 [24 92] [24 75]]] [24 71]] [24 87]] [24 64]] [3662 1.24 [24 82] [19 100]]] [24 62]] [24 54]]] [5473 0.157 [6401 0.172 [5705 0.213 [6081 0.162 [6077 0.482 [701 0.216 [632 0.414 [874 0.364 [2509 0.235 [3111 0.495 [7601 0.347 [5782 1.31 [5703 0.542 [4851 0.826 [3067 0.596 [2445 1.07 [72 1.15 [2411 1.06 [3487 1.71 [6413 1.42 [3905 7.25 [5812 0.982 [7620 1.37 [2966 2.39 [6623 1.58 [5260 2.59 [2259 10.2 [4530 1.52 [4612 1.56 [1239 2.53 [6859 3.88 [4159 5.5 [13 73] [12 36]] [719 1.4 [36 50] [36 100]]] [13 47]] [36 100]] [13 44]] [36 84]] [13 100]] [13 100]] [36 100]] [13 90]] [13 88]] [36 88]] [13 100]] [36 100]] [36 91]] [13 100]] [36 100]] [36 100]] [2320 2.96 [2342 0.826 [5472 16.1 [5753 2.22 [36 96] [36 100]] [36 93]] [36 100]] [36 86]]] [104 0.475 [7722 0.265 [1520 1.25 [6184 1.4 [890 2.08 [13 100] [13 87]] [13 100]] [13 100]] [13 100]] [13 100]]] [36 100]] [5402 1.8 [7149 2.13 [1980 3.55 [2201 2.7 [6199 0.402 [791 23.7 [5472 2.41 [36 66] [2326 2.33 [867 3.78 [7712 5.03 [5753 0.722 [899 4.08 [36 89] [36 100]] [36 100]] [36 60]] [24 42]] [36 100]]] [36 55]] [36 100]] [36 100]] [1253 4.65 [36 74] [36 66]]] [36 100]] [13 100]]] [7665 9.56 [36 87] [36 100]]] [13 100]] [2993 0.559 [36 100] [1 1.02 [36 87] [36 100]]]] [36 100]] [5732 0.216 [15 0.664 [2081 1.07 [434 2.61 [2628 0.631 [2445 0.68 [6261 0.395 [4087 1.87 [16 1.86 [4851 1.96 [36 96] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]]] [2570 1.18 [5472 7.22 [7572 0.964 [1888 1.39 [13 80] [13 100]] [13 100]] [20 1.85 [3821 1.96 [7622 2.3 [1164 2.44 [13 96] [13 100]] [13 100]] [13 100]] [13 100]]] [13 100]]] [1899 0.352 [429 14.5 [2752 14.3 [13 100] [13 94]] [13 100]] [13 100]]] [695 5.32 [7665 17.4 [7712 0.373 [2260 0.213 [896 4.39 [7601 0.178 [7512 15.7 [36 100] [36 85]] [36 100]] [36 80]] [36 100]] [36 100]] [36 100]] [36 100]]] [5753 1.22 [2093 1.67 [1738 0.205 [2993 5.23 [1429 35.2 [4414 5.84 [36 100] [36 91]] [36 100]] [7595 1.43 [36 98] [36 100]]] [36 100]] [36 70]] [5977 0.618 [36 100] [5061 0.603 [36 100] [7109 3.73 [5977 1.6 [1899 2.01 [36 90] [19 58]] [36 90]] [5012 1.3 [36 100] [36 62]]]]]]] [4663 21.5 [2570 11.5 [5820 0.787 [1239 6.95 [2616 5.72 [30 0.269 [4747 8.77 [5110 17.2 [5473 37.9 [2913 2.99 [5543 5.47 [791 2.89 [13 78] [324 6.37 [619 0.491 [1429 2.42 [2488 3.11 [13 98] [13 100]] [13 100]] [13 100]] [13 90]]] [13 90]] [32 71]] [13 76]] [13 66]] [13 83]] [13 100]] [4 50]] [13 88]] [2 72]] [2 53]] [13 65]]]] [7354 0.954 [2752 4.84 [2385 0.885 [6923 0.321 [2554 14.1 [145 1.66 [6859 6.02 [7169 11 [1274 0.29 [6690 0.104 [7255 8.27 [5692 1.09 [6836 2.19 [5412 3.44 [5397 14.6 [4891 19.6 [5952 0.667 [6399 4.07 [2445 1.69 [7560 7.12 [7224 3.52 [719 2.24 [2293 7.27 [6001 8.85 [6277 15.2 [2713 1.81 [1374 3.47 [2450 0.803 [4716 1.86 [7235 7.7 [1078 23.8 [2526 94.3 [6 93] [6 71]] [6 66]] [6 100]] [2262 1.36 [2029 10.4 [6 100] [7665 27.7 [6 83] [6 100]]] [6 100]]] [6 100]] [6 80]] [6 60]] [6 70]] [6 64]] [6 55]] [6 37]] [2579 9.64 [5988 1.73 [4889 6.1 [2526 39.2 [6 85] [2282 8.55 [5962 10 [6 100] [6 95]] [2569 1.69 [6 86] [6 100]]]] [6 85]] [6 71]] [7665 20.5 [5597 9.9 [6 62] [2569 12.5 [6 100] [6 75]]] [6 42]]]] [6 70]] [6 25]] [1899 2.35 [1275 6 [6 72] [16 66]] [1382 1.48 [7675 1.41 [6136 1.27 [6 83] [6 100]] [6 61]] [6 100]]]] [16 50]] [6098 10.9 [7419 6.18 [16 71] [6 90]] [16 54]]] [6 56]] [6 50]] [6 50]] [5693 0.824 [6 27] [18 64]]] [13 30]] [7506 1.66 [6 90] [6515 9.18 [6 100] [4674 4.04 [6 90] [6 83]]]]] [2223 5.16 [1335 6.37 [6 100] [4727 0.471 [6 80] [6 55]]] [6 100]]] [6 61]] [24 70]] [19 78]] [18 43]] [2526 36.7 [2599 0.271 [0 12.9 [4674 2.39 [4674 1.23 [6 100] [6 83]] [6 100]] [6 80]] [6 87]] [4154 2.91 [6923 10.4 [6422 13 [2293 0.715 [1089 3.32 [7560 6.8 [7541 1.17 [1320 0.343 [4937 4.13 [5409 7.77 [1783 7.71 [6 100] [4675 5.3 [6 100] [6 90]]] [5396 4.09 [6 79] [6 100]]] [16 57]] [6 100]] [7407 0.647 [6 63] [2262 6.73 [2549 1.82 [6 100] [6 88]] [6 77]]]] [2569 7.47 [6 55] [6 100]]] [7675 12.8 [2613 0.165 [6 85] [6 100]] [16 55]]] [6 100]] [6514 4.27 [16 62] [6 66]]] [5999 2.79 [1340 1.1 [6 96] [6 100]] [6 100]]] [6 83]]]] [18 46]] [6859 1.08 [1723 2.41 [1025 8.57 [5647 9.64 [978 0.81 [1899 4.76 [731 2.56 [22 32] [18 44]] [5192 0.715 [22 42] [36 44]]] [2526 37.7 [2081 1.91 [4338 2.06 [7722 4.11 [26 28] [17 58]] [24 100]] [2902 2.01 [4 33] [26 44]]] [4524 6.08 [6 57] [6 90]]]] [2763 3.92 [29 44] [2 84]]] [7665 7.37 [4 34] [2 43]]] [7420 2.74 [24 64] [2773 0.904 [1751 8.18 [24 60] [24 100]] [24 90]]]] [906 2.19 [4851 1.52 [1239 0.918 [899 1.1 [5454 10 [1788 0.653 [36 57] [36 83]] [24 72]] [36 100]] [2628 2.61 [7453 0.818 [4907 0.618 [2536 0.355 [7382 0.741 [36 68] [24 100]] [24 100]] [24 100]] [24 100]] [24 66]]] [36 100]] [36 95]]]] [731 1.14 [5480 2.1 [5454 0.246 [6920 5.26 [392 8.4 [1429 33.4 [1078 24.8 [6260 0.766 [36 75] [36 100]] [32 36]] [5693 0.773 [2411 0.329 [36 94] [36 100]] [36 75]]] [6 50]] [36 100]] [36 100]] [7724 1.07 [18 60] [19 88]]] [4889 0.155 [2939 1.46 [5693 4.44 [5154 1.98 [2434 0.538 [16 47] [16 50]] [5 30]] [18 69]] [5693 2.46 [18 90] [2939 4.93 [18 37] [16 42]]]] [18 75]]]]]] [3952 0.124 [2384 0.402 [5219 2.01 [663 0.107 [605 0.846 [826 0.236 [7338 0.357 [5283 1.01 [6436 3.51 [1116 0.4 [6529 1.06 [2562 0.357 [6109 0.325 [1400 3.06 [1226 0.48 [7747 0.467 [4781 1.02 [286 1.62 [4189 0.627 [5412 3.05 [5576 1.2 [5211 29.1 [429 7.68 [4246 1.56 [4359 0.986 [5034 1.5 [304 0.813 [1061 2.32 [2982 1.41 [3676 0.736 [3019 0.511 [5122 3.32 [273 4 [2526 0.68 [221 5.77 [2787 0.678 [4690 3.31 [6604 2.33 [4845 10.8 [7619 6.6 [5368 2.2 [1936 1.16 [22 19] [19 55]] [1078 7.19 [1 30] [11 55]]] [13 96]] [29 100]] [7665 3.11 [30 92] [30 100]]] [3227 3.14 [23 5.92 [20 87] [20 40]] [20 100]]] [8 100]] [30 57]] [6413 3.76 [24 20] [0 85]]] [20 76]] [4895 2.24 [6091 8.31 [7320 0.556 [2927 2.59 [4921 12.6 [247 6.76 [30 97] [30 71]] [30 50]] [30 100]] [30 100]] [30 50]] [30 100]]] [24 90]] [1511 7.72 [8 100] [8 71]]] [30 100]] [20 100]] [7512 0.849 [1429 24.5 [30 96] [30 100]] [30 100]]] [2752 5.9 [5673 2.89 [1078 28.8 [30 77] [30 60]] [30 100]] [4154 13 [30 93] [30 90]]]] [7165 1.54 [7757 2.02 [20 96] [20 100]] [20 100]]] [20 100]] [802 4.09 [227 1.09 [6033 0.425 [872 1.04 [7176 1.09 [5482 1.85 [4690 1.35 [6572 5.83 [1056 1.36 [5484 4.04 [5662 2.82 [6479 0.518 [935 0.975 [1078 19.6 [2696 0.425 [3661 1.72 [7444 5.05 [4870 0.994 [384 2.49 [6031 8.35 [5160 3.72 [7413 5.63 [5730 2.73 [2143 6.26 [5225 2.19 [6883 1.47 [429 32.2 [6413 3.07 [899 4.89 [2199 0.785 [30 38] [36 25]] [30 100]] [0 87]] [957 5.62 [791 41.7 [23 27] [22 31]] [30 55]]] [33 44]] [30 79]] [2225 3.36 [23 50] [21 36]]] [11 100]] [5692 2.92 [23 40] [28 37]]] [30 100]] [22 100]] [2259 3.18 [5211 8.84 [23 66] [23 71]] [23 66]]] [22 56]] [11 100]] [24 100]] [30 100]] [5034 1.8 [695 5.16 [2029 0.389 [5692 1.33 [4154 1.65 [11 37] [2251 5.03 [23 50] [10 50]]] [23 53]] [23 44]] [2763 1.46 [22 89] [36 62]]] [2091 5.7 [30 79] [3 57]]]] [23 91]] [1980 10.6 [23 62] [6479 6.94 [23 66] [23 100]]]] [11 76]] [22 95]] [11 100]] [24 88]] [5865 1.45 [7323 1.63 [4239 1.41 [3054 3.88 [8 22] [0 100]] [312 1.41 [20 95] [20 100]]] [8 100]] [0 71]]] [22 46]] [4764 1.02 [1062 2.31 [2526 9.13 [6342 2.02 [5211 21.6 [7461 1.44 [5227 2.47 [1078 37.8 [22 77] [35 50]] [11 58]] [22 100]] [22 89]] [22 62]] [8 82]] [2745 1.74 [7419 1.39 [22 50] [22 100]] [22 88]]] [35 77]]] [11 85]] [22 100]] [2752 14.9 [2526 1.99 [24 75] [4191 2.4 [24 80] [24 100]]] [24 100]]] [9 48]]] [583 5.38 [2902 5.56 [5160 5.71 [3018 7.69 [377 9.9 [6882 2.46 [6033 5.38 [6721 9.85 [5225 9.8 [5222 4.07 [6970 8.4 [7305 19.2 [4210 8.2 [4702 11.8 [7685 8.47 [5851 29.2 [2628 12.4 [2993 9.09 [2753 6.8 [6155 33.1 [700 7.69 [7381 15.2 [4245 31.3 [5040 14.3 [2526 19.7 [2764 13.8 [429 3.76 [30 38] [22 47]] [11 86]] [3022 15.2 [24 30] [24 100]]] [13 100]] [20 100]] [24 100]] [22 100]] [11 78]] [22 77]] [30 92]] [30 42]] [0 57]] [20 97]] [30 100]] [30 100]] [11 94]] [1 18]] [30 100]] [504 4.2 [3071 4.85 [30 70] [30 89]] [22 72]]] [30 100]] [22 100]] [30 100]] [30 62]] [24 89]] [859 8.03 [30 90] [30 85]]] [22 45]] [21 83]]] [221 30.8 [3658 6.29 [24 96] [24 86]] [2628 23.5 [24 62] [24 100]]]] [435 6.32 [567 10.6 [6428 0.664 [2847 0.898 [2567 4.59 [7512 8.26 [5480 3.6 [760 5.45 [5913 5.16 [2143 7.78 [1614 3.72 [1391 3.48 [6048 0.529 [5615 4.14 [5211 10.4 [4184 1.05 [23 14] [2 27]] [2199 11.8 [23 32] [22 81]]] [23 100]] [2259 4.99 [0 27] [21 57]]] [22 82]] [4 60]] [1239 8.82 [2143 20.9 [23 92] [23 75]] [30 61]]] [23 85]] [23 100]] [700 1.61 [5486 2.79 [22 78] [23 100]] [22 100]]] [5647 16.3 [998 2.09 [7381 2.27 [2259 4.45 [6342 7.72 [22 16] [20 66]] [23 63]] [24 62]] [23 100]] [896 1.44 [939 2.33 [6921 3.66 [23 82] [23 100]] [23 100]] [18 44]]]] [23 68]] [4533 1.4 [22 97] [22 100]]] [22 100]] [660 2.49 [23 92] [23 100]]] [1995 16.5 [23 77] [22 50]]]] [4789 1.88 [4279 2.97 [7566 0.381 [1640 9.74 [227 0.693 [24 93] [5211 3.86 [24 80] [24 87]]] [24 76]] [24 100]] [24 100]] [24 50]]] [7665 12.2 [2567 0.417 [685 0.549 [7413 2.83 [1094 2.05 [999 2.21 [4350 0.945 [23 60] [23 77]] [23 100]] [23 100]] [23 38]] [4583 0.549 [2251 1.21 [2764 0.882 [2259 1.59 [23 80] [23 95]] [23 100]] [23 100]] [23 85]]] [23 100]] [1078 43.2 [5732 0.891 [4359 1.37 [20 70] [20 100]] [24 87]] [20 50]]]] [362 5.93 [2764 2.38 [3043 3.76 [7451 1.9 [1911 2.61 [11 50] [11 100]] [11 80]] [22 100]] [11 90]] [30 55]]] [7536 1.21 [7665 8.48 [20 81] [7165 0.68 [2091 0.643 [20 98] [20 75]] [20 100]]] [20 100]]] [328 7.65 [7185 0.19 [2764 1.79 [7449 9.43 [978 1.6 [384 5.29 [30 33] [23 100]] [23 100]] [23 87]] [23 98]] [23 100]] [1429 22.3 [435 0.675 [23 81] [23 100]] [23 41]]]] [673 2.96 [1137 0.994 [6 1.22 [811 0.682 [1400 10.4 [695 3.55 [10 18] [10 62]] [6342 7.01 [5413 1.09 [7665 4.84 [10 61] [10 66]] [4 80]] [5216 3.7 [10 91] [10 100]]]] [1 2.02 [1079 0.96 [3526 4.05 [7674 0.978 [1253 1.01 [774 0.935 [3527 1.54 [7512 20.7 [5468 1.12 [10 97] [10 100]] [10 80]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [2259 14.6 [10 100] [10 75]]]] [10 100]] [10 100]] [26 60]]] [2108 0.231 [4288 0.287 [5228 0.316 [1062 6.2 [22 73] [22 96]] [22 100]] [22 100]] [22 100]]] [286 0.438 [660 1.88 [7610 1.77 [5824 0.508 [2589 0.835 [7119 2.42 [3045 0.792 [1094 2.04 [5865 1.46 [6737 2.79 [791 3.46 [1980 4.46 [0 39] [384 10.4 [2088 1.1 [7507 2.15 [23 84] [23 100]] [23 100]] [23 75]]] [3907 0.548 [6260 0.68 [1436 0.805 [5799 1.13 [23 64] [22 50]] [0 66]] [22 57]] [0 71]]] [0 100]] [0 100]] [6184 0.644 [23 82] [23 100]]] [35 87]] [0 100]] [0 92]] [0 85]] [8 100]] [5486 1.41 [2567 4 [23 91] [23 83]] [23 100]]] [5753 5.93 [4288 0.251 [4424 0.655 [4447 0.69 [2793 0.711 [2562 16.8 [5662 8.01 [978 8.29 [791 9.26 [23 80] [23 100]] [23 100]] [23 87]] [23 75]] [23 100]] [23 100]] [23 100]] [23 100]] [23 90]]]] [615 2.18 [4761 0.355 [6347 1.45 [6191 2.01 [7665 21.3 [6406 1.63 [398 1.12 [7731 3.59 [7254 1.25 [1764 1.22 [377 6.53 [4159 0.754 [6260 0.707 [6859 1.06 [5765 1.42 [2199 11.6 [1783 1.81 [7149 1.89 [567 2.56 [883 1.33 [6524 17 [22 98] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 94]] [22 100]] [22 93]] [22 100]] [22 100]] [22 91]] [22 100]] [22 85]] [22 90]] [22 80]] [22 90]] [22 75]] [22 76]] [22 80]] [22 81]] [9 57]]] [7305 1.8 [2023 1.47 [2759 3.74 [6974 1.93 [2366 7.4 [7623 1.49 [6775 1.25 [5776 2.67 [7615 1.2 [1451 2.46 [30 96] [30 80]] [3 42]] [30 100]] [30 100]] [30 98]] [30 66]] [30 75]] [8 44]] [30 72]] [10 54]]] [4984 1.13 [144 6.25 [2752 49 [5206 1.42 [1239 1.04 [5225 6.8 [2902 4.2 [2913 2.06 [6436 14.3 [4312 2.92 [30 57] [30 85]] [3025 1.38 [30 94] [30 100]]] [30 96]] [30 54]] [771 1.72 [30 98] [30 100]]] [5480 1.04 [30 50] [23 45]]] [30 70]] [30 54]] [22 42]] [30 100]]] [6342 3.01 [2811 7.52 [2081 0.975 [7255 1.33 [22 100] [22 66]] [22 100]] [22 83]] [22 75]]] [504 0.914 [7413 0.357 [7770 0.763 [5692 1.17 [22 96] [22 100]] [22 100]] [22 100]] [22 100]]] [2004 0.879 [7210 2.69 [5236 1.98 [5110 1.12 [1906 4.14 [5420 2.74 [7505 2.73 [4288 0.293 [5215 1.52 [978 4.4 [23 26] [2259 12.9 [23 89] [23 71]]] [23 50]] [23 100]] [23 100]] [23 91]] [11 50]] [2081 15.8 [11 100] [11 85]]] [20 100]] [23 57]] [859 1.18 [2088 4.93 [967 12.1 [2204 0.348 [6406 25 [23 100] [23 71]] [23 100]] [23 85]] [6921 4.3 [23 100] [23 90]]] [1980 32.1 [23 75] [11 66]]]]] [6730 30.5 [7665 9.32 [1783 1.16 [791 18.1 [24 100] [5675 4.88 [7031 22.9 [24 94] [24 63]] [24 57]]] [885 1.46 [2628 4.69 [24 100] [24 86]] [24 100]]] [24 100]] [24 62]]] [3492 0.585 [695 0.413 [2752 16.2 [811 1.05 [3055 0.699 [6603 3.18 [1611 0.803 [134 0.753 [1078 20.4 [896 0.797 [7411 0.756 [6375 2.49 [4253 3.73 [5480 1.6 [2696 4.2 [30 41] [30 100]] [22 97]] [22 77]] [22 77]] [30 83]] [20 26]] [2259 3.66 [22 79] [23 4.12 [22 34] [22 75]]]] [23 26.9 [4995 1.51 [0 20] [2 80]] [0 66]]] [30 100]] [0 100]] [0 100]] [4369 0.552 [10 89] [10 100]]] [6425 1.61 [2813 5.78 [5648 5.23 [7229 0.782 [1087 0.994 [1709 1.11 [877 0.448 [2616 0.891 [957 0.876 [4184 2.95 [7009 0.925 [2913 5.76 [996 2.22 [5693 5.86 [1391 1.25 [7176 1.79 [5211 7.03 [18 18] [30 40]] [22 73]] [22 100]] [22 93]] [22 85]] [30 100]] [22 89]] [663 3.11 [22 71] [22 96]]] [30 53]] [26 33]] [22 100]] [22 100]] [29 70]] [22 100]] [23 62]] [22 100]] [30 63]]] [5820 0.393 [7680 0.302 [1400 0.801 [6373 2.38 [5732 1.13 [4927 1.55 [7665 5.16 [4991 6.8 [436 4.77 [1065 3.48 [4630 3.31 [4851 5.71 [2139 0.339 [7084 1.96 [6949 1.77 [2083 4.13 [328 10.3 [7449 0.284 [4414 6.01 [2827 0.304 [5851 0.442 [5225 0.395 [112 0.2 [2016 1.59 [22 94] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [7169 12.1 [22 100] [22 66]]] [22 100]] [5480 5.75 [22 80] [22 100]]] [22 92]] [22 66]] [22 87]] [22 85]] [22 81]] [22 71]] [22 75]] [22 62]] [22 50]] [429 25 [859 0.481 [22 57] [22 100]] [18 45]]] [18 71]] [18 28]] [430 6.4 [22 40] [22 100]]] [5267 0.801 [7665 2.1 [10 95] [2752 9.68 [10 33] [10 28]]] [36 60]]] [10 100]] [2 80]]] [1062 5.69 [7431 1.02 [0 90] [0 100]] [0 77]]]] [1997 5.35 [2835 0.479 [2906 0.457 [2931 1.61 [6031 6.05 [3350 1.59 [811 0.891 [6848 5.65 [3019 2.99 [3207 6.71 [5412 9.38 [567 6.92 [5664 11 [136 4.5 [1044 1.1 [2492 2.49 [6328 9.66 [7352 9.26 [2793 0.654 [2004 7.97 [2902 2.17 [3103 1.84 [7665 7.63 [6445 9.82 [600 5.01 [5482 11.5 [4897 2.58 [663 1.24 [4414 52.7 [3337 2.8 [2544 6.44 [2361 0.158 [5803 4.72 [1101 13.1 [6970 11.4 [3470 15.6 [328 44 [6320 4.54 [5368 13.1 [2225 7.77 [6575 15.9 [392 0.118 [2589 3.23 [2562 58 [4893 0.316 [3675 0.367 [6261 2.2 [3353 9.44 [7179 0.0878 [5219 12.1 [2526 7.17 [8 88] [6581 11 [7255 0.408 [2321 0.303 [957 0.62 [1888 0.644 [685 1.07 [485 1.42 [3956 1.02 [8 98] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 87]]] [3124 1.03 [4235 3.45 [5267 1.61 [5219 26.8 [8 100] [7255 2.01 [3957 14.3 [8 99] [8 100]] [8 100]]] [8 100]] [8 100]] [8 100]]] [8 100]] [8 83]] [2526 23.4 [8 91] [8 100]]] [8 100]] [8 85]] [8 90]] [1009 0.336 [2199 0.278 [7179 0.527 [3497 9.41 [3318 1.22 [4279 0.4 [7009 1.05 [6581 0.52 [8 98] [8 100]] [8 100]] [8 100]] [8 100]] [8 62]] [8 100]] [8 80]] [8 100]]] [8 100]] [8 87]] [8 66]] [8 83]] [1899 0.861 [8 75] [8 90]]] [8 81]] [8 77]] [8 62]] [8 71]] [8 60]] [8 100]] [8 91]] [8 70]] [8 80]] [22 44]] [8 91]] [8 57]] [8 64]] [8 80]] [5345 2.6 [2752 27.6 [7449 0.606 [6653 0.818 [2259 1.54 [8 74] [1906 0.418 [7677 1.21 [3928 1.11 [2488 1.23 [491 4.2 [8 93] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]]] [8 100]] [8 85]] [8 40]] [10 54]]] [8 70]] [2 28]] [8 60]] [8 76]] [8 87]] [8 62]] [2589 2.63 [7210 0.758 [1078 11.8 [978 10.6 [8 100] [8 92]] [8 100]] [8 100]] [384 1.33 [8 88] [8 62]]]] [8 35]] [0 50]] [8 60]] [5851 1.02 [8 86] [23 50]]] [5480 1.3 [930 4.72 [5851 2.89 [8 81] [8 52]] [23 76]] [8 100]]] [8 61]] [24 100]] [35 69]] [10 100]] [0 100]] [22 82]] [23 55]] [23 100]] [23 100]] [1997 7.77 [0 75] [8 54]]]] [7241 3.39 [1333 0.345 [878 0.739 [7665 1.2 [10 91] [5439 9.56 [10 100] [5211 11.1 [10 100] [10 80]]]] [10 100]] [10 100]] [10 100]]] [8 100]]] [6136 1.26 [6124 0.254 [3533 1.19 [4870 1.26 [1164 0.269 [3404 17.2 [7210 3.61 [944 0.659 [1783 0.596 [434 0.824 [1146 1.66 [1159 0.543 [3269 0.919 [3968 1.92 [2628 8.46 [6342 0.635 [4326 0.336 [4279 1.22 [2628 1.35 [939 1.61 [27 98] [27 100]] [27 100]] [27 90]] [27 100]] [27 100]] [27 92]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [4369 1.25 [27 96] [27 100]]] [3931 5.29 [2752 4.33 [27 100] [27 85]] [27 100]]] [27 100]] [27 91]] [27 100]] [27 100]] [27 92]]] [3905 0.171 [5170 0.472 [6544 0.926 [1716 0.861 [6031 4.9 [6438 1.92 [1600 0.0611 [705 0.822 [731 0.766 [7657 0.849 [7354 2.36 [6177 6.17 [905 0.517 [7698 1.65 [6124 4.24 [3057 1.7 [3054 0.911 [537 0.775 [2518 0.87 [124 0.437 [248 10.9 [1333 0.182 [7623 6.3 [4309 1.23 [6887 0.701 [2320 3.16 [2742 1.42 [5860 2.17 [518 2.02 [5034 3.44 [6853 2.14 [6231 1.5 [743 0.763 [5155 1.18 [2913 0.754 [3381 12.6 [4218 4.36 [978 0.543 [1544 0.921 [1761 0.283 [5972 8.93 [5566 1.06 [2526 10.5 [1710 1.48 [7211 2.68 [5041 0.921 [3520 16.2 [2628 28.8 [6382 1.03 [4235 35.8 [407 17.8 [5454 0.6 [5784 6.57 [2488 3.4 [6428 0.84 [634 1.49 [1116 0.419 [1679 6.61 [2786 0.671 [7384 3.65 [4778 0.192 [5732 0.428 [574 0.963 [7514 0.832 [2521 0.883 [7665 9.83 [2993 18.2 [7491 10 [6809 2.96 [538 0.457 [5110 0.398 [724 0.952 [2445 3.33 [889 3.4 [4898 4.91 [2793 7.97 [1661 5.63 [4703 2.57 [6232 1.62 [695 9.85 [5040 5.6 [5637 2.96 [3292 7.22 [688 8.32 [6349 1.08 [7759 0.428 [802 6.95 [4279 1.87 [2752 15.7 [5851 25.5 [4326 3.69 [14 7] [27 63]] [1 31]] [3879 1.33 [32 25] [17 37]]] [28 23]] [3 45]] [10 60]] [10 100]] [7 66]] [37 100]] [38 50]] [21 87]] [14 39]] [22 81]] [33 43]] [18 90]] [24 77]] [33 54]] [32 100]] [18 42]] [6230 35.7 [17 50] [19 54]]] [7210 0.873 [21 18] [7502 0.398 [30 33] [30 90]]]] [9 83]] [32 100]] [7 27]] [21 75]] [7605 13.9 [3732 17.2 [7526 5.9 [5673 8.11 [6935 9.95 [791 20.6 [14 23] [14 45]] [5 62]] [14 76]] [17 33]] [17 88]] [14 81]]] [1980 0.73 [12 47] [33 36]]] [7737 2.62 [32 51] [19 90]]] [9 100]] [28 41]] [15 100]] [7 100]] [29 100]] [30 60]] [30 83]] [21 100]] [22 100]] [34 75]] [14 73]] [1628 0.6 [6711 0.743 [9 33] [21 100]] [29 94]]] [34 100]] [20 66]] [6955 1.5 [2752 5.43 [3 36] [32 74]] [32 87]]] [5 33]] [19 100]] [21 100]] [9 87]] [30 100]] [5851 11.5 [6582 0.615 [6243 4.28 [5509 8.07 [2570 1.7 [3558 8.14 [1429 22.3 [1025 10.5 [6581 3.31 [4 9] [5812 15.2 [5 44] [19 33]]] [4 80]] [5 17]] [5 46]] [4 50]] [5 89]] [19 50]] [4 100]] [0 72]]] [14 100]] [3072 1.39 [2521 2.53 [907 0.849 [5467 2.64 [1429 14.3 [12 67] [12 98]] [12 100]] [3 50]] [12 80]] [12 100]]] [429 12.6 [14 88] [14 100]]] [12 100]] [7133 1.22 [5480 1.78 [3273 0.86 [2259 6.63 [6310 1.54 [1580 1.4 [5632 2.89 [5751 0.917 [4479 1.65 [1497 2.75 [3014 3.72 [5847 0.416 [5677 1.71 [637 0.673 [3503 14.7 [4684 3.83 [4279 9.41 [1077 3.47 [6581 4.41 [3558 6.99 [791 1.7 [4861 7.87 [4154 2.22 [1993 1.42 [5 22] [4 37]] [23 26]] [14 33]] [3196 0.829 [1025 6.39 [5 29] [2752 12.2 [2 63] [4 47]]] [5 76]]] [5 71]] [642 4.2 [2573 2.67 [725 1.81 [1198 0.754 [2826 6.33 [17 46] [5 53]] [5 50]] [17 30]] [17 81]] [5 100]]] [5 86]] [4288 6 [5 36] [2628 4.56 [4 28] [4 92]]]] [8 45]] [17 100]] [2 81]] [16 58]] [4 100]] [5953 0.747 [791 8.87 [14 28] [17 83]] [38 55]]] [5 100]] [17 53]] [23 100]] [16 73]] [5829 6.14 [485 4.65 [17 73] [17 37]] [17 36]]] [978 30.8 [6550 0.78 [2826 14.9 [7512 13.2 [17 41] [7588 1.33 [5 56] [5 70]]] [17 70]] [695 0.78 [17 60] [17 72]]] [38 50]]] [1919 3.1 [4946 3.6 [7169 1.74 [1079 1.85 [2434 4.68 [7734 4.23 [5 21] [7 58]] [7 90]] [35 37]] [8 37]] [5 76]] [17 37]]] [35 58]] [6294 1.72 [5753 2.23 [2005 0.239 [2902 1.57 [2259 3.27 [18 23] [1239 2.85 [1078 19.3 [19 66] [18 71]] [18 88]]] [22 42]] [23 85]] [23 90]] [4 42]]] [4 100]]] [6199 3.67 [3014 2.59 [978 10.4 [2567 2.33 [5 30] [5 42]] [2081 1.11 [5 61] [5 72]]] [17 72]] [14 80]]] [7322 28.2 [7615 11.2 [30 65] [30 100]] [19 50]]] [2526 0.509 [4968 7.25 [2916 2.65 [1 4.11 [429 7.84 [30 81] [2752 11.8 [5 27] [791 13.7 [32 42] [32 80]]]] [3 50]] [30 60]] [30 92]] [7185 0.425 [5851 6.02 [23 17 [5 42] [5 28]] [0 88]] [16 54]]]] [5605 2.3 [6230 15.4 [21 2.35 [5 56] [5 57]] [7 35]] [17 62]]] [112 0.746 [21 96] [21 85]]] [5472 0.975 [1676 5.59 [6363 0.294 [6524 3.8 [1213 0.191 [2398 3.65 [4968 6.44 [1888 1.47 [23 31.1 [5804 2.11 [30 21] [10 100]] [29 50]] [13 39]] [30 50]] [12 100]] [10 50]] [22 90]] [27 61]] [12 100]] [13 100]]] [6232 0.743 [2752 1.85 [34 69] [5972 1.54 [4214 1.58 [5211 2.68 [1389 0.463 [1025 1.92 [28 18] [4349 0.967 [24 69] [24 100]]] [24 100]] [2847 1.11 [22 79] [22 100]]] [24 100]] [36 87]]] [22 76]]] [7457 0.306 [70 1.89 [221 5.85 [2902 2.76 [1079 5.81 [7704 2.65 [6199 5.55 [6604 5.05 [7340 1.47 [5673 8.07 [3931 7.5 [7692 0.931 [4210 4.42 [6342 7.22 [4851 14.7 [2199 7.73 [6382 1.87 [5851 8.12 [1587 5.91 [710 1 [7185 1.89 [5799 3.03 [5692 13.3 [14 77] [14 37]] [14 100]] [14 100]] [14 93]] [14 100]] [14 54]] [2752 7.19 [14 85] [14 100]]] [14 57]] [14 56]] [14 47]] [30 100]] [14 97]] [32 100]] [14 52]] [906 3.83 [32 93] [32 100]]] [30 70]] [6597 0.956 [14 77] [14 100]]] [32 100]] [7665 13.3 [32 75] [32 62]]] [14 86]] [30 50]] [30 100]] [32 85]]] [21 100]] [2604 1.46 [2259 6.02 [0 69] [0 95]] [0 100]]] [4 100]] [32 100]] [6230 4.55 [5 100] [5 81]]] [32 99]] [5214 1.81 [4007 2.67 [5692 3.58 [4332 0.288 [7656 0.106 [1679 1 [1429 1.5 [37 22] [34 53]] [30 100]] [14 31]] [34 83]] [30 88]] [34 100]] [30 100]]] [10 96]] [6177 1.27 [2268 1.93 [7722 0.824 [1913 4.79 [250 0.726 [4603 1.12 [2752 10.3 [7590 3.65 [685 12.8 [29 22] [26 75]] [26 75]] [4560 6.12 [26 55] [26 57]]] [432 3.32 [5480 1.62 [26 94] [26 60]] [26 72]]] [1 35]] [26 40]] [7665 11.4 [2913 1.08 [29 42] [26 69]] [23 1.63 [26 86] [26 92]]]] [34 55]] [25 83]]] [32 100]] [1078 3.45 [24 74] [24 57]]] [3 100]] [791 1.86 [0 96] [0 100]]] [1980 7.17 [1190 0.894 [1783 12.5 [5 71] [6 38]] [5 100]] [12 45]]] [6126 1.39 [774 0.898 [12 72] [27 85]] [12 100]]] [13 100]] [32 71]] [5999 18.5 [5605 6.39 [1079 0.295 [2939 8.14 [2526 3.78 [14 24] [2755 0.337 [23 1.1 [25 83] [7665 1.57 [25 94] [25 100]]] [25 100]]] [7 37]] [25 83]] [13 20]] [9 42]]] [5969 1.38 [2445 0.945 [6042 2.6 [5753 2.87 [2385 1.41 [383 1.99 [7698 0.87 [4654 4.19 [2320 1.24 [738 1.21 [4507 4.5 [3056 2.16 [1545 2.36 [6581 2.32 [4690 0.525 [6074 2.39 [1183 2.51 [7006 11 [5483 1.69 [6310 2.6 [7665 22.2 [2628 4.67 [4600 10.1 [573 3.73 [2526 3.55 [7210 3.22 [2488 1.73 [3205 2.92 [4324 2.65 [2752 36 [2902 2.86 [18 31] [32 33]] [7 25]] [7 66]] [5 66]] [13 50]] [36 41]] [18 38]] [12 70]] [12 41]] [4154 1.06 [7185 3.4 [5 52] [5 42]] [19 37]]] [32 56]] [5 48]] [18 100]] [5 77]] [5 83]] [7 81]] [8 81]] [6243 6.05 [978 13.8 [5 76] [5 58]] [19 60]]] [5 100]] [5 64]] [18 80]] [18 54]] [32 100]] [2913 3.4 [429 30.4 [5 91] [5 71]] [5 66]]] [791 18.6 [13 62] [13 100]]] [18 62]] [1078 12.6 [18 46] [18 90]]] [5192 2.98 [791 15.2 [4218 2.65 [2752 13.8 [5 30] [6581 3.89 [6848 3.52 [5 57] [5 75]] [19 61]]] [5 84]] [3057 3.31 [5 63] [5 94]]] [18 44]]] [6230 7.51 [7354 8.4 [18 66] [18 100]] [18 61]]] [5484 4.51 [18 40] [18 91]]] [6732 2.84 [719 4.12 [18 47] [18 100]] [5660 0.982 [18 88] [18 42]]]]] [1499 0.632 [6124 1.38 [6791 1.05 [5712 0.885 [2526 1.42 [112 1.13 [12 97] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]]] [4479 0.164 [5430 0.127 [1400 1.3 [2813 0.512 [3008 0.223 [7737 0.219 [6022 1.7 [5480 0.822 [3998 0.753 [7588 0.242 [6534 0.225 [3978 0.949 [1529 1.24 [3520 3.33 [5848 0.308 [5519 1.6 [3929 0.102 [6524 1.2 [2628 3.36 [6239 0.426 [1128 1.32 [6027 8.3 [978 15.9 [1240 1.37 [7333 3.81 [985 0.382 [3724 3.64 [5904 11.8 [2913 7.8 [731 19.3 [6184 4.01 [896 0.39 [3057 1.23 [685 0.87 [7742 1.96 [6591 8.21 [2752 33.7 [6342 7.94 [602 3.7 [1899 8.48 [5 16] [17 28]] [17 46]] [14 40]] [5 57]] [17 71]] [5 88]] [18 33]] [2752 14.5 [5 62] [5 96]]] [7085 3.29 [2902 3.27 [6342 1.72 [7343 1.04 [7210 3.77 [6199 6.25 [4292 1.15 [6557 5.3 [4861 3.64 [328 2.13 [688 6.37 [5 60] [7 57]] [7 37]] [12 33]] [5 100]] [5 50]] [5 33]] [5 37]] [5 92]] [5 25]] [6333 1.76 [5 73] [5 55]]] [5 30]]] [32 23]] [2829 6.45 [1239 4.5 [3130 15.8 [7586 5.8 [144 1.56 [384 2.2 [4805 1.86 [6581 37.4 [738 10.9 [6199 5.26 [2902 6.49 [7325 3.76 [7009 1.74 [5 33] [5 100]] [5 75]] [35 42]] [16 33]] [0 44]] [17 57]] [17 46]] [18 57]] [17 39]] [17 83]] [5 38]] [17 27]] [5 75]]] [5 71]] [19 68]] [5 88]] [5 60]] [17 53]] [24 81]] [5192 3.24 [3056 2 [384 3.75 [3798 2.65 [3724 1.59 [4304 4.38 [1707 3.7 [5851 3.57 [5637 9.35 [724 6.69 [407 4.67 [6581 1.01 [5297 8.4 [3190 1.74 [5 28] [5 85]] [19 66]] [5 53]] [7 88]] [19 55]] [5 70]] [17 41]] [17 46]] [12 53]] [5 53]] [5389 3.52 [17 54] [16 60]]] [7 44]] [5 79]] [17 27]]] [17 26]] [5 90]] [14 65]] [1909 1.83 [1210 1.11 [3675 2.85 [6977 2.75 [1630 3.5 [7381 4.99 [7598 1.24 [2023 3.09 [7009 1.19 [1899 5.13 [3027 4.87 [1011 6.81 [7176 1.18 [7590 4.55 [5 51] [5 42]] [7 85]] [5 85]] [15 42]] [5 26]] [719 1.42 [5 65] [5 90]]] [12 60]] [17 40]] [5 78]] [17 75]] [6313 2.33 [7414 2.49 [791 1.34 [5 64] [5 91]] [5 60]] [5 87]]] [6732 1.73 [5 71] [5 92]]] [5 100]] [2 40]]] [5647 3.27 [1783 6.33 [1011 8 [733 2.07 [7 93] [7 81]] [7 77]] [7 50]] [7 80]]] [3561 3.05 [567 1.03 [1544 1.53 [144 2.84 [1089 2.43 [6980 4.23 [913 0.464 [2526 4.1 [5 47] [6591 0.205 [6550 8.32 [733 0.855 [7009 1.27 [719 2.33 [1078 1.4 [5 41] [5 90]] [5 100]] [5 93]] [5 87]] [5 66]] [5 100]]] [38 50]] [5 87]] [5 46]] [6230 11.3 [6242 1.27 [5 55] [5 100]] [5 100]]] [5 100]] [14 37]] [38 50]]] [19 100]] [4 100]] [2526 8.83 [5692 1.73 [19 85] [19 93]] [19 66]]] [2902 0.785 [5 95] [5 100]]] [3313 2.38 [178 0.621 [5 96] [5 100]] [5 92]]] [4573 1.2 [17 42] [19 100]]] [5693 4.39 [2606 0.622 [610 0.816 [2842 2.25 [5514 11.1 [5 51] [2939 1.69 [5 92] [5 88]]] [5 94]] [5 100]] [929 1.16 [1529 0.207 [7512 26.6 [5154 0.891 [2616 0.691 [5 69] [5 78]] [5 100]] [5 57]] [5 100]] [5 33]]] [6776 0.654 [5 54] [17 100]]]] [1075 1.59 [1533 15.8 [3243 3.44 [4669 1.52 [2259 0.283 [642 5.38 [7665 6.36 [3978 0.911 [4338 0.389 [5 84] [5 100]] [5 100]] [1906 0.47 [3972 3.88 [6310 4.53 [3998 2.65 [18 36] [5 76]] [5 100]] [5 35]] [5 83]]] [5 40]] [6230 7.04 [4851 2.16 [1476 0.383 [5 93] [5 100]] [5 100]] [7734 1.33 [896 5.46 [5 100] [5 86]] [5 71]]]] [5 33]] [5 41]] [5 56]] [19 57]]] [3993 1.36 [5641 2.87 [4486 1.89 [1219 0.324 [5485 0.986 [653 1.99 [7711 1.71 [144 13.8 [4502 0.894 [6342 3.91 [2259 2.25 [7700 0.565 [18 55] [18 75]] [6040 8.59 [18 87] [18 66]]] [18 30]] [18 42]] [19 55]] [26 46]] [19 42]] [276 5.86 [1429 31.2 [18 50] [19 66]] [18 87]]] [5 33]] [5732 1.66 [19 31] [38 75]]] [19 33]] [16 36]]] [7427 1.25 [7 87] [7 100]]] [7301 0.253 [328 1.38 [18 34] [5198 1.29 [145 1.44 [1899 2.76 [2752 14.3 [18 100] [18 75]] [18 83]] [18 66]] [16 66]]] [132 0.219 [532 1.34 [19 68] [19 57]] [19 76]]]] [4754 3.24 [178 1.55 [1190 3.75 [669 1.26 [3021 2.96 [2055 0.954 [1646 1.05 [7314 0.682 [7343 6.83 [1648 3.39 [141 0.279 [1595 5.35 [3008 3.02 [17 40] [6550 10 [896 11.2 [3798 2.99 [5692 7.28 [6581 1.38 [7 31] [7682 9.17 [4805 4.41 [17 80] [17 100]] [17 57]]] [17 50]] [17 52]] [2541 1.57 [7665 18.8 [19 27] [17 90]] [38 45]]] [17 94]]] [7 100]] [7689 2.52 [17 35] [19 66]]] [5390 4.53 [719 3.35 [7665 12.7 [38 72] [17 42]] [19 70]] [3014 6.19 [1566 1.08 [2760 6.55 [19 58] [17 54]] [17 77]] [38 83]]]] [7 35]] [18 40]] [16 88]] [14 61]] [7 100]] [5 80]] [978 18.1 [978 7.11 [17 55] [17 94]] [16 36]]] [2752 32.7 [1899 1.19 [5 44] [25 50]] [896 3.03 [5 72] [5 92]]]] [7665 15.7 [19 85] [19 66]]]] [134 3.38 [5484 13.2 [4927 3.23 [602 2.15 [144 1.08 [6827 1.43 [5377 4.64 [5673 4.87 [532 1.07 [2809 2.93 [5192 0.302 [18 61] [18 62]] [18 100]] [18 81]] [16 71]] [30 54]] [18 100]] [18 51]] [3 33]] [144 3.34 [18 96] [18 87]]] [18 100]] [549 1.23 [5130 3.25 [7537 5.21 [18 42] [18 78]] [18 35]] [16 71]]]] [7305 3.47 [5820 0.496 [7571 1.63 [5267 3.29 [7725 1.69 [939 1.52 [5812 2.08 [1025 4.11 [6375 1.18 [144 1.66 [6178 7.19 [26 87] [25 100]] [26 50]] [26 85]] [2826 2.92 [26 83] [4 86]]] [1429 7.02 [4 88] [4 36]]] [26 41]] [4 90]] [791 5.6 [4 54] [26 37]]] [31 86]] [4 90]] [6216 0.756 [25 58] [26 100]]]] [5753 0.858 [12 50] [6230 6.1 [2676 2.97 [7325 1.81 [2005 1.42 [722 1.5 [6581 4.07 [5 100] [5 80]] [5 89]] [5 85]] [5 55]] [5 100]] [7414 0.711 [2081 3.83 [4718 1.06 [7563 1.51 [2526 7.23 [719 5.56 [3929 4.6 [653 5.07 [6230 24.7 [5 91] [5 75]] [5 50]] [5 61]] [19 50]] [7689 0.363 [1533 9.31 [17 0.635 [5693 0.488 [2616 7.88 [1078 3.76 [5 96] [5 90]] [12 42]] [5 100]] [5 100]] [5 66]] [5 100]]] [5 47]] [5 43]] [5 33]] [5 100]]]]] [2763 0.253 [7176 2.33 [6588 0.493 [1755 0.29 [4414 4.7 [5099 0.952 [5480 1.21 [5454 0.996 [2573 0.485 [7718 1.11 [6238 2.02 [407 2.15 [7185 0.627 [17 42] [17 85]] [7 85]] [3008 1.48 [3078 3.66 [14 21] [17 46]] [19 77]]] [7 83]] [17 88]] [17 100]] [16 28]] [7 85]] [7 72]] [16 55]] [1078 7.68 [17 100] [17 63]]] [7 94]] [723 0.543 [731 4.52 [4478 5.77 [17 38] [7 66]] [1913 0.931 [469 0.655 [17 42] [19 100]] [19 61]]] [16 57]]]]] [7340 4.2 [7255 0.412 [3557 1.1 [12 77] [12 100]] [663 0.885 [2199 1.46 [4279 0.861 [2268 1.17 [2957 0.54 [695 24.1 [12 100] [3027 3.37 [12 100] [12 77]]] [12 100]] [12 100]] [12 100]] [12 90]] [12 100]]] [4154 12.5 [6885 0.654 [6883 2.37 [5034 2.37 [12 100] [32 95]] [12 100]] [12 83]] [32 100]]]] [7 100]] [756 1.99 [5034 22.8 [30 100] [30 85]] [30 100]]] [7101 0.257 [6232 0.778 [7009 1.76 [7182 0.855 [7742 1.78 [5211 4.93 [7461 2.3 [22 33] [22 100]] [22 100]] [22 100]] [22 100]] [22 57]] [22 100]] [429 27.3 [22 100] [22 83]]]] [7689 1.44 [6438 0.469 [1888 0.496 [7320 0.907 [30 43] [30 83]] [6310 7.27 [18 23] [14 55]]] [30 98]] [17 50]]] [6396 0.471 [5564 0.418 [2926 0.914 [2091 8.42 [5472 0.662 [905 0.743 [828 1.27 [1676 1.64 [5405 1.25 [3317 2.25 [7340 0.994 [5918 2.31 [248 2.02 [134 0.99 [109 1.25 [1011 5.07 [915 2.53 [663 7.65 [5296 0.843 [662 1.4 [5972 0.816 [1587 0.864 [1239 27.4 [5776 0.759 [14 92] [14 100]] [14 41]] [14 100]] [3 75]] [14 100]] [14 100]] [1239 4.49 [5851 0.766 [2259 7.97 [1429 52.2 [14 100] [14 82]] [14 63]] [32 60]] [14 100]]] [3 100]] [17 50]] [14 100]] [17 33]] [14 100]] [3 33]] [1986 0.808 [32 97] [32 85]]] [14 46]] [31 100]] [14 100]] [32 100]] [32 100]] [23 7.66 [36 75] [36 81]]] [32 85]] [32 100]] [14 100]] [6581 0.539 [1072 4.23 [144 16.6 [1783 3.33 [4851 4.95 [3928 5.16 [731 2.18 [14 66] [17 63]] [7722 3.04 [791 6.34 [17 79] [17 44]] [17 94]]] [17 26]] [14 64]] [19 72]] [17 94]] [1919 1.46 [3732 4.73 [5383 7.62 [6591 8.86 [724 3.79 [5345 1.09 [5316 2.04 [4806 4.93 [17 100] [17 77]] [17 55]] [17 80]] [17 72]] [17 60]] [17 62]] [17 44]] [17 100]]]]] [7516 0.463 [4391 0.982 [5701 0.633 [4703 5.7 [6073 13.4 [362 0.686 [695 16.2 [1068 1.12 [6732 7.18 [2128 1.23 [5360 2.89 [134 1.17 [392 0.472 [1078 14.7 [5170 4.99 [19 36] [5170 16.7 [1783 10.2 [5174 3.96 [26 70] [26 93]] [26 50]] [26 41]]] [26 77]] [2749 4.63 [384 1.96 [26 62] [26 92]] [26 62]]] [26 91]] [33 90]] [26 66]] [26 100]] [33 55]] [14 100]] [33 44]] [26 100]] [33 84]] [33 100]] [26 92]] [1888 17.4 [4571 1.66 [4604 2.72 [7512 5.49 [26 93] [26 100]] [26 83]] [26 77]] [26 72]]]] [1151 0.491 [4154 1.71 [5904 0.214 [3519 0.09 [5662 0.483 [2913 0.603 [3865 0.28 [377 1.35 [4805 0.32 [7548 0.617 [4986 3.39 [410 0.43 [6205 1.39 [685 3.28 [7006 2.38 [4222 0.162 [710 2.04 [7718 3.7 [6395 0.234 [724 2.43 [3917 3.65 [6439 1.05 [968 0.498 [5430 0.971 [6544 0.775 [2331 1.09 [6358 0.718 [7009 9.06 [3675 2.82 [3929 4.8 [1587 0.353 [731 1.96 [7354 6.41 [2842 2.17 [906 3.32 [2846 8.23 [4424 3.39 [6177 2.51 [7734 6.1 [7512 20.9 [1007 4.1 [2966 0.417 [6312 3.33 [4478 11.5 [5509 6.34 [7598 0.32 [17 39] [17 50]] [17 69]] [17 95]] [35 53]] [38 50]] [17 75]] [14 61]] [18 26]] [19 50]] [17 50]] [14 53]] [37 37]] [5 60]] [7 84]] [3905 3.61 [957 0.452 [649 0.754 [2760 3.64 [17 85] [17 42]] [17 90]] [17 50]] [6550 2.22 [3332 0.931 [6239 6 [7176 2.91 [6910 0.528 [21 7.47 [2636 18.1 [1063 1.45 [663 19.3 [7722 6.48 [4479 9.54 [1429 64.6 [1888 2.81 [6732 9.48 [144 3.35 [722 2.64 [17 64] [17 40]] [17 100]] [17 50]] [5412 0.57 [17 40] [14 50]]] [5 53]] [7 75]] [7 47]] [17 35]] [35 26]] [4 42]] [19 55]] [35 38]] [7 100]] [7 77]] [35 62]] [2826 12.2 [6732 10.7 [7381 3.33 [17 92] [17 68]] [17 55]] [17 25]]]]] [145 1.07 [134 1.23 [14 26] [17 44]] [19 57]]] [3458 1.15 [12 53] [5 44]]] [5 36]] [5 52]] [7068 0.858 [2526 8.17 [35 87] [17 37]] [7526 3.04 [5462 1.12 [144 7.19 [2966 0.551 [4762 0.723 [4741 1.04 [3014 3.85 [17 92] [17 55]] [17 42]] [17 100]] [17 71]] [17 62]] [38 57]] [17 33]]]] [2753 1.6 [32 42] [36 50]]] [2902 0.921 [14 92] [14 57]]] [5 82]] [3912 0.478 [32 38] [38 73]]] [2910 1.47 [19 53] [38 71]]] [1429 17.9 [19 41] [7 38]]] [5952 1.03 [998 1.81 [436 0.561 [7712 1.7 [17 65] [17 100]] [17 83]] [16 33]] [485 5.52 [17 50] [19 33]]]] [6791 7.36 [6929 1.03 [7734 1.29 [2541 1.62 [724 9.82 [647 0.117 [7711 1.1 [6727 1.91 [5812 0.345 [7241 0.782 [602 2.13 [6230 4.17 [0 33] [1062 3.4 [17 62] [17 86]]] [17 43]] [14 33]] [6549 3.99 [17 85] [17 100]]] [17 87]] [2826 9.02 [17 100] [17 66]]] [17 100]] [19 50]] [16 37]] [7 28]] [14 50]] [17 61]]] [2259 1.25 [7 66] [7 100]]] [14 100]] [1911 0.524 [3732 5.32 [3915 0.589 [5 66] [4571 2.02 [5154 0.391 [3317 3.16 [4588 14.9 [1239 9.5 [5743 0.296 [6581 13.3 [5843 2.73 [2752 22.9 [1993 0.362 [2752 20.1 [896 9.92 [663 1.7 [17 88] [2259 9.82 [17 100] [17 85]]] [17 80]] [17 83]] [17 100]] [7384 4.26 [17 100] [14 50]]] [17 62]] [728 2.93 [3928 4.52 [6550 2.3 [17 83] [17 100]] [1690 5.53 [11 44] [17 92]]] [14 42]]] [17 100]] [17 40]] [14 57]] [17 60]] [7722 1.29 [17 88] [17 100]]] [6 50]]] [17 55]] [7381 4.98 [17 100] [17 90]]]] [7 34]] [896 3.81 [731 4.91 [18 48] [7 52]] [688 1.36 [7 81] [7 100]]]] [695 1.72 [18 78] [14 76]]] [7 100]] [724 0.73 [35 57] [35 100]]] [968 5.35 [14 69] [32 100]]] [6074 0.0814 [3381 1.05 [5281 0.42 [695 3.4 [2829 5.64 [7512 10.7 [1906 0.198 [1704 5.94 [6732 4.18 [7677 0.233 [134 2.99 [144 4.83 [17 83] [19 42]] [38 54]] [38 46]] [19 77]] [17 71]] [5 50]] [5509 3.77 [3733 0.713 [978 19.4 [4805 11.2 [723 1.84 [17 71] [17 56]] [19 42]] [38 41]] [16 25]] [19 61]]] [19 80]] [929 3.68 [1011 6.91 [1690 1.82 [791 13 [485 0.818 [929 1.83 [21 1.29 [17 47] [17 50]] [16 33]] [17 83]] [17 85]] [2752 15.1 [17 100] [17 87]]] [17 40]] [19 63]]] [17 100]] [19 84]] [5673 1.41 [6978 0.117 [5637 2.92 [4479 6.31 [5285 6.14 [7381 5.52 [4225 1.75 [1899 1.69 [17 100] [6395 2.27 [17 87] [17 100]]] [17 83]] [731 13.6 [17 87] [17 66]]] [17 100]] [17 62]] [17 60]] [17 100]] [17 61]]]] [7067 0.792 [14 73] [695 12.4 [7 100] [7 62]]]] [4218 0.28 [17 97] [17 100]]] [6671 0.778 [6877 0.747 [5219 0.703 [5632 1.26 [353 0.814 [978 1.82 [2628 3.33 [6403 2.3 [5034 0.502 [7 51] [32 96]] [32 100]] [5 50]] [7 77]] [7 100]] [7 100]] [0 100]] [7 50]] [0 100]]] [5851 2.69 [7428 0.509 [6980 0.102 [1011 2.88 [6977 0.728 [1429 35.2 [19 23] [7251 0.251 [5509 1.1 [567 2.28 [38 62] [17 100]] [17 50]] [17 83]]] [17 45]] [663 5.32 [4896 0.171 [3734 0.245 [17 89] [17 100]] [17 100]] [17 50]]] [1570 0.559 [2567 2.85 [3915 0.211 [17 71] [663 3.65 [4222 1.87 [17 57] [17 90]] [17 100]]] [17 57]] [17 100]]] [17 50]] [17 40]]] [7057 0.223 [4776 1.38 [6550 8.39 [1183 0.737 [5523 0.27 [7682 1.83 [1429 34.8 [19 89] [19 100]] [19 71]] [19 100]] [19 85]] [19 71]] [19 75]] [19 50]]] [6723 2.72 [6530 0.808 [1400 1.17 [5905 1.58 [7354 2.13 [736 1.98 [1557 0.992 [6550 1.76 [573 0.186 [7381 1.52 [978 13.2 [663 7.55 [19 66] [1838 1.04 [14 40] [17 50]]] [19 88]] [19 82]] [19 95]] [17 60]] [19 92]] [5157 10.6 [23 0.423 [1078 3.42 [19 100] [19 50]] [7241 1.72 [5819 0.137 [3929 0.423 [3905 8.29 [5677 0.559 [19 100] [19 87]] [19 75]] [19 100]] [19 100]] [19 77]]] [19 75]]] [7 54]] [2570 0.281 [724 0.401 [695 1.02 [19 85] [19 100]] [19 100]] [19 100]]] [14 100]] [7 85]] [14 71]]] [4170 0.303 [4801 0.543 [1704 0.867 [2259 2.55 [7253 0.678 [2570 1.28 [4160 1.15 [7354 0.855 [6382 1.11 [721 1.39 [7127 3.08 [695 8.98 [688 5.23 [21 0.672 [1011 4.21 [2760 0.971 [5192 0.16 [17 55] [5 44]] [17 60]] [17 27]] [19 42]] [7 100]] [14 57]] [17 75]] [14 100]] [14 72]] [7 90]] [2241 0.165 [4218 1.28 [17 77] [17 90]] [17 50]]] [4218 8.06 [7381 2.99 [4279 6.13 [4478 0.917 [17 59] [17 50]] [17 100]] [17 100]] [17 51]]] [3014 0.17 [1911 0.312 [728 1.17 [17 33] [728 4.55 [19 100] [19 50]]] [7689 3.56 [17 41] [17 63]]] [1899 5.26 [7711 1.06 [7512 11.8 [19 100] [19 72]] [17 50]] [33 33]]]] [688 1.06 [378 0.596 [5640 1.43 [4484 0.633 [5730 0.77 [6077 0.767 [7512 1.22 [34 32] [6809 2.22 [2616 1.08 [5472 1.64 [2260 5.79 [5034 0.959 [4663 1.87 [19 35] [7 66]] [7542 1.33 [14 61] [32 100]]] [14 93]] [36 83]] [4154 5.11 [5 45] [7 30]]] [32 100]]] [7 100]] [32 100]] [38 90]] [14 86]] [7 100]] [6310 0.312 [7354 1.37 [7 72] [7 100]] [7 60]]]] [4414 0.894 [1078 5.17 [567 3.24 [17 100] [17 85]] [5198 0.761 [978 16.5 [7665 8.28 [17 100] [7665 13.8 [17 58] [17 75]]] [17 54]] [17 29]]] [4587 0.318 [17 91] [17 100]]]] [5693 0.392 [32 88] [32 100]]] [883 1.11 [4991 3.04 [2846 0.348 [4558 0.982 [4288 4.35 [126 0.907 [4279 6.09 [2331 0.705 [2913 1.23 [429 20 [32 62] [32 88]] [32 100]] [32 100]] [32 100]] [32 100]] [32 85]] [32 100]] [32 100]] [32 80]] [32 66]]]] [1769 0.201 [1652 0.587 [1703 0.484 [1745 0.703 [5129 1.22 [828 0.754 [3563 0.196 [3014 5.2 [663 1.55 [14 24] [5034 1 [1201 0.696 [3929 0.325 [4851 1.53 [19 24] [2199 0.25 [957 1.01 [7413 0.571 [695 0.562 [17 46] [17 70]] [17 100]] [17 100]] [17 100]]] [7210 0.355 [17 70] [17 92]]] [16 41]] [6230 5.27 [32 83] [14 83]]]] [19 45]] [3415 1.15 [17 40] [19 100]]] [7 65]] [6230 5.45 [38 62] [38 93]]] [6732 5.47 [573 0.181 [6382 0.467 [17 100] [19 45]] [17 100]] [19 46]]] [5662 0.275 [6547 1.08 [1980 0.945 [3794 0.931 [1783 2.62 [3822 1.03 [17 60] [19 100]] [17 69]] [19 85]] [19 95]] [14 100]] [3078 0.327 [6599 1.15 [6598 1.07 [19 40] [19 100]] [19 70]] [5969 0.649 [19 62] [19 100]]]]] [35 84]] [4805 0.209 [5154 1.07 [6591 0.325 [3554 0.942 [7 25] [7 33]] [19 43]] [38 83]] [3519 0.453 [7203 0.894 [6575 1.52 [17 76] [7169 2.08 [17 1.25 [38 66] [19 66]] [17 40]]] [19 100]] [573 1.82 [494 0.142 [3014 2.98 [19 100] [19 66]] [6413 0.726 [733 2.23 [19 100] [1919 0.399 [19 80] [19 100]]] [19 57]]] [19 75]]]]]]]] [4417 1.5 [6983 0.143 [3606 0.228 [4522 0.196 [4154 8.5 [7512 1.12 [1 2.25 [673 1.98 [1405 0.16 [4369 2.23 [2394 1.92 [6457 0.283 [5731 0.126 [5827 0.193 [5270 1.48 [2526 4.41 [3442 0.232 [5110 1.43 [5589 0.861 [3909 0.376 [6471 0.726 [221 1.24 [4702 3.6 [1125 0.759 [3763 1.28 [5829 2.56 [6713 0.278 [811 0.596 [3051 0.795 [741 1.72 [6230 0.123 [5501 0.539 [6498 0.6 [7411 0.703 [7461 8.13 [4011 7.01 [5211 7.82 [3139 1.84 [5509 8.87 [826 3.09 [338 21.3 [3336 4.66 [6505 14.6 [7295 3.46 [2008 4.37 [4964 0.741 [3292 2.39 [6915 1.49 [3963 33.4 [2911 3.65 [5972 5.75 [429 39.2 [5345 1.94 [6294 10.3 [1609 0.979 [7449 26.8 [392 8.36 [2073 5.29 [978 9.19 [4414 28.4 [2199 0.945 [1429 1.55 [1400 9.82 [3027 56.1 [15 24] [4 92]] [15 87]] [5753 4 [715 3.7 [1400 1.14 [7058 2.88 [4200 1.41 [1841 1.84 [2055 0.133 [2054 8.28 [144 2.75 [4398 2.76 [3095 4.35 [3008 2.43 [2470 18.5 [328 0.907 [30 33] [4 26]] [15 20]] [3 30]] [15 50]] [1980 10.4 [30 37] [30 85]]] [30 63]] [33 50]] [25 37]] [33 42]] [30 57]] [30 54]] [15 79]] [15 100]] [4 30]]] [2055 1.48 [1783 1.49 [29 20] [25 40]] [19 33]]] [2760 4.35 [2913 5.49 [15 82] [15 100]] [15 66]]] [4 78]] [1 85]] [1400 5.22 [15 28] [25 56]]] [15 93]] [24 64]] [30 38]] [2752 1.45 [30 65] [30 42]]] [312 9.31 [11 29] [11 61]]] [6665 0.684 [31 54] [12 94]]] [2072 3.65 [3807 9.11 [21 57] [10 100]] [10 100]]] [11 100]] [15 97]] [11 100]] [4 91]] [11 100]] [31 100]] [11 100]] [11 100]] [26 88]] [7451 4.88 [6184 27.2 [15 74] [15 57]] [15 100]]] [26 53]] [11 93]] [7665 1.9 [5082 2.67 [30 58] [11 100]] [30 76]]] [15 100]] [15 67]] [4666 1.6 [4235 0.902 [4414 1.25 [15 85] [660 1.21 [15 99] [15 100]]] [15 66]] [15 100]]] [25 100]] [30 100]] [2826 1.83 [4630 1.99 [30 41] [25 50]] [4 55]]] [11 100]] [1116 32 [30 100] [2472 31.3 [30 100] [30 71]]]] [2081 1.21 [7455 5.05 [15 77] [15 75]] [12 50]]] [30 95]] [11 100]] [15 96]] [11 100]] [30 100]] [4611 2.48 [1576 0.268 [2628 0.32 [1429 28.6 [2752 22.9 [5225 9.6 [3742 0.803 [4061 2.96 [30 37] [30 55]] [30 88]] [30 100]] [15 37]] [30 71]] [4312 1.71 [1429 2.56 [30 100] [2259 21.6 [2993 2.59 [30 58] [30 100]] [4210 3.23 [30 86] [30 100]]]] [30 100]]] [11 37]] [29 47]]] [4571 1.55 [26 69] [26 100]]] [15 100]] [30 99]] [7322 0.627 [859 0.341 [6155 0.47 [2268 1.78 [3459 0.588 [1404 1.04 [6711 1.59 [2381 2.42 [7249 1.47 [5122 0.931 [1078 18.2 [355 5.15 [2914 1.89 [5007 0.835 [3008 3.18 [15 71] [30 100]] [15 85]] [30 100]] [30 100]] [2808 2.99 [4851 1.82 [5883 2.55 [1899 13.2 [30 23] [11 100]] [11 100]] [30 85]] [15 100]]] [6859 1.86 [2630 1.48 [5211 17.6 [30 88] [30 100]] [30 100]] [30 100]]] [30 100]] [30 100]] [4154 1.32 [30 100] [30 77]]] [15 100]] [15 100]] [30 100]] [7411 0.84 [5225 20.9 [30 88] [30 91]] [15 100]]] [4205 1.32 [6859 1.01 [5223 1.02 [6713 0.683 [221 0.606 [30 93] [30 100]] [30 100]] [11 100]] [30 100]] [30 63]]] [30 100]]] [11 100]] [2205 1.74 [2739 1.37 [2259 12.6 [4611 9.09 [1239 20.8 [1023 1.66 [25 50] [1025 0.374 [4 58] [4 100]]] [21 47]] [31 90]] [663 0.149 [25 20] [26 55]]] [4 90]] [12 42]]] [4398 2.68 [1997 0.785 [2100 0.239 [2299 0.697 [4 35] [4 60]] [4 50]] [25 23]] [4904 0.258 [4398 7.4 [2178 0.913 [31 87] [31 76]] [31 100]] [31 100]]]] [826 0.763 [967 1.09 [2480 0.386 [7444 1.49 [11 96] [11 100]] [11 100]] [11 100]] [11 100]]] [11 100]] [25 100]] [2470 1.58 [30 71] [2628 0.131 [7085 2.24 [5386 0.405 [2093 1.5 [4414 0.536 [30 88] [22 40]] [6648 9.14 [30 100] [30 81]]] [30 100]] [30 100]] [30 100]]]] [4412 1.18 [6665 5.65 [2639 2.79 [2380 0.867 [6614 0.226 [7085 4.58 [4790 1.18 [15 76] [31 75]] [15 93]] [15 100]] [31 100]] [31 100]] [12 93]] [31 100]]] [15 100]] [6620 1.11 [510 1.06 [1420 0.745 [384 2.38 [2764 1.94 [6528 3.45 [6184 1.03 [1429 21.3 [26 58] [25 46]] [25 100]] [25 100]] [25 66]] [26 63]] [25 100]] [2470 16.6 [26 68] [26 100]]] [25 100]]] [7007 1.21 [4446 0.77 [2480 0.154 [6290 0.191 [1400 1.63 [791 5.05 [5343 0.724 [30 47] [25 42]] [792 0.287 [5110 3.18 [5082 0.982 [11 79] [11 100]] [11 55]] [7428 1.55 [11 100] [11 77]]]] [5692 0.542 [15 79] [15 90]]] [11 100]] [11 100]] [31 100]] [25 100]]] [5007 4.36 [6457 0.138 [4601 1.01 [5225 0.561 [828 1.84 [896 1.27 [5978 0.536 [2755 0.579 [5255 0.677 [7381 0.575 [1980 2.53 [4701 1.39 [7295 0.873 [673 1.45 [5480 6.48 [5270 0.81 [5403 1.72 [1239 14.1 [1587 0.288 [2742 2.13 [7664 7.97 [178 2.01 [7044 2.46 [685 1.08 [826 3.35 [7340 2.76 [6074 0.952 [6619 3.7 [5812 1.41 [5211 0.978 [5993 9.52 [7324 3.04 [6732 9.01 [6177 2.2 [3931 16.2 [4721 9.23 [4799 0.615 [7185 13.2 [2846 0.741 [7491 5.38 [1899 18.6 [939 6.79 [2445 0.424 [6552 3.6 [663 1.67 [31 27] [14 27]] [4 100]] [30 37]] [31 71]] [31 78]] [31 50]] [4 50]] [4 83]] [15 55]] [4 100]] [4 36]] [25 81]] [4 56]] [4 100]] [31 100]] [30 89]] [4 83]] [25 100]] [733 1.66 [15 52] [4 100]]] [32 69]] [15 90]] [26 33]] [25 100]] [25 63]] [31 83]] [4 84]] [148 2.99 [392 0.865 [30 40] [30 84]] [30 100]]] [6514 0.644 [6 38] [6 85]]] [31 100]] [5603 0.945 [4154 7.26 [3357 2.73 [5152 0.623 [6298 0.956 [429 2.7 [31 81] [31 100]] [31 100]] [31 100]] [31 100]] [31 71]] [31 100]]] [4533 3.88 [732 3.55 [1011 4.42 [5692 3.76 [26 81] [26 100]] [26 100]] [26 100]] [26 71]]] [7007 0.483 [673 24.8 [719 1.72 [4851 0.693 [1429 8.22 [25 92] [25 81]] [26 88]] [26 81]] [26 71]] [25 100]]] [31 100]] [30 100]] [2005 1.37 [789 0.613 [6918 2.77 [1922 0.518 [392 4.65 [2808 0.649 [4953 1.07 [7008 1.41 [31 16] [25 100]] [31 100]] [15 84]] [25 92]] [10 100]] [31 100]] [31 100]] [5267 1.67 [6184 2.36 [25 68] [25 87]] [25 55]]]] [6980 2.67 [736 1.46 [2470 2.25 [4 55] [5769 1.22 [2608 3.82 [7588 5.65 [791 9.58 [4 92] [4 40]] [4 100]] [4 87]] [4 100]]] [4 100]] [4 66]]] [10 100]] [5637 4.58 [6363 0.562 [5851 2.38 [2764 1.14 [7187 1.3 [879 1.75 [6182 1.11 [2929 1.52 [736 0.699 [4377 0.705 [25 81] [25 100]] [26 66]] [25 100]] [25 100]] [25 100]] [26 95]] [25 87]] [25 100]] [25 100]] [25 100]]] [31 100]] [184 0.222 [5239 0.388 [4613 0.692 [1025 1.87 [4414 7.3 [5079 0.608 [392 0.455 [6997 1.65 [6178 0.968 [7585 1.31 [7711 1.5 [5574 0.242 [5270 1.17 [5320 1.55 [7571 1.04 [6131 2.11 [7561 3.23 [7241 3.99 [2470 10.7 [269 1.87 [1089 2.21 [4 24] [4 92]] [26 100]] [7428 5 [4533 1.94 [6294 1.42 [6550 0.73 [4 66] [4 83]] [4 20]] [31 30]] [26 62]]] [4 100]] [4 40]] [26 77]] [31 100]] [31 90]] [31 100]] [23 16.6 [7665 17.9 [4 60] [4 100]] [4 100]]] [26 84]] [31 96]] [25 100]] [896 13.3 [31 88] [31 83]]] [4369 1.31 [7203 3.24 [221 2.06 [5692 3.7 [26 75] [26 100]] [25 52]] [26 100]] [25 100]]] [25 88]] [248 5.41 [2526 11.4 [31 55] [31 100]] [25 50]]] [5509 0.85 [2605 3.67 [7085 0.522 [7381 0.482 [7516 1.58 [2526 7.4 [4 51] [1025 3.75 [4 50] [4 93]]] [26 66]] [434 0.423 [939 1.04 [429 26.8 [4 67] [1980 2.47 [4 95] [4 83]]] [4 100]] [5281 1.05 [7665 8.31 [4 100] [4 87]] [4 100]]]] [1980 1.57 [8 45] [2 42]]] [26 87]] [4 37]]] [791 6.31 [26 66] [26 88]]] [178 3.22 [4 100] [4 85]]] [4377 0.421 [5079 0.222 [7712 0.269 [4235 1.09 [25 63] [5412 1.51 [25 81] [25 100]]] [4 58]] [25 100]] [25 100]]]] [2259 5.29 [6545 1.57 [5972 2.92 [31 46] [31 100]] [31 100]] [31 100]]] [1980 2.56 [7241 0.339 [7645 0.759 [7695 0.787 [30 97] [30 100]] [30 100]] [30 100]] [2752 12.1 [30 100] [30 75]]]] [5812 2.58 [6184 1.59 [6732 1.86 [685 0.826 [25 35] [3008 0.75 [26 88] [26 66]]] [1239 1.47 [392 3.32 [26 100] [7665 7.78 [673 7.32 [26 85] [26 60]] [26 100]]] [26 66]]] [3008 2.69 [31 50] [25 88]]] [4 63]]] [6537 1.39 [232 0.138 [791 0.805 [7665 7.1 [25 100] [25 87]] [25 100]] [25 100]] [25 76]]] [1025 2.18 [5509 2.02 [4079 1.03 [7101 3.34 [248 17.3 [1769 6.58 [15 77] [15 100]] [202 1.18 [5692 6.53 [1429 3.73 [232 0.569 [26 74] [25 100]] [25 60]] [26 88]] [25 100]]] [26 54]] [31 100]] [26 73]] [2755 1.12 [7722 4.51 [4 51] [4 100]] [26 92]]]]] [4283 0.16 [2701 3.66 [5819 0.741 [3105 1.21 [2323 0.928 [791 16.3 [394 2.7 [7395 5.34 [4079 0.639 [771 0.615 [2628 8.3 [5693 1.6 [2473 1.93 [1679 1.25 [6524 0.87 [939 10.4 [731 2.64 [4420 2.73 [7665 2.77 [1 7.54 [7172 4.42 [4564 0.104 [1410 1.89 [5412 0.256 [4154 12.4 [1239 12.4 [15 20] [10 33]] [663 23.1 [7480 5.52 [5270 5.23 [4168 2.67 [2064 2.84 [328 1.28 [15 49] [15 19]] [25 44]] [15 89]] [31 90]] [15 100]] [15 40]]] [30 25]] [15 100]] [30 81]] [31 100]] [11 88]] [5034 1.17 [15 25] [4851 1.25 [32 93] [32 100]]]] [15 100]] [728 2.28 [4 42] [31 88]]] [27 44]] [25 75]] [30 91]] [15 100]] [4 63]] [2641 5.05 [4 40] [31 100]]] [25 100]] [4414 2.16 [31 96] [31 100]]] [32 100]] [26 59]] [2225 0.39 [7411 4.66 [5647 15.8 [3480 1.81 [4179 2.16 [7411 1.24 [978 3.79 [15 45] [4 54]] [15 70]] [15 100]] [15 94]] [4 38]] [15 100]] [11 43]]] [32 100]] [30 70]] [6074 0.699 [4 97] [4 100]]] [3931 2.92 [2814 2.23 [715 1.96 [15 92] [15 100]] [32 50]] [32 57]]] [2913 16.7 [1899 13.5 [1239 2.11 [1170 1.74 [7623 31.9 [1110 0.639 [3484 0.635 [4414 25.6 [7654 12.5 [2701 2.04 [590 2.73 [2760 0.575 [2475 1.47 [2444 2.47 [15 99] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 88]] [4429 13.2 [15 89] [15 97]]] [15 100]] [15 100]] [12 57]] [15 85]] [15 100]] [15 88]] [15 75]]]] [5824 0.283 [1888 1.63 [5211 1.95 [11 82] [11 100]] [4 58]] [11 100]]] [2950 13.4 [15 100] [15 91]]] [734 0.467 [2259 8.28 [7308 0.589 [7575 1.26 [5393 10.5 [1078 76.3 [4768 19.9 [6379 0.159 [5820 0.43 [597 3.7 [1594 8.07 [4611 6.94 [2148 3.04 [3566 6.58 [4159 1.09 [5447 5.82 [2752 39.6 [7185 0.234 [43 0.327 [7168 6.07 [5972 1.37 [5423 2.8 [23 3.24 [5879 2.92 [6582 5.78 [7169 11.8 [6983 29.7 [723 2.66 [5660 9.62 [4 97] [4 77]] [4 88]] [2628 3.7 [4 98] [4 100]]] [4 85]] [4 88]] [4 63]] [4 92]] [4 85]] [31 80]] [4 57]] [1023 4.3 [2178 0.327 [7520 2.17 [1429 36.4 [4 100] [4 88]] [4 94]] [4 100]] [4 90]]] [1023 0.359 [7449 0.563 [647 2.96 [4 100] [4 87]] [4 100]] [4 100]]] [4 71]] [4 66]] [4 88]] [4 60]] [4 50]] [4 55]] [4 66]] [31 100]] [5413 8.24 [24 0.759 [5820 3.76 [1069 3.46 [4690 0.657 [134 0.39 [2478 3.72 [4 100] [2616 3.47 [4 92] [4 100]]] [4 100]] [4 100]] [4 85]] [4 100]] [4 87]] [4 85]]] [4 50]] [4 66]] [4 60]] [4 60]] [31 100]] [2081 0.786 [1783 12.9 [31 100] [31 70]] [31 100]]] [7571 0.551 [7381 0.136 [6784 0.775 [2977 2.5 [2526 13.8 [1713 1.17 [2939 9.2 [1980 4.37 [6997 2.08 [2484 0.564 [985 1.27 [31 69] [4 75]] [4 100]] [31 89]] [4279 1.18 [4 55] [4 57]]] [2684 1.23 [4 52] [4 100]]] [31 100]] [6074 10.4 [435 1.39 [1899 16.8 [1888 2.76 [5240 1.37 [4 70] [4 100]] [4 94]] [4 50]] [4 44]] [31 76]]] [31 100]] [31 100]] [2763 0.461 [5812 5.05 [7588 1.32 [43 1.69 [2241 0.166 [4 100] [4 50]] [4 100]] [4 100]] [25 0.963 [2478 10.8 [6732 9.01 [4 100] [4 62]] [4 70]] [4 100]]] [4 100]]] [31 100]]] [31 100]]] [6367 3.22 [3443 0.756 [6287 0.506 [2616 0.688 [6544 2.15 [5231 1.55 [1888 4.53 [4168 9.11 [2048 3.82 [2232 1.1 [3182 1.85 [5323 17.1 [7461 0.246 [2526 3.58 [5927 0.635 [3884 0.629 [4771 0.456 [2763 9.64 [5267 9.35 [628 2.11 [4424 25 [5462 1 [1025 0.165 [3459 1.08 [1253 0.736 [3027 15.4 [3304 1.47 [826 0.747 [5192 0.573 [1400 1.59 [15 61] [1062 7.21 [15 100] [15 88]]] [15 100]] [15 100]] [15 100]] [15 90]] [15 100]] [15 100]] [15 100]] [15 100]] [11 50]] [15 77]] [15 66]] [15 83]] [15 100]] [15 100]] [15 100]] [4 42]] [15 100]] [15 83]] [15 80]] [15 84]] [15 45]] [15 66]] [12 80]] [11 100]] [31 90]] [4 81]] [6921 0.994 [11 81] [11 100]]] [11 100]] [4 100]]]] [4253 0.129 [2562 1.53 [4959 0.196 [2820 1.14 [6539 0.514 [5446 0.32 [5295 1.69 [5732 0.108 [494 0.393 [6927 1.18 [7020 0.293 [312 0.333 [2526 6.11 [5049 0.327 [978 9.05 [5571 0.487 [7182 0.821 [569 0.856 [5662 0.455 [4929 1.06 [535 3 [4336 0.699 [6582 1.1 [5047 2.02 [7544 4.79 [2752 11.7 [5548 2.96 [1069 1.7 [6078 8.19 [5693 9.04 [5919 5.08 [6076 10.4 [2055 1.76 [2897 4.11 [4611 4.89 [4883 5.95 [2628 20.6 [7015 0.938 [7413 9.03 [5999 9.85 [435 2.73 [5911 0.434 [4326 1.03 [1047 6.29 [1239 70 [2 20] [3 57]] [2 28]] [12 50]] [15 33]] [35 46]] [2259 16 [28 35] [2 23]]] [33 50]] [9 85]] [4 66]] [31 85]] [5 53]] [1 37]] [2 55]] [24 87]] [9 90]] [2 72]] [31 80]] [4 100]] [9 100]] [202 1.19 [2763 0.752 [6983 2.18 [4851 0.585 [4159 13 [7428 1.14 [434 1.56 [5753 10.8 [2764 0.593 [2470 3.36 [2 30] [7449 2.93 [15 60] [15 88]]] [2 36]] [23 50]] [22 55]] [12 60]] [2 75]] [2 16]] [4 83]] [6732 0.931 [17 36] [22 37]]] [15 62]]] [2 81]] [3 100]] [4 100]] [35 100]] [21 100]] [639 0.343 [3130 0.975 [4768 0.234 [7210 3.22 [4 28] [22 50]] [4 93]] [4 40]] [4 100]]] [22 53]] [429 95.4 [2993 2.06 [3 60] [21 60]] [21 100]]] [22 100]] [22 100]] [4338 23.5 [4930 3.1 [5154 5.29 [6074 0.954 [1190 10.3 [5411 1.83 [2023 1.42 [23 9.09 [2826 0.35 [685 0.882 [1025 39.8 [4833 19.6 [2 23] [35 38]] [2 92]] [8 37]] [4 64]] [2 53]] [2 75]] [23 83]] [2 80]] [6988 0.6 [7512 7.85 [2 58] [2 75]] [2 100]]] [19 75]] [4 25]] [2 100]]] [572 1.36 [6261 1.14 [520 1.83 [9 70] [21 82]] [21 100]] [9 100]]] [1429 31.5 [392 0.518 [7414 2.65 [573 1.43 [2647 1.42 [2361 1.29 [6984 0.907 [912 1.11 [527 11 [6982 6.39 [2802 4.95 [6991 0.236 [1993 9.6 [7266 4.1 [2453 1.08 [3905 1.11 [2535 0.559 [1072 0.188 [429 66.1 [7588 0.998 [2939 19.4 [4503 9.8 [5969 0.935 [2062 2.56 [4288 23.6 [5480 5.63 [655 3.24 [5693 3.76 [5576 2.15 [7544 29.4 [1899 21.8 [23 10.4 [2 60] [2 76]] [2 93]] [4 60]] [134 1.74 [2753 5.75 [2 93] [2 100]] [2 100]]] [5345 0.419 [2752 31.2 [2 85] [2 40]] [2 33]]] [2 84]] [2 27]] [4 30]] [2 50]] [2 45]] [2 58]] [4 87]] [7512 21.7 [4 44] [4 80]]] [21 66]] [5660 5.11 [7292 5.66 [7544 0.188 [2 93] [2 100]] [2 66]] [2 75]]] [2 81]] [7665 9.66 [2 33] [17 55]]] [24 83]] [2 88]] [2 33]] [2 100]] [4 33]] [1078 4.35 [4 75] [4 90]]] [4 68]] [21 61]] [4 100]] [8 100]] [4 95]] [7588 1.51 [6186 1.15 [1076 0.986 [1051 2.07 [7722 4.36 [4 41] [2 32]] [3667 1.15 [2 60] [2 100]]] [2 53]] [2 92]] [4 100]]] [1068 0.921 [7544 4.79 [4226 3.56 [2 79] [4 42]] [7512 19 [2 100] [2 88]]] [2 88]]] [23 47]] [228 4.16 [2616 1.05 [685 0.773 [4184 1.02 [5 19] [5 75]] [23 55]] [5 65]] [2 71]]]] [7132 0.276 [6983 0.295 [2939 9.66 [6735 0.48 [6538 0.763 [6653 2.23 [6347 0.527 [5192 2.32 [2779 4.41 [2905 4.06 [2939 0.382 [5403 4.64 [913 0.64 [6367 1.25 [1025 11.5 [7623 0.715 [6791 0.595 [4 51] [2 28]] [4 62]] [2 68]] [4 100]] [4 83]] [31 100]] [1011 4.98 [4 80] [31 42]]] [2 83]] [2 75]] [1919 1.5 [2 47] [2 56]]] [8 36]] [4 64]] [2 100]] [4154 18.6 [2 76] [2 50]]] [144 1.57 [2 86] [2 100]]] [4338 0.295 [6077 0.867 [4 76] [31 85]] [4 93]]] [4 96]]] [2526 26.8 [1062 0.293 [7512 13.9 [4 100] [4 66]] [4 83]] [4 75]]] [4154 9.15 [6988 1.17 [736 1.09 [2647 1.26 [2616 3.2 [2628 10.4 [3670 3.53 [7185 1.56 [1062 6.79 [978 11.2 [2 89] [1000 0.485 [2 73] [2 80]]] [2 50]] [2 40]] [2 50]] [4 77]] [1025 5.19 [4 76] [2 62]]] [4 100]] [4 71]] [2 95]] [7512 15.9 [2628 4.06 [2 76] [5665 0.615 [7009 1.97 [1640 0.866 [2 88] [2 100]] [2 85]] [2 100]]] [2 64]]]] [7253 0.657 [7512 15.1 [1429 15.1 [2 30] [5662 1.95 [17 100] [17 86]]] [2752 18.9 [17 63] [38 46]]] [1567 0.29 [17 50] [19 88]]]] [5969 0.216 [3905 0.823 [4279 0.157 [1888 1.5 [4585 1.08 [520 2.67 [24 41] [15 66]] [24 100]] [24 88]] [3 33]] [15 60]] [978 7.58 [17 76] [19 50]]]] [731 2.76 [2 28] [5812 6.73 [4 58] [6074 11.6 [4 100] [4 83]]]]] [6260 17.9 [4832 1.87 [9 46] [4748 2.97 [9 94] [9 46]]] [9 44]]] [4418 0.785 [1079 3.71 [5660 8.24 [731 0.627 [5820 0.343 [1980 9.84 [2 100] [2 87]] [2 100]] [2 100]] [2 83]] [2 87]] [2 87]]] [5192 1.43 [2 93] [2 89]]] [17 8.05 [1445 1.38 [7197 2.18 [2964 2.63 [1769 1.06 [4 100] [4 95]] [4 83]] [4 87]] [4 87]] [4 85]]] [2321 0.73 [999 2.39 [8 44] [8 100]] [8 100]]] [574 1.1 [4960 0.322 [6735 0.25 [685 1.14 [7329 0.475 [6982 0.518 [7314 1.51 [6581 0.748 [23 9.95 [4663 20.4 [5198 6.05 [7441 5.62 [6939 1.74 [2202 0.926 [7035 0.677 [3879 0.121 [5198 2.91 [1911 3.67 [637 4.37 [4832 32.4 [1888 12.2 [4587 3.97 [6449 1.38 [2674 7.94 [4414 17 [5753 4.22 [292 14.1 [6088 0.33 [6294 0.282 [1076 8.11 [6184 1.82 [2 88] [7292 10.5 [2907 5.31 [667 0.416 [4262 1.35 [2 100] [2 71]] [2 100]] [2 85]] [2 85]]] [2 88]] [2 100]] [2 100]] [2 90]] [2 90]] [2 83]] [2 88]] [2 90]] [2 91]] [7414 0.283 [663 5.98 [2 100] [2 44]] [2 100]]] [2 80]] [2 78]] [5694 0.54 [2 100] [2 50]]] [6537 4.52 [2 38] [2 100]]] [2 85]] [2 76]] [2 57]] [2 55]] [2 33]] [2 50]] [4 57]] [6187 6.89 [5647 12.4 [2 70] [2 37]] [2 92]]] [17 64]] [2 41]] [4 66]] [2 40]] [23 55]] [1089 2.59 [3667 1.86 [2826 0.251 [1783 8.98 [818 0.893 [5847 0.186 [5692 6.88 [310 0.465 [1253 2.71 [2628 10.3 [430 1.34 [4835 5.06 [7512 19.1 [2 100] [2 83]] [2 80]] [2 85]] [2677 0.541 [2 96] [2 100]]] [2 91]] [2 75]] [6537 7.04 [2676 0.197 [6989 0.219 [2 44] [2 92]] [2 100]] [2 100]]] [4 71]] [2 71]] [2 60]] [4 57]] [1074 0.256 [4343 0.124 [6977 0.364 [1980 2.63 [4324 0.68 [2 95] [2 100]] [2 100]] [2 100]] [2 100]] [2 100]]] [144 1.53 [2 45] [7085 0.494 [1079 0.331 [2 90] [6791 2.54 [2 85] [2 57]]] [2 100]]]]] [4226 0.0927 [1429 20 [4 100] [4 83]] [4 100]]] [9 100]]]] [5197 3.42 [1911 3.12 [5192 13.7 [4154 21.4 [1402 0.142 [7456 0.473 [1062 0.275 [7455 17.8 [1980 0.498 [7241 0.599 [6550 0.34 [1429 1.87 [1888 1.77 [6542 3.72 [429 21.6 [12 100] [12 97]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 93]] [12 100]] [12 100]] [12 100]] [12 85]] [12 92]] [4154 4.1 [826 2.99 [12 100] [12 93]] [12 87]]] [12 83]]] [7601 8.07 [863 0.155 [6388 37.5 [13 100] [13 87]] [13 100]] [13 96]]] [3030 3.6 [1119 3.18 [6584 0.621 [4154 5.44 [5637 1.49 [3538 1.76 [4130 2.63 [5864 4.45 [1197 0.402 [3299 0.0998 [3106 2.35 [3041 4.06 [896 3.25 [5904 0.402 [4781 1.17 [3879 1.89 [3389 1.21 [1500 8.67 [2461 0.0744 [1913 15.2 [6643 0.517 [7343 2.19 [663 1.53 [2759 1.68 [6936 1.08 [4789 4.08 [1923 9.92 [6347 6.49 [2978 3.11 [3113 30.6 [4398 0.345 [5019 24.3 [7085 4.69 [826 0.649 [4101 5.5 [429 64.2 [6909 3.89 [479 2.47 [221 0.761 [3990 4.29 [939 12.7 [791 17.5 [2259 11.9 [722 0.843 [2787 0.501 [3317 0.503 [3301 9.79 [452 0.963 [3972 15.2 [3222 12.7 [4108 2.79 [1463 1.62 [7210 1.57 [3837 3.31 [3125 2.59 [1078 40.6 [3316 1.62 [37 97] [37 100]] [37 75]] [37 100]] [37 100]] [37 100]] [37 100]] [37 100]] [37 70]] [37 100]] [37 100]] [37 83]] [37 100]] [37 100]] [37 100]] [37 77]] [4071 7.87 [3182 4.59 [3128 8.55 [37 94] [37 86]] [37 100]] [37 87]]] [37 76]] [3907 0.885 [2775 0.668 [3997 0.864 [2753 16.9 [37 100] [37 83]] [37 100]] [37 100]] [37 100]]] [37 85]] [37 92]] [37 54]] [37 73]] [37 82]] [3548 12.6 [37 100] [37 88]]] [37 85]] [37 55]] [37 75]] [37 70]] [37 75]] [37 75]] [37 70]] [37 55]] [37 66]] [37 43]] [3499 5.17 [791 5.04 [37 94] [7210 4.78 [905 4.15 [2784 4.98 [1995 8.64 [3991 3.92 [3351 4.01 [4235 0.849 [3555 11.9 [3125 6.46 [3264 0.818 [3897 3.26 [3912 0.261 [5019 1.2 [1253 11 [1529 1.08 [4012 8.12 [3292 1.02 [663 29.8 [37 100] [3056 4.88 [37 100] [37 88]]] [37 100]] [37 83]] [37 100]] [37 91]] [37 90]] [37 100]] [37 91]] [37 100]] [3905 16.5 [37 100] [37 62]]] [37 75]] [37 100]] [37 83]] [37 90]] [37 90]] [37 90]] [37 77]] [37 93]]] [37 90]]] [3701 1.73 [37 86] [37 100]]] [37 66]] [37 60]] [27 83]] [37 70]] [35 75]] [706 4.03 [5412 1.17 [37 51] [37 50]] [37 96]]] [37 46]] [19 53]] [19 37]] [3103 1.32 [37 66] [35 70]]] [37 44]] [5015 3.63 [5656 1.49 [320 2.2 [5851 14 [3281 1.45 [3250 1.98 [3130 9.32 [791 1.72 [37 87] [6836 2.15 [4083 2.97 [5109 5.19 [155 6.59 [1488 0.676 [791 6.02 [50 0.394 [7343 0.754 [2143 0.0753 [145 2.49 [3897 0.456 [37 98] [37 100]] [37 71]] [37 100]] [37 77]] [37 100]] [619 0.278 [1063 4.12 [728 5.62 [3576 11.4 [826 7.2 [3748 6.42 [3159 2.9 [3088 15.8 [28 1.47 [3297 6.67 [37 100] [3464 13.4 [37 87] [37 100]]] [4414 5.56 [37 100] [37 80]]] [3296 2.96 [2752 31.3 [37 100] [37 83]] [37 100]]] [3159 4.71 [37 71] [3292 13.4 [37 77] [37 100]]]] [37 91]] [839 0.342 [37 97] [37 100]]] [37 93]] [37 80]] [37 50]] [37 75]]] [132 0.457 [695 30.7 [4414 0.216 [1535 0.365 [3779 0.268 [1507 6.14 [37 100] [37 97]] [37 100]] [37 100]] [37 100]] [37 85]] [37 100]]] [37 57]] [37 50]] [37 66]] [37 62]]] [37 72]] [1899 0.743 [37 44] [37 100]]] [37 57]] [37 66]] [1899 1.97 [3912 0.665 [37 63] [37 100]] [37 44]]] [37 50]] [37 66]]] [37 45]] [7169 13.8 [37 72] [37 50]]] [38 81]] [35 87]] [3998 0.949 [1992 0.622 [3929 1.12 [3905 12.8 [2178 1.1 [3262 13.7 [5637 4.81 [3914 2.73 [16 33] [16 45]] [2752 13 [37 100] [37 46]]] [37 88]] [16 50]] [37 100]] [839 0.861 [112 1.31 [37 66] [37 91]] [37 100]]] [16 66]] [37 100]]] [771 1.14 [1911 5.26 [708 0.488 [6353 4.02 [6865 1.2 [2763 0.793 [37 58] [37 55]] [37 100]] [35 57]] [37 100]] [27 66]] [35 40]]] [5 46]] [27 77]] [27 100]]] [7718 0.381 [7233 0.441 [2000 1.72 [3666 0.548 [3381 0.725 [5094 0.215 [3642 1.53 [5299 0.145 [4767 0.609 [5972 1.53 [5209 3.31 [3640 1.1 [1980 24.2 [4684 1.03 [1083 2.77 [685 0.668 [4781 3.45 [429 43.4 [4851 7.8 [7057 5.63 [6337 12.6 [6516 3.81 [6213 0.643 [5270 12.5 [1622 7.82 [7335 2.52 [2259 83.5 [1587 2.65 [1738 28.9 [4340 3.85 [1769 14.9 [2518 11.8 [5962 0.67 [3562 0.209 [2246 3.16 [7241 1.82 [4524 7.87 [1445 3.28 [4346 9.09 [4818 6.76 [1429 92.7 [2526 41.2 [6266 17.6 [6738 8.2 [2993 2.97 [1783 20.3 [4339 21.3 [7210 0.103 [5605 10.4 [4342 18.9 [429 14.4 [1047 17.1 [5368 2.79 [7382 11.6 [5412 9.02 [1199 0.173 [6962 4.65 [24 100] [24 83]] [24 100]] [24 87]] [1047 1.25 [24 96] [24 100]]] [24 80]] [4147 2.38 [24 100] [24 80]]] [24 100]] [3659 1.5 [24 97] [24 100]]] [24 87]] [24 100]] [24 87]] [24 90]] [24 92]] [24 91]] [24 96]] [24 91]] [24 91]] [24 90]] [2616 9.71 [24 72] [24 100]]] [24 83]] [24 85]] [24 80]] [24 71]] [24 80]] [24 81]] [208 3.53 [896 0.154 [24 98] [24 100]] [24 60]]] [24 85]] [3656 4.55 [3641 2.24 [24 90] [24 100]] [24 83]]] [19 44]] [4145 1.33 [3663 2.9 [24 90] [24 66]] [19 50]]] [24 66]] [24 85]] [24 60]] [24 45]] [24 63]] [24 75]] [19 53]] [24 83]] [24 55]] [24 26]] [24 66]] [24 66]] [7414 0.743 [24 100] [35 62]]] [6739 1.35 [3648 2.35 [3102 0.287 [2793 2.65 [7665 5.52 [24 75] [7672 0.998 [24 88] [24 100]]] [24 100]] [24 81]] [24 83]] [24 66]]] [24 36]] [774 1.32 [4279 10.5 [24 81] [24 56]] [24 100]]] [5052 1.67 [4338 18.7 [24 90] [24 46]] [19 50]]] [36 64]] [5209 1.1 [15 28] [24 100]]] [2 30]] [5270 1.19 [286 2.87 [7174 1.48 [2275 4.27 [4545 0.546 [6853 5.33 [3645 4.34 [23 7.24 [1023 2.1 [7520 2.25 [4956 0.511 [978 4.79 [791 7.07 [6260 0.673 [24 50] [4279 8.49 [24 83] [24 100]]] [24 100]] [24 100]] [24 100]] [24 66]] [24 81]] [19 41]] [2795 6.94 [19 62] [19 55]]] [1738 2.72 [2795 18 [2832 0.169 [2536 0.597 [3026 0.675 [978 3.31 [24 100] [24 85]] [24 100]] [24 100]] [24 100]] [24 71]] [24 60]]] [24 100]] [19 50]] [24 60]] [19 50]] [3663 2.11 [19 81] [24 87]]]] [16 44]] [36 50]] [1429 6.07 [4573 1.04 [6338 2.58 [7343 0.873 [2421 3.53 [5792 0.419 [3652 9.26 [24 60] [19 71]] [24 50]] [24 92]] [24 60]] [19 100]] [5641 0.635 [2517 12.6 [19 80] [19 70]] [19 83]]] [24 69]]] [15 100]] [31 100]] [4 57]]] [31 100]] [6383 0.327 [4854 0.655 [2259 40.6 [2865 0.307 [199 0.0539 [4103 0.669 [4622 4.97 [1836 1.39 [2890 0.202 [2526 1.69 [126 0.613 [3960 0.51 [6257 3.56 [7347 0.742 [1296 2.13 [6868 0.956 [7072 4.3 [7423 1.14 [5701 0.678 [1429 15.3 [4879 2.47 [791 3.47 [2951 1.16 [7665 3.47 [6134 8.2 [6133 5.26 [328 5.24 [7329 2.7 [5435 7.55 [2628 2.33 [685 1.39 [1078 2.67 [144 16.6 [5412 6.42 [7512 2.99 [2081 1.93 [2259 20.5 [33 45] [1 46]] [23 40]] [1 90]] [33 90]] [26 40]] [248 24.1 [29 37] [33 50]]] [18 25]] [7255 14.7 [5627 1.98 [2709 3.55 [2983 5.29 [2941 9.06 [2429 3.67 [2939 41.5 [7726 18.6 [5099 23.3 [166 20 [2859 0.792 [7343 21.3 [2849 102 [6959 10.5 [5753 1.69 [38 34] [38 36]] [16 66]] [16 50]] [38 70]] [38 44]] [38 68]] [16 64]] [14 100]] [38 33]] [38 87]] [6 50]] [38 24]] [16 50]] [16 82]] [16 44]]] [16 30]] [13 84]] [33 31]] [16 78]] [16 68]] [187 2.47 [5410 2.62 [913 2.8 [107 7.33 [6581 11.6 [33 26] [14 37]] [33 72]] [16 40]] [33 77]] [6 33]]] [2724 1.17 [7104 4.93 [4414 15.4 [4840 0.0955 [6177 7.7 [5170 1.68 [5100 0.915 [2683 5.39 [5594 4.74 [7049 2.79 [4074 3.46 [2660 3.65 [2666 6.17 [7454 2.89 [5985 9.28 [190 1.35 [5799 7.31 [5568 6.7 [7241 22.8 [6409 13.9 [5605 1.81 [7255 22.6 [4717 18.5 [4051 2.33 [5851 6.03 [5130 4.01 [1429 13.5 [6208 1.67 [166 28.4 [2225 2.29 [7370 1.75 [2259 5.96 [5999 2.09 [38 71] [38 100]] [38 60]] [38 100]] [38 100]] [6207 23.5 [38 55] [38 60]]] [38 96]] [38 33]] [38 69]] [38 50]] [38 100]] [16 66]] [38 55]] [16 63]] [16 46]] [5 36]] [5 28]] [5438 11.7 [187 11.9 [16 42] [26 50]] [16 45]]] [1429 11.5 [4538 2.21 [6848 3.5 [6940 12.7 [1997 3.62 [7491 8.34 [2889 5.13 [2656 4.13 [429 0.421 [2849 32.5 [38 83] [165 26.6 [2955 25.3 [2850 5.92 [1936 1.42 [4956 0.117 [2143 4.86 [2691 1.82 [6199 17.9 [7255 8.66 [190 6.08 [38 90] [2707 33.4 [1980 6.4 [37 42] [38 100]] [38 66]]] [10 38]] [94 6.49 [38 79] [38 75]]] [5 33]] [38 50]] [38 90]] [5 33]] [38 78]] [38 94]] [23 10.2 [38 45] [38 50]]]] [38 90]] [5 40]] [38 50]] [38 55]] [1980 8.11 [10 30] [38 60]]] [7 44]] [38 100]] [38 100]] [38 59]]] [16 23]] [6 42]] [16 51]] [16 49]] [2951 13.1 [38 50] [5 45]]] [16 52]] [16 42]] [4725 4.08 [16 52] [38 62]]] [5099 106 [6007 6.01 [5438 10.1 [5100 6.82 [18 27] [2891 9.01 [45 3.18 [5100 25.2 [2667 11.8 [7281 15.7 [6409 8.26 [5723 2.06 [2654 6.27 [1980 3.55 [16 43] [16 57]] [16 83]] [16 75]] [6 60]] [6 83]] [16 46]] [2868 2.46 [2712 8.51 [6 45] [6 70]] [16 50]]] [16 87]] [7 100]]] [18 63]] [16 44]] [6 70]]] [26 68]] [7 61]] [4940 7.13 [16 63] [16 50]]] [16 40]] [2649 1.71 [2853 6.14 [4716 7 [16 50] [16 66]] [16 86]] [16 50]]] [7 86]]] [4388 0.635 [3905 0.231 [6653 3.7 [178 9.59 [2802 0.722 [7449 6.97 [896 2.9 [820 0.994 [906 3.24 [6207 1.99 [29 27] [26 20]] [1899 3.55 [29 67] [29 50]]] [11 100]] [7665 17.1 [26 38] [32 21]]] [5526 2.02 [23 20.7 [29 81] [22 60]] [29 100]]] [112 2.66 [29 84] [29 100]]] [25 81]] [5827 1.15 [11 50] [11 100]]] [32 32]] [26 92]]] [29 73]] [4769 0.942 [7281 9.01 [23 5.92 [190 0.191 [2671 5.67 [7461 3.26 [631 0.898 [1184 0.761 [4414 10.5 [968 0.843 [5130 2.2 [4611 4.04 [2846 0.65 [112 1.19 [2655 10.8 [144 4.67 [5110 0.994 [896 8.61 [3292 1.27 [7449 4.65 [663 8.85 [187 12.5 [1913 15.3 [2649 4.86 [377 2.76 [16 10] [26 50]] [16 33]] [8 40]] [7255 9.43 [6199 24.3 [38 30] [17 70]] [6 33]]] [5 26]] [29 27]] [37 100]] [5 45]] [30 64]] [29 33]] [16 22]] [7343 1.79 [29 42] [14 30]]] [22 73]] [29 68]] [18 52]] [28 87]] [2849 19.5 [16 45] [4414 48.3 [26 15] [16 55]]]] [11 72]] [2781 1.43 [6859 14.1 [28 93] [28 100]] [28 100]]] [7449 18.8 [660 0.967 [22 56] [4500 0.967 [7491 5.38 [29 100] [28 70]] [29 100]]] [28 50]]] [276 3.23 [4717 1.9 [6832 1.49 [7 60] [2940 3.51 [18 69] [18 87]]] [18 87]] [18 50]]] [1429 57.1 [1239 45.1 [5412 4.22 [5874 4.65 [2259 17 [5723 7.27 [5480 3.32 [5900 1.84 [7446 0.726 [38 45] [38 56]] [16 57]] [18 70]] [16 50]] [16 36]] [38 100]] [16 55]] [7 73]] [17 35]]] [2752 5.47 [6720 0.57 [2662 0.914 [1638 0.852 [1342 1.17 [2987 2.06 [54 6.19 [7472 0.115 [7084 3.18 [2891 1.9 [6048 2.39 [2442 7.23 [5873 6.15 [5723 0.28 [6779 4.27 [4682 1.68 [7726 1.67 [2654 2.76 [2679 2.73 [1980 0.502 [1913 5.05 [3675 6.67 [5435 15.4 [23 30.2 [791 3.82 [2850 0.396 [5673 10.1 [16 18] [16 61]] [38 44]] [18 20]] [7132 2.92 [4098 4.27 [1239 12.2 [1722 5.49 [16 19] [33 100]] [6199 12 [16 17] [17 56]]] [16 50]] [38 71]]] [16 64]] [37 42]] [5 44]] [7457 3.18 [5007 6.79 [2881 1.69 [791 9.15 [2225 3.43 [2859 1.26 [2178 0.998 [1913 3.4 [38 40] [16 27]] [38 54]] [17 50]] [10 28]] [1980 11.1 [13 36] [1 33]]] [13 77]] [18 88]] [5 63]]] [16 90]] [2469 2.3 [16 53] [16 88]]] [14 31]] [33 95]] [37 87]] [2717 0.609 [5641 11.6 [5103 4.51 [16 81] [6 50]] [6 42]] [16 85]]] [38 86]] [12 69]] [16 100]] [7 58]] [2955 1.11 [37 37] [4478 3.76 [5 63] [5 77]]]] [38 52]] [5 70]] [33 91]] [33 92]] [14 100]] [16 39]] [38 81]] [99 0.949 [731 3.53 [2807 0.415 [187 3.57 [642 4.07 [4895 1.47 [3086 0.775 [6206 0.22 [859 4.93 [2707 5.89 [6491 1.89 [5526 1.08 [968 1.86 [7340 4.42 [7428 1.78 [1078 7.26 [722 0.457 [6732 4.18 [5192 2.54 [5007 8.35 [2023 1.26 [1429 29.4 [6 18] [1783 36.7 [37 12] [33 66]]] [16 36]] [30 30]] [6 20]] [18 33]] [12 18]] [6031 2.35 [2939 5.59 [2764 6.85 [29 19] [16 40]] [14 62]] [22 100]]] [12 40]] [32 45]] [6853 14.9 [28 87] [28 100]]] [29 100]] [29 71]] [1896 0.162 [2753 5.4 [37 2.02 [16 52] [5 50]] [16 71]] [28 30]]] [22 100]] [1429 52.5 [28 77] [28 50]]] [37 100]] [7665 2.52 [3079 2.88 [38 21] [37 50]] [18 33]]] [19 78]] [663 2.75 [2955 16.2 [4977 3.96 [7354 3.89 [1899 10.3 [16 42] [37 23]] [19 40]] [2871 1.26 [6 44] [6 40]]] [17 35]] [2649 0.832 [16 50] [16 40]]]] [22 100]] [18 44]] [2831 1.59 [22 43] [22 100]]]]] [6 47]] [4611 0.998 [29 92] [29 100]]]] [221 1.53 [4895 2.42 [33 91] [33 100]] [33 100]]] [2655 12.9 [2889 4.85 [2876 8.2 [166 3.76 [5722 0.782 [37 12.5 [16 72] [2939 26.7 [16 100] [16 87]]] [5721 10.8 [6 30] [16 53]]] [36 31]] [16 57]] [38 75]] [16 100]]] [16 92]] [37 100]] [1821 0.705 [7 89] [7 100]]] [5170 0.319 [7472 0.701 [1696 2.42 [6382 8.73 [2276 11.5 [6134 1.24 [2713 4.43 [4896 1.82 [187 15 [5894 0.788 [23 37.6 [6831 1.46 [16 25] [16 37]] [5933 3.61 [2650 1.41 [2656 3.31 [16 35] [16 40]] [16 83]] [16 40]]] [18 57]] [2851 2.67 [5641 2.07 [2102 0.8 [2853 0.65 [78 12.2 [1899 3.18 [1980 3.02 [1239 5.73 [16 53] [16 77]] [28 30]] [1 25]] [6 33]] [16 57]] [16 91]] [16 100]] [16 40]]] [17 72]] [6372 2.73 [1896 0.766 [16 58] [16 88]] [16 100]]] [4895 1.72 [190 11.1 [5637 3.48 [7150 4.32 [4738 4.72 [7048 0.621 [19 35] [311 6.6 [190 9.43 [23 46 [7255 10.3 [28 38] [26 66]] [16 53]] [3 40]] [28 100]]] [16 50]] [2939 11.6 [17 61] [4457 2.69 [16 77] [13 25]]]] [13 72]] [16 63]] [6959 3.02 [5681 6.37 [16 88] [16 66]] [16 81]]]] [5 38]] [17 70]] [5801 21.5 [26 70] [187 22.9 [16 61] [26 88]]]] [2259 2.41 [38 33] [22 30]]] [2678 0.0842 [5692 3.45 [7049 2.9 [16 37] [26 78]] [26 100]] [26 100]]]] [18 63]] [29 100]] [807 3.47 [695 7.91 [7456 1.39 [5013 3.64 [7449 0.441 [29 59] [1429 7.27 [29 100] [29 88]]] [29 100]] [38 33]] [28 43]] [29 100]]] [2655 0.196 [7132 3.64 [1059 2.62 [2259 15.8 [6528 1.08 [107 2.38 [2663 0.16 [5597 2.16 [232 0.551 [2809 0.172 [3243 2.34 [1062 0.342 [5174 0.654 [5734 1.52 [3905 5.18 [980 0.937 [5140 0.942 [3273 4.22 [6363 8.25 [7255 8.68 [6537 2.01 [6862 2.58 [3095 4.9 [6077 0.931 [2207 3.44 [1888 1.24 [2936 0.707 [600 4.57 [695 4.95 [5376 4.51 [1587 1.13 [181 1.25 [2733 1.07 [2023 3.82 [6848 2.71 [7206 0.381 [4716 2.65 [663 16.7 [5 9] [19 33]] [26 54]] [16 41]] [14 27]] [38 69]] [16 69]] [26 60]] [2862 7.75 [5681 4.45 [16 40] [16 75]] [16 54]]] [26 43]] [37 29]] [17 80]] [25 100]] [2526 7.94 [5170 0.888 [26 46] [26 75]] [17 15]]] [12 62]] [4 65]] [12 66]] [26 88]] [286 5.32 [2 61] [1 66]]] [5681 3.11 [2656 1.69 [94 4.94 [16 28] [16 100]] [7255 13.1 [18 42] [18 62]]] [16 88]]] [25 71]] [35 66]] [33 62]] [1081 6.55 [26 85] [26 44]]] [3964 0.486 [2826 6.26 [17 35] [17 83]] [23 4.81 [19 33] [19 83]]]] [7 100]] [685 2.9 [2755 0.669 [2955 2.48 [2628 5.81 [33 55] [26 83]] [26 77]] [1078 2.65 [26 90] [26 100]]] [26 53]]] [5799 2.43 [4200 1.72 [939 1.42 [7215 1.11 [7251 1.48 [5316 0.998 [5007 7.49 [6199 0.179 [134 0.463 [5673 9.99 [5753 0.414 [6862 0.402 [2628 1.76 [18 24] [6732 1.23 [18 50] [2 20]]] [16 40]] [16 40]] [19 40]] [16 38]] [17 42]] [19 70]] [35 90]] [1703 0.258 [5 47] [19 90]]] [19 90]] [13 53]] [5 75]] [16 55]]] [3928 4.89 [3972 1.95 [2178 5.39 [2048 2.83 [37 34] [37 100]] [8 40]] [37 100]] [5 32]]] [5484 0.166 [2707 14.8 [407 0.25 [18 70] [18 33]] [16 66]] [16 58]]] [5753 1.88 [33 52] [33 100]]] [1587 0.535 [2955 7.58 [4414 0.406 [1429 19 [2939 8.26 [17 25] [16 60]] [16 70]] [16 76]] [6 43]] [16 91]]] [5578 4.37 [978 8.7 [3006 5.1 [7421 0.316 [6425 5.86 [2081 1.38 [2978 1.25 [2868 16.7 [7210 0.16 [5673 3.09 [4017 13 [16 89] [16 71]] [16 80]] [16 60]] [16 70]] [16 30]] [16 40]] [16 92]] [16 85]] [26 100]] [18 36]] [16 40]]] [6844 1.08 [33 60] [33 88]]] [5692 6.75 [6178 2.24 [25 35] [25 100]] [1 50]]] [2707 1.92 [2526 5.02 [18 36] [1081 2.02 [2569 3.93 [16 19] [16 88]] [18 50]]] [7474 2.85 [5349 8.9 [286 0.943 [279 1.07 [4820 4.79 [192 6.72 [1786 0.57 [1783 10.4 [5988 0.551 [4726 3.57 [5349 0.835 [4731 1.62 [2616 12.7 [7737 2.41 [16 60] [16 42]] [6 100]] [6 75]] [16 100]] [30 31]] [6 70]] [4939 0.986 [5637 0.826 [16 46] [16 87]] [16 80]]] [18 76]] [6 50]] [2370 3.41 [16 91] [16 85]]] [18 60]] [6 81]] [6 76]] [38 75]]]] [26 85]] [4513 1.21 [6007 1.54 [5753 0.705 [7 63] [7 55]] [7 100]] [7 100]]] [6471 0.609 [5898 0.457 [7419 6.77 [16 63] [6 48]] [4725 0.975 [5962 0.457 [7149 0.36 [5 40] [16 71]] [16 87]] [16 94]]] [26 66]]]] [5 75]] [76 1.38 [96 0.38 [964 3.2 [7679 4.24 [2526 9.81 [5517 2.27 [5904 1.6 [5435 3.75 [2199 5.72 [7259 2.19 [284 3.06 [7154 18.2 [4940 1.43 [5013 1.25 [2611 0.558 [5799 2.76 [719 14 [23 28 [2752 15 [2868 2.8 [2716 0.575 [18 70] [18 60]] [2259 14.2 [6830 34.6 [5626 4.94 [16 29] [18 88]] [18 70]] [18 75]]] [18 80]] [16 57]] [18 90]] [560 1.49 [18 85] [18 71]]] [16 50]] [16 28]] [16 75]] [16 40]] [19 53]] [28 40]] [6 33]] [16 44]] [19 80]] [16 73]] [978 3.11 [18 44] [5894 3.82 [18 80] [18 100]]]] [7149 11 [1078 10.2 [7665 5.43 [18 33] [5594 4.01 [2939 17.8 [18 89] [18 46]] [18 66]]] [18 63]] [429 14.8 [18 58] [16 37]]]] [18 70]] [2466 0.8 [2023 0.885 [429 5.6 [16 100] [16 60]] [16 50]] [16 83]]] [5639 1.3 [2951 25.2 [7039 0.71 [5681 0.795 [2151 0.397 [16 40] [6 70]] [2241 1.04 [19 77] [16 44]]] [16 85]] [7 58]] [16 100]]]] [6778 5.39 [4414 0.24 [37 73] [18 41]] [54 3.76 [4716 3.09 [5104 4.39 [6406 1.37 [4326 0.785 [37 41] [37 85]] [5 50]] [16 75]] [18 40]] [18 46]]]] [88 0.602 [3120 4.5 [1539 1.87 [5972 2.46 [2983 0.339 [5007 4.31 [7512 1.93 [3544 7.76 [2245 1.25 [2955 13.2 [3107 6.36 [2442 4.83 [5 59] [37 85]] [3972 8.22 [7726 14.4 [5 80] [3677 4.69 [5 71] [37 80]]] [38 75]]] [1911 1.68 [1897 3.5 [4104 6.02 [5 54] [5 90]] [5 80]] [5 90]]] [37 55]] [5 87]] [16 33]] [29 77]] [5 75]] [12 100]] [5 81]] [5 86]] [2322 5.58 [2877 9.56 [7153 0.0597 [6575 0.397 [37 55] [5 100]] [37 57]] [16 66]] [37 80]]]] [1011 0.39 [1899 19.3 [77 0.278 [286 10.6 [5637 0.666 [7304 2.88 [6574 3.61 [5776 0.718 [2628 52.2 [2881 0.783 [2676 9.17 [7401 1.65 [3251 1.03 [1239 27.8 [3675 2.16 [6177 4.61 [1981 8.82 [1897 5.95 [38 89] [38 52]] [38 66]] [17 33]] [38 92]] [38 60]] [38 55]] [5 28]] [38 62]] [17 40]] [2712 1.03 [5393 6.99 [38 94] [38 100]] [38 75]]] [38 42]] [38 55]] [8 46]] [3897 0.816 [6035 2.33 [4807 1.05 [5753 2.9 [2870 4.45 [38 73] [38 89]] [19 50]] [7623 1.36 [6199 17.1 [2691 0.654 [38 66] [38 75]] [17 40]] [17 45]]] [8 33]] [38 53]]] [17 90]] [24 17]] [2750 6.58 [2851 6.03 [12 47] [1997 19.5 [26 50] [24 85]]] [38 72]]] [25 30]]] [2955 0.922 [7 95] [7 100]]] [5964 2.29 [2275 0.144 [2862 0.0526 [5609 1.17 [1974 2.89 [2846 0.627 [5597 2.35 [5678 2.33 [5322 1.77 [5099 6.37 [5164 0.365 [7457 1.1 [2439 0.84 [7123 8.83 [719 2.39 [2723 0.835 [1786 1.93 [2686 23.9 [88 3.33 [1436 11.3 [61 9.49 [1370 1.44 [2440 6.21 [1895 8.11 [2868 4.99 [2616 2.87 [7135 3.18 [1078 2.01 [1429 14.1 [38 56] [16 24]] [1239 34.6 [38 23] [8 62]]] [38 100]] [6 100]] [6 52]] [38 30]] [38 100]] [38 95]] [38 87]] [17 54]] [3435 7.05 [37 83] [2628 28.5 [2707 7.61 [6 40] [16 55]] [37 57]]]] [6677 1.44 [38 91] [38 100]]] [8 33]] [6 62]] [144 5.13 [18 83] [18 37]]] [14 26]] [2430 0.323 [38 96] [1370 1.18 [38 80] [38 100]]]] [5 46]] [7122 1.54 [7136 0.678 [38 97] [38 100]] [38 90]]] [2259 52.5 [16 70] [6 35]]] [5327 1.77 [30 83] [190 12.1 [16 36] [16 70]]]] [7159 8.79 [38 88] [38 66]]] [2616 3.85 [194 8.14 [2649 6.73 [2707 5.18 [7301 1.27 [5598 5.21 [18 37] [18 28]] [19 66]] [16 50]] [2079 9.08 [16 57] [6 80]]] [6 87]] [6287 1.99 [6 83] [6 100]]]] [18 53]] [2584 3.5 [16 60] [6 60]]] [6 35]] [2357 4.35 [5067 1.04 [7665 0.117 [5957 8.07 [2432 3.56 [61 4.08 [5345 2.06 [38 69] [19 37]] [2888 14.6 [3984 1.14 [97 3.97 [3819 5.73 [2413 3.82 [2357 1.44 [23 51.6 [17 50] [2431 0.351 [1980 0.992 [38 100] [38 57]] [38 100]]] [38 91]] [1807 3.17 [38 100] [26 37]]] [38 48]] [38 40]] [38 82]] [38 51]]] [1860 2.38 [199 1.04 [1808 0.642 [38 66] [38 72]] [19 52]] [17 37]]] [38 100]] [6 33]] [17 36]] [187 0.593 [38 84] [6422 5.5 [38 94] [38 83]]]]] [1349 0.626 [7041 6.41 [2616 4.3 [26 20] [7153 0.826 [6 100] [6 85]]] [16 48]] [6 100]]] [5099 30.7 [6 60] [16 88]]]] [5330 0.345 [1116 2.52 [5692 0.641 [2954 1.3 [6506 2.26 [85 1.28 [2984 4.92 [305 2.84 [2650 0.217 [3006 1.16 [6779 7.25 [2737 0.763 [6207 1.96 [302 4.4 [3375 1.06 [7549 1.09 [2713 2.71 [6952 2.11 [2628 4.35 [2709 2.92 [4504 2.82 [6514 1.43 [7734 7.37 [6791 0.707 [7419 1.47 [18 29] [6 41]] [28 41]] [23 1.3 [18 87] [18 57]]] [6 45]] [18 77]] [38 27]] [5662 1.27 [4537 4.16 [7739 0.385 [23 1.4 [221 1.76 [5007 9.21 [2649 28.4 [4731 2.33 [4895 5.32 [2940 16 [3008 5.18 [248 7.54 [5627 7.97 [1895 4.49 [4431 13.8 [4154 1.25 [2851 1.01 [7149 14.7 [6406 20.6 [2023 0.75 [7679 3.05 [7255 0.662 [1899 6.01 [6 41] [6 37]] [6 50]] [16 57]] [16 71]] [16 54]] [16 61]] [16 41]] [16 50]] [6 37]] [16 50]] [19 45]] [26 71]] [26 75]] [6 100]] [16 36]] [6 100]] [6 57]] [16 72]] [6 84]] [2897 0.213 [7038 1.61 [2093 3.25 [2667 11.9 [5673 16.1 [1660 7.11 [23 9.98 [6129 1.12 [2720 3.41 [6959 5.39 [1783 0.31 [16 37] [1820 0.0619 [4431 4.37 [312 0.372 [16 33] [16 37]] [16 75]] [16 66]]] [18 50]] [16 90]] [6 33]] [7232 22.3 [5642 1.1 [5874 2.76 [2939 31.1 [1899 16.9 [6382 3.28 [190 8.99 [16 39] [16 55]] [17 44]] [6 69]] [6008 2.11 [3675 0.378 [3008 2.19 [7149 5.74 [6 39] [16 85]] [5 66]] [18 50]] [16 37]]] [7 75]] [18 75]] [26 53]]] [6 54]] [5103 15.3 [2683 2.13 [190 15.4 [1783 3.2 [18 37] [16 42]] [6 64]] [18 70]] [6 45]]] [16 85]] [18 83]] [2734 1.77 [7419 0.33 [2983 6.4 [5103 9.18 [6409 1.34 [6 68] [16 45]] [16 55]] [16 45]] [4940 0.0721 [187 6.36 [5900 0.471 [5898 1.3 [5090 2.01 [2549 1.57 [16 85] [16 100]] [16 50]] [6 50]] [6 62]] [16 44]] [16 88]]] [6 37]]] [16 72]]] [19 81]] [38 92]] [18 90]]] [17 100]] [5480 0.182 [5673 1.9 [7325 1.85 [1374 6.41 [791 0.343 [5627 4.38 [2985 1.39 [6471 11.4 [5101 16.5 [2351 0.967 [4854 39.4 [5010 11.5 [6177 9.4 [2396 5.35 [2955 31.7 [5067 3.01 [3120 5.18 [6961 0.695 [6152 3.36 [2663 0.922 [62 2.65 [6500 2.64 [7611 4.37 [1895 3.44 [23 4.68 [5722 1.6 [7665 3.26 [187 31.7 [4717 2.19 [4716 2.89 [6 72] [6 25]] [38 62]] [6 43]] [6 92]] [16 62]] [4939 10.7 [2412 3.66 [4851 30.5 [2878 2.56 [6 44] [6 56]] [6 68]] [14 33]] [16 75]]] [6 70]] [30 36]] [16 44]] [16 50]] [16 91]] [16 62]] [5851 0.615 [1273 0.713 [37 9.2 [5898 6.33 [1786 1.11 [1356 0.842 [1900 0.412 [2955 6.47 [6 46] [6 80]] [16 83]] [6 88]] [6 45]] [6 85]] [6 93]] [6 83]] [16 66]]] [16 85]] [18 33]] [16 39]] [16 81]] [16 63]] [7203 0.242 [4414 2.2 [16 43] [18 47]] [16 45]]] [6 68]] [7421 9.07 [6 92] [6 71]]] [6 94]] [26 75]] [16 41]] [4431 9.16 [6688 1.6 [6 33] [16 62]] [16 62]]] [4854 8.16 [7 63] [4716 1.28 [16 41] [6 58]]]] [16 50]] [5 91]] [5345 4.07 [7101 15.8 [190 16.1 [5799 16.3 [1820 0.2 [5350 1.79 [5985 29.4 [7281 2.9 [2852 0.481 [5130 0.585 [1900 3.78 [2450 3.95 [4763 1.32 [1429 25.7 [5724 5.26 [6515 5.27 [2619 7.68 [5102 12 [2691 3.2 [5037 1.17 [5721 0.484 [5436 1.04 [1356 0.475 [91 2.82 [7099 0.861 [5894 2.88 [2939 14.4 [6 81] [7255 5.52 [16 36] [16 66]]] [16 40]] [16 100]] [16 80]] [6 56]] [16 33]] [6 81]] [6 50]] [16 80]] [5415 7.46 [2178 0.201 [6761 1.81 [187 26.9 [6 45] [16 59]] [6 60]] [6 94]] [6 85]]] [16 91]] [6 100]] [7149 0.454 [6499 2.92 [16 54] [16 75]] [16 45]]] [791 11.4 [16 54] [5 40]]] [6 70]] [6 88]] [18 37]] [26 62]] [16 100]] [6 30]] [6 100]] [6 100]] [6 55]] [16 71]] [5873 1.12 [5099 67.6 [6 47] [6 77]] [16 44]]] [1 70]] [16 64]]] [5578 0.462 [3421 1.3 [1011 1.19 [6832 2.65 [7734 1.23 [2649 8.03 [16 66] [16 62]] [18 44]] [18 40]] [6 50]] [5 40]] [18 57]]]] [7405 2.17 [7153 0.895 [6 72] [2125 0.193 [6 87] [6 100]]] [16 55]]] [37 100]] [30 80]] [6952 0.462 [2750 0.323 [4739 3.1 [5891 1.26 [6040 2.55 [2666 5.25 [5435 3.63 [6574 3.17 [5641 3.42 [4743 1.31 [196 1.51 [76 0.296 [248 6.19 [4685 2.38 [5187 5.39 [3675 4.13 [166 4.47 [1429 18.5 [16 33] [83 0.284 [19 36] [16 30]]] [5 28]] [6 45]] [18 70]] [6207 7.2 [14 100] [14 50]]] [26 50]] [6074 0.296 [16 60] [6 57]]] [7260 2.62 [6 42] [6 50]]] [7 83]] [16 82]] [4685 2.27 [35 40] [17 87]]] [1239 8.73 [14 57] [6131 0.544 [16 38] [14 75]]]] [16 48]] [32 35]] [17 57]] [18 50]] [17 33]] [5345 1.6 [4943 2.26 [4685 17.7 [17 97] [1896 1.02 [167 8.13 [17 100] [17 55]] [17 62]]] [17 76]] [17 77]]]] [7409 2.92 [38 84] [38 66]]] [16 32]] [429 8.88 [1783 2.21 [26 36] [2849 27.6 [26 95] [26 50]]] [26 80]]] [5482 1.21 [6517 3.23 [7611 1.84 [6370 9.54 [1356 1.7 [83 4.03 [2656 14.2 [196 1.26 [5673 17 [5438 11.6 [2939 37 [328 1.24 [2723 5.01 [1895 5.6 [2714 0.25 [16 37] [2871 1.04 [16 72] [16 66]]] [7343 0.743 [16 57] [17 33]]] [28 44]] [16 20]] [6 41]] [16 100]] [6 50]] [16 85]] [6 41]] [7260 8.26 [16 51] [2644 0.365 [23 24.2 [26 100] [2713 4.31 [4854 12.3 [4738 7.65 [3742 3.16 [6 33] [26 55]] [26 70]] [16 66]] [5007 1.41 [2714 4.34 [13 23] [32 50]] [25 44]]]] [26 66]]]] [6 66]] [7038 0.238 [5933 0.65 [16 40] [16 93]] [16 83]]] [26 50]] [5626 3.43 [7255 9.18 [4854 8.77 [16 45] [18 21]] [4763 1.62 [16 52] [28 75]]] [16 66]]] [18 100]]] [5103 1.89 [30 66] [30 100]]] [2955 12.7 [6920 0.65 [312 0.299 [1261 1.13 [2941 4.03 [194 2.61 [2707 33.5 [5103 4.42 [1429 11.4 [2720 2.43 [2259 2.91 [6 69] [6 82]] [6 30]] [6471 8.46 [6 33] [16 57]]] [18 57]] [5102 1.02 [16 50] [6 75]]] [7282 5.31 [4763 0.375 [1429 10.3 [16 60] [16 72]] [5626 12.5 [2714 0.193 [16 75] [16 62]] [6 53]]] [2984 14.4 [6 33] [16 50]]]] [1429 4.04 [6 57] [6 87]]] [6 100]] [6 88]] [18 57]] [2849 25.3 [6 94] [6755 0.359 [5627 2.76 [4680 1.87 [6959 2.54 [5986 15.2 [62 2.52 [7281 22 [6 40] [6 75]] [6 50]] [16 60]] [6 33]] [16 50]] [5673 4 [6 50] [6 100]]] [2939 37.2 [6 75] [6 85]]]]]] [6687 1.48 [6152 3.95 [7101 2.53 [6256 10.8 [18 52] [2858 1.17 [4762 10.1 [5799 3.09 [18 80] [18 100]] [18 62]] [18 100]]] [18 100]] [5017 0.786 [429 4.3 [18 87] [18 83]] [18 100]]] [6 33]]] [1646 1.74 [6688 0.854 [6831 0.821 [6507 11.9 [7 100] [7 88]] [7 100]] [7 100]] [2667 0.464 [6506 7.83 [7 66] [7 90]] [7 100]]]] [305 6.21 [304 1.13 [30 84] [30 100]] [30 71]]] [2393 0.598 [432 2.24 [5429 1.19 [7186 3.98 [5211 2.2 [5345 0.325 [980 0.109 [3008 0.635 [4728 0.321 [6830 2.56 [7734 1.68 [299 2.11 [2749 0.86 [5933 0.78 [4431 4.4 [5692 11.4 [7611 1.86 [2640 2.92 [85 0.935 [1078 7.24 [1783 5.67 [7048 0.671 [16 25] [26 60]] [16 44]] [14 37]] [18 71]] [18 50]] [16 50]] [16 48]] [5192 0.277 [6941 1.11 [6 61] [7 40]] [16 50]]] [18 55]] [2628 18.8 [7681 0.705 [26 80] [26 100]] [26 57]]] [6 80]] [7737 1.87 [18 100] [18 37]]] [4762 4.46 [2902 1.15 [1980 3.3 [91 0.598 [3207 0.247 [6207 1.05 [5007 0.713 [19 30] [16 60]] [7 45]] [16 50]] [16 60]] [16 83]] [5681 1.99 [18 87] [6 33]]] [18 83]]] [18 87]] [16 46]] [5412 0.414 [26 91] [26 61]]] [2955 0.429 [284 2.71 [18 73] [19 60]] [2259 7.38 [7601 0.641 [6199 2.6 [194 2.5 [16 44] [18 70]] [26 75]] [18 30]] [2955 6.39 [6959 2.48 [16 42] [16 87]] [14 28]]]]] [193 0.611 [5110 5.79 [302 1.34 [30 42] [1980 0.448 [30 91] [30 83]]] [22 50]] [16 36]]] [2526 0.998 [18 60] [18 100]]] [7232 2.42 [6474 3.78 [5931 1.93 [7281 0.816 [5693 0.688 [26 52] [1783 1.42 [26 83] [26 85]]] [26 100]] [26 100]] [26 61]] [26 50]]] [328 22.4 [26 100] [26 70]]] [14 32]]] [5932 7.94 [2707 5.82 [30 85] [30 97]] [30 78]]] [2691 2.3 [5985 0.529 [30 98] [30 100]] [30 75]]]] [6688 0.27 [2851 0.914 [5593 0.442 [2670 0.301 [5940 7.28 [1945 0.787 [2877 1.59 [4414 3.84 [5753 0.898 [2469 0.219 [2081 0.387 [2649 3.67 [6959 0.87 [3972 1.44 [4897 5.73 [2955 23.6 [5681 3.25 [1897 3.59 [37 2 [1429 20.8 [14 38] [38 36]] [38 60]] [38 100]] [26 25]] [38 100]] [5 46]] [5 80]] [7 26]] [16 68]] [14 25]] [6842 5.27 [6208 7.76 [4610 9.41 [2690 0.41 [6848 0.356 [2713 4.41 [1687 24.8 [5622 0.33 [2752 2.45 [2050 0.441 [2178 1.89 [1895 4.44 [6227 0.149 [2259 0.109 [38 46] [7343 0.579 [6306 6.6 [2862 8.38 [38 89] [38 62]] [38 57]] [2628 34.1 [38 50] [38 100]]]] [38 90]] [38 48]] [8 28]] [6 62]] [6824 1.59 [38 38] [17 28]]] [19 71]] [17 100]] [16 64]] [38 100]] [16 90]] [17 50]] [2951 28.7 [17 64] [38 66]]] [17 88]]] [2753 0.463 [7476 1.09 [38 23] [5 22]] [6 28]]] [6825 0.497 [2655 1.07 [4851 10.2 [16 37] [16 78]] [2469 1.76 [16 90] [16 66]]] [2862 8.63 [38 46] [38 63]]]] [16 70]] [7445 1.21 [37 36] [8 43]]] [16 83]] [5637 11 [17 50] [17 82]]] [4716 4.61 [5637 5.66 [5396 1.14 [5594 2.07 [2862 1.85 [2241 0.196 [4939 0.348 [3238 0.842 [37 40] [37 71]] [19 27]] [2862 0.999 [16 71] [26 57]]] [6 66]] [3208 0.899 [2726 1.67 [16 48] [19 44]] [18 36]]] [2707 14.1 [6 100] [6 66]]] [4431 2.22 [5639 1.84 [7419 0.424 [2076 0.535 [16 64] [1980 3.6 [16 33] [16 80]]] [6 66]] [7206 0.986 [16 62] [16 100]]] [16 33]]] [3238 0.931 [2983 3.06 [194 2.66 [16 47] [16 25]] [8 25]] [2466 7.49 [2707 20.8 [5593 5.13 [16 75] [2643 1.48 [16 38] [37 50]]] [2714 1.15 [3208 1.57 [16 68] [16 100]] [16 83]]] [2707 18.4 [7149 2.97 [16 80] [17 40]] [16 100]]]]]] [1866 7.85 [2737 1.96 [6952 0.775 [3239 1.71 [1229 0.613 [1642 0.785 [1239 52.7 [2426 1.95 [2526 1.03 [7484 5.77 [3120 0.564 [7038 0.609 [1436 0.17 [6383 7.01 [7419 1.38 [4897 1.63 [38 76] [5 30]] [16 60]] [16 50]] [167 4.17 [3110 9.13 [6382 0.611 [1436 11.9 [7242 0.936 [7445 5.61 [3110 6.33 [2691 2.9 [1961 0.288 [6383 3.09 [23 7.98 [4051 0.42 [38 85] [38 100]] [5210 1.61 [38 50] [2112 0.949 [38 71] [38 100]]]] [7445 3.22 [38 40] [1895 1.13 [6199 4.7 [2466 11.9 [38 76] [12 33]] [17 42]] [38 94]]]] [38 90]] [38 53]] [1 28]] [7446 7.36 [38 100] [2469 8.2 [38 35] [1445 3.05 [2849 38.9 [7487 2.52 [5641 17.1 [7446 10.1 [38 100] [38 86]] [4895 2.18 [38 57] [38 100]]] [38 87]] [38 66]] [16 66]]]]] [4050 2.83 [17 26] [19 50]]] [38 34]] [38 41]] [14 47]] [38 89]]] [16 30]] [37 66]] [38 80]] [5809 0.49 [1997 0.216 [5 75] [23 14.1 [7475 2.39 [38 46] [38 85]] [5681 4.62 [1997 3.41 [16 55] [6 57]] [16 100]]]] [200 0.4 [17 33] [38 66]]]] [1789 0.74 [37 57] [38 86]]] [2750 1.53 [38 27] [16 72]]] [17 90]] [16 58]] [7038 0.898 [2466 8.41 [16 93] [25 54]] [16 100]]] [7476 1.17 [17 77] [6951 1.79 [17 100] [17 83]]]] [2748 5.38 [2870 4.46 [2851 1.27 [38 80] [2430 11.5 [7429 0.483 [5594 5.21 [5130 4.91 [5673 0.359 [5637 1.56 [38 93] [7343 1.7 [1748 1.77 [38 85] [6848 10.9 [38 100] [38 83]]] [38 100]]] [38 100]] [38 62]] [38 90]] [38 100]] [7474 3.37 [38 100] [38 75]]]] [38 75]] [38 75]]] [4851 0.705 [1429 53.1 [38 50] [17 87]] [2750 1.86 [17 100] [7487 2.99 [17 81] [17 100]]]]]] [4515 0.212 [2748 0.261 [5894 3.11 [6008 3.32 [7512 8.39 [7260 5.01 [5721 2.65 [2690 0.153 [18 60] [5681 4.04 [187 6.5 [16 26] [6 66]] [16 76]]] [6 80]] [16 76]] [16 100]] [2849 35.9 [7 28] [6 71]]] [1895 0.605 [19 54] [3208 0.18 [18 33] [6 77]]]] [1661 0.274 [4897 1.89 [2732 1.28 [38 76] [38 33]] [19 57]] [16 60]]] [16 53]]]]] [3772 0.129 [7665 1.78 [5681 0.0346 [7411 1.77 [5219 1.55 [3003 0.332 [939 5.25 [7369 0.0447 [1895 0.691 [3687 1.55 [7657 0.187 [6544 0.125 [607 0.164 [4794 0.711 [1710 0.405 [3262 0.96 [2795 1.66 [1400 2.68 [6438 0.486 [5047 0.344 [5938 1.1 [5564 0.0332 [3292 5.76 [695 0.428 [3103 1 [4770 0.0494 [5827 0.254 [915 2.01 [934 0.123 [384 0.429 [1634 1.56 [968 1.44 [2913 1.1 [232 1.31 [1722 2.36 [3105 3.45 [5941 0.0485 [535 1.57 [5812 0.136 [5034 1.49 [6230 4.53 [1582 1.47 [5049 0.747 [5100 0.123 [2707 1.47 [4114 27.1 [1672 0.407 [3849 0.246 [957 14.2 [6859 3.77 [1600 0.84 [5995 0.699 [5730 0.523 [2488 8.48 [809 0.133 [429 0.221 [6982 7.14 [3033 0.341 [1696 3.61 [7627 3.81 [4658 0.739 [3006 1.64 [4655 0.684 [7615 1.11 [2517 0.377 [5171 3.21 [2793 0.18 [165 2.93 [3435 1.02 [5267 0.882 [4556 1.28 [663 0.213 [176 1.2 [2199 1.07 [7176 2.29 [2526 6.58 [1235 0.611 [2849 0.324 [5499 1.61 [5539 4.24 [4231 3.43 [5110 0.243 [5333 4.27 [5972 15.6 [7623 71.3 [3764 20.7 [4279 0.0333 [2894 5.76 [4593 3.07 [1862 0.738 [1645 2.54 [2848 4.07 [2417 11.6 [6711 35.8 [673 4.31 [1783 6.36 [5231 11.1 [6178 3.65 [23 7.03 [5589 3.88 [1 18] [30 100]] [5562 4.42 [33 8] [33 88]]] [25 100]] [11 100]] [227 20.7 [1701 15.9 [5254 4.13 [5991 0.55 [33 18] [25 13]] [10 100]] [6452 11.1 [16 47] [1 55]]] [3008 11.1 [36 83] [24 100]]]] [7742 3.45 [980 2.39 [408 7.19 [1078 0.151 [5170 13.3 [25 38] [26 40]] [26 45]] [26 88]] [26 79]] [18 50]]] [30 75]] [4 100]] [12 97]] [15 100]] [30 91]] [15 100]] [6791 5.88 [6328 8.86 [33 93] [2 50]] [33 100]]] [2931 1.51 [1917 10.1 [4518 4.85 [1592 5.93 [1429 9.83 [4353 23.7 [1101 29.6 [1901 0.319 [2476 8.13 [144 24.9 [3480 22.3 [4665 28.7 [5211 16.5 [33 7] [30 68]] [27 100]] [15 57]] [19 34]] [15 100]] [19 100]] [15 64]] [3 34]] [3243 4.13 [5809 6.14 [1737 9.21 [2342 11.1 [5462 13.2 [2122 19.8 [5299 2.87 [2117 17.9 [32 10] [24 90]] [2 50]] [24 85]] [2 60]] [27 12]] [20 100]] [24 50]] [15 90]]] [3 75]] [24 100]] [23 48]] [23 40]]] [15 100]] [2055 7.18 [2764 18.2 [248 22.9 [5605 8.7 [6981 1.99 [3037 8.99 [5647 8.99 [1948 8.32 [1247 9.8 [2020 11.9 [7656 49.5 [2130 10.7 [7626 22.8 [2207 4.36 [4991 15.8 [35 24] [1 50]] [35 69]] [35 70]] [35 77]] [6 16]] [35 61]] [35 87]] [35 72]] [17 30]] [35 60]] [35 100]] [6 45]] [2 50]] [12 90]] [1239 19.5 [35 68] [35 78]]]] [5972 32 [1429 43.5 [12 40] [12 68]] [12 73]]] [11 100]] [6074 5.7 [5174 1.46 [5326 2.46 [2701 2.92 [6721 2.89 [5122 0.65 [5140 0.243 [30 31] [6056 4.76 [6199 6.37 [4895 8.77 [328 1.6 [5647 47.1 [33 98] [33 78]] [33 87]] [33 75]] [33 66]] [33 100]]] [30 93]] [30 100]] [15 86]] [30 100]] [1429 11.4 [33 95] [33 57]]] [5110 14.7 [15 71] [15 100]]]] [78 17.6 [4920 1.27 [100 2.86 [177 0.381 [5369 2.3 [10 57] [10 100]] [19 88]] [19 76]] [10 100]] [13 55]]] [1813 1.96 [6031 2.57 [1841 1.74 [248 21 [2259 3.76 [13 57] [5753 10.6 [5531 3.6 [13 83] [13 100]] [13 83]]] [13 94]] [13 100]] [13 100]] [13 100]]] [30 100]] [2881 8.2 [6831 10.5 [3238 2.76 [4539 2.92 [1341 5.15 [4724 2.82 [5799 17.9 [5140 1.14 [2662 2.42 [2885 3.18 [67 0.901 [7765 7.46 [4528 2.28 [7149 3.45 [5110 3.6 [4682 14.1 [5753 15.4 [3136 1.93 [2752 1.71 [3008 0.966 [3027 13.5 [7623 7.04 [33 16] [33 80]] [16 37]] [33 44]] [4051 49.7 [33 23] [15 42]]] [5 28]] [33 40]] [33 100]] [30 66]] [18 18]] [16 78]] [28 37]] [33 100]] [38 75]] [16 48]] [33 100]] [16 53]] [6 80]] [38 100]] [38 100]] [1748 2.96 [16 88] [16 100]]] [1445 1.08 [18 40] [16 50]]] [13 52]]] [10 100]] [5963 2.15 [7032 2.65 [7650 2.13 [419 4.59 [6182 3.36 [6099 1.99 [2295 2.26 [5597 4.33 [2829 11.3 [2562 5.15 [5447 1.33 [5972 14.9 [2533 7.04 [7413 3.45 [5170 2.72 [1849 2.06 [6653 25.8 [2470 2.96 [6528 14.3 [2605 1.83 [4369 4.83 [248 20.7 [6524 16.7 [1389 4.76 [8 9] [24 100]] [25 65]] [1081 2.76 [5668 5.26 [25 57] [33 69]] [25 52]]] [25 73]] [25 74]] [25 91]] [25 46]] [8 94]] [25 100]] [261 3.88 [33 62] [33 94]]] [33 76]] [6 71]] [12 63]] [32 75]] [0 66]] [17 37]] [2526 24.5 [6 42] [6 85]]] [6 100]] [6 89]] [25 100]] [26 84]] [33 77]] [7381 17.6 [2 51] [2 58]]] [6 74]]] [7180 1.33 [5071 2.54 [5140 1.72 [107 1.47 [5972 5.49 [6310 2.56 [4690 16.6 [2841 3.07 [7177 5.88 [5118 2.79 [33 33] [22 50]] [7 100]] [22 38]] [8 100]] [35 85]] [2764 5.49 [7176 22.4 [12 70] [2814 11.1 [12 80] [12 100]]] [12 100]]] [328 2.13 [33 94] [33 75]]] [4154 1.29 [7415 2.62 [33 90] [33 100]] [33 100]]] [33 88]] [33 88]]] [2119 17.9 [4207 0.792 [2143 1.07 [1576 1.07 [3099 0.942 [6462 3.07 [4832 5.23 [1980 31.2 [2253 0.481 [5692 4.94 [2052 3.7 [6449 2.39 [5539 1.28 [1849 3.1 [155 26.1 [2050 15.6 [328 0.19 [6031 0.642 [2011 1.31 [5140 3.11 [2180 0.907 [2199 303 [2246 8.07 [2218 11.7 [286 24.5 [2028 15.7 [1 21] [33 71]] [1 73]] [23 66]] [2199 14.1 [3 29] [1 26]]] [31 41]] [1 43]] [33 90]] [29 45]] [2199 18.6 [26 26] [22 66]]] [33 13]] [11 54]] [1 61]] [25 100]] [13 69]] [4 38]] [1 50]] [33 50]] [1 39]] [2232 46 [2005 7.69 [1459 7.93 [2064 11.1 [4338 10.6 [1998 16.9 [1451 7.87 [1 14] [15 25]] [15 50]] [23 66]] [23 28]] [32 37]] [23 40]] [1 60]]] [2 83]] [25 100]] [25 94]] [2 37]] [7629 1.66 [4332 0.611 [23 0.514 [1698 2.02 [394 0.8 [3622 1.49 [1995 3.13 [1237 0.832 [2064 0.62 [7606 14.7 [4158 4.46 [2226 14.3 [1436 1.38 [2205 2.91 [2048 34.3 [248 1.17 [7343 1.2 [4214 7.53 [2098 61.3 [2178 5.71 [2217 2.2 [2023 30.7 [2202 25.7 [1 34] [29 30]] [35 29]] [1 81]] [1997 8.05 [1104 12.5 [5368 4.35 [29 16] [1 70]] [22 54]] [1953 0.937 [1429 143 [29 23] [23 57]] [11 40]]]] [29 90]] [29 76]] [29 60]] [1 29]] [1 59]] [23 34]] [2050 2.45 [2170 0.352 [1 16] [1 66]] [1 66]]] [1 88]] [2 31]] [19 85]] [1997 8.93 [2072 13.9 [2194 4.64 [4768 6 [2136 3.78 [1451 10.4 [2121 9.06 [2216 2.8 [1078 1.99 [1262 1.17 [1957 1.55 [2225 15.8 [2003 2.59 [29 30] [29 78]] [23 29]] [29 80]] [1 61]] [2232 6.05 [2199 2.75 [19 20] [1 38]] [28 46]]] [29 62]] [29 90]] [28 42]] [2143 9.72 [1 20] [1 88]]] [29 55]] [23 30]] [23 33]] [2131 2.81 [2143 9.89 [1 68] [1 18]] [29 58]]]] [29 100]] [1 17]] [1429 97.3 [2069 0.557 [29 92] [29 100]] [29 66]]] [1453 0.8 [685 3.07 [28 52] [23 55]] [30 90]]] [25 100]] [1997 0.888 [29 24] [26 20]]] [22 28]] [35 45]]] [29 100]] [1429 23.2 [1783 142 [35 53] [23 33]] [29 45]]]] [5641 1.87 [94 1.02 [19 57] [19 100]] [19 55]]] [6806 1.89 [5485 25 [4851 9.82 [2808 5.62 [978 2.82 [2251 4.28 [5402 5.38 [112 11.8 [2526 37.8 [3308 3.82 [2011 10.2 [6184 16.8 [5122 5.26 [1063 17.7 [4978 4 [5692 4.26 [1062 28 [5516 9.94 [7305 12.7 [168 7.82 [2093 1.52 [6031 9.61 [37 9] [22 94]] [14 44]] [28 33]] [0 53]] [16 68]] [17 41]] [22 46]] [28 56]] [35 100]] [30 77]] [10 55]] [29 87]] [29 66]] [0 48]] [6524 12.8 [4011 4.76 [22 14] [37 71]] [22 41]]] [13 100]] [23 4.95 [29 46] [29 58]]] [6817 11.1 [328 4.68 [19 17] [26 100]] [2 100]]] [15 87]] [16 36]] [18 100]] [32 100]]] [23 96]] [5299 0.875 [7078 0.49 [4928 3.27 [1101 0.452 [5999 0.262 [5270 3.27 [3337 16.4 [2023 3.46 [7285 11.5 [7554 3.7 [6929 5.85 [4183 6.41 [2342 2.85 [3928 5.54 [1239 3.06 [7255 22.4 [1783 27 [4 9] [4 22]] [12 90]] [33 9]] [12 62]] [15 71]] [32 90]] [22 50]] [10 80]] [10 55]] [2093 1.57 [10 18] [32 100]]] [15 44]] [6809 5.03 [328 13.2 [6784 1.42 [2262 2.62 [6294 1.37 [6164 3.23 [4953 3.14 [2062 2.65 [4337 2.39 [2379 1.81 [3308 1.85 [5972 2.89 [4369 3.82 [2138 7.94 [1844 4 [6914 6.85 [2470 4.27 [31 27] [31 82]] [13 90]] [31 91]] [31 100]] [31 87]] [31 96]] [22 38]] [11 16]] [13 44]] [31 69]] [31 100]] [31 100]] [4904 1.73 [1899 4.84 [31 58] [31 84]] [31 93]]] [6914 10.8 [11 77] [11 100]]] [31 100]] [2 17]] [32 100]]] [1221 0.891 [1783 63.1 [38 13] [23 36]] [10 100]]] [10 78]] [32 100]] [33 33]] [5496 3.5 [1772 0.481 [5270 1.55 [10 64] [1684 7.25 [2 22] [11 71]]] [21 42]] [2 80]]]] [5368 0.873 [2178 8.97 [3251 3.36 [3997 1.36 [1999 1.45 [2643 2.86 [1252 7.2 [2151 1.07 [2143 23.1 [7656 11 [1955 14.9 [2108 3.45 [5637 3.55 [35 25] [16 30]] [1 50]] [35 75]] [35 92]] [35 55]] [29 53]] [35 77]] [37 37]] [1 57]] [17 60]] [35 53]] [1051 3.65 [29 40] [29 50]]] [1 81]]] [1783 19.5 [38 27] [6830 10.1 [7418 1.9 [38 61] [38 75]] [16 50]]]] [1101 5 [1888 7.87 [2039 18.3 [168 10.6 [2452 12.7 [3338 0.903 [6266 2.44 [3905 8.96 [4159 0.18 [3655 3.45 [5873 7.37 [2042 1.61 [2939 7.84 [328 22.3 [2764 11.4 [2199 3.05 [24 27] [23 57]] [23 68]] [25 27]] [16 50]] [35 40]] [18 57]] [24 63]] [1104 5.38 [2002 2.76 [23 47] [23 100]] [15 66]]] [36 36]] [24 84]] [8 100]] [14 100]] [36 57]] [23 100]] [2259 3.31 [24 52] [24 84]]] [28 18]]] [6899 5.31 [5192 8.62 [6537 3.03 [4663 2.16 [45 3.7 [178 8.09 [5110 9.01 [6328 3.84 [4962 0.808 [6845 4.88 [2936 10.7 [2011 0.503 [6791 8.8 [4338 1.62 [328 28.9 [6040 3.94 [2260 2.59 [33 90] [33 77]] [33 100]] [33 72]] [33 100]] [5170 23.3 [33 80] [33 57]]] [33 100]] [33 57]] [1 50]] [33 100]] [33 60]] [33 100]] [33 67]] [1239 19.3 [33 100] [1 22]]] [33 100]] [33 71]] [33 96]] [33 62]]] [2752 29.1 [3652 10.6 [3208 2.02 [24 88] [24 66]] [2752 15.2 [24 100] [2517 20.5 [24 50] [19 44]]]] [24 82]]] [6380 1.44 [2232 2.18 [4233 6.8 [5368 1.11 [3 71] [3 87]] [3 96]] [3 100]] [3 100]]] [2894 1.61 [7413 9.66 [2763 2.13 [1319 7.34 [6058 3.86 [324 12.8 [250 14.3 [5799 16.2 [6524 4.72 [7623 38.5 [5753 2.99 [1 98] [1 84]] [1 85]] [3635 1.36 [1980 19.9 [248 54.6 [1 82] [1 50]] [1 97]] [1 100]]] [1 72]] [1 77]] [1 100]] [1 60]] [4655 23.5 [33 66] [1 100]]] [33 60]] [1239 13.5 [1 57] [1 41]]] [33 74]]] [248 51.1 [2466 8.64 [26 70] [16 30]] [26 100]]] [7512 18.9 [6524 22.7 [3323 2.1 [4414 0.635 [1 91] [1 100]] [427 1.24 [4978 2.92 [2526 2.76 [1 77] [1 100]] [1 100]] [1264 7.7 [33 77] [1 57]]]] [1 100]] [1 100]]] [2128 1.39 [2001 21.8 [1936 36.1 [2108 20.1 [5851 5.53 [1951 2.04 [35 58] [7623 166 [35 90] [35 100]]] [32 33]] [5 45]] [35 100]] [1 50]] [35 86]]] [1701 13.7 [7301 3.82 [23 31.9 [7241 3.71 [3027 4.18 [26 67] [26 100]] [16 75]] [26 84]] [19 50]] [16 75]]] [2048 12.8 [2062 9.01 [3098 8.93 [2011 2.54 [2538 2.76 [23 65] [23 100]] [23 100]] [23 27]] [23 66]] [23 71]]] [4851 3.45 [1429 62.2 [4684 1.23 [2752 15.6 [7032 8.85 [5447 1.33 [7305 8.58 [4 85] [31 92]] [31 94]] [4 100]] [1429 28.3 [4 42] [4 75]]] [31 100]] [32 55]] [4 100]]] [6524 2.39 [4282 7.85 [6660 2.19 [826 0.828 [3016 1.42 [877 0.515 [6897 0.463 [5970 1.37 [7453 1.68 [728 0.531 [1980 7.86 [7170 0.938 [2701 0.629 [6768 0.573 [2394 3.14 [3884 0.935 [3310 3.04 [1078 4.73 [6619 2.79 [5211 7.07 [560 0.878 [1382 0.515 [1429 14.7 [6892 3.4 [3217 1.73 [7382 2.14 [4154 12 [2752 2.19 [978 1.67 [4218 1.77 [6260 1.42 [7615 3.82 [5322 5.73 [1302 2.37 [5915 1.5 [5290 2.99 [4069 1.23 [1687 0.37 [1277 14.5 [756 0.846 [7233 3.55 [392 9.71 [3013 8.88 [6803 2.79 [21 20] [9 100]] [26 100]] [26 17]] [32 53]] [21 78]] [9 100]] [9 75]] [35 80]] [1428 4.17 [328 9.04 [24 83] [24 100]] [19 42]]] [9 92]] [9 86]] [21 64]] [3 100]] [2411 1.42 [5278 0.88 [9 33] [9 86]] [24 42]]] [3 61]] [3155 0.975 [978 51.6 [1883 12.7 [5673 3.31 [4 34] [18 45]] [2 44]] [2 29]] [35 72]]] [6982 5.88 [1025 19.4 [107 1.09 [7255 49.6 [2769 0.443 [23 2.43 [2804 4.5 [818 11.1 [5322 12.4 [7497 12.7 [2023 17.2 [6178 5.49 [2796 4.26 [2081 16.9 [685 11.2 [429 47.1 [15 7] [15 21]] [23 55]] [2081 25.9 [23 40] [23 70]]] [15 85]] [25 100]] [15 53]] [23 75]] [23 46]] [12 69]] [8 100]] [19 8]] [24 78]] [8 100]] [33 85]] [1026 3.07 [2 35] [12 60]]] [4 78]]] [5753 14.3 [2342 3.45 [6643 3.14 [429 28.6 [24 24] [7185 2.39 [2178 1.39 [1239 8.87 [5322 8.47 [3 33] [3 66]] [3 89]] [21 24]] [3 100]]] [3 100]] [24 25]] [5647 25.1 [3 45] [28 80]]]] [24 88]] [2195 1.06 [2062 1.83 [24 52] [24 94]] [36 92]]] [907 1.82 [21 87] [21 100]]] [5893 1.65 [397 0.778 [24 33 [1428 1.15 [6461 0.149 [4944 7.62 [6380 1.4 [7354 6.29 [6076 1.09 [1560 5.26 [6541 2.86 [5868 0.763 [978 0.0792 [5900 1.28 [4865 2.24 [7734 4.76 [4154 13.9 [5090 17.9 [5769 0.491 [4614 0.863 [5693 4.1 [28 8] [5 16]] [29 100]] [6082 0.492 [328 1.32 [4 34] [28 38]] [11 53]]] [22 100]] [5272 1.4 [1691 1.39 [7512 4.22 [1062 13.2 [32 12] [16 54]] [7512 21.3 [24 88] [24 40]]] [8 100]] [10 100]]] [18 100]] [3 100]] [5989 0.55 [18 42] [18 94]]] [5390 1 [6441 0.0668 [3675 3.32 [2753 12.7 [3929 5.05 [5769 3.31 [6595 2.37 [7301 8.81 [17 11] [6 100]] [4 100]] [4 40]] [5 66]] [1429 42.3 [19 20] [19 40]]] [5 62]] [19 57]] [38 46]]] [7 100]] [12 100]] [0 100]] [5989 5.48 [3061 1.1 [11 33] [11 72]] [2 75]]] [18 19]] [32 28]] [28 69]] [25 93]] [24 66]] [13 89]] [7354 13.7 [6354 4.42 [18 48] [18 76]] [18 100]]] [498 14.7 [791 18.5 [23 6.74 [1678 2.44 [6777 0.839 [328 1.55 [17 60] [3 25]] [35 37]] [17 85]] [3 27]] [17 65]] [17 100]]]] [6 100]] [18 70]] [1477 1.08 [4456 1.82 [7052 14 [6375 19.9 [7305 3.07 [887 3.56 [6550 15.4 [731 14.8 [6653 3.8 [660 4.27 [7413 3.49 [6469 3.88 [2470 14.8 [6732 5.29 [3008 14.8 [2562 1.83 [7623 13.6 [1769 14.8 [2939 5.35 [906 0.332 [996 4.67 [5225 13.2 [22 28] [23 60]] [23 44]] [20 22]] [22 62]] [23 46]] [30 85]] [2526 39.1 [23 91] [8 45]]] [30 66]] [22 80]] [11 65]] [22 100]] [23 50]] [23 68]] [30 62]] [4 54]] [0 60]] [22 77]] [0 58]] [22 100]] [11 100]] [2526 65.1 [0 85] [0 100]]] [8 100]]] [25 100]] [1268 0.0601 [792 3.07 [1052 0.413 [6031 3.18 [5482 0.294 [3944 0.286 [1219 0.197 [6428 0.904 [3747 0.758 [5106 1.92 [6732 27.8 [3908 5.33 [996 1.34 [3660 0.323 [6000 1.14 [392 1.72 [4326 0.635 [5151 1.44 [4673 0.369 [4154 1.07 [5462 11.1 [3273 1.23 [1184 4.61 [4500 4 [2628 6.86 [6572 11.4 [23 6] [24 97]] [726 4.42 [4 31] [4 100]]] [29 100]] [11 84]] [820 4.24 [11 51] [11 100]]] [6375 1.6 [5568 8.72 [23 4.42 [2526 5.75 [35 29] [35 71]] [28 27]] [35 100]] [35 57]]] [4369 0.825 [6813 1.17 [5366 0.671 [7751 2.96 [5630 1.17 [1081 1.81 [23 17] [8 55]] [15 100]] [24 93]] [23 100]] [32 100]] [5267 5.29 [32 58] [31 75]]]] [5963 0.437 [6 72] [6 71]]] [6800 0.763 [31 53] [15 100]]] [7169 5.72 [4114 0.672 [4154 8.36 [27 78] [27 31]] [27 100]] [27 86]]] [2526 10.2 [896 2.01 [5110 5.26 [2760 5.02 [2270 3.07 [4154 15.9 [6363 11.8 [7512 18.4 [5732 1.15 [846 2.56 [28 26] [35 50]] [28 96]] [10 50]] [11 50]] [8 41]] [27 55]] [19 50]] [11 45]] [18 62]] [23 55]]] [5299 0.449 [10 71] [10 100]]] [24 91]] [23 62]] [32 69]] [22 95]] [28 100]] [11 100]] [22 97]] [10 64]] [35 76]] [144 3.17 [5009 1.12 [6199 1.43 [1587 1.09 [5969 1.21 [2466 2.11 [18 59] [19 78]] [18 100]] [312 2.44 [19 44] [19 69]]] [19 52]] [896 7.64 [18 33] [19 71]]] [7537 6.73 [7185 2.42 [4571 2.02 [19 62] [18 75]] [18 60]] [19 100]]]] [5368 1.31 [2236 3.53 [6427 2.76 [2837 2.35 [5090 2.72 [5647 2.51 [7176 1.48 [22 65] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [28 60]] [22 22]]] [10 100]] [820 2.6 [2752 28.2 [11 100] [11 85]] [11 100]]] [6424 3.28 [6749 0.921 [6 100] [6 80]] [6 77]]]] [6353 5.28 [23 51] [29 77]]] [15 84]] [0 73]] [31 100]] [5192 1.72 [7251 2 [5851 16.7 [7731 1.44 [2470 2.94 [5509 6.89 [4414 34.3 [3323 2.73 [4851 5.43 [824 5.53 [2703 1 [7766 1.15 [2808 2.76 [2131 1.77 [7102 1.68 [7491 14.1 [5455 0.78 [4611 22.7 [4279 3.87 [7255 5.43 [5011 4.59 [906 0.298 [4414 13.1 [29 83] [29 66]] [4501 2.26 [29 97] [29 100]]] [29 83]] [29 100]] [29 57]] [29 62]] [29 100]] [15 57]] [29 100]] [29 100]] [15 100]] [29 100]] [29 100]] [15 54]] [29 100]] [29 100]] [15 66]] [15 50]] [15 86]] [29 100]] [29 46]] [15 100]] [15 95]]] [7095 0.938 [15 83] [15 100]]] [4338 1.1 [3449 0.627 [4769 1.38 [6479 2.69 [1617 1.99 [6921 0.732 [1078 6.1 [7615 2.75 [5272 0.655 [5186 35.1 [3308 8.48 [2156 2.65 [978 0.447 [4279 13.2 [398 2.11 [907 6.34 [2939 28.4 [1242 5.56 [26 5.95 [2354 1.38 [4759 0.111 [3439 3.94 [5267 7.81 [2002 8.15 [859 1.44 [5976 2.89 [448 4.95 [7491 4.91 [906 2.53 [1735 0.736 [2987 2.57 [1054 8.09 [6665 1.47 [15 7] [12 100]] [21 71]] [23 65]] [29 95]] [5192 4.35 [1253 3.82 [5692 17.9 [21 40] [9 66]] [9 38]] [15 71]]] [23 45]] [23 65]] [3 100]] [23 48]] [21 47]] [31 21]] [11 92]] [30 100]] [22 100]] [1 85]] [5991 0.406 [29 46] [15 69]]] [21 50]] [21 75]] [23 92]] [7363 5.51 [1841 1.23 [5664 6.87 [791 30.1 [4876 0.66 [29 32] [3 28]] [29 50]] [12 40]] [30 55]] [3 85]]] [7512 2.73 [23 50] [4 23]]] [5851 0.885 [21 49] [21 28]]] [6375 2.07 [584 5.88 [429 9.2 [19 30] [11 66]] [23 100]] [11 78]]] [21 94]] [10 100]] [3 100]] [7103 3.06 [4614 0.982 [3555 1.29 [5116 0.686 [5007 1.93 [7287 4.94 [5247 0.494 [4154 0.506 [929 2 [23 4.56 [567 0.294 [7404 1.28 [820 1.4 [816 6.99 [2181 5.03 [6471 0.864 [377 0.516 [978 2.1 [2259 35.1 [5110 4.56 [1913 37.3 [3619 0.707 [6848 2.15 [3275 1.68 [6732 10.8 [453 4.13 [11 14] [22 100]] [22 66]] [11 100]] [35 69]] [27 78]] [29 37]] [906 3.11 [11 63] [11 80]]] [10 9]] [2764 4.04 [23 50] [23 89]]] [2143 4.1 [11 41] [28 45]]] [26 43]] [2241 0.967 [1078 34.1 [29 26] [12 66]] [30 80]]] [328 2.82 [1101 4.11 [11 41] [29 40]] [11 96]]] [11 93]] [6 100]] [1108 0.94 [5883 41.7 [2567 1.37 [2081 18.4 [3029 23 [5887 0.52 [23 36] [5885 1.42 [11 70] [11 88]]] [23 88]] [1 62]] [23 90]] [11 88]] [11 92]]] [1081 2.86 [2081 19.5 [4424 4.85 [2029 1.59 [3873 0.858 [6184 1.69 [2004 8.24 [1995 24.5 [5641 1.55 [1452 5.43 [22 19] [4 50]] [2 18]] [21 44]] [29 60]] [29 36]] [32 100]] [11 40]] [12 45]] [29 46]] [25 46]]] [7449 2.18 [2763 5.98 [23 65] [2 50]] [23 77]]] [781 0.363 [847 15.4 [6569 1.27 [784 2.67 [7623 7.56 [6328 1.06 [6110 2.49 [4291 2.22 [1476 0.743 [4555 1.37 [5662 2.8 [5482 11.4 [5692 3.15 [2004 4.73 [798 4.96 [774 15.6 [2939 6.13 [404 0.269 [23 22] [28 85]] [1025 3.67 [29 41] [15 55]]] [27 87]] [23 90]] [4279 0.942 [1429 4.85 [29 50] [23 55]] [23 62]]] [5118 1.93 [5753 9.77 [23 47] [28 61]] [22 100]]] [18 90]] [1239 8.26 [22 75] [23 33]]] [23 100]] [12 100]] [15 100]] [22 100]] [15 81]] [27 50]] [27 100]] [32 100]] [2939 25.3 [29 78] [29 71]]] [28 76]]] [11 100]] [2759 6.02 [11 95] [11 100]]] [5211 1.6 [7491 2.24 [29 46] [29 84]] [1078 33.3 [23 75] [22 50]]]] [11 100]] [32 97]] [29 100]] [22 100]]] [2902 10.6 [2845 0.904 [3029 1.75 [4414 7.94 [5693 1.25 [23 92] [23 100]] [23 61]] [23 85]] [23 100]] [11 44]]] [10 100]] [4154 1.95 [978 20.7 [2280 2.35 [1899 8.91 [1062 4.64 [23 100] [23 85]] [23 75]] [23 100]] [23 70]] [23 100]]] [2902 8.97 [29 89] [29 62]]] [35 83]] [5647 28.4 [4288 10.4 [23 74] [23 48]] [1 33]]]] [155 5.18 [6298 1.26 [6353 4.37 [5972 0.657 [5254 1.58 [4279 16.9 [5007 4.52 [1909 9.27 [2143 0.855 [5482 2.07 [649 5.83 [23 15.1 [847 1.01 [2023 6.39 [5673 4.27 [17 23] [19 57]] [10 50]] [31 100]] [36 58]] [16 66]] [18 81]] [2143 3.82 [18 50] [10 81]]] [38 50]] [18 29]] [10 88]] [10 100]] [6767 3.61 [36 58] [31 100]]] [18 76]] [31 100]] [10 83]]] [7493 15.6 [221 2.22 [5110 4.37 [859 0.879 [978 2.73 [4288 0.808 [1429 23.9 [1217 0.581 [144 1.59 [4684 3.36 [2526 13 [1783 11.6 [2083 1.06 [1429 12.4 [29 46] [23 38]] [23 35]] [29 75]] [23 96]] [23 75]] [29 76]] [11 28]] [5480 10.9 [3310 1.21 [5482 0.858 [29 37] [29 77]] [29 91]] [29 80]]] [4279 11.9 [23 85] [23 91]]] [4663 1.73 [23 78] [23 100]]] [22 48]] [11 38]] [29 79]] [22 22]]] [221 1.67 [5480 0.382 [23 71] [5486 0.382 [23 79] [23 100]]] [29 90]]] [6013 12 [1687 0.241 [625 0.463 [822 2.37 [9 70] [9 70]] [9 83]] [823 3.16 [9 80] [9 45]]] [21 75]]] [22 100]] [6730 30.6 [24 88] [24 66]]] [1993 0.414 [3557 2.6 [5211 0.732 [1078 11.1 [7457 8.57 [2178 5.21 [791 56.5 [12 36] [1980 20 [15 36] [11 35]]] [2178 35.1 [23 50] [3 55]]] [15 76]] [5753 13.8 [1980 1.54 [4373 3.94 [2178 4 [504 19.4 [12 39] [12 100]] [12 50]] [15 57]] [7428 2.75 [3452 0.752 [4279 2.69 [7491 7.17 [576 1.52 [2251 2.18 [6342 2.36 [11 54] [23 42]] [22 55]] [11 90]] [12 25]] [2199 1.55 [4279 13.9 [12 66] [15 33]] [23 71]]] [11 100]] [35 42]]] [4154 2.96 [23 42] [23 80]]]] [930 0.522 [7176 1.5 [312 5.6 [2259 5.1 [23 60] [5420 1.12 [978 2.33 [23 58] [23 100]] [1253 1.73 [867 3.14 [5420 14.5 [23 100] [23 82]] [23 100]] [23 100]]]] [11 44]] [11 65]] [23 100]]] [12 87]] [23 100]]] [1769 3.45 [5830 3.14 [2944 3.61 [6114 10.8 [5227 0.652 [2243 1.13 [442 2.04 [5322 0.876 [11 58] [11 90]] [11 69]] [11 96]] [11 100]] [11 23]] [21 100]] [11 100]] [429 22.1 [11 57] [11 100]]]] [583 2.46 [3451 4.76 [6122 5.36 [569 4.67 [1 8.51 [4159 16.7 [1899 18.4 [2199 0.8 [907 4.07 [5632 4.13 [3 73] [3 100]] [3 100]] [3 30]] [1 27]] [15 50]] [3 100]] [3 100]] [13 68]] [35 73]] [3 100]]] [7729 2.42 [2526 8.07 [6427 0.888 [6566 0.795 [6178 1.62 [4270 5.75 [5283 1.75 [1429 9.28 [802 5.41 [7502 0.162 [3237 2.58 [2099 11.7 [5110 2.17 [4398 9.83 [4611 2.22 [436 1.87 [978 14.6 [119 2.39 [5211 5 [2753 2.56 [4655 8.2 [2081 28.4 [2251 3.47 [28 27] [28 45]] [22 53]] [1 100]] [22 79]] [6732 3.14 [4312 3.7 [685 22.3 [22 76] [22 100]] [22 100]] [22 100]]] [22 100]] [25 56]] [22 53]] [31 40]] [15 81]] [429 38.1 [22 63] [22 37]]] [15 70]] [11 100]] [28 91]] [21 51]] [6711 4.51 [5692 4.9 [1911 6.75 [5110 1.44 [6732 3.13 [7354 23.4 [5482 0.519 [6708 28 [978 3.86 [5211 3.27 [2081 1.27 [4154 3.52 [28 44] [4568 4.76 [4332 19.3 [429 14.5 [28 88] [28 61]] [28 62]] [28 100]]] [5412 5.01 [1062 1.18 [28 37] [28 33]] [28 82]]] [22 100]] [2259 9.95 [7 23] [7 33]]] [7 83]] [22 61]] [7 80]] [22 85]] [7449 10.5 [22 68] [22 62]]] [28 69]] [1239 11 [6110 1.18 [6364 1.08 [435 2.22 [22 62] [28 50]] [28 66]] [22 100]] [1 28]]] [1429 25.9 [22 90] [22 100]]]] [1429 47.8 [2354 1.73 [1078 5.54 [22 90] [22 100]] [22 100]] [23 7.81 [22 77] [22 100]]]] [36 100]] [25 100]] [435 2.97 [11 70] [11 66]]] [22 100]] [7623 2.73 [673 8.77 [201 2.89 [6526 1.87 [25 43] [25 100]] [25 100]] [25 100]] [1 60]]] [2225 5.87 [1 91] [33 62]]]]] [859 0.302 [7512 0.739 [22 69] [22 100]] [22 100]]] [4218 3.27 [3768 4.35 [4338 0.603 [5709 2.18 [5764 0.294 [4896 1.93 [685 6.04 [4690 0.508 [112 3.1 [5769 0.995 [3462 0.882 [1062 3.99 [23 4.98 [5260 3.6 [6597 4.98 [6853 2.13 [2562 5.26 [6643 9.43 [5393 1.22 [7512 13 [2268 3.27 [3165 3.27 [8 65] [8 100]] [34 85]] [13 100]] [35 30]] [13 92]] [0 100]] [1429 29.5 [34 100] [34 57]]] [34 71]] [13 94]] [1764 1.95 [13 49] [0 100]]] [1997 5.15 [429 31.9 [8 33] [2488 18.1 [8 57] [8 92]]] [34 45]]] [0 64]] [2 44]] [13 86]] [7307 0.542 [3497 1.85 [2536 6.7 [883 0.963 [1025 4.52 [731 3.11 [8 74] [8 71]] [0 80]] [0 100]] [8 100]] [0 78]] [0 100]]] [1089 2.86 [3224 3.23 [8 98] [8 100]] [8 100]]] [32 83]] [0 100]] [34 100]] [8 94]] [13 100]] [13 100]]] [1899 0.826 [6134 0.803 [4353 1.9 [5830 0.994 [11 78] [11 100]] [32 100]] [32 96]] [7139 6.98 [5117 0.422 [6342 0.592 [11 100] [1980 13.2 [11 100] [11 80]]] [11 100]] [11 85]]]] [2259 38.1 [3027 8.28 [2701 0.719 [2939 2.62 [663 2.11 [29 74] [29 100]] [29 70]] [1783 11.3 [2199 0.719 [112 0.838 [29 97] [29 100]] [29 100]] [29 88]]] [29 55]] [29 61]]] [7 100]] [1020 0.485 [6470 2.01 [2793 4.49 [5282 2.2 [4550 7.52 [2548 4 [312 4.36 [6767 4.37 [7491 15.4 [5989 2.99 [1218 0.997 [7176 1.35 [7591 12.5 [7243 1.95 [601 3.31 [4485 3.07 [5480 1.93 [7425 14.6 [794 2.33 [429 21.9 [5873 3.98 [23 13.1 [24 50] [36 59]] [36 85]] [36 70]] [28 100]] [24 100]] [22 72]] [36 100]] [36 100]] [36 100]] [36 100]] [22 100]] [36 100]] [28 86]] [22 65]] [31 100]] [31 61]] [24 100]] [31 100]] [22 100]] [5454 11.7 [1649 2.02 [24 91] [24 100]] [24 100]]] [22 100]] [24 100]]] [4321 7.69 [429 61.3 [3691 0.631 [774 0.562 [434 28.7 [65 3.23 [1123 1.31 [756 10.2 [6349 10.8 [5485 4.85 [5732 2.46 [7185 7.29 [4114 1.61 [957 41 [3008 14.7 [1630 6.67 [4228 2.49 [2180 0.84 [1119 4.35 [5160 7.19 [3506 8.47 [4382 2.73 [2939 14.5 [5480 5.52 [728 14.5 [392 16.7 [6524 4 [2752 9.72 [7149 6.85 [27 40] [5 20]] [4414 6.92 [27 13] [11 29]]] [7 40]] [27 90]] [728 26.8 [36 44] [17 55]]] [18 50]] [957 16.7 [10 37] [10 81]]] [27 100]] [37 50]] [30 100]] [27 100]] [27 73]] [27 100]] [32 33]] [10 62]] [27 70]] [27 89]] [663 5.52 [18 45] [18 75]]] [28 62]] [18 71]] [10 100]] [30 100]] [27 100]] [30 100]] [37 80]] [4331 2.3 [4227 2.44 [1926 4 [4372 2.44 [3031 1.12 [4569 7.41 [4665 15.5 [27 92] [27 85]] [27 100]] [27 100]] [27 100]] [10 85]] [27 100]] [27 100]]] [37 95]] [3735 2.04 [2199 15.5 [6970 10.6 [4533 12.8 [6087 2.33 [27 81] [27 100]] [27 72]] [10 100]] [27 65]] [27 100]]] [10 100]]] [6260 3.44 [3272 2.71 [313 3.65 [4218 0.109 [7664 16 [6653 0.386 [4145 0.3 [31 7.84 [1761 5.14 [3972 1.79 [4533 10 [2161 1.18 [3561 1.1 [2753 2.18 [5838 11.6 [3272 1.09 [5211 3.42 [4408 3.74 [7314 8.51 [787 3.07 [3130 1.78 [5019 14.7 [1101 0.516 [2849 2.02 [3099 21.7 [3045 39 [1906 2.25 [4876 12.7 [2143 3.53 [3449 18 [3857 1.83 [3862 30.6 [3457 0.656 [1429 72.9 [2259 62.5 [4205 7.07 [3675 6.4 [333 4.62 [4154 3.64 [5680 2.49 [3538 0.852 [835 1.36 [429 1.58 [5462 8.47 [4414 6.17 [35 79] [35 87]] [35 62]] [35 89]] [35 100]] [3539 20.1 [35 100] [35 87]]] [35 96]] [3849 12.5 [35 69] [35 95]]] [35 100]] [35 80]] [26 50]] [1 50]] [6791 7.94 [3045 14.9 [429 13.2 [35 78] [35 53]] [35 95]] [35 66]]] [35 95]] [35 57]] [32 37]] [35 60]] [35 92]] [35 50]] [35 100]] [35 67]] [35 66]] [26 42]] [35 93]] [35 57]] [35 94]] [35 50]] [35 58]] [35 100]] [35 46]] [35 55]] [35 75]] [35 25]] [30 100]] [35 96]] [35 53]] [8 81]] [35 94]] [17 66]] [35 44]] [29 35]] [35 50]] [8 44]] [37 60]] [3045 11.5 [489 1.66 [5673 2.54 [35 97] [35 100]] [35 100]] [35 94]]] [8 50]]] [5368 0.773 [1999 4.79 [22 100] [22 93]] [22 100]]] [435 6.88 [377 3.14 [4326 1.86 [3931 10.2 [4141 16.5 [4323 2.51 [1159 7.65 [4115 12.5 [4140 13.5 [906 12.2 [23 3.7 [2931 7.46 [5345 3.5 [1986 2.59 [4315 3.31 [2752 21.6 [3227 3.31 [4154 1.31 [27 28] [27 42]] [23 16]] [27 47]] [27 100]] [23 55]] [27 100]] [27 87]] [4114 40.3 [0 40] [29 25]]] [27 64]] [27 85]] [27 72]] [27 82]] [27 100]] [4114 64 [27 87] [27 50]]] [27 84]] [27 96]] [23 42]] [1995 3.94 [23 38] [23 66]]]] [4538 6.11 [7255 0.13 [1341 0.398 [6471 0.775 [88 0.701 [6370 31.9 [75 0.237 [7457 0.952 [6353 11.5 [305 2.06 [4851 3.94 [2259 60.9 [2717 0.191 [7765 0.982 [2683 1.29 [2709 0.458 [301 10.1 [2948 0.835 [2955 3.74 [6831 1.28 [2737 2.37 [2951 43.4 [3243 0.928 [7132 58.2 [4740 3.78 [5594 0.647 [2941 13 [1783 55.3 [6406 28.2 [2729 7.46 [6920 4.68 [5767 0.18 [5632 0.401 [2207 4.65 [4457 16.5 [2661 6.85 [3675 62.6 [38 31] [33 77]] [16 43]] [16 72]] [38 72]] [16 26]] [5 50]] [16 70]] [16 88]] [16 56]] [7330 16.1 [25 25] [22 61]]] [6 42]] [16 43]] [16 42]] [7 90]] [5 52]] [38 63]] [38 100]] [16 39]] [2852 9 [7122 5.71 [2644 1.37 [6409 9.37 [6431 18.9 [4074 0.53 [2978 2.26 [2891 12.4 [7134 15.9 [2939 107 [2951 35.2 [2734 3.31 [2897 3.07 [3419 1.5 [2983 26.8 [7132 16.3 [1789 5.12 [2661 6.33 [194 1.43 [4987 3.27 [2181 1.25 [2143 4.92 [1445 0.993 [7445 22 [5632 10.5 [5363 5.11 [7475 16.2 [5345 4.13 [38 53] [38 31]] [38 92]] [38 88]] [16 50]] [26 57]] [37 21]] [38 89]] [12 50]] [7 41]] [38 20]] [14 27]] [38 77]] [38 93]] [7 100]] [5 75]] [38 61]] [6 28]] [7390 2.03 [38 65] [38 85]]] [187 0.524 [5577 7.87 [3061 5.41 [2642 2.26 [4895 7.53 [7009 31.1 [5007 2.02 [38 75] [38 65]] [4601 13.4 [37 37] [36 54]]] [38 54]] [17 45]] [38 93]] [16 87]] [38 84]]] [7 100]] [7 100]] [2979 15.9 [38 47] [16 92]]] [5 72]] [7 87]] [16 52]] [16 36]] [16 93]] [16 47]]] [2039 3.24 [38 81] [38 100]]] [30 96]] [5637 13.3 [2993 5.8 [2734 0.396 [5412 0.537 [2667 3.88 [5985 17 [38 28] [16 46]] [16 63]] [16 28]] [16 48]] [16 81]] [16 55]]] [4426 2.24 [7122 18.4 [16 85] [16 55]] [38 45]]] [7 32]] [2870 2.05 [189 1.17 [5438 1.6 [3207 5.01 [5637 1.16 [7206 8.66 [2646 3.46 [16 61] [16 87]] [2628 54.8 [28 30] [2653 13.9 [16 73] [10 42]]]] [2663 3.09 [16 77] [16 54]]] [14 25]] [16 50]] [18 72]] [6688 3.36 [16 33] [7 22]]]] [3110 11.5 [5753 0.266 [2374 5.59 [7445 5.76 [2364 1.29 [1429 11.7 [167 2.73 [38 76] [38 90]] [7474 1.83 [38 36] [2862 7.56 [38 75] [38 83]]]] [38 100]] [14 71]] [38 100]] [22 50]] [14 66]]] [5901 5.3 [6433 6.19 [2668 9.34 [85 5.18 [6571 4.42 [2880 3.65 [5595 5.97 [6701 4.41 [2941 1.4 [2667 7.13 [6181 4.07 [2974 3.26 [6199 5.1 [7123 67.7 [7759 8.65 [2707 47 [5723 5.92 [187 6.69 [16 33] [2939 71.9 [5647 19.8 [2232 1.64 [6 32] [28 37]] [6 75]] [6 93]]] [6 81]] [2978 32.5 [6 61] [16 70]]] [13 71]] [16 33]] [2752 3.36 [95 4.59 [14 20] [17 57]] [1 22]]] [17 60]] [35 45]] [2951 26 [16 54] [2951 43.1 [38 41] [16 60]]]] [2466 3.18 [2940 38.9 [16 66] [188 7.34 [6 61] [6 100]]] [6 87]]] [18 58]] [16 64]] [14 80]] [17 60]] [18 76]] [7 100]] [1754 1.17 [17 37] [17 100]]] [18 62]]] [307 2.33 [30 61] [30 95]]] [7 51]] [1429 7.37 [5 38] [6031 7.96 [5 67] [5 86]]]] [7421 0.237 [193 6.29 [1429 5.85 [16 36] [4515 0.701 [187 1.9 [16 65] [2707 9.61 [16 76] [16 96]]] [16 87]]] [6 80]] [16 100]]] [16 54]] [2711 20 [37 39] [6779 22.4 [37 92] [37 42]]]] [7210 11.9 [2628 7.55 [26 86] [5617 2.51 [2734 3.7 [248 4.63 [1899 4.93 [26 37] [26 75]] [26 64]] [6 75]] [26 62]]] [26 85]]] [1239 23.3 [7343 0.705 [38 92] [38 100]] [5414 1.69 [2688 32.7 [38 90] [38 42]] [38 97]]]] [4743 1.02 [83 3.46 [6199 12.7 [63 4.02 [6509 1.89 [5894 1.09 [6380 2.17 [1821 1.43 [429 1.88 [2466 4.4 [5438 1.97 [2679 7.51 [3675 15 [2081 10.1 [2435 14.1 [7445 0.606 [2707 36.7 [16 38] [38 60]] [26 30]] [8 71]] [17 30]] [38 73]] [7122 53.1 [2683 7.85 [18 45] [18 66]] [16 60]]] [6134 2.37 [7150 10.2 [16 50] [16 71]] [16 40]]] [16 65]] [16 23]] [7 100]] [2112 0.805 [25 23] [38 100]]] [6961 13 [1980 9.12 [6687 1.35 [1262 1.92 [7425 2.22 [6342 0.949 [6139 1.33 [18 66] [18 44]] [18 54]] [16 54]] [19 25]] [6 35]] [16 62]] [7 62]]] [7 100]] [16 72]] [38 53]] [6875 3.09 [7445 4.62 [7041 6.09 [2650 9.71 [7104 2.59 [2207 3.76 [6473 2.26 [83 13.2 [5635 9.16 [16 29] [25 44]] [16 52]] [26 66]] [16 66]] [16 73]] [2849 71.1 [7255 21.6 [16 57] [16 100]] [16 50]]] [16 45]] [16 50]] [38 68]]] [5594 1.16 [16 67] [6417 3.03 [7 88] [7 100]]]]] [4943 1.96 [2718 4.32 [38 88] [38 98]] [1807 3.82 [17 66] [38 45]]]]] [2669 0.588 [1646 2.43 [7048 1.41 [189 4.83 [5753 2.61 [5003 1.78 [1611 3.65 [5600 6.52 [2849 27.3 [2979 1.01 [6159 6.73 [2954 5.88 [7038 6.39 [4727 2.24 [5647 0.654 [6431 5.57 [7765 4.82 [5568 5.43 [192 7.1 [301 6.73 [7154 3.28 [4880 9.04 [3008 1.96 [2719 1.92 [2081 5.49 [5594 13.6 [2143 3.22 [6 32] [18 54]] [16 75]] [6 48]] [7255 4.86 [6 42] [7 42]]] [32 27]] [6 70]] [16 50]] [30 75]] [16 85]] [32 38]] [7 26]] [7 95]] [190 2.96 [37 40] [16 50]]] [6 85]] [2640 0.761 [6406 4.65 [16 52] [6 57]] [16 85]]] [30 85]] [16 84]] [6 72]] [5102 20.5 [6422 4.91 [5281 1.53 [6152 6.8 [1769 19.1 [5983 20.4 [4414 57.4 [5933 6.94 [3972 4.59 [4623 32 [6256 2.85 [3675 6.91 [6756 18 [6689 2.07 [1888 2.82 [5632 3.13 [5104 18.3 [6500 12.9 [2951 16.8 [5102 14.9 [94 0.718 [2853 0.396 [187 17.9 [2469 3.1 [16 50] [16 81]] [16 58]] [16 66]] [6 44]] [2727 6.5 [4762 0.468 [6 54] [16 77]] [16 37]]] [6959 2.84 [16 37] [6 60]]] [6 66]] [6 100]] [16 58]] [6 80]] [6 72]] [16 100]] [16 72]] [18 67]] [5 33]] [37 35]] [2849 50.2 [16 85] [16 53]]] [32 45]] [5986 11.5 [6 76] [1429 3.65 [6 30] [6 60]]]] [16 80]] [18 82]] [18 63]] [6 78]] [2849 39.5 [6940 4.93 [7149 7.87 [6 51] [18 52]] [6 84]] [5595 14.8 [6 63] [16 55]]]]] [2466 1.87 [16 57] [16 100]]] [5211 10.5 [30 85] [30 100]]] [7 100]] [23 10.5 [4452 3.4 [6961 3.3 [7149 0.467 [2720 7.53 [7759 12.5 [2707 36.2 [6409 12.8 [18 34] [28 40]] [2628 49.7 [16 75] [18 37]]] [7 88]] [18 100]] [16 42]] [7 55]] [6 100]] [7260 1.05 [2955 9.72 [18 77] [4854 11.4 [7 66] [18 46]]] [2707 12.5 [18 90] [18 85]]]]] [2662 0.438 [6 71] [6 100]]] [2260 6.64 [5100 14.2 [16 31] [30 29]] [30 100]]] [1661 0.577 [2978 2.66 [5637 2.2 [16 44] [16 100]] [6 50]] [16 50]]] [7 96]]] [6395 1.15 [5851 9.16 [4751 1.87 [1757 3.62 [1304 2.11 [6194 8.85 [815 0.303 [816 1.31 [5410 31.3 [803 3.76 [5831 2.37 [4414 0.963 [2178 11.3 [5692 18.5 [634 1.99 [5050 2.76 [5187 2.2 [21 80] [21 100]] [9 85]] [21 100]] [21 100]] [9 77]] [1980 3.48 [21 71] [21 55]]] [9 90]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [2259 1.97 [9 87] [21 60]]] [9 76]] [9 87]] [21 54]] [21 100]]] [3 100]] [6297 1.04 [3055 1.89 [5122 2.54 [7453 1.65 [6242 0.27 [7322 3.34 [5296 3.76 [5482 2.53 [4210 0.942 [7623 6.02 [4338 8.95 [731 1.01 [6235 15.4 [663 7.58 [756 6.97 [3381 10.5 [874 0.766 [5211 2.07 [978 5.54 [4802 2.65 [3204 0.613 [2968 1.92 [7739 4.82 [2470 2.39 [1888 18.8 [4205 5.38 [4364 10.1 [5568 2.65 [2488 2.01 [5617 9.62 [2526 21.9 [1716 4.35 [5999 13.2 [3251 9.98 [7140 4.07 [5641 0.439 [7254 13.9 [4884 12.3 [3308 10.8 [4809 5.03 [7373 4.07 [3056 10 [1679 7.5 [5140 1.42 [2260 6.89 [5588 5.52 [6027 0.441 [4170 3.82 [4218 20.5 [7340 3.6 [1239 9.95 [2987 4 [3095 7.46 [3424 25.5 [7009 23.2 [1089 7.91 [112 7.68 [12 9] [29 50]] [1 25]] [5 50]] [1 30]] [1 36]] [17 66]] [6395 13 [429 30.1 [1980 4.65 [4154 9.6 [2628 12.1 [3 10] [16 50]] [3 33]] [10 25]] [3 45]] [13 44]]] [1078 27.2 [32 100] [32 85]]] [5 87]] [32 72]] [38 55]] [21 25]] [18 52]] [33 100]] [30 66]] [1429 51.1 [12 58] [5 50]]] [24 35]] [35 46]] [29 46]] [32 100]] [14 50]] [6230 12.2 [26 33] [19 66]]] [9 50]] [18 83]] [1 47]] [30 50]] [0 28]] [33 87]] [34 68]] [33 55]] [34 59]] [7 50]] [5 19]] [2081 3.31 [30 41] [30 100]]] [18 85]] [5 52]] [12 63]] [1 63]] [1078 32.9 [17 19] [328 2.37 [5 46] [5 42]]]] [0 28]] [12 100]] [30 88]] [30 100]] [5632 4.12 [985 1.98 [726 3.6 [4861 16.1 [2826 4.9 [1429 51.1 [1062 2.56 [5 15] [5 75]] [30 37]] [6241 3.36 [17 29] [5 50]]] [5 66]] [5 50]] [17 62]] [16 100]]] [34 70]] [178 3.65 [663 10.1 [896 8.64 [2081 7.67 [733 11.6 [978 29.1 [3056 4.81 [2939 9.64 [2526 4.96 [17 21] [429 3.89 [5 20] [2607 5.74 [5 57] [19 62]]]] [19 48]] [5 91]] [17 32]] [7 21]] [18 50]] [7 76]] [1740 1.62 [7445 1.83 [2259 5.33 [17 38] [23 3.95 [7 27] [5 66]]] [16 38]] [19 60]]] [7354 13.8 [2826 6.25 [38 63] [5 58]] [2826 8.81 [18 57] [5 25]]]]] [4 21]] [34 59]] [34 70]] [18 36]] [19 50]] [30 70]] [7185 3.94 [5 60] [5 100]]] [7449 19.7 [7 55] [22 85]]] [30 95]] [0 100]] [31 100]]] [2526 0.416 [1888 6.98 [6809 0.488 [5692 0.8 [221 0.861 [906 3.79 [5225 1.59 [5211 4.75 [39 3.65 [2081 31.3 [5035 3.11 [4865 2.49 [2939 99.2 [4895 28.5 [730 5 [4444 1.32 [6239 2.26 [7340 1.37 [3554 11.1 [2793 5.16 [4564 1.87 [802 11 [7314 18.9 [2143 8.87 [429 1.13 [2023 3.18 [14 53] [14 87]] [6445 2.26 [4233 2.51 [5918 14.7 [5267 1.82 [429 67.2 [5017 1.47 [14 37] [3 50]] [3 83]] [32 44]] [14 42]] [3 100]] [14 75]]] [3 79]] [14 68]] [802 23.8 [3 72] [3 96]]] [3 62]] [1980 2.67 [14 93] [14 100]]] [32 100]] [32 95]] [14 100]] [1951 2.13 [1 43] [1 100]]] [28 64]] [20 42]] [38 82]] [3 100]] [20 100]] [3 65]] [3 100]] [4279 3.07 [30 95] [30 100]]] [6713 10.5 [4210 4.76 [30 97] [30 100]] [30 78]]] [328 15.1 [2002 3.7 [2081 11.8 [4154 6.99 [3 79] [4282 1.31 [3 75] [3 100]]] [3 100]] [3 100]] [3 50]]] [5034 11.1 [1980 2.39 [30 79] [30 83]] [1429 15 [30 55] [328 4.42 [4851 4.2 [30 66] [30 100]] [30 85]]]]] [685 1.83 [5211 1.53 [28 30] [7067 2.44 [2259 57.3 [1769 2.59 [6155 6.88 [2016 1.75 [7169 0.888 [6708 2.89 [30 98] [30 100]] [30 100]] [30 66]] [30 62]] [30 100]] [30 85]] [30 100]]] [28 71]]] [32 100]] [7343 5.38 [5605 5.26 [14 67] [14 63]] [14 100]]] [2826 1.25 [5462 1.98 [2081 25.2 [3 40] [3 100]] [14 42]] [14 57]]]] [4213 1.5 [2574 0.182 [2470 0.697 [2039 7.53 [3008 9.76 [7255 10.4 [4408 0.745 [291 1.9 [3667 12.2 [1207 1.71 [2624 7.92 [5979 2.16 [2097 0.507 [5520 0.571 [5972 5.88 [6552 2.33 [7381 9.07 [6582 0.365 [2517 0.154 [4968 1.49 [3155 0.577 [5007 0.123 [392 1.46 [6537 7 [4833 16.4 [6529 9.37 [7292 0.743 [7363 5.99 [2628 11.3 [1429 18.8 [1240 0.732 [1106 17.4 [2200 4.48 [2505 3.23 [5814 3.95 [2259 3.87 [5480 0.795 [228 1.24 [5239 11.1 [2529 12.8 [2161 0.606 [4764 0.901 [5673 11.8 [7512 1.93 [1783 32.5 [4158 2.56 [6927 5.49 [1078 106 [4931 1.74 [5662 10.1 [429 65.6 [2 33] [35 33]] [2 53]] [4 100]] [4 44]] [2 100]] [2 68]] [11 33]] [429 36.1 [1094 3.07 [4851 3.14 [2 54] [4 41]] [2 75]] [19 44]]] [35 46]] [2 62]] [4 50]] [2 60]] [4 85]] [2 75]] [22 35]] [4832 0.539 [4159 2.67 [4 13] [12 42]] [2 40]]] [35 22]] [13 100]] [13 60]] [4 100]] [23 80]] [733 0.639 [896 7.76 [7251 3.6 [4332 11.5 [6413 1.1 [3492 5.47 [2199 2.09 [896 1.18 [4851 1.13 [2628 6.55 [6230 7.74 [5673 0.543 [2081 11.6 [5267 12.3 [7255 0.348 [2488 9.24 [1025 4.03 [6977 4.95 [5 16] [5 40]] [1 20]] [13 76]] [8 27]] [12 30]] [12 21]] [3 26]] [17 37]] [17 70]] [32 50]] [38 42]] [29 44]] [17 50]] [7 71]] [5 81]] [19 41]] [5 60]] [5 69]]] [4 31]] [4 94]] [1239 6.36 [429 38.6 [4279 2.39 [2 50] [4 62]] [4 42]] [4 66]]] [22 58]] [2 73]] [2752 16.3 [2 100] [2 87]]] [19 18]] [29 31]] [35 59]] [328 3.89 [35 75] [19 75]]] [24 100]] [4 100]] [2 50]] [4 100]] [12 80]] [19 100]] [29 94]] [12 100]] [12 92]] [2 90]] [7633 6.8 [35 77] [35 50]]] [2 54]] [3744 6.2 [1078 21.4 [35 77] [35 100]] [35 53]]] [12 67]] [3667 1.57 [3851 1.75 [3232 3.7 [6584 1.16 [6285 0.697 [24 45] [24 88]] [19 50]] [35 100]] [35 66]] [35 84]]] [35 68]] [1919 0.858 [5625 2.19 [6332 4.93 [7132 0.987 [6581 1.22 [2232 1.03 [7742 1.52 [4 72] [2617 8.47 [4 83] [4 100]]] [4 88]] [4 100]] [4 100]] [4 69]] [4 100]] [4 95]]] [1075 10.3 [4 43] [1 77]]] [12 100]]] [371 0.938 [2081 0.873 [6883 9.08 [5916 1.27 [4480 10.7 [6711 13 [6091 20.6 [791 27.5 [5918 1.86 [1239 78.8 [21 99] [21 77]] [21 54]] [6082 0.931 [5206 0.911 [4690 1.48 [765 4.13 [6059 27 [21 99] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]]] [9 66]] [21 81]] [21 80]] [9 100]] [5041 2.54 [21 81] [21 100]]] [21 100]] [2994 3.07 [4154 5.75 [21 87] [21 57]] [21 100]]]] [5940 9.32 [5271 0.107 [1461 0.0709 [6760 0.346 [6943 7.26 [5896 0.384 [4058 0.146 [5940 2.86 [2069 0.0806 [5910 0.162 [4537 0.831 [4456 0.093 [6308 5.92 [6382 17.3 [2058 0.183 [7197 0.123 [1997 0.278 [6227 0.205 [17 33] [17 55]] [2093 0.436 [4576 0.278 [32 54] [32 100]] [32 47]]] [17 100]] [17 46]] [19 47]] [32 100]] [17 100]] [4640 0.63 [19 50] [19 85]]] [17 92]] [32 50]] [4279 13.3 [4456 1.03 [273 3.14 [4630 9.01 [3 48] [2280 0.895 [1078 3.48 [2259 36.3 [1689 7.17 [17 38] [19 85]] [17 61]] [3 55]] [17 42]]] [1568 1.45 [32 57] [32 100]]] [1711 2.99 [17 75] [19 62]]] [32 73]]] [2275 0.342 [17 69] [17 42]]] [3995 1.49 [2169 0.341 [1588 0.203 [3597 2.21 [4764 0.796 [5892 2.96 [17 95] [17 65]] [17 55]] [17 30]] [6227 0.101 [17 66] [17 100]]] [29 41]] [14 50]]] [4896 0.635 [6809 19.4 [32 100] [32 85]] [32 84]]] [3 100]] [3 100]] [4009 0.107 [32 88] [32 100]]] [5892 9.49 [3597 3.22 [1899 0.264 [1581 1.18 [3 86] [3 100]] [3 100]] [3 58]] [7333 11.1 [362 8.31 [4867 1.78 [1673 2.66 [3 31] [17 88]] [3 100]] [3 100]] [17 78]]]]] [4398 4.98 [1888 10.8 [30 86] [4 69]] [15 64]]] [1913 1.12 [2464 5.5 [4587 4.94 [1058 5.75 [4920 3.42 [6528 1.22 [1587 4.19 [3695 1.19 [4684 2.77 [328 29.7 [6900 43.3 [2068 0.655 [6040 3.68 [6959 4 [5618 1.36 [1445 5.8 [3424 6.86 [4900 2.18 [5851 27.1 [1337 1.79 [2213 2.28 [5211 2.04 [7208 2.42 [1391 13.3 [7329 15.8 [1342 2.48 [1722 20.5 [33 83] [33 94]] [33 100]] [33 60]] [33 60]] [33 88]] [33 87]] [33 87]] [33 100]] [33 70]] [33 100]] [33 100]] [13 46]] [33 100]] [11 28]] [1239 12.4 [33 100] [32 50]]] [33 64]] [33 66]] [33 72]] [33 66]] [1980 1.19 [33 93] [33 90]]] [33 61]] [33 37]] [30 30]] [33 42]] [33 50]] [33 100]] [33 57]]] [6189 0.813 [7729 0.787 [6949 1.09 [404 5.6 [1849 1.77 [2202 1.77 [33 12.8 [4655 4.51 [1239 73.9 [5617 29.5 [392 2.16 [7154 1.44 [7428 14.3 [6928 46.9 [6935 19 [4154 3.37 [5462 11.1 [5509 5.2 [5462 5.24 [6711 1.86 [3993 5.11 [1813 4.08 [5622 0.73 [2894 19.7 [1769 12 [5278 1.72 [4533 9.05 [7769 14.4 [1293 9.26 [5423 0.852 [2526 33.6 [6445 0.724 [2881 9.54 [67 17.6 [5361 8.7 [2892 4.14 [6397 18.4 [4858 2.62 [286 1.36 [3130 1.18 [7726 0.673 [2939 17.7 [4682 73.7 [6068 1.47 [6964 2.04 [5170 1.08 [5753 15.4 [2894 0.945 [4895 1.52 [4703 8.64 [33 90] [5617 9.09 [1980 4.5 [33 98] [33 100]] [33 100]]] [33 100]] [33 100]] [33 93]] [33 100]] [33 100]] [33 100]] [33 75]] [33 86]] [33 100]] [33 100]] [33 100]] [33 87]] [33 83]] [5412 7.51 [33 97] [33 92]]] [33 62]] [33 87]] [33 73]] [33 100]] [33 88]] [33 100]] [33 92]] [33 81]] [33 88]] [33 87]] [33 84]] [33 91]] [33 85]] [6406 1.71 [33 68] [33 92]]] [33 57]] [33 37]] [33 64]] [33 50]] [28 66]] [1062 14.3 [1980 10.5 [4214 1.04 [1301 3.4 [25 1.87 [1429 46 [33 100] [33 80]] [33 85]] [5753 1.14 [23 28.6 [33 57] [33 100]] [33 100]]] [33 100]] [33 100]] [33 85]]] [33 50]] [13 50]] [33 50]] [33 76]] [30 62]] [33 50]] [6899 8.47 [33 72] [33 44]]] [33 67]] [33 66]] [25 44]] [25 100]] [28 43]] [25 42]] [7415 1.99 [33 53] [33 55]]] [25 88]]] [3905 6.77 [1713 2.79 [5211 0.499 [4364 0.787 [2913 48.9 [5589 3.27 [7340 2.59 [6177 3.4 [1664 1.24 [6024 5.62 [243 0.835 [502 0.341 [2916 4.08 [3501 2.16 [328 46.1 [5768 4.2 [2253 5.7 [6230 3.27 [2178 13 [5122 0.882 [660 5.99 [3055 3.76 [4601 0.36 [4597 0.568 [301 3.94 [148 2.46 [2917 5.72 [2713 10.3 [2628 9.44 [1429 13.3 [5040 9.92 [4353 3.23 [7085 13.2 [802 0.69 [6524 8.36 [6342 10.9 [4312 2.96 [4369 6.05 [1783 1.95 [2913 47.1 [5509 14.4 [4210 0.73 [2004 8.65 [7241 4.76 [3 13] [3 63]] [11 57]] [30 72]] [7 62]] [15 50]] [1429 5.05 [3 51] [9 27]]] [32 60]] [3 66]] [7 38]] [25 57]] [328 5.45 [906 6.22 [1239 1.38 [15 50] [3 75]] [3 75]] [3 66]]] [15 85]] [9 36]] [791 38.2 [21 70] [21 100]]] [6959 1.85 [429 3.93 [4533 1.59 [30 48] [32 43]] [3130 5.92 [5034 1.08 [6929 10.1 [5 17] [11 25]] [32 66]] [0 28]]] [7 75]]] [5 49]] [16 75]] [4282 1.04 [7316 2.92 [2917 10.8 [3 48] [1783 41.8 [3 85] [3 37]]] [3 100]] [3 100]]] [30 68]] [30 87]] [15 100]] [26 54]] [0 100]] [5 49]] [30 100]] [6643 7.19 [3 46] [3 100]]] [2178 2.06 [5 36] [6 30]]] [2251 12.7 [30 100] [6773 7.84 [30 50] [30 81]]]] [3 95]] [26 48]] [0 100]] [5509 6.63 [2259 4 [6732 1.33 [26 45] [26 100]] [30 64]] [26 58]]] [26 97]] [2293 1.99 [30 60] [30 92]]] [7 100]] [1664 3.5 [3 62] [3 100]]] [879 4.19 [1986 1.79 [1002 2.2 [429 14.3 [392 2.54 [328 4.15 [25 73] [25 100]] [25 100]] [3 54]] [25 100]] [3 33]] [25 100]]] [7340 10.8 [1899 4.59 [32 76] [32 100]] [7340 14.2 [791 14 [32 100] [32 75]] [32 95]]]] [30 100]] [4601 0.215 [2145 0.515 [2127 1.39 [5205 1.71 [6177 1.07 [4338 5.19 [2023 14 [2137 0.507 [7742 2.2 [2914 6.68 [2029 5.72 [2259 40.8 [847 0.565 [26 35] [26 95]] [30 62]] [25 33]] [30 52]] [25 100]] [26 85]] [18 33]] [26 88]] [25 89]] [26 69]] [26 77]] [26 71]] [26 82]]] [906 9.11 [32 93] [32 50]]] [429 13.7 [2039 2.65 [2093 0.232 [7324 1.01 [1783 8.18 [2526 34.3 [6184 4.75 [7624 0.345 [1995 2.39 [6375 3.75 [1676 10 [5589 1.04 [1062 3.27 [5345 24.1 [7255 11.2 [6436 7.05 [2392 8.71 [304 6.47 [4702 1.29 [1436 6.96 [2628 1.77 [5211 50.8 [3069 6.34 [30 97] [2913 24 [30 83] [30 100]]] [30 75]] [30 100]] [30 90]] [30 100]] [30 85]] [30 83]] [30 83]] [30 66]] [30 69]] [30 71]] [30 99]] [30 60]] [30 90]] [30 66]] [7624 16.7 [30 100] [30 90]]] [30 85]] [0 100]] [30 100]] [30 60]] [6717 0.4 [1078 1.2 [30 100] [329 0.232 [30 100] [6 50]]] [30 100]]] [30 62]] [435 1.34 [6671 0.763 [7169 1.09 [5851 2.27 [7623 3.26 [4210 2.24 [2752 5.06 [30 39] [30 67]] [30 100]] [30 90]] [5860 1.63 [0 88] [0 100]]] [0 87]] [0 100]] [2023 1.94 [0 84] [0 50]]]]] [31 100]] [2259 68.9 [112 1.47 [4369 5.26 [1530 2.7 [32 48] [3 50]] [32 100]] [32 71]] [30 100]]]] [429 11.3 [631 0.91 [153 1.92 [5495 1.41 [1576 0.721 [7006 1.31 [1874 1.26 [6339 0.454 [1069 0.302 [2939 8.48 [4165 0.667 [5294 30.9 [5412 2.97 [1684 6.41 [1783 66.9 [3027 0.0878 [6328 2.52 [4058 18.2 [7314 0.107 [1242 3.18 [7255 6.49 [28 10] [12 21]] [15 57]] [28 55]] [11 100]] [11 71]] [12 36]] [28 21]] [429 6.95 [11 87] [15 66]]] [2752 6.62 [968 4.41 [10 21] [11 44]] [28 55]]] [8 66]] [22 66]] [30 33]] [4 100]] [11 90]] [11 71]] [1783 40.6 [21 25] [26 100]]] [2752 7.43 [1834 5.24 [2 59] [11 55]] [11 57]]] [5495 7.6 [1813 0.232 [2 70] [22 40]] [4703 0.53 [2 27] [11 60]]]] [3694 0.846 [3130 4.85 [6157 2.16 [28 85] [1343 7.49 [28 100] [28 92]]] [2752 5.7 [28 100] [28 62]]] [28 75]]] [28 100]] [6859 1.01 [2286 0.162 [1664 0.137 [4005 0.963 [6853 1.87 [969 1.08 [2555 1.35 [1691 4.95 [2005 1.15 [5647 1.68 [4631 4.17 [5412 5 [3830 5.15 [6154 8.33 [2568 2.28 [7255 1.36 [826 2.76 [5194 0.888 [818 1.58 [2526 26.8 [2320 3.45 [436 0.421 [5632 10.3 [2131 2.8 [6310 0.99 [2083 6.91 [4478 1.74 [377 7.53 [5368 0.351 [4012 0.756 [968 36.7 [1054 5.11 [6063 1.13 [2628 22.6 [2138 0.0654 [2470 0.334 [6969 2.44 [794 0.785 [3310 6.8 [3726 3.45 [1239 11.6 [685 4.75 [2752 22 [2241 8.48 [2225 5.36 [28 29] [12 57]] [11 36]] [28 65]] [28 89]] [1025 6.82 [2048 0.355 [17 11] [19 40]] [28 87]]] [32 100]] [9 50]] [28 100]] [11 71]] [4 29]] [19 40]] [1 22]] [22 100]] [15 66]] [5034 18.5 [28 60] [28 83]]] [28 100]] [5 12]] [28 92]] [22 33]] [28 91]] [5891 5.45 [37 36] [17 55]]] [11 55]] [28 100]] [11 61]] [32 100]] [8 96]] [4 58]] [28 80]] [15 40]] [2939 13.7 [12 34] [4 70]]] [8 100]] [2897 1.82 [28 97] [28 100]]] [8 100]] [6732 1.19 [2902 2.02 [2796 12.1 [4205 2.96 [28 52] [28 90]] [28 100]] [28 87]] [4414 9.45 [28 90] [28 66]]]] [11 91]] [5110 3.98 [7491 17.5 [4568 0.31 [5732 2.79 [112 1.14 [968 8.71 [28 46] [5192 6.3 [221 1.2 [28 72] [28 93]] [3 62]]] [28 54]] [28 100]] [6643 7.31 [28 100] [1429 23.6 [28 100] [28 75]]]] [28 94]] [11 30]]] [23 80]] [8 100]] [8 100]] [21 30]] [28 97]] [2939 17.9 [28 100] [28 86]]] [248 3.9 [7101 0.129 [5904 0.135 [6353 0.744 [3271 16.4 [5267 0.0894 [5844 0.933 [4896 3.98 [1714 0.305 [3 37] [1796 14.5 [17 40] [1563 1.57 [4637 1.73 [38 55] [6389 3.06 [19 80] [19 50]]] [17 42]]]] [7210 0.291 [35 64] [17 66]]] [19 42]] [35 87]] [38 60]] [38 75]] [3515 0.135 [19 62] [19 100]]] [35 71]] [5891 12.9 [18 42] [6681 0.182 [19 80] [19 91]]]]] [7 20]] [1899 5.68 [438 0.75 [2628 4.03 [595 0.739 [975 27.6 [3698 0.76 [6853 68.8 [631 1.63 [28 86] [5918 1.78 [2832 5.98 [4587 1.16 [1980 0.802 [2897 9.16 [5036 1.3 [28 97] [28 100]] [28 83]] [28 100]] [28 100]] [28 91]] [28 100]]] [4851 7.76 [28 57] [28 100]]] [28 100]] [28 62]] [28 100]] [28 66]] [28 81]] [28 81]]]]] [2169 1.05 [6981 0.492 [2466 7.14 [2259 45.6 [2143 6.68 [5545 2.62 [5386 2.46 [6294 1.11 [4764 0.345 [1844 0.829 [13 99] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 88]] [13 95]] [13 77]] [13 100]] [13 66]]] [3449 0.613 [2005 1.1 [2004 0.478 [4704 3.22 [1980 2.92 [6471 0.168 [6182 3.24 [1836 0.864 [7734 1.95 [6729 1.32 [2550 0.518 [7354 2.91 [7512 1.34 [5751 0.998 [3849 1.93 [2466 1.41 [5803 4.85 [5750 5.38 [6524 4.88 [3224 5.05 [2913 2.46 [286 0.864 [2707 3.14 [383 13 [996 3.7 [3207 10.2 [6490 1.66 [6617 4.42 [134 1.72 [3008 22.3 [6230 1.84 [5799 16.7 [5586 7.69 [5170 3.11 [3675 5.24 [5110 6.65 [2628 9.02 [1533 5.38 [3095 3.89 [4680 2.86 [5366 4.59 [23 49] [23 100]] [26 42]] [0 33]] [8 100]] [16 30]] [8 62]] [8 33]] [26 64]] [23 100]] [23 76]] [7 45]] [26 50]] [7 28]] [7 100]] [23 100]] [26 84]] [23 80]] [16 40]] [6 26]] [4350 2.92 [2526 2.16 [23 98] [23 100]] [23 100]]] [685 11.5 [25 33] [26 83]]] [8 100]] [6177 20 [25 88] [25 77]]] [23 100]] [35 90]] [7 20]] [35 50]] [23 100]] [6 38]] [7419 4.56 [18 52] [16 100]]] [2526 22 [8 78] [8 100]]] [26 66]] [2809 5.01 [5617 1.63 [5480 4.54 [18 47] [7425 1.93 [6959 1.54 [278 2.26 [4946 2.7 [5262 2.13 [7512 12.2 [18 86] [896 9.54 [6 60] [18 100]]] [18 100]] [18 100]] [18 59]] [18 75]] [18 100]]] [18 50]] [16 28]]] [18 72]] [25 80]] [663 1.4 [26 67] [26 100]]] [1094 0.634 [4897 2.26 [5480 4.17 [5509 4.81 [929 4.57 [1483 2.44 [7449 0.576 [5647 2.49 [5376 1.62 [6471 13.7 [286 4.07 [2232 1.51 [2550 0.508 [23 51] [0 85]] [23 50]] [23 93]] [26 100]] [23 100]] [33 57]] [23 97]] [8 100]] [23 89]] [328 1.43 [23 60] [23 100]]] [4926 2.18 [23 65] [18 100]]] [8 44]] [4288 0.525 [1025 0.832 [23 70] [23 100]] [23 100]]]] [25 84]] [5898 0.371 [7210 8.33 [4122 0.286 [398 0.244 [4663 0.792 [5969 0.519 [1986 0.717 [567 3.14 [5412 1.43 [23 76] [1025 1.93 [23 97] [23 100]]] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 42]] [23 100]]] [2081 0.472 [1062 2.32 [1078 36.1 [23 65] [26 50]] [23 92]] [1986 0.159 [6885 0.701 [1025 7.19 [2567 0.747 [2088 0.878 [384 2.64 [23 85] [23 100]] [23 100]] [23 75]] [23 66]] [23 100]] [23 100]]]] [35 82]]] [4154 0.678 [978 0.796 [1078 3.33 [328 6.41 [4447 2.91 [1044 8.11 [23 42] [23 100]] [11 92]] [3 42]] [1226 0.915 [2179 0.126 [934 6.44 [429 14.9 [11 42] [2939 4.86 [2752 6.74 [11 33] [1239 0.504 [11 77] [1089 1.96 [11 100] [11 80]]]] [11 40]]] [1062 4.66 [11 26] [5110 4.33 [11 62] [11 100]]]] [11 95]] [23 75]]] [967 0.202 [760 1.32 [5412 2.97 [2845 0.57 [978 14.1 [23 77] [23 39]] [23 100]] [23 100]] [23 100]] [685 0.16 [5647 6.4 [23 100] [23 88]] [23 100]]]] [1047 3.18 [4365 0.231 [1980 13.5 [1429 22.5 [7185 0.382 [440 1.2 [2760 1.06 [978 5.68 [28 37] [23 88]] [23 85]] [23 100]] [23 80]] [11 38]] [2187 0.734 [4154 12.6 [567 0.852 [5211 11.8 [392 0.934 [384 0.864 [6640 1.15 [23 88] [23 100]] [23 100]] [23 100]] [23 86]] [23 100]] [23 60]] [23 57]]] [435 0.57 [5486 0.261 [23 84] [23 100]] [23 100]]] [2 100]]]] [2917 1.36 [5011 1.87 [1664 1.33 [1429 8.46 [750 1.56 [5446 1.43 [4279 11 [201 3.18 [658 10.1 [5049 2.51 [144 6.26 [5041 1.17 [7461 0.615 [2029 2.15 [5246 6.49 [6803 0.595 [802 7.88 [1328 2.51 [5513 5.88 [371 15.4 [4917 0.808 [5034 2.13 [7766 1.33 [5480 0.503 [5972 12.5 [6015 1.2 [5937 2.46 [553 7.11 [112 7.53 [7491 3.3 [2913 5.05 [2624 1.86 [1429 0.975 [21 41] [6 30]] [9 100]] [21 70]] [21 78]] [20 50]] [3 100]] [21 84]] [21 71]] [21 50]] [29 30]] [21 75]] [3 67]] [21 85]] [21 90]] [3 64]] [9 52]] [6085 5.15 [1253 1.79 [7428 4.02 [657 1.14 [6897 2.42 [1980 67.4 [802 48.2 [802 16.5 [621 1.86 [21 76] [21 100]] [5034 2.99 [916 6.27 [21 61] [21 95]] [3 100]]] [21 96]] [3 37]] [9 55]] [9 100]] [9 50]] [21 88]] [21 92]]] [9 100]] [9 63]] [3 52]] [23 71]] [633 1.73 [4925 0.335 [5692 0.832 [21 99] [21 100]] [21 100]] [21 100]]] [29 61]] [4924 19.2 [574 1.35 [126 3.62 [236 8.36 [793 2.61 [1985 7.76 [5051 2.86 [5462 1.05 [5278 1.71 [7086 0.932 [114 2.51 [21 96] [21 75]] [21 100]] [21 100]] [21 100]] [21 75]] [21 80]] [5693 4.06 [21 63] [21 69]]] [9 57]] [9 50]] [9 100]] [21 66]]] [9 90]] [9 72]] [4193 6.33 [4318 1.41 [6092 1.07 [3 90] [3 100]] [21 54]] [3 100]]] [9 100]] [3 92]] [2251 1.18 [1997 2.12 [906 14.2 [827 1.36 [2083 1.46 [4865 1.46 [1078 4.05 [5403 3.55 [1687 3.43 [3 34] [9 90]] [3 100]] [29 22]] [3 100]] [1429 22.2 [3 86] [11 44]]] [2 50]] [1078 1.82 [21 66] [21 81]]] [747 2.15 [21 31] [21 100]]] [29 41]]] [3 95]] [29 88]] [3 85]]] [2199 0.294 [2062 0.496 [23 17 [5110 0.656 [2752 1.35 [11 97] [11 100]] [11 100]] [11 81]] [11 100]] [11 100]]] [7101 9.09 [515 0.0826 [1943 3.72 [6015 3.85 [6017 0.0274 [145 1.22 [1101 0.832 [2201 2.39 [4770 18.5 [29 100] [29 96]] [29 100]] [29 100]] [29 100]] [29 100]] [29 95]] [1951 1.29 [29 95] [29 100]]] [29 100]] [29 85]]] [2488 2.35 [2149 1.66 [5753 1.49 [1986 4.18 [6408 14.8 [515 3.3 [7098 6.79 [429 5.01 [1025 3.16 [2143 3.02 [3444 2.96 [831 0.904 [4663 33.2 [248 3.19 [35 80] [26 50]] [35 71]] [35 100]] [35 100]] [35 75]] [35 74]] [7061 7.76 [4611 4.61 [2913 2.39 [2161 3.57 [3746 2.16 [3332 4.97 [1078 6.83 [35 95] [35 72]] [328 12.4 [5647 0.613 [35 91] [35 100]] [35 96]]] [35 55]] [1429 20.1 [35 55] [35 87]]] [30 100]] [3538 1.21 [4154 1.48 [3711 6.1 [35 100] [4092 3.14 [35 100] [35 83]]] [35 90]] [35 100]]] [35 71]]] [35 80]] [35 70]] [35 97]] [1429 6.06 [35 86] [35 59]]] [35 63]] [30 42]] [35 100]]] [538 0.32 [2807 0.155 [6712 0.421 [6033 0.315 [2787 0.13 [3929 0.333 [5732 0.162 [276 0.367 [5484 0.408 [6853 1.34 [2526 3.97 [404 1.15 [714 0.129 [5199 0.836 [695 10.6 [1391 2.11 [5730 0.173 [939 1.29 [6363 0.744 [5480 3.38 [6483 0.223 [4006 1.02 [3045 1.27 [5766 0.467 [1239 51.1 [7488 4.11 [5071 3.12 [2701 0.263 [4493 0.236 [730 1.52 [1796 0.316 [889 1.52 [2818 0.824 [7330 3.28 [6124 4 [6809 0.568 [1634 3.15 [377 0.724 [6031 4.34 [7212 1.74 [1180 1.67 [527 0.454 [1209 0.126 [1167 1.96 [5784 4.74 [3644 2.59 [489 2.22 [5999 0.446 [3995 0.906 [1164 3.82 [4280 1.03 [851 10.7 [5978 0.671 [6449 15 [5211 3.05 [906 17.1 [6297 2.75 [3274 1.08 [5296 0.351 [1055 1.96 [6230 1.68 [2753 5.23 [7198 1.37 [7413 0.281 [6091 8.22 [1445 8.43 [685 2.72 [4704 0.309 [1517 0.146 [5040 2.96 [6034 1.76 [1429 8.47 [7428 1.06 [5647 1.16 [11 16] [21 42]] [28 44]] [1932 0.15 [6077 0.911 [7354 1.7 [957 14.4 [28 20] [37 70]] [36 39]] [2 60]] [37 35]]] [18 50]] [4 38]] [37 42]] [33 62]] [384 0.208 [28 64] [26 50]]] [12 25]] [32 69]] [28 73]] [28 88]] [36 38]] [5 16]] [11 80]] [19 50]] [11 100]] [31 100]] [21 76]] [2199 1.28 [2259 15.7 [23 2.49 [1078 12 [22 62] [11 81]] [30 85]] [22 80]] [30 42]]] [12 73]] [31 100]] [6777 0.718 [17 50] [3 50]]] [29 100]] [13 100]] [17 37]] [26 25]] [35 100]] [36 100]] [429 15.6 [14 75] [14 100]]] [29 100]] [4 85]] [4 80]] [13 80]] [10 100]] [22 100]] [28 40]] [1783 52.6 [13 72] [13 100]]] [32 100]] [12 90]] [1997 0.467 [13 58] [13 45]]] [12 91]] [32 100]] [7189 0.729 [19 85] [17 57]]] [4205 0.635 [28 90] [28 100]]] [36 100]] [4154 9.83 [4889 0.52 [2752 22.8 [4768 0.805 [29 81] [29 100]] [685 1.23 [29 70] [29 100]]] [29 100]] [29 44]]] [29 86]] [38 100]] [1980 2.42 [5693 2.22 [4502 0.362 [21 36] [9 75]] [9 90]] [9 81]]] [28 100]] [35 91]] [28 100]] [13 100]] [6342 0.754 [392 4.54 [880 1.08 [22 46] [22 100]] [392 13 [18 70] [18 75]]] [23 30]]] [2817 0.728 [1025 0.53 [5897 1.18 [1584 0.232 [1742 0.756 [28 44] [28 94]] [28 83]] [28 100]] [22 33]] [22 100]]] [1025 4.96 [4279 2.05 [6015 0.424 [29 62] [29 92]] [6342 3.2 [28 34] [28 88]]] [11 70]]] [11 100]] [6530 0.991 [6363 0.931 [6886 0.97 [5851 7.01 [6488 0.167 [6159 0.389 [939 1.01 [5270 1.19 [22 56] [9 88]] [35 58]] [0 54]] [22 100]] [22 100]] [9 100]] [22 100]] [22 100]]] [7288 5.88 [7449 13.2 [5974 3.23 [1391 0.775 [6124 2.37 [2990 3.11 [6117 3.31 [5110 0.87 [1167 2.32 [2488 8.33 [1367 5.49 [1332 3.4 [802 9.67 [4040 3.55 [5542 3.7 [874 1.98 [3004 3.94 [3711 1.66 [6711 9.24 [3959 2.56 [5766 1.86 [978 2.38 [5412 1.55 [2826 4.84 [5474 6.17 [5972 1.39 [7340 3.03 [6260 0.852 [3587 1.6 [5824 7.58 [5692 7.46 [794 4.43 [6339 5.62 [3338 1.94 [5234 7.94 [429 91.4 [5211 8.87 [4235 33.3 [6484 4.22 [2259 13.9 [3779 3.76 [2752 6.32 [6230 15.2 [2136 0.431 [4624 5.15 [688 7.41 [2701 19.2 [2470 3.34 [1239 41.4 [814 5.62 [3332 4.37 [6929 15.6 [1997 16.1 [37 9] [32 62]] [2 85]] [35 100]] [14 50]] [9 31]] [4 30]] [29 78]] [21 63]] [14 100]] [35 40]] [17 25]] [392 2.59 [3837 7.46 [7255 26.3 [4312 5.05 [1899 3.97 [5799 3.55 [7354 8.13 [23 4.61 [28 37] [14 28]] [5 30]] [28 50]] [28 23]] [28 100]] [12 94]] [37 100]] [28 68]]] [37 100]] [5368 32.5 [22 13] [22 100]]] [25 100]] [26 50]] [70 8.26 [6566 9.9 [22 64] [11 100]] [22 88]]] [21 100]] [11 100]] [28 90]] [28 100]] [28 81]] [22 36]] [11 85]] [37 100]] [22 68]] [32 69]] [7623 7.25 [7176 4.76 [36 50] [12 100]] [31 66]]] [13 75]] [2753 12.3 [2826 11.1 [12 52] [4851 5.26 [14 49] [14 70]]] [5 41]]] [4978 5.13 [2793 7.83 [5270 2.18 [7413 0.692 [7314 1.55 [4870 1.47 [28 44] [28 50]] [28 57]] [28 91]] [31 46]] [28 71]] [28 100]]] [1239 1.47 [5211 5.38 [7 18] [22 60]] [6 33]]] [28 88]] [29 100]] [22 89]] [35 93]] [36 100]] [36 56]] [13 100]] [36 100]] [688 14.5 [21 47] [21 100]]] [9 94]] [21 100]] [7197 4.2 [663 3.27 [1429 75.7 [13 93] [13 72]] [13 100]] [13 100]]] [29 100]] [5110 28 [2939 6.71 [5662 1.63 [22 44] [5211 15.2 [22 47] [22 96]]] [12 76]] [12 21]]] [28 100]] [12 100]] [3676 1.9 [2701 19.9 [12 97] [12 80]] [12 100]]] [4154 11.9 [435 1.32 [22 93] [22 100]] [22 46]]] [21 92]] [695 66.3 [6232 1.39 [1062 22.9 [7335 5.8 [5480 2.65 [1913 4.23 [7255 1.41 [6155 5.88 [28 27] [12 66]] [1899 1.92 [5979 3.03 [2816 3.88 [1078 3.31 [12 83] [12 100]] [12 100]] [12 100]] [12 100]]] [22 42]] [22 66]] [12 100]] [29 72]] [12 71]] [22 47]]] [12 100]]] [22 96]] [5420 0.204 [5439 0.404 [791 41.9 [22 100] [22 80]] [22 100]] [22 100]]] [2004 0.688 [28 79] [28 100]]] [7620 3.39 [709 0.476 [981 0.634 [312 0.569 [1899 15.7 [4424 2.73 [2081 24.3 [3537 0.69 [5410 26 [2913 2.66 [6595 3.07 [2752 28.3 [6988 0.743 [3045 1.68 [3850 1.79 [7381 0.732 [3019 5.05 [957 2.36 [6074 0.52 [685 1.87 [1077 0.564 [6230 5.97 [6333 0.606 [2081 10.3 [4 12] [21 57]] [36 35]] [14 25]] [31 50]] [18 24]] [4 42]] [18 36]] [24 100]] [4 41]] [35 100]] [35 100]] [2 100]] [12 22]] [4 100]] [5 36]] [21 66]] [35 100]] [3 58]] [23 48]] [791 31.3 [4 34] [22 42]]] [221 4.71 [4 68] [4 62]]] [23 88]] [4 100]] [2470 2.56 [4 64] [4 85]]]] [867 0.421 [6210 0.994 [5007 0.154 [5211 3.5 [5053 0.78 [1842 1.72 [2275 0.867 [6922 1.15 [890 0.437 [7354 4.05 [3029 1.99 [6260 2.52 [6230 6.38 [4457 3.36 [794 0.907 [705 0.849 [7241 2.16 [2108 0.678 [5753 0.304 [28 70] [6732 12.1 [28 90] [28 80]]] [28 38]] [36 92]] [12 60]] [28 100]] [36 77]] [5 30]] [36 86]] [28 100]] [36 83]] [36 100]] [36 100]] [4485 0.359 [36 84] [36 100]]] [28 100]] [36 100]] [2628 1.98 [22 97] [22 37]]] [3698 0.262 [28 72] [28 93]]] [36 100]] [6997 0.422 [6260 0.224 [28 60] [22 100]] [28 100]]]] [906 1.99 [859 0.174 [5482 1.35 [6044 1.86 [2671 0.785 [673 0.686 [4424 0.749 [722 7.06 [3515 1.88 [134 18.5 [1995 2.28 [5346 2.45 [2199 12.6 [791 11.1 [4154 5.95 [338 1.18 [429 8.6 [18 50] [4977 2.99 [434 0.366 [282 27.6 [18 75] [18 61]] [18 100]] [6 50]]] [26 85]] [18 48]] [22 62]] [22 100]] [19 40]] [22 91]] [18 75]] [19 66]] [22 42]] [22 60]] [18 100]] [2951 16.3 [18 52] [16 60]]] [18 100]] [695 18.9 [282 2.09 [532 0.956 [5483 1.09 [4338 0.498 [248 3.4 [1023 2.74 [2752 28.5 [145 2.13 [18 89] [18 62]] [18 57]] [18 80]] [18 100]] [18 57]] [18 100]] [18 57]] [18 50]] [22 46]]] [22 100]] [2023 0.501 [22 51] [22 100]]]] [328 30.9 [190 4.27 [6251 7.78 [1186 4.95 [7101 1.83 [685 38.5 [7245 10.4 [7281 9.55 [5130 8.39 [2826 2.25 [2717 1.25 [7210 7.87 [978 29.9 [5412 2.05 [731 26.8 [1587 0.904 [7354 22.1 [2381 7.69 [6740 7.26 [18 85] [18 54]] [6 33]] [5 37]] [18 100]] [16 35]] [18 58]] [18 50]] [33 57]] [18 100]] [16 36]] [18 51]] [6 71]] [18 60]] [6 29]] [18 54]] [19 58]] [18 100]] [16 33]] [429 9.39 [18 77] [6 38]]]] [896 0.568 [968 0.116 [889 2.9 [3409 0.454 [429 45.5 [4279 3.77 [6380 0.327 [1587 16.2 [2470 3.6 [5491 6.96 [1567 0.521 [1980 1.04 [1738 6.27 [730 0.956 [5034 5.62 [695 33.4 [2760 0.854 [6230 7.23 [6301 1.86 [2849 10 [5410 4.01 [23 21.8 [4533 0.832 [1025 6.77 [5462 1.94 [1239 16.4 [28 85] [28 71]] [4944 1.83 [4895 8.77 [28 97] [28 85]] [28 100]]] [28 44]] [28 80]] [28 57]] [28 62]] [28 70]] [28 100]] [7 40]] [28 42]] [28 55]] [30 50]] [1078 18.2 [28 100] [28 62]]] [14 42]] [28 94]] [28 100]] [20 33]] [15 91]] [13 46]] [28 40]] [28 62]] [1429 16.2 [21 83] [28 50]]] [15 64]] [32 100]] [5155 0.352 [4455 0.579 [7324 1.73 [7435 0.615 [4456 0.96 [6621 5.61 [4568 2.3 [855 1.92 [4158 2.32 [7445 4.72 [6856 0.187 [6970 5.39 [906 0.174 [7210 0.17 [596 0.513 [28 98] [28 100]] [28 100]] [28 100]] [28 88]] [28 100]] [28 83]] [28 94]] [28 100]] [5412 4.65 [28 75] [28 100]]] [2830 2.06 [28 77] [28 100]]] [28 80]] [28 80]] [28 78]] [28 55]] [28 77]]] [7 45]]] [5110 8.83 [6074 1.55 [6365 1.08 [1128 0.68 [1997 2.5 [6175 1.17 [6230 4.59 [6373 1.48 [713 2.01 [3334 0.59 [3591 0.357 [1436 1.75 [705 7.94 [3113 4.08 [328 3.25 [3841 0.767 [12 33] [12 62]] [37 47]] [37 36]] [12 100]] [5 55]] [429 14.8 [37 53] [5 70]]] [12 100]] [12 100]] [5 42]] [7012 1.77 [12 69] [12 100]]] [12 100]] [5 41]] [37 83]] [12 100]] [2259 2.72 [12 66] [12 100]]] [15 82]]] [4611 3.71 [5753 0.155 [6859 1.24 [377 1.14 [28 67] [3605 1.21 [28 89] [28 100]]] [1630 0.813 [28 98] [28 100]]] [7491 0.325 [4200 1.85 [6068 0.528 [4337 0.941 [6363 1.59 [6199 0.252 [1457 2.31 [28 100] [28 87]] [28 100]] [28 87]] [28 83]] [28 70]] [28 57]] [28 100]]] [2752 22.1 [28 81] [429 19.7 [20 66] [28 100]]]]] [22 100]] [22 97]] [22 100]] [1328 4.21 [6893 0.355 [1306 0.0701 [6320 3.32 [4773 0.602 [1331 0.332 [4748 1.89 [791 67.3 [621 1.92 [2178 0.463 [6150 0.782 [572 1.83 [6029 6.1 [699 18.4 [429 89 [6181 8.86 [1434 1.06 [5293 1.07 [594 2.28 [6015 7.02 [2624 0.703 [9 56] [9 85]] [21 72]] [9 92]] [9 100]] [21 83]] [9 100]] [21 53]] [21 68]] [21 92]] [9 94]] [9 64]] [21 82]] [21 87]] [21 94]] [4751 8.29 [5535 2.88 [629 1.58 [6085 0.376 [9 91] [9 71]] [9 80]] [9 69]] [906 9.89 [9 100] [9 85]]]] [1757 0.304 [9 100] [9 83]]] [9 100]] [112 0.717 [21 63] [21 100]]] [1899 0.16 [9 79] [9 100]]] [21 95]] [9 100]]]] [3497 0.867 [7623 19.9 [2764 3.18 [4154 0.266 [3921 0.481 [3223 8.3 [3993 15.7 [4768 7.58 [832 2.92 [6342 17.2 [2259 7.36 [3297 3.7 [4611 12.9 [820 4.67 [3990 15.6 [131 1.21 [663 15.2 [481 0.297 [221 4.67 [3342 2.11 [3292 25.6 [37 46] [37 82]] [37 80]] [1 22]] [37 100]] [37 54]] [37 100]] [37 100]] [11 100]] [37 94]] [126 11.6 [1505 3.55 [3910 2.02 [3190 2.07 [37 94] [37 100]] [37 100]] [37 50]] [37 77]]] [23 31.9 [37 41] [17 25]]] [1 37]] [37 98]] [3292 14.1 [1 25] [37 57]]] [1 57]] [8 90]] [1507 9.9 [4073 1.65 [1488 2.46 [3701 0.752 [4533 4.36 [37 96] [37 85]] [37 100]] [37 100]] [37 60]] [37 75]]] [1239 13.2 [8 30] [17 33]]] [3990 3.27 [11 53] [37 100]]] [25 33]] [8 100]]] [1566 3.01 [2241 8.24 [2117 0.747 [5784 0.124 [2464 1.36 [3049 9.94 [6953 8.59 [2939 45.4 [1587 4.1 [251 0.0479 [3161 0.317 [2143 1.91 [23 11.2 [4414 0.33 [851 0.368 [4703 0.0332 [2826 3.11 [1429 55.5 [14 98] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 98]] [5637 0.31 [695 2.19 [14 100] [14 88]] [14 100]]] [14 100]] [14 100]] [14 87]] [14 95]] [14 86]] [14 90]] [14 93]] [14 100]] [14 88]] [14 87]] [14 72]]] [6655 1.64 [112 3.69 [6170 13.7 [6874 10 [1318 4.57 [7203 3.39 [6017 5.8 [7032 0.503 [1769 11.3 [541 7.05 [4681 5.56 [6092 1.18 [7210 13.7 [6317 16.3 [5799 3.18 [4748 4.42 [567 12.8 [6621 1.81 [126 3.68 [225 1.04 [1436 5.62 [909 8.76 [749 2.01 [221 7.77 [5249 10.1 [538 2.66 [5692 1.39 [6085 14.9 [747 1.83 [920 3.27 [6342 6.9 [5323 3.94 [688 11.1 [816 5.03 [804 19.2 [21 96] [21 60]] [21 100]] [21 100]] [21 100]] [21 81]] [21 100]] [21 100]] [21 88]] [21 100]] [21 86]] [21 57]] [21 75]] [21 100]] [21 85]] [21 71]] [21 100]] [21 88]] [21 100]] [28 40]] [9 100]] [21 75]] [9 50]] [9 50]] [21 100]] [21 70]] [21 100]] [21 64]] [21 70]] [21 80]] [21 72]] [9 66]] [21 66]] [21 60]] [791 31.9 [9 55] [21 100]]] [6048 5.62 [9 66] [21 100]]]] [791 23.1 [2225 0.301 [2993 0.907 [1 0.732 [7363 0.344 [6091 1.25 [429 79.7 [3 100] [5412 2.73 [583 2.02 [5410 7.94 [5322 8.2 [6872 4.07 [3 98] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [5322 1.93 [2200 5.4 [3 100] [3 76]] [3 100]]]] [6708 6.78 [5675 0.805 [756 0.486 [5222 1.21 [429 25.8 [2752 9.55 [2694 3.76 [30 93] [30 100]] [30 100]] [1626 7.04 [30 85] [30 100]]] [30 100]] [30 100]] [30 100]] [30 80]]] [3458 0.412 [5972 4.41 [685 1.94 [2530 0.724 [4704 1.23 [6124 4.48 [4417 0.845 [959 0.445 [1391 1.09 [7634 2.65 [3111 4.29 [5403 2.64 [2701 2.65 [1239 23.1 [248 16.9 [5629 1.61 [5843 0.87 [6973 2.51 [145 4.74 [985 0.818 [4088 1.36 [826 3.68 [1405 0.826 [7095 1.72 [743 1.9 [4771 8.52 [1078 25.7 [7483 3.94 [3905 9.9 [701 0.605 [5211 2.67 [5738 0.84 [4919 1.44 [7032 5.82 [430 5.75 [2514 3.5 [1410 5.87 [6230 0.545 [5041 1.98 [5413 5.91 [6947 3.5 [731 2.85 [5467 6.82 [2913 2.64 [3895 2.44 [1411 15.6 [328 27.5 [7340 2.22 [429 39.1 [2241 1.85 [5999 0.554 [1425 6.16 [7009 9.19 [1696 3.28 [1932 0.976 [7287 7.33 [7381 0.697 [1980 3.18 [4991 16.8 [7434 3.6 [1402 7.84 [7241 2.09 [5393 0.692 [3735 3.03 [6199 1.77 [7623 2.56 [4851 1.29 [15 32] [26 21]] [15 60]] [0 25]] [15 71]] [15 38]] [25 28]] [15 77]] [12 100]] [12 33]] [1995 7.89 [15 11] [32 50]]] [2 66]] [12 100]] [35 45]] [26 75]] [12 53]] [15 91]] [14 43]] [36 42]] [2143 33 [3 14] [21 100]]] [12 63]] [4663 3.45 [12 41] [4768 11.5 [12 100] [12 80]]]] [15 95]] [12 100]] [15 65]] [12 85]] [4 53]] [10 85]] [15 92]] [21 100]] [4 44]] [15 91]] [12 100]] [32 90]] [2 85]] [21 100]] [15 100]] [4115 7.46 [6666 9.35 [10 57] [10 100]] [10 100]]] [10 72]] [3905 16.7 [15 95] [15 70]]] [15 100]] [4664 6.22 [3667 2.82 [1426 1.31 [3903 6.17 [4114 1.05 [784 0.62 [4398 1.64 [1429 17.2 [4370 1.31 [1110 1.64 [828 9.35 [1101 11.5 [4279 15.4 [2259 8.05 [5851 10.9 [3480 8.77 [248 3.06 [3619 10.5 [10 28] [10 100]] [25 50]] [15 81]] [27 64]] [1062 2.84 [10 74] [10 55]]] [15 50]] [1980 40.4 [15 66] [10 33]]] [15 100]] [15 80]] [10 88]] [1104 5.79 [32 23] [32 66]]] [15 100]] [10 63]] [5467 1.29 [978 5.2 [10 64] [10 90]] [10 100]]] [10 100]] [10 87]] [2 60]] [15 83]]] [828 4.42 [15 80] [15 100]]] [21 65]] [5394 2.65 [7428 13.2 [15 100] [12 62]] [15 100]]] [15 97]] [2444 0.581 [1069 13.2 [5322 9.87 [15 89] [15 100]] [15 73]] [15 98]]] [36 100]] [663 1.08 [4 65] [4 43]]] [32 48]] [10 100]] [1400 6.52 [10 66] [5467 0.87 [5218 1.89 [10 91] [10 100]] [10 100]]]] [15 100]] [3480 17.8 [2849 6.06 [2586 2.24 [2759 10.9 [6189 1.17 [7623 9.36 [1980 31 [2826 1.36 [7737 4.41 [727 3.45 [2580 2.26 [4564 6.67 [253 2.79 [7187 2.91 [2755 10 [791 15.2 [25 42] [15 60]] [663 21.4 [6230 4.85 [2755 15.7 [26 37] [26 73]] [25 100]] [25 40]]] [2752 31.3 [26 81] [35 42]]] [25 100]] [26 75]] [25 95]] [26 100]] [25 100]] [26 83]] [25 100]] [15 66]] [25 86]] [26 93]] [25 100]] [26 57]] [15 100]]] [6082 2.16 [4050 1.46 [328 8.53 [7169 2.97 [1987 1.3 [590 3.25 [2099 6.15 [21 25] [21 83]] [3 66]] [21 100]] [1980 8.33 [21 80] [3 33]]] [25 32]] [25 60]] [5040 2.15 [9 33] [21 100]]]] [2143 3.26 [4283 1.31 [465 1.53 [4353 2.16 [429 26.3 [5110 0.671 [15 50] [15 100]] [2470 1.55 [10 68] [15 100]]] [15 100]] [15 100]] [15 100]] [15 25]]] [1429 30.2 [4154 12.2 [1769 1.58 [7210 7.99 [5412 1.54 [31 81] [811 8.21 [31 87] [31 100]]] [31 77]] [31 100]] [3 69]] [21 40]]] [7623 3.18 [4011 2.67 [15 84] [15 100]] [15 100]]] [4326 1.81 [10 97] [10 86]]] [6929 1.68 [4374 0.904 [5065 1.81 [6413 2.07 [1899 2.11 [1429 48.4 [15 88] [15 55]] [6791 3.26 [1410 1.16 [1429 12.9 [15 86] [30 66]] [15 100]] [15 71]]] [15 27]] [15 100]] [15 100]] [15 66]]] [10 100]] [4398 0.917 [3304 0.785 [2752 2.89 [15 76] [15 98]] [15 100]] [15 100]]] [4418 3.27 [2752 1.26 [791 17.1 [10 28] [10 72]] [663 0.645 [702 1.61 [7623 15.8 [7009 3.4 [12 89] [12 100]] [12 100]] [12 100]] [12 83]]] [12 71]]] [25 69]] [6862 3.13 [25 65] [25 100]]] [4968 5.61 [929 0.675 [6524 1.95 [5767 5.15 [2605 1.16 [4603 1.23 [404 4.43 [2763 5.22 [3381 3.39 [1401 2.01 [1432 1.57 [6471 3.49 [2891 1.16 [6177 4.11 [181 1.04 [957 0.713 [379 1.68 [4457 3.77 [26 59] [26 50]] [26 100]] [10 34]] [26 100]] [2530 0.843 [25 97] [25 100]]] [26 85]] [407 1.83 [673 17.9 [2259 2.31 [26 46] [26 84]] [26 100]] [26 100]]] [385 0.852 [26 69] [26 100]]] [12 100]] [10 80]] [15 60]] [15 45]] [338 49.1 [269 8.52 [4602 0.978 [26 93] [26 100]] [26 80]] [26 50]]] [25 100]] [12 44]] [7330 1.07 [25 88] [25 100]]] [7244 0.675 [1081 4.93 [2752 6.2 [26 80] [26 75]] [26 64]] [26 87]]] [26 85]]] [1414 3.65 [2474 3.3 [7301 6.07 [1 4.47 [286 0.498 [3323 19.3 [580 1.24 [915 1.83 [7464 15.8 [2969 0.558 [4454 3.8 [7571 3.21 [7176 2.98 [7139 14.8 [2913 2.33 [4799 1.93 [2178 0.368 [4220 21.7 [2701 7.45 [6074 10.1 [3763 2.89 [2143 7.37 [248 1.66 [6294 3.49 [1913 6.44 [7493 17.2 [6091 7.18 [5410 21 [1170 2.51 [628 8.52 [7009 11.2 [4369 1.38 [4154 16.5 [3929 2.03 [2760 18.5 [5328 10.5 [2698 3.94 [4154 10.3 [3074 3.03 [7623 3.82 [4414 7.78 [12 91] [12 100]] [12 97]] [12 100]] [12 87]] [12 100]] [12 75]] [12 85]] [12 100]] [12 72]] [12 100]] [12 95]] [12 75]] [12 100]] [12 80]] [2752 39.3 [12 86] [15 54]]] [12 90]] [12 70]] [12 81]] [15 92]] [7449 15.5 [429 15.4 [12 63] [12 100]] [12 100]]] [15 100]] [15 70]] [12 60]] [12 70]] [12 100]] [15 80]] [15 96]] [15 66]] [4279 16.9 [1400 39.3 [7654 2.51 [1170 0.798 [826 0.695 [2814 11.5 [2259 2.42 [6103 1.49 [12 97] [12 100]] [12 100]] [12 93]] [12 100]] [12 88]] [12 100]] [12 90]] [12 40]]] [31 57]] [1899 16.6 [12 100] [12 87]]] [12 100]] [15 44]] [5972 9.28 [3 42] [12 79]]] [21 100]] [31 80]] [4374 0.166 [2259 17.5 [7428 0.911 [23 5.75 [12 84] [7169 2.26 [12 88] [12 100]]] [2763 0.761 [2822 1.31 [12 94] [12 100]] [12 100]]] [12 78]] [12 100]]] [12 63]] [36 50]] [15 100]] [15 100]]] [7638 0.752 [2693 0.376 [4017 2 [6177 3.59 [5732 0.743 [2475 0.669 [6910 1.65 [7254 5.48 [7169 4.83 [6342 4.16 [2808 0.904 [695 9.06 [15 78] [15 79]] [15 100]] [15 100]] [15 100]] [12 50]] [15 100]] [15 100]] [15 100]] [25 100]] [15 55]] [15 100]] [12 100]]]] [1101 1.92 [5480 3.23 [6015 0.914 [4326 6.77 [2548 3.28 [631 5.24 [5412 6.17 [2902 1.97 [203 0.719 [5267 1 [5454 6.94 [178 5.95 [5007 6.44 [2515 1.4 [7373 0.492 [6708 3.28 [2341 4.87 [4154 43 [3026 3.8 [4189 0.879 [4519 2.44 [1239 6.51 [24 60] [24 54]] [1199 1.07 [3640 4.98 [1020 0.673 [208 26.1 [791 0.99 [3662 8.09 [3641 12.5 [7149 6.31 [24 93] [24 62]] [24 57]] [19 57]] [24 96]] [24 100]] [24 100]] [19 50]] [24 100]]] [24 100]] [4299 0.787 [24 86] [24 100]]] [24 50]] [2517 1.47 [24 90] [24 100]]] [24 44]] [24 100]] [24 100]] [24 61]] [24 98]] [24 100]] [5013 2.15 [3637 8.54 [1025 32 [4341 0.629 [4279 12.2 [24 53] [24 92]] [3643 1.71 [3659 11.8 [24 66] [24 83]] [19 66]]] [19 40]] [24 62]] [19 66]]] [24 76]] [24 59]] [791 6.29 [24 60] [22 42]]] [28 71]] [2411 0.835 [5793 1.11 [24 96] [24 100]] [24 100]]] [27 29]] [28 57]] [22 77]] [4159 9.6 [27 29] [14 33]]]] [3851 2.22 [6007 0.285 [6199 7.08 [3773 2.46 [3130 0.846 [1456 0.608 [4102 1.72 [7035 0.713 [4895 2.09 [3587 0.503 [3724 3.29 [791 52.1 [3822 13.8 [1631 2.44 [4073 4.71 [3561 0.855 [668 2.42 [3929 0.14 [5285 0.448 [4108 8.23 [3779 0.208 [3867 6 [7428 8.34 [3990 12.6 [4092 2.82 [201 4.85 [2775 7.13 [3610 12.2 [3972 2.89 [131 2.16 [3718 1.42 [5871 0.739 [663 24.2 [1078 14.1 [37 96] [1104 0.813 [1986 1.73 [37 84] [37 77]] [37 100]]] [3079 18.4 [37 81] [37 62]]] [37 66]] [37 100]] [37 100]] [3214 1.96 [37 99] [37 100]]] [37 63]] [37 71]] [37 72]] [37 66]] [37 100]] [37 71]] [37 100]] [3908 1 [3498 0.835 [3912 2.56 [37 98] [37 100]] [37 100]] [37 100]]] [16 33]] [37 100]] [843 0.433 [3359 0.324 [2784 2.33 [841 0.657 [37 97] [37 100]] [37 100]] [37 100]] [37 100]]] [37 62]] [37 70]] [2763 1.19 [37 88] [16 50]]] [16 83]] [37 76]] [37 73]] [112 6.02 [37 92] [3262 17.6 [35 77] [37 71]]]] [37 100]] [791 4.37 [312 1.18 [37 75] [16 62]] [37 100]]] [29 100]] [957 6.6 [144 1.29 [429 5.85 [16 57] [37 83]] [37 100]] [37 100]]] [38 83]] [37 74]] [33 55]] [37 66]] [6 27]] [35 50]]] [3135 10.9 [3928 4.52 [2434 0.0673 [1906 14.4 [6647 81 [1815 6.63 [7330 18.9 [2057 3.05 [7429 4.75 [7366 12.5 [6773 12.9 [4712 0.788 [304 0.271 [1710 46.1 [2167 0.662 [4566 9.62 [6449 0.215 [7330 7.65 [2181 0.219 [23 3.86 [1913 0.327 [6342 1.37 [4920 9.75 [1786 0.633 [2259 1.44 [30 82] [1899 8.77 [30 100] [30 88]]] [30 100]] [30 100]] [30 100]] [30 100]] [30 100]] [30 100]] [1841 7.08 [30 87] [30 100]]] [30 100]] [2752 2.73 [30 95] [30 75]]] [30 90]] [30 89]] [30 80]] [5758 0.493 [5296 0.708 [4064 0.297 [1997 12.3 [30 100] [2302 0.183 [30 96] [30 100]]] [30 100]] [30 83]] [30 100]]] [30 75]] [30 85]] [30 91]] [30 85]] [30 83]] [2138 0.0349 [30 92] [30 100]]] [30 70]] [30 66]] [30 83]] [30 66]] [30 82]]] [657 0.888 [6713 0.477 [4794 42 [4925 0.185 [907 3.8 [6199 7 [6017 8.15 [2081 9.8 [583 3.41 [957 3.12 [2993 0.571 [6191 0.911 [917 1.84 [1062 0.959 [909 4.07 [5040 2.01 [663 2.99 [21 29] [29 50]] [21 100]] [21 100]] [28 36]] [21 89]] [21 100]] [4813 1.25 [21 98] [21 100]]] [27 92]] [5393 0.942 [21 92] [21 100]]] [5972 4.85 [2225 15.7 [21 72] [28 62]] [21 55]]] [21 61]] [9 41]] [6565 0.693 [628 2.05 [7211 4.79 [5386 1.76 [1980 15.5 [6406 6.62 [6426 1.02 [524 0.568 [590 0.952 [2099 5.29 [906 12 [21 86] [21 97]] [21 71]] [21 100]] [21 100]] [21 100]] [21 66]] [524 2.01 [21 76] [21 100]]] [21 57]] [21 70]] [9 66]] [9 60]]] [6529 0.879 [7451 5.17 [4663 16.7 [916 0.832 [6060 3.76 [4533 3.06 [5246 1.44 [4917 5.56 [21 100] [2993 2.62 [21 90] [21 100]]] [21 100]] [21 90]] [21 100]] [21 100]] [21 75]] [5040 1.64 [21 90] [21 100]]] [21 85]]] [518 4.85 [21 35] [526 3.68 [21 94] [21 100]]]] [9 93]] [21 53]]] [1597 2.24 [7472 3.03 [628 0.62 [2628 1.87 [6653 6.94 [2143 16.7 [4414 0.493 [77 5.19 [583 0.477 [6380 12.2 [4911 0.664 [7354 1.66 [5034 0.876 [3 97] [3 100]] [3 85]] [3 100]] [3 66]] [3 100]] [3 83]] [3 100]] [3 77]] [3 88]] [3 70]] [3 75]] [3 62]] [3 100]]] [607 0.306 [5393 0.627 [850 0.715 [6260 0.633 [919 0.751 [6809 2.46 [663 0.339 [11 0.852 [1690 5.49 [542 1.12 [5047 1.12 [7340 3.02 [23 0.671 [7623 2.98 [791 11.4 [6342 1.04 [978 8.86 [14 55] [31 85]] [31 80]] [6548 7.58 [3 55] [6544 25.8 [36 54] [36 55]]]] [31 87]] [145 13.2 [907 0.816 [5976 1.33 [6199 35 [6382 2.91 [1429 15.8 [4279 6.46 [3 59] [3 90]] [14 59]] [14 100]] [31 55]] [3 100]] [3 65]] [14 80]]] [32 87]] [907 1.12 [7451 1.68 [6177 1.25 [5047 4.45 [3 88] [3 100]] [3 100]] [3 100]] [3 100]]] [3 100]] [17 66]] [31 100]] [3928 2.05 [7731 5.8 [3895 3.82 [2225 1.48 [5637 0.471 [6199 3.2 [6382 2.62 [5439 3.5 [7009 2.44 [7512 15.2 [32 26] [14 88]] [13 55]] [14 80]] [14 90]] [14 85]] [32 43]] [16 25]] [31 55]] [32 100]] [17 57]]] [32 100]] [3 100]] [3008 1.9 [3 76] [3 100]]] [36 100]] [1899 0.259 [6997 0.741 [3 86] [3 100]] [3 100]]] [3 100]]] [5979 0.272 [7233 0.441 [5447 6.16 [7084 0.637 [3008 7.3 [7201 2.06 [5471 0.423 [6445 4.8 [874 0.403 [5211 5.49 [2232 12.6 [3929 0.331 [814 0.443 [3698 0.982 [1062 1.39 [4664 1.75 [3027 1.15 [811 0.84 [7661 2.7 [7343 4.43 [2969 5.56 [4663 2.28 [6091 2.06 [3357 6.33 [286 1.68 [6977 5.15 [12 99] [12 100]] [12 100]] [12 60]] [12 100]] [12 100]] [12 95]] [12 88]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 90]] [12 66]] [12 100]] [12 88]] [12 100]] [12 75]] [12 42]] [12 83]] [31 90]] [31 100]] [12 100]]] [730 1.29 [3299 0.27 [2259 7.5 [695 1.94 [3929 1.15 [2151 0.722 [2955 4.68 [3687 5.05 [978 0.279 [836 0.463 [1995 2.92 [37 45] [35 28]] [37 84]] [35 50]] [3691 1.81 [1513 2.59 [3057 2.16 [1429 9.85 [37 37] [4851 2.96 [5007 0.0363 [1025 5.38 [4085 2.83 [328 31.2 [3292 3.99 [3374 2.96 [4071 6.42 [3849 1.93 [1517 1.57 [4279 1.34 [37 76] [4 25]] [37 60]] [35 50]] [37 100]] [37 100]] [37 95]] [37 45]] [37 71]] [37 95]] [29 50]] [37 66]]] [3262 2.09 [37 50] [37 100]]] [13 64]] [663 5.29 [37 100] [37 77]]]] [7260 1.42 [38 46] [7 33]]] [19 21]] [481 7.44 [37 96] [37 84]]] [6390 3.96 [3879 5.38 [5019 12.5 [7491 7.4 [3207 3.71 [7324 1.52 [6353 1.77 [3472 12.2 [131 8.59 [1513 2.73 [3748 17.3 [3288 1.64 [6199 9.93 [452 11.5 [2947 4.7 [7502 2.53 [4369 0.599 [3975 12.5 [3086 18.8 [3295 0.57 [1899 17.2 [37 100] [37 84]] [37 100]] [37 94]] [37 83]] [37 100]] [37 60]] [37 84]] [37 83]] [37 71]] [5663 0.552 [3056 9.14 [5007 1.84 [37 100] [37 88]] [37 80]] [37 83]]] [37 75]] [13 93]] [37 66]] [37 80]] [37 73]] [37 73]] [37 66]] [37 57]] [37 44]] [37 35]] [13 50]]] [1391 3.42 [7457 0.925 [5693 0.265 [1239 19 [5851 3.08 [3262 0.559 [30 14] [37 92]] [12 30]] [16 23]] [22 40]] [5 44]] [22 94]]] [5851 6.72 [2766 1.73 [77 1.7 [1906 6.76 [112 4.08 [3338 5.94 [4015 0.43 [7512 0.305 [3929 0.406 [112 2.63 [5663 0.747 [3056 0.914 [5605 3.7 [3298 1.71 [3474 1.95 [37 99] [37 100]] [37 100]] [37 100]] [37 100]] [37 100]] [37 90]] [37 100]] [37 100]] [37 100]] [3687 12 [37 95] [37 75]]] [132 1.76 [1499 0.529 [37 95] [37 100]] [37 76]]] [37 92]] [37 71]] [37 81]] [37 71]]] [28 87]]] [2429 0.537 [6877 0.555 [2889 2.19 [3008 1.46 [2682 0.137 [2667 0.104 [5899 0.333 [4738 0.265 [2405 1.5 [5170 1.62 [1701 1.23 [4896 2.2 [6517 0.377 [5723 1.72 [6687 1.1 [3399 0.609 [2081 3.85 [2707 3.51 [6825 1.48 [1587 6.19 [5597 0.876 [3243 3.94 [2868 5.84 [7343 9.21 [38 22] [14 30]] [4940 3.23 [16 37] [16 100]]] [35 40]] [16 70]] [16 66]] [38 64]] [5491 11.6 [7488 0.365 [6227 0.728 [1078 2.02 [4910 0.937 [2357 0.73 [5138 2.96 [7149 2.65 [2951 42.6 [4686 3.36 [1800 3.67 [5799 3.02 [6148 12.8 [2042 1.25 [1783 8.32 [6842 2.94 [5410 5.59 [187 1.95 [38 48] [328 3.56 [38 38] [5 33]]] [38 100]] [5 41]] [2691 0.65 [1897 12.4 [2628 45.6 [1896 3.76 [16 31] [97 1.05 [38 52] [38 87]]] [38 82]] [2707 20.3 [16 47] [16 83]]] [14 40]]] [12 100]] [5 86]] [7255 2.31 [6 38] [16 52]]] [1895 6.09 [38 93] [38 84]]] [17 88]] [38 66]] [2868 3.55 [38 53] [1897 5.22 [16 47] [16 72]]]] [16 100]] [4889 9.78 [38 100] [38 86]]] [2939 40 [7260 4.23 [38 85] [38 100]] [38 90]]] [2869 0.971 [1913 1.04 [38 34] [16 28]] [19 30]]] [5 40]] [38 88]] [14 86]]] [2849 20.9 [2006 0.925 [38 77] [38 96]] [38 64]]] [4004 5.54 [5 72] [6 37]]] [2690 5.1 [6 47] [6 58]]] [1981 1.89 [5102 3.14 [23 5.84 [16 54] [75 1.72 [16 57] [16 69]]] [6 84]] [16 88]]] [5007 4.83 [16 42] [3 30]]] [4807 8.35 [4538 43.5 [1078 0.517 [187 3.69 [17 28] [17 73]] [17 57]] [38 100]] [38 100]]] [1980 0.942 [16 42] [5 37]]] [7149 4.59 [2849 34.5 [26 57] [26 78]] [16 63]]] [5148 0.566 [5641 5.42 [6824 3.03 [5956 2.91 [3984 4.23 [2357 1.21 [38 70] [38 100]] [6384 1.07 [38 66] [38 66]]] [2862 1.1 [38 100] [38 85]]] [1807 4.17 [38 57] [38 90]]] [6385 1.36 [38 71] [17 51]]] [192 0.929 [2885 11.5 [4538 59.5 [5637 4.37 [2259 59.7 [38 57] [38 90]] [1429 13.3 [38 66] [38 100]]] [4673 1.32 [38 100] [2367 5.38 [38 76] [38 97]]]] [38 71]] [38 57]]]] [5491 6.09 [2649 6.79 [4854 2.47 [16 37] [26 41]] [4739 17.2 [2955 2.06 [301 15.6 [16 57] [30 100]] [7255 2.85 [6 50] [16 50]]] [6 69]]] [14 100]]] [16 38]] [301 5.07 [4762 3.7 [5412 3.78 [7169 0.542 [7343 9.12 [5721 2.84 [2729 0.313 [90 0.888 [16 42] [26 42]] [16 72]] [6 63]] [16 79]] [2640 2.97 [16 100] [16 60]]] [38 30]] [18 46]] [30 100]]] [1442 3.82 [6449 0.743 [3238 3.85 [2752 7.1 [7445 1.07 [2955 12.6 [5626 0.277 [28 33] [7420 0.137 [2690 1.56 [5900 2.03 [16 90] [18 55]] [7 42]] [6 66]]] [14 37]] [1888 5.5 [7260 1.41 [16 57] [6 30]] [17 33]]] [6 32]] [16 72]] [6 20]] [16 100]]] [7162 0.537 [1895 2.14 [26 35] [7210 0.832 [144 1.11 [2696 4.07 [4507 0.879 [16 33] [25 50]] [30 100]] [37 40]] [30 81]]] [30 100]]] [2890 1.5 [1899 1.18 [2707 18.4 [18 38] [5 71]] [1897 2.85 [5 100] [5 54]]] [3338 0.673 [3980 6.96 [3752 24.4 [7449 9.8 [2081 0.503 [4991 5.56 [1429 17 [5 52] [1587 6.26 [2951 20.1 [2951 6.04 [5 75] [187 5.3 [5 93] [5 100]]] [1429 24.7 [5 100] [5 54]]] [5 66]]] [37 57]] [4074 0.548 [55 0.697 [5 85] [5 100]] [5 100]]] [7474 5.23 [5 47] [5 75]]] [37 75]] [5 62]] [3677 8.42 [5 93] [5 75]]]]] [4071 3.82 [695 1.38 [1783 21.1 [6778 22.6 [1897 0.33 [37 37] [5102 4.75 [4011 10.5 [37 56] [5 58]] [16 40]]] [2955 4.29 [1896 9.82 [37 100] [37 87]] [37 77]]] [25 22]] [37 100]] [18 37]]] [7132 30.7 [38 97] [4577 13.1 [38 100] [38 54]]]]] [7132 1.24 [5556 1.35 [7210 0.301 [7473 0.0526 [23 96.9 [1436 24.5 [5467 2.39 [5565 0.397 [6208 0.735 [5759 0.0863 [2628 23 [3401 2.79 [3342 5.33 [5602 1.5 [5564 0.445 [5629 0.816 [4188 0.562 [5539 4.31 [5647 3.26 [5994 5.32 [6782 5.05 [6810 3.49 [2469 3.24 [5500 0.76 [6461 0.494 [1912 15.4 [3242 4.95 [5110 5.65 [377 6.97 [5960 1.29 [4851 1.97 [2752 42.6 [415 0.235 [7302 12.4 [4557 18.1 [3994 9.62 [1239 0.899 [28 12] [907 0.968 [6287 4.32 [286 3.25 [2165 2.16 [4279 2.25 [5891 7.03 [5447 3.27 [4030 0.552 [6333 1.24 [2268 1.1 [2253 13 [5295 0.352 [2132 1.54 [6294 1.91 [5991 0.715 [7428 0.284 [435 1.52 [1997 4.7 [7329 1.23 [3995 5.92 [1253 2.59 [25 13] [12 44]] [4 50]] [4 60]] [3 18]] [3 28]] [1078 4.86 [2 40] [22 28]]] [28 25]] [23 25]] [29 62]] [15 42]] [11 71]] [1429 40 [18 37] [18 42]]] [38 44]] [24 100]] [28 23]] [7428 0.0782 [17 27] [11 44]]] [3 27]] [1078 1.81 [17 42] [2 71]]] [3 53]] [12 50]] [3 73]]] [25 69]] [7 100]] [28 91]] [28 63]] [31 26]] [32 41]] [32 91]] [5568 3.94 [28 37] [14 100]]] [30 71]] [7 100]] [31 88]] [25 100]] [30 100]] [4009 2.28 [16 27] [38 85]]] [32 100]] [31 100]] [15 48]] [33 45]] [13 100]] [3 93]] [15 100]] [14 100]] [15 57]] [28 80]] [14 100]] [2849 0.0933 [1726 1.15 [2181 13.5 [6877 0.833 [2955 28.8 [17 38] [14 57]] [19 57]] [38 66]] [2199 0.867 [17 71] [17 100]]] [7391 6.1 [6445 1.52 [2081 1.21 [1980 10.2 [38 30] [38 72]] [38 96]] [17 66]] [16 88]]]] [30 100]] [1996 0.987 [6826 0.565 [17 47] [17 100]] [14 28]]] [14 100]] [12 100]] [2241 14.1 [5994 13 [1876 1.03 [2181 3.8 [2259 45 [31 31] [7 87]] [3 14]] [31 22]] [15 100]] [36 42]]] [1458 0.426 [32 72] [32 100]]] [4562 0.0873 [7401 0.392 [5038 0.44 [37 1.93 [6824 6.68 [4708 0.426 [6572 0.616 [3222 0.376 [2111 14.2 [2951 13 [7370 6.02 [6397 0.309 [5210 5.32 [2466 4.31 [2707 4.27 [2143 2.72 [38 51] [19 44]] [2081 3.24 [166 10.2 [38 75] [38 100]] [38 75]]] [6380 3.12 [1687 1.77 [38 45] [8 30]] [3238 0.535 [4895 3.17 [7369 5.41 [7343 0.322 [2862 11 [2707 11.4 [14 25] [38 81]] [38 84]] [17 50]] [14 42]] [38 85]] [16 57]]]] [38 40]] [17 63]] [38 77]] [4601 3.83 [3523 0.971 [5570 2.6 [2873 10.1 [7343 26.6 [2081 2.32 [1888 5.18 [7391 0.0719 [2955 25.9 [2466 2.79 [2055 1.76 [1262 4.63 [1920 4.19 [2948 5.35 [1437 2.11 [5918 2.07 [38 96] [38 71]] [38 87]] [38 85]] [38 84]] [2875 5.99 [38 88] [38 85]]] [12 44]] [2748 2.7 [38 44] [38 72]]] [38 63]] [3243 0.144 [1429 38.2 [1239 4.43 [38 100] [7149 0.478 [38 88] [38 100]]] [38 57]] [38 100]]] [24 42]] [4051 0.246 [2628 41.2 [38 71] [38 95]] [1980 17.2 [2102 0.585 [2851 3.87 [38 100] [38 92]] [38 100]] [38 83]]]] [38 71]] [38 70]] [2093 0.289 [17 50] [14 50]]] [38 60]] [38 36]]] [5 57]] [17 33]] [1748 0.205 [5607 14.8 [38 50] [35 75]] [17 73]]] [25 44]] [6199 6.19 [8 34] [38 50]]] [2111 0.695 [3928 1.77 [7332 1.31 [1913 3.3 [1783 1.05 [38 50] [1913 1.03 [1436 6.57 [4050 2.23 [5209 0.961 [38 60] [5 25]] [17 46]] [38 76]] [1687 0.465 [37 40] [17 54]]]] [38 66]] [38 28]] [5 88]] [2469 11.2 [2687 10.5 [2951 13 [2862 6 [38 100] [38 55]] [7331 0.434 [38 60] [35 44]]] [38 100]] [17 50]]]] [17 66]] [1749 4.62 [6495 0.483 [5809 0.247 [37 56] [2862 6.73 [17 90] [5809 2.6 [17 75] [17 30]]]] [17 84]] [14 25]]] [6108 10.9 [69 5.08 [2072 0.351 [1239 4.17 [6719 1.36 [7439 10.7 [2367 2.22 [7242 3.13 [38 100] [19 50]] [6824 0.987 [38 66] [38 100]]] [7009 2.33 [2242 0.874 [38 83] [38 100]] [38 100]]] [38 79]] [38 66]] [17 72]] [4895 6.33 [2955 5.29 [5954 10.4 [38 100] [2864 5.85 [38 83] [38 66]]] [19 50]] [38 95]]] [1900 5.92 [6720 2.09 [19 62] [1436 3.08 [38 63] [7472 4 [38 85] [38 63]]]] [17 71]]]]] [6774 0.5 [5587 1.56 [4183 7.68 [537 0.259 [2951 0.929 [5891 2.11 [6835 0.377 [3857 3.82 [5290 0.0984 [5194 0.101 [6638 0.411 [3570 1.27 [5529 0.316 [5129 0.616 [6606 1.29 [2944 4.6 [5732 1.28 [4288 1.56 [1997 0.468 [6853 0.0652 [2055 5.94 [2274 3.18 [6471 0.633 [2093 3.52 [7623 2.18 [2131 0.181 [6397 0.976 [453 0.161 [688 0.682 [1687 1.38 [3929 0.0894 [5999 2.92 [4704 4.03 [4 11] [30 42]] [10 30]] [12 33]] [15 50]] [21 87]] [11 41]] [8 27]] [31 35]] [30 26]] [1 20]] [26 36]] [22 70]] [32 40]] [7369 2.28 [3 54] [3 50]]] [1913 16.4 [3136 1.29 [2251 0.155 [5210 0.767 [1876 0.943 [4398 0.788 [6382 1.14 [25 14] [14 44]] [18 37]] [1078 3.99 [25 100] [25 33]]] [38 46]] [2235 0.0969 [3 35] [3 50]]] [5 35]] [15 76]]] [32 80]] [5412 0.498 [15 25] [28 50]]] [21 90]] [28 77]] [15 50]] [15 100]] [23 100]] [30 100]] [28 100]] [4778 0.589 [5 28] [15 100]]] [35 88]] [7 43]] [5267 1.06 [2151 0.791 [5368 0.1 [14 30] [32 66]] [17 72]] [17 70]]] [1983 0.259 [6287 0.123 [1783 15.2 [83 0.127 [2642 0.84 [4820 0.884 [4050 0.414 [2242 0.1 [7445 1.02 [2628 22.5 [38 36] [38 60]] [38 85]] [38 75]] [38 100]] [38 66]] [6937 0.685 [14 70] [17 66]]] [37 60]] [2869 0.452 [17 48] [38 55]]] [17 66]] [17 25]]] [3 100]] [32 100]] [23 100]] [30 100]]] [29 98]] [6397 0.847 [1997 11.1 [7260 2.02 [1748 0.121 [1899 3.34 [17 27] [8 50]] [2075 0.404 [38 66] [69 1.56 [38 94] [6200 1.12 [2628 38.9 [38 100] [6103 3.01 [38 83] [38 100]]] [38 100]]]]] [6383 0.616 [38 90] [38 60]]] [16 50]] [5164 5.31 [5635 5.08 [5209 4.47 [2879 0.427 [4050 3.13 [6393 2.88 [38 100] [38 80]] [38 97]] [38 100]] [7445 4.34 [38 100] [38 81]]] [38 62]] [38 71]]]]] [5829 0.338 [6434 0.177 [7449 1.18 [3619 1.49 [384 1.52 [567 1.53 [1628 0.136 [6124 0.134 [7441 0.815 [1133 0.707 [3573 0.287 [500 0.573 [3231 0.451 [3079 0.255 [5845 0.445 [3944 0.17 [3803 0.232 [5007 0.648 [4602 3.54 [4120 1.08 [1429 24.6 [811 2.93 [5211 2.19 [2752 6.76 [7357 2.54 [929 3.98 [3097 1.33 [6994 7.56 [4312 1.05 [221 1.47 [4331 5.66 [4070 3.94 [470 1.47 [806 10.6 [759 0.914 [1909 5.14 [2108 7.14 [1207 12.2 [435 11.9 [3968 1.03 [7101 1.23 [3535 3.92 [802 0.479 [4114 2.13 [1239 26.1 [3273 0.756 [3405 1.05 [1 0.787 [3292 4.73 [2259 3.98 [1395 9.13 [6848 4.38 [6660 6.85 [5969 1.31 [1991 26.6 [2068 0.6 [2143 4.77 [392 11.4 [4611 6.74 [976 0.506 [1888 5.97 [2062 0.673 [791 39.3 [906 2.79 [1124 1.37 [312 6.55 [2461 0.585 [27 34] [27 100]] [1 40]] [27 100]] [957 4.98 [27 19] [27 100]]] [35 30]] [27 100]] [24 31]] [27 100]] [35 90]] [27 30]] [435 0.524 [27 28] [27 65]]] [27 38]] [23 57]] [27 100]] [11 100]] [35 35]] [27 100]] [1995 2.32 [2241 2.2 [4 11] [36 44]] [27 50]]] [11 64]] [11 70]] [27 100]] [11 85]] [2526 3.46 [27 17] [8 70]]] [4115 13.7 [2526 0.299 [27 97] [27 100]] [791 22.1 [27 100] [27 85]]]] [3 28]] [27 100]] [35 42]] [27 100]] [11 28]] [2 90]] [35 33]] [8 100]] [11 100]] [2081 1.87 [32 37] [26 33]]] [27 100]] [35 77]] [27 96]] [29 31]] [27 95]] [10 81]] [5994 0.846 [4373 13.4 [27 97] [27 83]] [27 100]]] [6 18]] [35 65]] [835 0.832 [4373 2.7 [4326 0.945 [2701 0.441 [758 1.6 [3439 1.01 [3503 3.94 [4288 4.28 [23 18 [4611 1.53 [448 1.32 [3554 6.44 [2764 3.17 [6199 2.87 [5368 8.89 [3103 0.792 [2148 2.93 [762 2.13 [952 2.46 [6015 2.33 [5270 2.39 [6196 1.35 [1221 1.7 [4929 2.82 [5322 11.2 [1400 10.8 [380 1.96 [6661 5.26 [2259 2.19 [6230 13.4 [6114 0.613 [2993 2.73 [2180 8.38 [2913 2.65 [2201 3.78 [774 3.48 [27 22] [23 64]] [27 62]] [11 40]] [11 33]] [11 58]] [23 88]] [19 24]] [906 9.18 [10 15] [435 12.1 [11 66] [11 83]]]] [11 81]] [25 36]] [25 28]] [27 71]] [4 50]] [10 66]] [11 66]] [31 40]] [29 71]] [10 57]] [23 100]] [23 61]] [35 77]] [11 28]] [28 25]] [2005 7.97 [11 44] [23 85]]] [435 3.45 [32 37] [32 85]]] [27 66]] [35 33]] [34 3.82 [2143 6.13 [29 55] [29 60]] [32 88]]] [23 61]] [11 100]] [1995 2.87 [11 90] [11 100]]] [11 100]] [2785 2.33 [2108 0.441 [145 2.26 [939 10.7 [29 61] [29 91]] [29 100]] [29 100]] [29 100]]] [2767 0.562 [2752 40.7 [27 79] [29 40]] [27 75]]] [1164 11 [27 93] [4373 18 [27 66] [27 57]]]] [11 88]]] [4520 1.23 [1055 3.46 [4326 2.35 [877 1.71 [1068 0.318 [5827 1.72 [859 20 [23 28] [10 100]] [11 100]] [23 64]] [22 100]] [27 75]] [11 100]] [11 100]]] [10 66]] [5892 2.68 [5467 4 [5673 11.5 [5972 1.74 [2461 4.85 [6198 6.67 [5732 0.146 [6230 1.71 [3457 0.0669 [429 6.55 [2 29] [2917 6.97 [4768 2.66 [985 3.74 [2752 0.581 [5270 3.93 [144 7.77 [7335 3.5 [685 1.9 [2029 8.73 [695 4.48 [4369 1.81 [2093 0.372 [8 16] [4 23]] [13 66]] [7 29]] [3 50]] [27 45]] [30 75]] [13 47]] [31 100]] [6859 11.7 [4288 5.47 [3447 0.971 [619 10.4 [807 0.754 [7413 1.18 [3514 0.795 [28 19] [35 100]] [28 44]] [28 33]] [28 100]] [35 92]] [22 54]] [28 42]]] [4 66]] [2259 20.9 [29 70] [2 30]]] [32 100]]] [35 100]] [1913 2.67 [5 26] [1 44]]] [2199 1.66 [28 87] [28 71]]] [29 100]] [27 100]] [36 58]] [30 65]] [12 73]] [14 74]]] [1162 5.59 [2143 4.11 [4151 19.9 [1170 1.57 [1233 0.858 [5342 0.306 [6342 1.06 [3533 9.02 [1160 0.821 [7210 0.8 [3844 1.48 [1062 1.53 [16 3.76 [1157 1.77 [27 91] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 90]] [27 100]] [27 100]] [27 100]] [27 100]] [27 88]] [27 81]] [27 84]]] [4601 16.9 [2178 2.7 [2916 4.03 [26 44] [26 90]] [26 57]] [26 88]]] [6799 2.15 [2752 6.79 [11 14] [6230 4.67 [7101 0.891 [5692 0.39 [6152 1.48 [29 49] [29 66]] [28 50]] [29 100]] [18 20]]] [29 100]]] [3705 0.509 [3236 0.658 [3452 0.277 [11 92] [11 100]] [11 100]] [11 100]]] [35 75]] [10 100]] [1078 46 [832 0.778 [144 0.849 [37 86] [37 95]] [37 100]] [7623 0.614 [8 30] [27 100]]]] [3953 0.978 [35 100] [35 85]]] [6162 0.465 [27 98] [27 100]]] [10 100]] [3227 1.56 [3132 0.613 [3527 24.6 [3844 0.724 [1078 37.9 [10 71] [2752 6.75 [4125 3.37 [1980 1.45 [27 97] [27 100]] [27 100]] [27 90]]] [27 100]] [4328 9.46 [27 100] [27 93]]] [27 100]] [1164 5.24 [27 73] [27 100]]]] [441 3.29 [1913 0.352 [906 6.99 [950 0.175 [7443 0.426 [939 9.96 [5211 2 [27 61] [7139 1.01 [11 75] [11 80]]] [131 0.637 [3931 3.26 [453 2.22 [27 80] [27 100]] [27 100]] [27 100]]] [27 100]] [27 100]] [11 57]] [27 58]] [11 50]]] [434 7.3 [3290 1.65 [1888 0.754 [3794 0.99 [7188 3.14 [2232 2.06 [6015 4.04 [4279 8.1 [6025 2.72 [3406 0.334 [3027 1.42 [2752 13.9 [4373 0.531 [4135 3.86 [7635 3.6 [1135 5.99 [27 96] [27 100]] [27 100]] [27 100]] [27 100]] [27 80]] [27 100]] [27 100]] [27 70]] [27 85]] [429 38.9 [27 75] [27 100]]] [27 83]] [12 100]] [27 100]] [27 55]] [12 50]] [27 40]]] [2139 0.192 [2166 1.01 [2701 0.161 [1094 0.538 [1087 0.136 [1078 36.2 [36 57] [29 100]] [29 100]] [2199 1.27 [29 70] [29 100]]] [1943 1.72 [23 7.14 [29 100] [906 0.321 [5455 7.05 [29 100] [29 93]] [29 100]]] [29 100]]] [29 83]] [29 100]]] [2562 1.06 [857 0.219 [2423 2.86 [4120 1.62 [5648 12.2 [3997 0.649 [2015 0.395 [6342 7.16 [1078 15.4 [23 26] [2763 0.291 [3237 0.395 [2083 1.19 [5421 1.07 [826 2.7 [1101 4.35 [11 74] [11 40]] [11 57]] [23 90]] [11 100]] [11 100]] [6653 0.466 [11 84] [11 100]]]] [23 53]] [11 100]] [37 100]] [11 28]] [27 66]] [23 100]] [1055 0.532 [11 90] [11 100]]] [23 95]]] [23 77]] [2149 6.06 [485 0.873 [1106 0.413 [3324 2.32 [7634 0.276 [1104 0.645 [3620 1.84 [4135 4.11 [1400 16.5 [3095 9.18 [1991 2.56 [685 1.92 [939 34.4 [27 83] [11 58]] [27 100]] [11 85]] [27 42]] [10 100]] [27 95]] [1068 1.61 [4120 0.752 [774 4.97 [475 15.5 [27 96] [27 82]] [27 100]] [27 100]] [27 100]]] [27 54]] [5462 0.386 [27 100] [27 80]]] [27 69]] [499 0.826 [27 90] [27 100]]] [27 100]] [11 42]]] [998 0.386 [6754 0.678 [499 1.65 [1167 0.59 [6514 5.1 [3139 0.11 [6491 2.73 [2802 1.58 [7444 0.876 [2470 0.627 [5482 0.379 [1425 0.53 [695 0.418 [860 0.364 [7450 2.5 [384 0.516 [3616 3.94 [2701 2.92 [392 12.1 [7335 1.65 [1400 9.14 [6184 20.5 [2526 2.92 [1108 2.49 [5211 2.76 [23 21] [2259 2.65 [11 69] [22 66]]] [28 50]] [2562 0.756 [23 75] [23 100]]] [11 43]] [12 73]] [23 42]] [28 63]] [6699 4.76 [29 73] [29 100]]] [27 60]] [23 100]] [11 52]] [11 100]] [5146 0.418 [1218 4.59 [7497 0.79 [695 4.65 [28 42] [12 27]] [29 54]] [695 5.34 [36 46] [28 50]]] [22 54]]] [12 90]] [29 88]] [2178 1.77 [880 1.98 [11 62] [11 100]] [11 84]]] [11 100]] [29 100]] [1226 0.952 [23 48] [23 100]]] [11 100]] [36 62]] [29 100]] [2081 5.7 [499 7.21 [27 100] [660 9.61 [27 84] [29 57]]] [27 50]]] [29 100]] [23 100]]] [429 21.3 [11 33] [1203 0.177 [2259 11.6 [1 0.406 [7442 0.573 [11 82] [11 100]] [11 100]] [32 69]] [1995 7.59 [11 100] [2897 1.67 [11 83] [11 100]]]]]] [5226 0.655 [1062 0.29 [567 1.69 [5110 0.898 [11 98] [11 100]] [11 100]] [11 100]] [11 100]]]] [5267 1.14 [4329 0.978 [4179 1.7 [2081 0.924 [328 10.8 [1239 29 [27 100] [27 64]] [27 97]] [27 100]] [27 100]] [27 100]] [27 100]]] [1391 1.68 [5345 5.08 [7061 0.919 [6310 4.3 [4703 2.07 [144 4.42 [6597 5.6 [5227 1.03 [4288 0.95 [7193 1.17 [6603 2.29 [660 2.43 [867 1.82 [3055 1.66 [567 8.55 [850 8.27 [1906 10.2 [934 4.7 [438 5.32 [435 10.5 [398 13.8 [7385 14 [4968 20.5 [7323 18.3 [1025 6.73 [6761 2.1 [2588 6.22 [5911 10.8 [2178 15.5 [379 14.1 [1980 43.9 [3008 19.2 [6923 4.27 [5270 4.18 [221 21.4 [4716 11.5 [2767 3.4 [4858 2.88 [7445 3.91 [3552 0.141 [1081 5.71 [5322 19.5 [2707 4.45 [1078 86.2 [7346 5.52 [4067 3.14 [3223 0.219 [4693 0.212 [3929 11.8 [2178 9.65 [774 10.8 [5851 25 [2827 10.9 [2015 0.257 [3956 0.339 [7169 0.121 [6670 0.592 [2312 19.2 [2081 6.11 [4601 0.458 [2562 37.4 [5753 4.68 [7428 0.739 [2312 0.497 [4611 1.19 [7009 0.605 [4851 0.246 [1239 0.695 [7251 1.07 [3464 2.3 [685 0.81 [2536 1.31 [6294 2.11 [887 2.13 [1495 2.73 [429 2.96 [8 98] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 97]] [8 95]] [8 100]] [4601 0.535 [5192 0.945 [4154 6.62 [8 88] [8 100]] [8 100]] [8 100]]] [8 95]] [8 100]] [8 100]] [8 100]] [8 100]] [8 84]] [0 60]] [8 75]] [8 87]] [8 77]] [8 100]] [8 100]] [8 71]] [8 90]] [8 85]] [8 90]] [8 94]] [8 85]] [8 100]] [8 97]] [8 80]] [8 88]] [8 87]] [8 83]] [8 57]] [8 70]] [24 60]] [8 63]] [8 66]] [8 62]] [429 23.6 [8 66] [8 88]]] [8 70]] [8 71]] [5412 8.3 [6294 0.726 [491 1.08 [8 86] [8 100]] [8 100]] [8 62]]] [8 66]] [8 71]] [8 70]] [8 62]] [8 58]] [8 90]] [8 53]] [8 82]] [8 50]] [8 66]] [0 100]] [23 50]] [8 72]] [35 80]] [23 100]] [3476 1.71 [8 58] [8 100]]] [8 45]] [20 37]] [10 31]] [23 50]] [0 66]] [5662 0.778 [23 57] [23 100]]] [2312 1.16 [7413 1.42 [3957 0.879 [8 81] [8 100]] [8 100]] [8 100]]] [3724 1.28 [22 33] [0 100]]]] [3480 0.348 [4420 0.536 [2752 18.8 [1239 8.57 [3849 0.894 [3972 0.935 [756 0.964 [1404 1.98 [3040 1.44 [2701 1.85 [5023 0.978 [957 1.06 [6114 2.74 [6155 0.79 [826 4.18 [2471 2.46 [4611 3.46 [5851 2.01 [6367 2.72 [6883 2.86 [6310 1.52 [3475 4.12 [2973 1.36 [7354 1.39 [3667 3.36 [4564 2.2 [1415 0.565 [2759 4.2 [1391 17.6 [828 8.08 [5568 1.39 [6848 3.55 [896 2.04 [2259 5.4 [6294 0.935 [15 42] [12 44]] [3 13]] [26 42]] [6353 11.9 [35 61] [35 50]]] [35 61]] [15 100]] [15 68]] [35 66]] [26 83]] [30 80]] [35 75]] [5 52]] [31 66]] [15 100]] [35 50]] [35 90]] [25 100]] [4684 1.91 [5219 0.917 [35 8] [8 61]] [7169 15.2 [15 44] [23 33]]]] [685 9.7 [35 70] [30 33]]] [15 100]] [15 76]] [15 93]] [35 92]] [7354 6.07 [3905 1.57 [4851 1.29 [27 32] [30 71]] [37 58]] [5 84]]] [35 95]] [695 3.33 [15 75] [15 95]]] [4748 1.33 [2526 3.94 [35 91] [35 100]] [35 100]]] [15 100]] [30 84]] [2470 2.12 [1473 4.74 [7411 4.65 [37 66] [8 52]] [8 100]] [15 100]]] [740 0.792 [4414 5.94 [1648 1.27 [3708 0.645 [35 72] [35 100]] [35 87]] [35 100]] [35 100]]] [233 0.982 [2628 9.65 [4092 2.14 [5989 1.53 [1953 1.79 [5040 1.53 [7615 1.06 [5368 2.45 [4154 2.81 [4534 2.69 [1025 2.58 [35 23] [35 47]] [35 69]] [4764 1.46 [3 64] [3 90]]] [25 31]] [3 100]] [524 1.31 [21 66] [21 100]]] [35 75]] [30 31]] [30 68]] [38 17]] [33 92]]] [7480 1.49 [1025 0.991 [3079 3.83 [6883 3.31 [802 0.309 [731 1.33 [4061 1.26 [2897 0.952 [2526 0.855 [7742 1.75 [859 4.59 [893 3.76 [1085 2.48 [6115 3.16 [4956 3.55 [6342 20.3 [5673 8.24 [3506 2.39 [5851 3.22 [5972 16.9 [6080 0.971 [7241 2.76 [5034 1.55 [1888 6.17 [1921 2.92 [1410 1.6 [6394 1.62 [1429 47.4 [826 6.56 [3905 7.53 [5491 10.6 [6196 3.7 [144 3.11 [5007 1.72 [15 63] [15 100]] [28 33]] [15 100]] [15 100]] [429 17 [15 100] [15 77]]] [791 33.3 [15 100] [15 80]]] [4533 13.1 [35 34] [35 90]]] [15 100]] [15 100]] [15 100]] [32 35]] [30 88]] [30 55]] [15 100]] [15 57]] [37 17]] [30 28]] [35 33]] [37 50]] [35 64]] [35 90]] [35 78]] [241 1.5 [5154 2.13 [3243 2.3 [15 92] [15 100]] [15 100]] [15 100]]] [30 88]] [5 63]] [4414 1.08 [2081 7.5 [1783 0.956 [35 77] [26 33]] [23 40]] [23 43]]] [35 66]] [7623 3.48 [30 85] [30 100]]] [5 32]] [802 6.06 [15 86] [3884 1.42 [15 93] [15 100]]]] [2763 1.66 [35 62] [35 100]]] [37 84]] [312 1.99 [4956 2.84 [2029 1.59 [7411 9.73 [978 2.83 [6155 0.873 [7210 1.05 [6184 7.74 [3262 3.75 [15 42] [37 100]] [15 100]] [12 21]] [15 88]] [23 31]] [35 55]] [28 33]] [35 100]] [3292 1.29 [37 66] [37 100]]]] [4664 1.23 [4369 0.775 [15 98] [15 100]] [15 100]]]] [4414 42.2 [4663 0.773 [15 98] [15 100]] [7461 1.31 [1769 1.06 [4424 4.93 [15 96] [15 85]] [15 100]] [15 100]]]] [3072 0.534 [3675 1.78 [5753 8.36 [2081 0.953 [4851 0.599 [4768 0.747 [5732 0.226 [4218 12.8 [2471 1.59 [15 98] [15 100]] [15 83]] [15 100]] [15 100]] [15 100]] [2023 0.976 [791 11.3 [15 88] [15 100]] [15 100]]] [15 57]] [15 80]] [15 100]]]] [5003 0.592 [5210 0.0585 [2694 0.771 [3912 0.289 [4937 1.23 [7038 0.649 [6877 1.09 [2734 0.08 [7255 3.24 [95 1.05 [6677 0.32 [3675 6.03 [560 0.461 [6959 0.688 [429 5.56 [7222 0.134 [6572 2.33 [5103 0.0403 [7134 3.74 [7101 1.67 [5673 23.6 [6953 2.11 [2891 8.01 [4648 1.04 [7343 8.15 [7206 3.06 [5673 0.882 [6 85] [2111 0.299 [5007 4.85 [2939 106 [663 3.49 [16 27] [16 58]] [38 66]] [16 36]] [38 75]]] [38 68]] [2023 1.19 [16 44] [16 70]]] [38 92]] [2849 25.1 [7 42] [7 75]]] [17 80]] [4457 4.5 [2851 2 [4426 15.4 [5435 3.69 [38 35] [6 33]] [16 40]] [38 78]] [38 57]]] [1783 1.08 [6 34] [6 60]]] [7 82]] [7373 0.739 [3576 0.724 [189 8.19 [2891 4.15 [1 2.04 [2853 4.12 [16 32] [16 55]] [6 66]] [7 90]] [6 77]] [16 100]] [6 44]]] [17 38]] [7222 9.76 [6 80] [16 60]]] [7260 0.398 [5597 4.48 [26 17] [16 69]] [18 63]]] [5100 2.75 [4854 17.5 [4504 0.991 [5723 14.3 [6007 0.821 [5898 3.82 [5368 0.319 [2663 0.48 [16 63] [16 100]] [16 33]] [16 33]] [16 42]] [16 83]] [18 100]] [6 75]] [5099 52.7 [2655 0.861 [2093 0.904 [5412 0.52 [5482 3.97 [5099 34.8 [4854 7 [16 68] [5681 10.3 [6 50] [6 37]]] [16 92]] [16 37]] [16 44]] [18 77]] [4527 11.4 [5099 30.5 [6 50] [2628 32 [6 50] [2713 20.3 [18 63] [6 37]]]] [2655 19.7 [6 66] [6 100]]]] [6 94]]]] [5100 1.66 [18 84] [18 46]]] [38 67]] [167 4.37 [38 51] [17 82]]] [6677 0.891 [2469 1.12 [7401 2.68 [2939 30.4 [3008 0.163 [429 7.6 [17 23] [18 33]] [17 25]] [2951 18.4 [16 57] [6207 3.03 [37 35] [5 40]]]] [17 75]] [16 57]] [5637 5.27 [17 100] [17 50]]]] [7169 2.29 [2730 4.41 [5170 1.44 [5435 4.78 [7419 0.283 [5681 11.3 [2722 10.2 [5462 1.67 [6756 0.873 [5345 4.48 [2435 2.18 [6659 0.808 [1262 2.55 [2660 7.47 [4763 1.28 [83 4.53 [2955 16 [392 2.02 [4854 13 [4977 4.94 [1888 4.04 [5632 6.13 [5799 7.21 [2978 1.08 [6959 5.98 [6830 3.62 [38 26] [15 23]] [16 46]] [16 37]] [7 44]] [18 60]] [16 90]] [19 44]] [18 71]] [18 87]] [7150 1.83 [18 52] [18 85]]] [7149 5.07 [16 62] [6 57]]] [16 75]] [6 45]] [19 46]] [19 50]] [38 83]] [6 53]] [6 50]] [10 31]] [16 100]] [5931 12.5 [192 13 [2679 12.9 [2849 81.8 [16 55] [23 60.5 [18 45] [16 54]]] [16 92]] [23 36.4 [6 40] [18 50]]] [16 35]]] [429 6.65 [2689 0.343 [7231 4.54 [5673 13.5 [194 1.27 [1783 15.7 [16 52] [16 89]] [16 100]] [16 53]] [16 30]] [16 100]] [18 50]]] [7149 17 [957 0.724 [166 4.04 [7343 18 [7611 1.4 [2728 0.516 [5900 4.13 [2951 4.25 [95 7.99 [16 57] [16 75]] [3742 1.22 [1239 52.6 [6257 3.86 [4879 5.85 [5673 18.3 [16 54] [18 41]] [6 50]] [18 40]] [16 70]] [4457 6.1 [78 0.62 [14 25] [26 55]] [7 44]]]] [18 77]] [7048 4.07 [16 81] [16 100]]] [28 100]] [5681 13 [16 100] [16 60]]] [5801 14.6 [18 50] [19 44]]] [18 60]] [16 83]]] [731 0.296 [6473 5.94 [7149 4.49 [18 53] [26 53]] [16 66]] [16 33]]] [6506 1.91 [7 66] [7 100]]] [6347 3.07 [1395 2.37 [16 83] [16 33]] [16 33]]]] [4738 2.89 [2653 1.06 [7255 1.47 [2984 19.2 [2849 38.2 [4527 0.881 [7099 11 [2952 0.716 [5627 10 [2734 5.74 [1356 1.1 [2628 44.7 [2723 0.522 [1260 0.371 [6 59] [16 80]] [6 100]] [6 94]] [18 62]] [16 40]] [6 85]] [6 42]] [18 71]] [2939 21.7 [6 90] [6 75]]] [16 37]] [6 67]] [23 9.95 [6 45] [2984 5.69 [5692 0.475 [16 38] [16 50]] [6 50]]]] [1596 0.538 [16 42] [16 78]]] [4939 1.26 [16 58] [16 60]]]] [6199 4.5 [5681 2.66 [3972 3.79 [1897 0.473 [37 46] [37 100]] [5345 0.36 [37 57] [37 50]]] [5724 0.566 [7206 4.92 [5626 0.81 [2849 62.6 [2711 1.91 [16 40] [18 39]] [4104 0.719 [37 52] [37 66]]] [6 54]] [37 66]] [16 37]]] [16 47]]] [5484 1.71 [75 0.693 [6008 6.31 [7282 5.79 [2680 0.427 [5187 1.08 [78 0.709 [4768 0.867 [2656 3.17 [1661 4.11 [6136 1.09 [2419 0.9 [2640 8.89 [2584 5.24 [6380 1.23 [5723 1.91 [1836 0.461 [7042 0.496 [7038 1.26 [6 75] [3435 8.45 [2030 1.06 [4674 8.75 [5598 18 [4879 2.78 [5100 0.0809 [6406 8.72 [2955 18.2 [2951 6.84 [5673 6.65 [16 50] [16 87]] [2728 0.635 [190 3.78 [18 38] [16 60]] [16 90]]] [0 20]] [16 46]] [4651 0.233 [2262 0.193 [6409 1.75 [7210 5.32 [2370 0.212 [5408 1.03 [2728 0.162 [194 0.437 [16 75] [195 4.13 [16 60] [16 62]]] [16 100]] [16 87]] [16 100]] [6 50]] [6 42]] [16 100]] [16 83]]] [6 41]] [16 37]] [6 33]] [16 38]] [5 58]]] [17 25]] [7041 1.05 [16 92] [16 66]]] [2649 8.33 [2412 1.23 [6 30] [14 25]] [16 81]]] [5962 1.7 [4716 1.28 [16 66] [16 55]] [6 80]]] [6 52]] [18 54]] [7041 3.41 [6 90] [2419 4.11 [37 50] [6 50]]]] [2466 1.53 [16 36] [6 73]]] [2717 1.49 [18 72] [16 44]]] [5962 0.834 [2412 5.66 [5801 8.45 [16 34] [3 28]] [18 40]] [26 60]]] [6 83]] [248 8.09 [3207 1.14 [1374 1.93 [2940 15.2 [88 2.39 [5680 0.321 [2671 2.75 [1981 2.76 [6121 0.854 [4527 0.31 [2282 0.418 [7255 8.36 [5963 2.74 [2006 0.157 [94 5.73 [6409 0.33 [2978 7.42 [2640 5.7 [5099 1.34 [16 40] [16 60]] [16 88]] [16 75]] [5799 0.595 [16 66] [16 100]]] [16 50]] [6 33]] [6 41]] [7150 3.46 [190 2.52 [6 50] [18 53]] [16 50]]] [16 95]] [2707 10.2 [16 63] [16 94]]] [26 55]] [83 2.25 [17 33] [30 50]]] [18 70]] [18 61]] [37 33]] [6 45]] [2579 2.02 [2679 1.31 [18 55] [18 50]] [18 75]]] [16 28]] [26 71]]] [18 66]] [23 6.25 [7 55] [7 100]]] [6 51]] [26 50]] [1078 4.84 [2955 3.32 [16 88] [2951 4.78 [6 42] [4426 1.99 [16 87] [6 50]]]] [7476 0.357 [2862 0.402 [16 50] [16 66]] [16 58]]]] [5901 0.294 [5103 1.87 [16 66] [18 78]] [18 91]]]] [7512 1.09 [7206 4.89 [194 10.3 [7134 3.11 [685 1.09 [6761 1.92 [5007 13.3 [2983 11.9 [187 11.6 [7038 0.59 [6 30] [5597 0.465 [16 50] [16 60]]] [7042 0.388 [5722 0.888 [6 58] [6 77]] [16 45]]] [5102 4.48 [18 53] [16 60]]] [18 66]] [5103 3.41 [2048 1.71 [5799 0.45 [18 47] [6 100]] [6 62]] [6 100]]] [16 36]] [7 100]] [18 35]] [16 69]] [18 45]]] [37 100]] [5962 0.209 [2656 2.02 [6299 1.05 [5330 0.511 [1429 34.5 [6409 2.55 [30 61] [30 60]] [16 54]] [30 97]] [30 100]] [30 33]] [30 41]]] [7301 0.364 [4686 2.15 [2649 3.09 [7331 5.82 [2469 2.16 [7473 4.26 [3238 0.0902 [7370 7.19 [38 77] [12 60]] [38 41]] [38 92]] [2721 1.22 [2978 2.73 [38 75] [38 37]] [16 66]]] [12 33]] [16 50]] [6721 1.11 [2939 8.16 [17 85] [17 75]] [17 50]]] [17 58]]] [7 100]]] [6926 0.0526 [6866 0.416 [5240 0.181 [4832 0.355 [6081 0.162 [4891 0.73 [7034 0.265 [2482 0.532 [6859 0.164 [6230 1.58 [4235 25.6 [2562 1.02 [3480 1.03 [6471 0.138 [5034 1.3 [6189 0.362 [168 9.09 [6100 0.145 [1240 0.995 [6260 1.08 [5480 0.951 [2962 1.77 [7354 1.1 [7222 2.2 [6350 0.457 [7009 3.52 [6544 0.199 [6982 0.167 [673 1.45 [6515 0.654 [2763 0.56 [5472 0.807 [7768 0.952 [2818 0.313 [5753 1.5 [5409 5.55 [6550 0.77 [4338 7.3 [5403 1.22 [1116 0.807 [6284 3.4 [5769 2.71 [5747 0.722 [4673 2.14 [1400 1.98 [2488 8.34 [2445 3.55 [3020 6 [1600 0.662 [1919 0.962 [6524 3.48 [1047 3.39 [2793 7.25 [1239 26.6 [5972 4.76 [2412 4.49 [2594 7.07 [7132 4.24 [5424 0.761 [6537 3.73 [6182 0.614 [4108 0.928 [3794 0.955 [6106 0.738 [7549 0.552 [4699 0.56 [7542 5.82 [4934 2.85 [6178 0.695 [3667 1.39 [3016 1.2 [5670 1.1 [23 52.9 [3734 0.402 [232 0.6 [2388 1.47 [6732 1.71 [7421 1.59 [4851 3.23 [2475 2.86 [4210 1.08 [4865 3.08 [5833 6.78 [3912 0.824 [6581 1.49 [719 2.15 [7695 4.47 [7233 0.945 [377 0.449 [6575 7.09 [5242 4.59 [5812 5.72 [7522 1.15 [7520 1.01 [5360 3.03 [5564 2.22 [7529 3.18 [1025 12.2 [14 8] [2 25]] [2517 7.12 [24 90] [24 87]]] [14 100]] [5110 0.963 [33 85] [33 100]]] [3645 3.5 [4806 10.5 [4312 6.45 [723 6.73 [14 16] [16 35]] [24 41]] [17 75]] [24 80]]] [2004 1.45 [3687 0.894 [4235 3.63 [22 31] [20 50]] [37 71]] [23 58]]] [1089 1.69 [1429 30.3 [4663 12.8 [2 40] [4 57]] [7 40]] [1888 2.18 [4 50] [4 75]]]] [31 61]] [5 77]] [221 0.945 [896 4.1 [2268 7.58 [14 28] [14 76]] [14 59]] [28 66]]] [32 57]] [30 86]] [5110 18.6 [7414 2.7 [7384 1.99 [4 32] [7 79]] [22 44]] [33 55]]] [6581 14.3 [5647 2.28 [1078 24.5 [144 12.5 [7512 11.4 [1429 46.6 [17 28] [5 44]] [17 61]] [19 62]] [17 74]] [4 33]] [5 38]]] [37 95]] [6591 30.2 [5509 4.5 [17 18] [5 38]] [17 88]]] [3 100]] [4312 9.01 [30 51] [3 100]]] [15 100]] [95 8.5 [3225 2.15 [4112 11.8 [7742 7.48 [2541 5 [4587 4.04 [2849 14.1 [5219 4.76 [6317 5.49 [4369 10.8 [6203 9.8 [392 8.08 [7192 3.11 [4718 5.6 [7340 3.31 [5789 27.8 [3130 28.8 [7588 1.63 [7233 3.36 [14 31] [32 100]] [5729 3.5 [5 38] [17 71]]] [32 68]] [36 100]] [4308 5.88 [32 92] [32 66]]] [7 71]] [17 59]] [2259 7.96 [28 27] [7 75]]] [17 31]] [32 81]] [7 100]] [8 100]] [16 25]] [7665 34.8 [17 94] [17 50]]] [19 34]] [4 86]] [5 88]] [7 100]] [17 60]]] [2080 11.9 [6422 8.43 [6 79] [6 81]] [6 36]]] [7722 4.98 [4754 3.77 [2636 2.67 [2628 10.9 [7188 1.89 [5819 2.41 [3579 9.04 [2561 3.72 [2005 1.63 [5871 19.2 [1429 8.65 [7512 0.967 [17 35] [6734 2.65 [6920 2.94 [7185 5.82 [5675 6.33 [4 27] [5 40]] [14 29]] [2 71]] [2 59]]] [5198 14.1 [6091 8.3 [6333 11.2 [4083 11.1 [573 11.5 [7664 11.5 [978 19.5 [2259 12.4 [7253 3.08 [647 0.466 [17 26] [4 66]] [17 75]] [7 16]] [4 24]] [14 40]] [2 29]] [16 42]] [5 50]] [7 44]] [14 33]]] [14 66]] [4 31]] [2 83]] [7 77]] [2 76]] [7711 20.2 [17 25] [19 66]]] [4 28]] [7 50]] [17 88]] [5267 1.31 [4414 14.8 [6743 5.21 [178 6.47 [5 28] [6583 4.59 [14 30] [17 73]]] [14 30]] [5 70]] [14 33]]]] [6 96]] [4398 0.6 [1287 1.04 [5322 1.22 [33 78] [1 57]] [33 100]] [33 100]]] [4896 0.812 [1239 4.59 [17 75] [17 50]] [17 68]]] [4533 10.5 [5368 13.7 [4650 0.975 [7514 1.09 [4154 21.8 [2280 0.296 [6445 3.07 [430 7.87 [3 16] [22 41]] [14 52]] [19 85]] [22 73]] [1982 9.59 [2466 2.6 [663 1.12 [4154 0.6 [19 44] [19 62]] [13 28]] [19 30]] [19 63]]] [19 58]] [33 50]] [22 77]]] [31 94]] [5728 3.76 [24 97] [24 100]]] [1783 6.97 [4 48] [2 80]]] [25 100]] [4154 1.31 [14 95] [14 75]]] [32 55]] [4239 0.56 [20 61] [20 100]]] [6 82]] [32 95]] [5211 8.29 [7185 1.82 [6732 6.34 [2573 18.7 [7335 5.59 [5345 0.157 [38 21] [38 50]] [17 87]] [38 87]] [17 61]] [573 1.17 [7417 0.634 [17 53] [17 87]] [38 66]]] [8 100]]] [3056 0.928 [7665 21.2 [37 95] [36 37]] [37 100]]] [25 100]] [1993 5.42 [6537 6.76 [33 44] [719 10.2 [285 3.8 [7719 1.36 [2259 6.08 [2 64] [2 58]] [2 100]] [33 100]] [2 95]]] [896 5.88 [2 85] [2 100]]]] [32 97]] [4 71]] [5 68]] [6 86]] [5976 2.86 [7067 6.44 [5705 2.54 [6103 1.3 [111 2.28 [328 2.9 [6732 13 [3093 3.55 [6173 2.92 [756 8.44 [3874 2.06 [978 9.44 [7689 5.62 [2766 2.7 [791 4.91 [178 15.2 [2993 5.75 [7461 6.33 [12 46] [12 75]] [36 71]] [12 66]] [12 44]] [12 100]] [36 100]] [31 90]] [12 100]] [30 100]] [31 100]] [12 100]] [12 91]] [12 48]] [12 100]] [31 88]] [36 62]] [36 100]] [3 100]]] [6749 7.88 [6287 2.56 [7514 2.58 [328 29.2 [5917 2.33 [6581 1.04 [6330 0.942 [695 2.32 [4726 3.19 [5090 7.65 [212 0.621 [1330 1.31 [232 1.86 [247 12.9 [6169 4.07 [5610 2.24 [7405 2.24 [4233 0.593 [1247 7.21 [6114 19.4 [6342 11.6 [2526 19.7 [7672 0.54 [429 19.9 [5799 9.89 [6883 3.88 [2259 42.3 [2892 2.01 [2936 7.73 [328 10.7 [2849 9.58 [2119 0.987 [6 14] [1 66]] [16 32]] [33 37]] [33 72]] [33 75]] [5598 11.4 [6 28] [6 100]]] [33 71]] [7 66]] [2259 22.8 [2939 7.81 [3 43] [6 28]] [6 71]]] [10 16]] [896 4.57 [6 69] [16 41]]] [6 100]] [6 100]] [24 35]] [3 100]] [6 91]] [6 83]] [6 93]] [3 72]] [33 94]] [32 90]] [3 100]] [221 4.5 [6 88] [6 100]]] [6 87]] [2081 16.3 [7176 1.31 [328 7.72 [33 31] [33 50]] [33 100]] [16 33]]] [1336 2.22 [6 80] [6 100]]] [2202 0.87 [16 18] [3 100]]] [10 100]] [4878 0.559 [14 45] [14 100]]] [2260 2.4 [7737 6.2 [19 55] [19 100]] [26 26]]] [6 89]] [5797 3.36 [6 93] [6 100]]]] [14 64]] [688 2.54 [24 67] [2 69]]] [2752 36.7 [6177 2.37 [1011 3.29 [4704 3.99 [663 4.93 [4658 2.02 [6531 2.37 [2259 1.96 [6328 5.01 [1597 1.69 [6524 12.1 [1 65] [7413 19.1 [6185 12.6 [4655 3.82 [695 11 [3100 2.15 [1 28] [1 95]] [7 46]] [4656 19.2 [3099 3.82 [1 83] [1 100]] [1 69]]] [25 90]] [25 76]]] [1 100]] [22 33]] [2752 16.6 [1 19] [10 24]]] [7 97]] [1 100]] [5198 2.28 [7 52] [36 40]]] [221 8.1 [7528 2.82 [1812 2.67 [4235 2.24 [1 48] [1 63]] [1 90]] [1 100]] [1 45]]] [7 76]] [25 92]] [22 61]]] [7712 0.502 [7404 2.65 [5812 1.23 [6933 10.1 [3008 2.33 [248 2.92 [4154 0.832 [6 49] [2 45]] [1 78]] [6 72]] [6 100]] [2902 1.7 [312 12.6 [4235 3.65 [2 42] [896 5.74 [2 90] [1 33]]] [2 100]] [1980 13.2 [2 100] [2 81]]]] [6 100]] [2 67]]] [7 100]] [4517 1.92 [6 96] [6 100]]] [6374 2.35 [2434 11.9 [429 11.6 [2260 14.1 [4817 2.92 [6882 0.697 [5679 17.6 [5110 2.02 [5647 1.39 [19 25] [10 42]] [30 85]] [30 33]] [26 55]] [23 100]] [5205 2.04 [1078 13.5 [19 60] [2039 0.19 [19 59] [14 37]]] [18 40]]] [7149 8.36 [14 15] [2 70]]] [18 45]] [6 68]]] [1429 24.3 [1919 2.73 [13 89] [13 100]] [6621 2.92 [2493 1.83 [13 77] [13 56]] [13 100]]]] [939 2.21 [2580 0.942 [5461 2.39 [4627 2.96 [2259 7.91 [5732 0.524 [811 1.39 [4991 3.64 [1427 3.31 [6853 5.81 [5110 5.21 [2755 3.31 [701 5.66 [4253 1.03 [7187 1.59 [5467 2.97 [6791 25.6 [899 1.93 [1429 22 [3668 7.64 [2902 0.364 [682 6.18 [4374 2.51 [695 2.38 [4420 5.8 [1089 1.25 [6920 5.49 [1980 9.9 [4 29] [25 58]] [4 50]] [4 80]] [15 77]] [4 68]] [10 57]] [2 85]] [906 0.914 [4 80] [4 53]]] [2 77]] [14 59]] [14 44]] [15 72]] [12 90]] [4 89]] [6538 3.08 [2 71] [2 90]]] [10 90]] [25 53]] [15 53]] [25 72]] [25 100]] [2 52]] [10 79]] [15 75]] [7434 1.36 [3903 2.3 [7185 9.64 [362 0.675 [7411 1.45 [429 10.9 [14 14] [10 41]] [15 50]] [15 85]] [4 57]] [10 85]] [12 100]]] [12 93]] [2 100]] [25 100]] [2470 1.33 [1980 10.8 [7449 1.59 [688 2.38 [2143 3.18 [1062 4.91 [6 1.22 [10 87] [10 100]] [10 71]] [10 71]] [10 33]] [4 50]] [10 56]] [4 70]]]] [6 87]] [1059 0.813 [6 81] [6 100]]] [4964 0.332 [663 3.46 [682 7.56 [5771 2.73 [6885 1.36 [791 4.24 [4 20] [1429 26.2 [719 3.74 [4 27] [4 94]] [2 21]]] [20 60]] [2628 37.4 [6077 7.58 [7381 6.14 [1980 12.2 [1170 1.75 [2 43] [2 87]] [2 88]] [5575 3.76 [2 69] [2 88]]] [6735 13.2 [2 93] [2 66]]] [4 83]]] [2 85]] [5090 2.82 [1883 7.92 [4995 11.6 [6184 7.67 [6991 0.805 [5770 0.898 [4991 8.22 [7722 5.71 [1025 6.02 [1078 24.1 [2616 5.11 [2 66] [2 100]] [2 50]] [2 50]] [2 50]] [2 100]] [2 40]] [2 100]] [4991 2.24 [6074 1.5 [2 30] [2 95]] [2 100]]] [2 75]] [2 60]] [2 57]]] [7381 2.82 [4 85] [4 66]]]] [2339 3.4 [605 3.65 [24 87] [24 97]] [24 100]]] [6068 0.726 [3052 0.695 [4738 0.754 [7695 1.69 [4991 5.94 [30 70] [3 100]] [30 86]] [30 80]] [30 100]] [3 50]]] [7571 1.69 [6578 1.72 [6732 7.98 [6342 7.53 [1899 6.67 [1583 1.98 [583 2.59 [312 0.623 [7722 28.5 [7411 3.45 [811 1.53 [725 7.94 [5403 11.7 [1400 1.27 [3 40] [31 100]] [31 97]] [31 100]] [31 100]] [31 100]] [31 76]] [7665 22.7 [695 8.56 [31 100] [31 80]] [31 100]]] [3 100]] [31 100]] [31 76]] [31 77]] [31 69]] [31 100]] [31 100]]] [2574 3.97 [2793 2.36 [1995 2.39 [248 2.28 [4158 6.41 [1078 18.5 [885 2.3 [2795 1.25 [1986 1.08 [1389 1.9 [978 7.08 [24 34] [2 45]] [4189 3.76 [2421 3.8 [24 94] [24 100]] [24 100]]] [17 33]] [24 94]] [24 100]] [2 27]] [2 35]] [25 41]] [2 30]] [3742 0.855 [781 3.07 [2225 3.37 [2143 7.96 [5698 4.51 [24 76] [2793 11.3 [24 100] [24 88]]] [7 55]] [23 85]] [19 40]] [19 53]]] [2 83]]] [3858 1.53 [6583 0.705 [3014 2.06 [2616 33.1 [5052 0.32 [6550 30.2 [5574 0.561 [5904 0.792 [7682 1.78 [527 1.12 [4369 2.09 [1888 41.7 [1650 2.96 [1023 0.709 [6883 3.86 [7133 0.785 [3771 1.75 [6591 7.74 [324 2.04 [2571 1.19 [6040 1.81 [2913 8.9 [7241 3.69 [2398 8.38 [2811 2.79 [1888 22.7 [2616 17.8 [6584 1.82 [17 20] [1429 65.4 [1888 2.54 [7665 16.6 [978 1.42 [17 100] [17 40]] [17 33]] [17 93]] [17 100]]] [5 51]] [4 26]] [19 56]] [4 88]] [663 5.92 [17 25] [5 71]]] [5 72]] [5 50]] [17 80]] [17 61]] [17 72]] [8 100]] [4 100]] [5 66]] [17 77]] [14 44]] [4 87]] [32 75]] [4 100]] [7381 3.75 [17 60] [7526 2.59 [17 81] [17 100]]]] [19 91]] [7742 0.561 [4 55] [4 100]]] [663 2.13 [1656 5.62 [19 37] [17 100]] [19 63]]] [5 87]] [2752 17.2 [5 51] [5 66]]] [4939 0.507 [2616 3.58 [17 50] [731 1.6 [17 94] [7665 20.1 [17 44] [17 88]]]] [1201 1.02 [19 77] [19 100]]]] [2588 7.16 [5348 0.551 [17 49] [17 83]] [2591 9.62 [19 52] [17 62]]]] [35 86]]] [2241 1.05 [7560 3.1 [4712 3.14 [6 70] [6 100]] [7335 4.85 [6 94] [6 100]]] [6 66]]] [5879 0.99 [7683 1.11 [5454 1.14 [5171 0.97 [5110 3.25 [3959 0.911 [2526 1.69 [3872 1.1 [576 0.872 [5757 1 [286 0.975 [4088 2.7 [4231 2.79 [2793 5.31 [39 3.67 [1011 3.07 [3105 1.89 [3806 2.18 [2701 4.78 [5413 4.19 [1301 2.57 [4369 4.97 [7561 21.3 [7251 1.57 [249 7.94 [4624 2.33 [1373 3.54 [3635 1.2 [5254 1.23 [328 2.53 [5316 3.34 [5871 13.7 [2628 0.917 [5429 16.1 [3308 6.31 [7759 0.552 [7381 1.45 [203 5.26 [2064 1.06 [2470 6.69 [6883 12.3 [36 27] [11 30]] [15 45]] [17 42]] [36 88]] [19 28]] [20 60]] [23 71]] [791 20 [5 50] [5 85]]] [2259 17.5 [5 13] [31 70]]] [14 66]] [32 85]] [6732 0.797 [7168 1.22 [14 13] [28 71]] [15 41]]] [10 100]] [1 82]] [3 45]] [14 54]] [1 70]] [36 55]] [31 88]] [144 6.4 [1078 24.4 [5753 11.2 [32 76] [36 50]] [36 40]] [32 100]]] [33 60]] [14 30]] [29 92]] [10 100]] [30 100]] [1463 4.07 [5 35] [5 88]]] [3 77]] [24 58]] [10 100]] [36 100]] [798 0.186 [28 18] [20 44]]] [6529 1.19 [2259 1.04 [29 50] [4207 2.35 [4184 28.6 [7512 17 [29 100] [29 87]] [29 86]] [29 100]]] [29 100]]] [1239 1.99 [248 4.78 [29 87] [29 100]] [29 100]]] [32 85]] [1171 0.901 [5623 0.903 [1640 1.74 [4519 1.85 [1528 1.37 [4653 0.78 [2389 0.634 [7236 3.82 [2453 4.98 [7008 0.77 [7419 3.55 [7609 4.16 [1025 1.89 [6584 0.55 [7679 1.98 [3008 0.829 [7512 25.3 [1883 2.36 [6184 1.41 [7381 10.3 [7566 0.876 [733 4.07 [2529 0.914 [5192 0.963 [7255 1.13 [4 11] [4 28]] [4 44]] [25 75]] [4 37]] [5 66]] [1429 14.2 [4 50] [2 40]]] [248 4.5 [2 41] [25 87]]] [2 58]] [6732 4.76 [31 51] [5 50]]] [7 28]] [6 70]] [17 25]] [2 24]] [8 86]] [6 60]] [25 100]] [24 100]] [6 90]] [7 100]] [6 100]] [5 100]] [3660 1.39 [24 90] [24 87]]] [23 3.1 [2 90] [24 50]]] [2533 0.903 [6 77] [6 100]]] [2 100]]] [2407 0.686 [1980 1.85 [29 66] [791 15.5 [29 94] [29 85]]] [29 100]]] [3074 1 [7726 1.47 [5273 0.963 [1400 1.73 [7657 2.56 [6031 2.28 [7155 2.22 [6294 1.92 [2259 4.31 [4703 1.13 [3323 4.19 [6616 2.49 [7501 5.75 [1783 14.9 [33 37] [33 100]] [12 100]] [6762 11.1 [12 96] [12 100]]] [33 63]] [232 7.47 [33 100] [33 81]]] [30 20]] [1 27]] [30 100]] [22 88]] [12 100]] [12 81]] [33 100]] [1783 9.81 [33 100] [33 50]]] [12 100]]] [4348 0.527 [6653 2.37 [33 95] [33 100]] [33 100]]] [29 89]] [3273 7.7 [1 100] [2081 4.42 [1 83] [1 94]]]] [31 78]]] [6542 0.25 [6732 8.86 [6092 0.475 [2939 0.939 [4424 2 [5007 1.33 [12 92] [12 56]] [12 62]] [12 100]] [12 100]] [12 100]] [12 100]]] [7737 1.03 [1429 14.1 [10 100] [10 83]] [10 100]]] [7149 6.67 [7518 1.55 [5412 3.21 [7742 3.14 [2526 4.69 [3768 0.879 [6184 0.975 [1025 5.08 [5904 5.26 [2752 8 [6791 20.8 [7712 13.3 [5478 3.18 [3647 1.96 [663 17.6 [2488 2.86 [7241 3.82 [2309 3.31 [5640 10.6 [4851 1.86 [719 3.07 [429 29.5 [2637 6.49 [1980 12.7 [36 80] [36 60]] [36 100]] [36 67]] [13 70]] [36 95]] [13 100]] [36 92]] [36 93]] [13 100]] [36 87]] [36 100]] [36 100]] [13 57]] [13 100]] [6867 1.35 [2275 0.978 [6743 5.34 [1888 16.7 [1078 18.8 [2832 2.26 [811 2.01 [1641 1.11 [6529 2.49 [36 91] [36 100]] [36 100]] [36 100]] [36 100]] [36 80]] [36 59]] [36 76]] [36 100]] [36 100]]] [13 81]] [1496 3.39 [1 1.83 [5735 2.82 [7389 3.45 [13 89] [13 100]] [13 100]] [13 75]] [13 100]]] [13 79]] [13 100]] [13 25]] [4 88]] [2259 7.94 [791 1.99 [13 88] [7185 2.05 [6077 4.47 [5472 12.7 [13 100] [429 39.5 [13 100] [13 88]]] [13 91]] [13 90]]] [5402 2.01 [36 62] [13 71]]]] [36 100]] [5061 1.75 [36 97] [36 100]]]] [5812 1.59 [5472 1.14 [2570 1.49 [1812 0.838 [2397 0.876 [2004 1.14 [248 0.78 [7491 4.76 [5467 1.4 [5403 0.778 [4895 3.36 [7512 32 [834 0.571 [896 2.89 [2759 6.23 [7742 2.66 [2752 66.3 [2701 3.39 [2 11] [29 75]] [1078 2.28 [24 25] [1899 25.1 [22 84] [22 66]]]] [4 83]] [8 50]] [5197 0.653 [7665 22.2 [2005 5.14 [7677 1.45 [17 2.3 [7566 1.07 [4279 1.32 [2752 33.6 [429 18.7 [2 60] [2 47]] [24 45]] [4 71]] [4 47]] [4 42]] [2 54]] [2 90]] [2616 14.3 [2 100] [2 50]]] [5197 5.09 [17 42] [17 37]]]] [37 100]] [5 17]] [19 57]] [1077 1.72 [31 91] [31 100]]] [12 83]] [22 41]] [7726 3.7 [2610 1.1 [1081 2.91 [6178 3.03 [312 0.898 [2934 0.881 [1077 1.68 [1899 30.8 [1 34] [1 100]] [1 80]] [33 100]] [26 33]] [25 100]] [25 75]] [33 60]] [33 75]]] [29 64]] [22 100]] [33 100]] [7343 0.773 [5883 42 [1429 11.5 [1239 16 [5140 3.04 [1919 2.55 [1 85] [2 67]] [33 83]] [1 40]] [18 19]] [2 28]] [2 28]]] [36 90]] [671 1.68 [2518 0.863 [599 0.446 [5734 0.978 [2674 0.153 [1883 1.2 [1075 3.73 [2470 0.37 [5999 7.9 [1545 0.402 [2453 1.44 [4218 0.25 [3516 0.845 [1023 0.415 [1083 2.85 [3655 1.34 [5914 1.01 [3584 4.26 [7533 1.46 [3220 1.78 [1593 2.23 [1389 2.62 [3078 0.459 [7520 9.96 [5812 16 [2390 1.44 [826 4.64 [7365 0.504 [2178 7.39 [2902 9.5 [4663 12.8 [7449 6.2 [573 3.83 [4184 7 [5753 1.59 [6184 3.55 [2 37] [5692 5.42 [2 84] [2 50]]] [5 30]] [2 75]] [17 20]] [2616 1.91 [2 45] [2 81]]] [4 83]] [5 36]] [2 50]] [4 100]] [12 50]] [24 92]] [4 26]] [1888 21.4 [4 80] [4 50]]] [17 45]] [24 90]] [24 80]] [5693 4.84 [2628 12.2 [5 75] [5 100]] [5 63]]] [7 78]] [17 85]] [2 45]] [24 100]] [2 72]] [7566 0.484 [738 1.42 [4338 0.664 [2 48] [4 33]] [17 64]] [2 57]]] [19 100]] [1239 5.34 [6310 3.47 [7742 1.22 [17 48] [24 42]] [17 80]] [17 80]]] [24 100]] [5 78]] [4 100]] [660 1.03 [4 84] [4 50]]] [4187 6.03 [144 1.29 [2570 14.2 [7414 11.4 [2005 2.88 [2 31] [2 38]] [4 71]] [17 47]] [5692 8.27 [2 80] [2 100]]] [2 57]]] [4253 0.528 [7292 1.69 [1011 5.74 [7210 2.7 [2628 12.5 [1919 4.9 [2 70] [2 94]] [21 33]] [2 92]] [2 62]] [2 62]] [2 100]]] [5851 0.22 [2005 9.48 [4414 0.508 [7384 0.803 [1919 2.93 [2 69] [4991 18.1 [144 0.684 [5692 1.25 [2 81] [2 100]] [7665 6.09 [2 80] [2 100]]] [2 83]]] [2 85]] [2 100]] [2 66]] [2 100]]] [7 100]] [6817 0.892 [978 1.29 [2 36] [2 87]] [6074 3.58 [2 100] [2 71]]]] [1025 1.09 [24 84] [4349 2.6 [24 100] [24 85]]]] [2674 3.91 [144 1.98 [2 75] [2 100]] [2 80]]]]] [4725 7.2 [2526 13.5 [6 42] [1011 0.644 [1078 0.761 [1429 52.7 [6116 0.668 [2526 60.9 [1899 6.76 [1314 1.08 [2569 6.74 [6 97] [6 50]] [6 97]] [6 100]] [6099 14.3 [4675 2.18 [2419 19.4 [7506 2.13 [6 80] [6 50]] [6 100]] [6 66]] [6 100]]] [6 100]] [6 53]] [6 100]] [6 100]]] [4673 1.23 [2419 2.07 [6 90] [6 90]] [6 100]]]] [6619 0.456 [7720 0.73 [4870 0.421 [7680 0.644 [6528 0.779 [5246 1.08 [7007 0.281 [4205 0.478 [4980 4.12 [6733 0.552 [286 4.51 [7609 1.57 [4704 2.71 [253 3.64 [771 2.78 [674 1.43 [1980 9.81 [4201 9.08 [1881 2.64 [5870 1.77 [1 1.75 [1995 1.34 [7731 3.42 [7044 2.51 [6524 1.41 [6907 1.42 [2571 5.12 [1025 9.8 [2936 2.62 [913 2.93 [264 2.51 [7665 20.3 [663 5.58 [3849 3.9 [144 6.86 [1775 1.12 [26 70] [16 37]] [26 40]] [35 57]] [26 87]] [2178 1.78 [6177 6.33 [26 60] [25 100]] [16 33]]] [26 92]] [26 89]] [25 100]] [6 50]] [25 82]] [25 100]] [2143 8.41 [429 10 [978 2.79 [7665 22 [25 66] [25 85]] [25 100]] [1 57]] [1 100]]] [25 100]] [25 61]] [25 40]] [31 61]] [26 95]] [178 4.62 [25 100] [25 72]]] [5692 8.52 [1073 8.22 [26 57] [26 71]] [26 100]]] [5661 1.85 [791 3.66 [6791 4 [26 48] [26 50]] [7683 2.46 [4158 0.46 [25 48] [20 27]] [1 100]]] [1 64]]] [1 66]] [25 100]] [6178 2.56 [25 73] [25 100]]] [25 51]] [25 64]] [6537 1.37 [6178 2.96 [25 48] [25 100]] [1 82]]] [7665 7.36 [25 54] [221 2.22 [25 76] [25 100]]]] [26 100]] [7101 7.11 [4854 2.48 [4389 4.72 [3332 7.2 [939 3.15 [2470 7.39 [7321 2.79 [5431 9.92 [5007 3.72 [1432 1.25 [423 6.63 [978 12.6 [26 98] [26 85]] [26 87]] [26 92]] [393 1.19 [731 1.52 [26 69] [26 80]] [26 83]]] [26 100]] [26 100]] [26 62]] [26 75]] [35 42]] [26 85]] [26 60]] [26 36]]] [25 100]] [7515 0.867 [6182 0.569 [1429 10.4 [2470 1.82 [25 100] [26 57]] [25 54]] [25 100]] [25 42]]] [567 0.39 [25 68] [1 100]]] [429 1.99 [25 95] [25 100]]] [7722 0.384 [6460 0.418 [4369 3.08 [2526 19.5 [25 59] [25 100]] [25 100]] [25 100]] [23 9.26 [25 100] [25 93]]]] [1025 6.33 [2005 0.73 [429 6.96 [1 100] [1 77]] [1 100]] [1 87]]] [25 100]]] [597 1.31 [4079 1.65 [7365 0.782 [6984 0.167 [7381 1.23 [2478 5.64 [324 4 [7722 3.41 [2605 1.85 [1400 6.18 [5403 0.69 [2470 1.85 [4 43] [7592 7.39 [7085 3.19 [4 87] [4 100]] [4 80]]] [31 94]] [31 57]] [31 100]] [31 74]] [4 100]] [4 100]] [639 15 [4 93] [4 71]]] [178 7.76 [4 94] [4 90]]] [324 0.399 [1073 5.54 [2657 17.5 [7363 9.43 [5812 9.32 [4 100] [2470 10.5 [4 83] [4 100]]] [4 100]] [4 85]] [4 57]] [4 100]]] [31 95]] [31 100]]] [124 0.736 [6077 0.439 [6547 3.29 [1062 0.365 [632 4.33 [6584 0.134 [1704 0.612 [6173 1.33 [1011 2.91 [5892 1.97 [2466 1.57 [14 30] [14 44]] [3 53]] [31 97]] [31 100]] [4690 0.885 [7742 0.612 [7719 1.52 [17 71] [17 72]] [17 100]] [2 28]]] [1690 0.472 [14 41] [6230 0.973 [6588 8.09 [6732 8.35 [1704 11.7 [3928 9.28 [5732 12.4 [17 60] [17 100]] [17 33]] [17 79]] [17 58]] [17 86]] [17 50]]]] [36 100]] [901 3.27 [1429 8.9 [32 39] [5742 2.73 [6206 1.13 [1980 11.6 [6980 0.319 [2926 1.92 [2753 2.58 [5192 0.329 [17 58] [17 84]] [17 63]] [32 100]] [17 97]] [17 55]] [16 57]] [14 33]]] [36 100]]] [1239 14.6 [14 100] [3 60]]] [6544 34.3 [4324 5.52 [791 28.8 [7742 1.32 [141 1.61 [4424 0.994 [5405 1.78 [31 77] [31 100]] [31 100]] [31 100]] [31 100]] [31 63]] [31 80]] [31 80]]] [32 100]]] [6873 1.77 [6983 1.36 [7019 1.79 [2943 1.08 [4304 0.96 [4218 5.63 [7563 0.78 [2739 1.82 [6217 0.953 [5472 1.01 [519 2.09 [3660 1.31 [7535 0.815 [2763 6.41 [6103 1.03 [7008 1.05 [6093 1.54 [7593 0.241 [6732 9.66 [312 0.905 [7455 1.86 [2910 0.64 [5694 0.273 [1078 3.9 [6524 1.42 [2616 0.743 [5430 1.44 [7025 1.64 [1062 3.79 [6015 7.05 [6363 2.25 [6320 1.61 [5673 1.26 [99 1.99 [12 23] [26 44]] [19 26]] [19 66]] [12 100]] [12 83]] [5 44]] [12 78]] [5 70]] [5 49]] [33 42]] [1164 1.61 [7605 9.81 [7737 5.27 [896 1.75 [5267 5.87 [112 4.39 [248 2.14 [12 20] [15 41]] [13 25]] [36 46]] [1011 5.22 [6203 2.87 [5 36] [4 40]] [1429 36.8 [4 42] [5 100]]]] [22 27]] [5 86]] [10 66]]] [5 92]] [6311 2.43 [5 45] [5 81]]] [12 100]] [31 23]] [5 50]] [5 61]] [13 86]] [25 100]] [12 56]] [5693 6.85 [4 67] [4 50]]] [4602 0.524 [5 35] [56 6.45 [26 92] [26 100]]]] [3652 7.18 [24 100] [24 85]]] [13 100]] [5322 4.06 [5735 1.04 [632 3.31 [3663 2.26 [7722 1.78 [5264 1.92 [13 91] [13 100]] [13 78]] [36 100]] [36 100]] [13 100]] [13 100]]] [4 100]] [4 88]] [1476 2.14 [1017 5.23 [5 65] [5515 5.5 [16 26] [5 37]]] [5 33]]] [3768 3.58 [4587 1.42 [7255 1.23 [13 57] [13 83]] [2526 2.92 [5 81] [3205 7.72 [5 42] [5 80]]]] [13 100]]] [5 58]] [2763 1.58 [4 71] [2 87]]] [6199 17.1 [5673 1.37 [2628 4.69 [12 74] [12 85]] [12 72]] [12 44]]] [2902 6.37 [6732 19.7 [6375 2.28 [7381 14.3 [7009 7.31 [4 80] [7014 1.96 [6581 8.85 [4 100] [4 95]] [4 85]]] [4 77]] [4 75]] [4 50]] [4 75]]] [12 95]]] [1436 0.723 [1424 0.428 [5372 0.661 [5269 0.387 [978 3.41 [1785 0.531 [6184 0.9 [7739 1.79 [878 0.838 [10 96] [10 100]] [10 100]] [10 100]] [10 100]] [10 81]] [10 100]] [10 100]] [10 100]] [10 100]]] [1986 0.237 [7038 2.23 [2752 2.87 [7675 20 [7549 17.7 [328 15.7 [2951 4.21 [4939 13.3 [6923 3.55 [2259 7.7 [25 25] [2577 2.89 [7407 0.521 [7513 7.53 [5769 2.75 [2293 3.29 [1062 12.7 [5778 14.2 [4674 1.21 [6422 38.2 [5721 1.8 [2295 13.5 [4414 2.04 [4673 0.422 [2272 19 [1276 1.02 [4513 2.15 [6689 1.36 [6 96] [6 100]] [6 100]] [6 100]] [6 90]] [6 100]] [6 85]] [6 83]] [6 100]] [6 85]] [6 100]] [6 85]] [6 85]] [6 42]] [6 77]] [6 92]] [6 81]] [5090 11.1 [6 92] [6 57]]]] [6 100]] [6 62]] [6 61]] [19 50]] [6 40]] [6 42]] [7418 1.17 [6342 4.49 [5812 0.748 [1078 20.9 [7665 18.1 [6 25] [6 55]] [1089 4.41 [20 17] [4 50]]] [2943 0.797 [4 30] [4 50]]] [15 42]] [22 100]]] [4514 1.19 [7505 2.96 [6959 3.11 [7404 1.25 [4725 7.09 [6 51] [6 91]] [6 100]] [16 75]] [16 55]] [2611 1.71 [7 54] [6 50]]]] [896 1.66 [30 50] [6 50]]]] [3429 0.821 [4765 1.89 [2509 0.938 [1521 0.274 [6341 0.763 [2331 0.504 [6853 0.404 [3434 4.35 [5413 1.17 [5972 1.19 [3226 1.08 [7381 0.946 [5728 1.98 [6083 1.27 [7665 38.9 [2326 1.66 [2376 2.7 [2884 1.41 [6588 1.98 [5873 12.2 [6031 4.28 [2913 4.01 [5270 1.89 [2707 0.761 [5429 3.85 [5211 2.2 [2752 9.26 [5472 0.713 [1812 1.14 [7203 6.02 [23 8.32 [4279 1.94 [407 5.19 [7255 7.05 [36 18] [18 44]] [7 85]] [19 20]] [33 30]] [16 37]] [33 83]] [13 77]] [4718 4.27 [7377 1.39 [4369 10.3 [673 2.35 [16 4.69 [6373 4.69 [248 11.4 [1069 1.68 [6404 2.49 [30 1.73 [6581 1.42 [978 1.43 [392 3.82 [2488 1.85 [5693 7.86 [7583 8.65 [36 55] [7 50]] [18 31]] [13 100]] [7 46]] [3584 2.35 [7 37] [18 60]]] [5 69]] [13 75]] [36 100]] [36 56]] [18 29]] [18 62]] [36 100]] [25 70]] [32 44]] [36 100]] [6581 4.2 [5 33] [5 91]]]] [8 72]] [5 64]] [16 33]] [36 100]] [5 42]] [7354 13 [22 60] [22 83]]] [5 71]] [5 91]] [16 86]] [14 100]] [36 100]] [7563 3.6 [36 44] [36 88]]] [13 100]] [8 100]] [7 49]] [7 100]] [719 7.35 [4569 3.02 [642 3.76 [4154 4.75 [1429 9.16 [36 82] [7495 0.978 [6404 1.45 [5693 1.87 [4814 5.58 [3641 2.56 [36 96] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]]] [36 100]] [36 72]] [36 92]] [36 75]]] [1023 13.3 [2023 12.2 [6791 4.65 [2763 2 [248 1.26 [187 5.83 [2143 4.37 [978 1.49 [18 30] [18 35]] [29 44]] [16 80]] [1 60]] [7188 6.16 [5655 0.99 [3548 0.838 [1482 1.05 [18 46] [5 62]] [5 71]] [18 37]] [18 75]]] [18 60]] [13 45]] [7354 21 [32 53] [7 77]]]] [4038 1.68 [23 5.36 [36 100] [36 87]] [36 100]]] [3264 0.931 [36 93] [36 100]]] [653 1.19 [2311 6.29 [7563 1.01 [5673 4.18 [3434 1.12 [7354 16.7 [7698 1.43 [36 86] [36 100]] [5692 3.37 [36 95] [36 100]]] [36 100]] [36 76]] [36 100]] [36 83]] [8 45]]] [7 100]] [13 100]] [13 100]] [13 100]] [36 100]]] [3019 0.971 [5833 1.3 [3734 2.33 [7463 0.956 [7739 1.62 [7032 4.09 [6074 0.805 [2707 0.766 [828 1.36 [7571 1.39 [2103 1.04 [6853 2.73 [7690 7.16 [7742 1.55 [7563 2.37 [6173 4.59 [5007 3.21 [1078 60.9 [31 23] [10 77]] [36 58]] [31 100]] [5 75]] [4 66]] [36 37]] [5412 12.4 [3935 1.49 [7169 4.81 [31 100] [31 90]] [31 100]] [31 66]]] [10 100]] [7308 2.37 [695 6.26 [31 100] [31 90]] [31 100]]] [31 89]] [16 28]] [3905 4.17 [31 96] [31 83]]] [7276 2.26 [3868 2.67 [1078 34.2 [2628 33.8 [2259 39 [6855 1.99 [7571 0.891 [312 6.31 [31 100] [31 87]] [31 100]] [31 100]] [31 92]] [31 80]] [2752 1.52 [31 91] [4 47]]] [31 100]] [31 100]]] [10 75]] [5 90]] [19 45]] [17 56]] [1025 36.5 [24 100] [24 80]]]] [660 1.49 [4613 0.234 [7735 0.0881 [5484 1.11 [1081 2 [899 0.812 [248 14.2 [5757 0.649 [906 2.59 [859 0.393 [7404 1.62 [2893 1.29 [5762 0.307 [232 0.553 [5211 5.56 [5170 3.21 [4571 3.3 [6529 1.82 [1429 6.55 [7734 1.94 [5791 0.626 [392 7.45 [673 14 [2905 0.326 [1783 13.6 [6983 1.52 [7248 12.4 [4184 0.667 [5681 5.65 [929 2.84 [6074 0.826 [7520 10.4 [5612 3.61 [2628 9.34 [384 2.82 [7588 6.99 [731 16.2 [1995 6.48 [18 24] [29 54]] [18 50]] [26 100]] [18 87]] [2868 0.166 [4 37] [16 63]]] [16 66]] [18 80]] [2 40]] [18 37]] [18 100]] [1 37]] [4 60]] [312 1.99 [4 93] [4 100]]] [33 52]] [2 73]] [26 89]] [7255 2.84 [26 61] [26 50]]] [10 100]] [18 67]] [2259 8.08 [4614 0.703 [6983 1.33 [4859 2.29 [1671 2.05 [2654 1 [4897 1.34 [5480 5.24 [2607 1.19 [7722 2.48 [7664 1.78 [2466 1.03 [5599 1.23 [4414 3.62 [5438 0.168 [5090 2.21 [6831 3.69 [5099 0.83 [248 1.74 [221 1.2 [663 4.49 [429 20.3 [16 33] [1899 5.45 [11 33] [18 50]]] [19 36]] [2 37]] [26 37]] [18 50]] [16 66]] [22 83]] [18 50]] [7512 4.04 [37 37] [12 33]]] [22 62]] [18 87]] [16 45]] [2005 0.441 [7566 4.5 [1011 1.03 [16 31] [18 45]] [18 73]] [18 62]]] [5971 2.19 [7185 1.32 [16 70] [18 71]] [19 40]]] [1640 1.74 [7314 6.85 [4486 4.7 [187 8.62 [2701 3.4 [7520 10.4 [6155 0.8 [1641 3.4 [5693 2.99 [1753 4.71 [429 3.12 [7425 4.27 [18 25] [18 72]] [5971 8.44 [7343 7.19 [112 4.95 [7169 1.49 [1009 6.07 [18 56] [18 66]] [18 27]] [5 33]] [18 100]] [16 71]]] [18 50]] [2143 1.4 [2567 1.71 [7241 7.72 [5693 7.69 [2939 0.386 [18 78] [18 100]] [7512 9.81 [18 51] [5692 11.9 [18 82] [18 50]]]] [18 40]] [19 33]] [18 91]]] [16 58]] [18 100]] [26 31]] [2752 8.16 [29 62] [29 88]]] [5673 1.64 [16 70] [18 50]]] [16 60]] [2 19]] [2 50]]] [1062 2.2 [18 34] [19 71]]] [6207 5.25 [738 1.27 [5593 3.59 [16 92] [1078 4.88 [16 66] [18 50]]] [18 61]] [18 75]]] [724 1.08 [1888 15.8 [6042 0.756 [5693 3.5 [18 60] [7665 9.1 [18 50] [18 100]]] [5851 0.705 [7354 10 [18 69] [18 100]] [18 100]]] [16 33]] [18 37]]] [18 79]] [4 81]] [29 100]] [3515 2.63 [4977 6.67 [1786 4.51 [2426 0.532 [4611 6.7 [6757 1 [5412 4.97 [4540 0.824 [7188 15.5 [2029 3.68 [695 5.12 [5270 8.62 [3905 1.42 [6152 5.19 [5130 12.5 [7601 11.6 [5348 2.75 [2259 55.1 [2717 1.65 [6449 1.5 [7038 10.4 [7742 2.22 [5482 0.56 [2951 8.97 [4338 1.49 [6732 2.98 [18 48] [18 81]] [18 83]] [18 30]] [5130 3.14 [2607 0.722 [7302 8.62 [1062 17.1 [7566 4.29 [5605 0.64 [18 79] [18 66]] [18 54]] [18 58]] [19 33]] [18 66]] [16 66]]] [1671 4.8 [18 82] [18 100]]] [37 42]] [18 36]] [18 33]] [18 44]] [18 44]] [19 33]] [18 100]] [19 50]] [18 21]] [13 30]] [18 35]] [16 45]] [18 92]] [18 100]] [978 1.57 [31 66] [18 35]]] [16 41]] [36 42]] [2526 12 [4 30] [8 62]]] [10 70]] [6 66]] [132 0.957 [3515 6.21 [18 66] [19 64]] [19 57]]]]] [29 89]] [7737 1.66 [1838 1.82 [16 40] [4507 2.13 [2526 8.87 [19 90] [19 57]] [19 85]]] [19 82]]] [33 66]] [714 1.02 [5480 2.79 [2939 2.44 [23 57] [4 50]] [2764 8.53 [112 1.71 [4279 13.3 [23 7.74 [2831 1.6 [4690 3.03 [22 84] [8 94]] [22 50]] [22 100]] [22 50]] [22 100]] [22 50]]] [22 100]]] [7330 1.66 [33 100] [33 45]]] [2939 7.58 [1786 2.3 [10 53] [10 100]] [10 100]]] [33 100]] [6 100]] [6621 0.617 [7665 3.16 [430 1.23 [22 82] [22 100]] [7335 3.95 [429 30.5 [1701 0.673 [1931 0.583 [887 1.83 [5225 0.898 [2752 23 [22 87] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [7449 7.64 [22 96] [22 75]]] [22 100]]] [22 100]]] [5673 15.1 [6621 6.67 [532 0.494 [2571 0.424 [221 0.935 [4288 0.968 [29 33] [22 54]] [695 0.935 [29 100] [28 33]]] [18 57]] [29 80]] [1 30]] [3 33]]] [29 91]] [685 7.92 [250 1.08 [7180 0.835 [423 0.701 [23 22.7 [7731 1.27 [2755 5.32 [5348 3.74 [673 2.78 [107 0.907 [5851 3.82 [2470 1.65 [5692 3.61 [26 50] [18 72]] [26 94]] [18 25]] [33 60]] [2902 6.5 [429 5.73 [26 85] [23 6.08 [392 2.01 [26 70] [26 58]] [26 71]]] [15 42]]] [18 50]] [7516 4.81 [26 80] [1011 6.09 [26 97] [26 70]]]] [18 75]] [221 1.36 [33 56] [33 100]]] [7722 6.66 [26 100] [26 85]]] [33 100]] [33 87]] [5206 1.49 [269 1.11 [791 16.7 [2759 0.481 [26 84] [26 100]] [26 58]] [2752 22.5 [269 39.4 [429 0.952 [269 20.8 [26 92] [26 98]] [5509 4.79 [26 89] [26 71]]] [26 70]] [392 7.35 [4205 2.24 [26 83] [26 91]] [26 50]]]] [26 100]]]] [3100 0.715 [7601 0.448 [2259 9.36 [899 1.16 [29 47] [328 1.63 [1888 2 [906 0.573 [4414 3.66 [29 76] [29 93]] [6111 0.659 [1062 0.59 [29 97] [29 100]] [29 100]]] [13 25]] [29 59]]] [4926 1.13 [29 55] [18 54]]] [978 1.46 [36 42] [18 100]]] [1 100]]] [6040 1.17 [6046 2.31 [6732 16.8 [397 1.71 [181 2.6 [7301 7.33 [7737 0.739 [7742 3.63 [5154 4.07 [7623 3.65 [1027 0.858 [2752 43.6 [2913 17.3 [7244 3.74 [5693 5.35 [4154 12.6 [26 94] [26 77]] [26 88]] [26 57]] [26 75]] [26 45]] [26 75]] [26 57]] [26 50]] [18 81]] [26 50]] [18 66]] [26 50]] [7734 6.41 [18 100] [18 87]]] [26 95]] [26 72]] [18 83]]] [2705 2.06 [2813 12.7 [3515 4.47 [6486 1.61 [5778 3.41 [4205 9.9 [2259 17.4 [7742 1.49 [4851 3.81 [1661 0.934 [663 28.3 [5267 6.97 [2202 1.09 [132 1.92 [5516 0.724 [929 5.83 [2199 0.433 [328 14.8 [2813 2.18 [6036 2.46 [5154 6.54 [5131 8.36 [7734 2.69 [18 48] [1899 12.8 [6911 2.79 [187 4.08 [18 82] [18 68]] [18 100]] [16 60]]] [6 60]] [18 90]] [18 100]] [18 80]] [7734 7.25 [1429 29.5 [16 50] [6 33]] [18 61]]] [18 92]] [7 37]] [7734 4.03 [16 69] [18 87]]] [7601 9.45 [560 26.4 [392 3.08 [695 3.69 [18 84] [5693 8.36 [5692 5.15 [5612 3.18 [278 0.36 [2726 2.76 [18 94] [18 88]] [18 87]] [18 100]] [18 100]] [18 71]]] [18 78]] [16 55]] [18 66]]] [22 50]] [16 60]] [14 25]] [7149 1.91 [18 85] [685 0.928 [16 90] [18 40]]]] [18 37]] [2752 18.4 [685 0.805 [957 0.621 [18 80] [18 94]] [18 100]] [18 79]]] [7302 1.53 [1078 10.1 [1011 1.77 [1429 71.9 [279 4.8 [4540 0.846 [2259 35.2 [5007 5.37 [18 79] [19 57]] [7665 34.5 [18 42] [18 75]]] [18 87]] [18 42]] [16 46]] [18 50]] [4279 1.43 [282 6.8 [279 10.5 [18 92] [7723 8.43 [18 60] [18 71]]] [7 29]] [18 43]]] [7354 3.48 [19 50] [2526 2.44 [5632 0.864 [18 50] [18 100]] [19 53]]]]] [26 50]] [19 81]] [16 80]] [19 76]] [2846 3.36 [18 63] [6031 7.46 [22 78] [22 100]]]] [29 100]]] [4573 0.372 [4820 2.33 [1919 0.0791 [276 6.86 [324 3.96 [1429 23.5 [7343 1.19 [2445 0.829 [1888 3.83 [5647 0.898 [18 38] [19 75]] [18 63]] [23 6.63 [18 57] [18 100]]] [18 100]] [4479 0.491 [5904 2.49 [695 1.36 [5011 4.26 [392 8.12 [2902 1.2 [18 80] [18 62]] [18 100]] [18 83]] [4509 0.42 [2466 4.74 [1011 2.1 [18 79] [18 52]] [18 70]] [18 72]]] [392 2.1 [19 63] [18 62]]] [16 28]]] [18 100]] [5632 4.25 [5969 3.4 [18 47] [18 100]] [38 41]]] [4508 0.471 [4859 3.1 [985 0.533 [1899 4.19 [18 91] [18 100]] [18 87]] [18 75]] [18 54]]] [18 42]] [1262 3.82 [6981 0.806 [19 75] [18 25]] [18 41]]]] [2526 7.88 [7241 0.412 [4205 16.2 [2752 21.9 [26 100] [6733 1.18 [26 100] [26 71]]] [26 50]] [26 63]] [978 17 [26 100] [26 85]]]] [4926 1.66 [276 0.542 [653 1.79 [5011 0.381 [4207 1.2 [434 2.43 [429 36 [1919 2.35 [6342 2.33 [7601 0.945 [1980 0.942 [29 39] [29 67]] [16 44]] [29 40]] [2 75]] [5509 0.835 [6114 0.846 [6490 0.674 [29 83] [29 100]] [29 100]] [29 100]]] [29 100]] [29 100]] [29 100]] [18 100]] [18 60]] [18 80]]]] [6404 0.546 [2517 0.6 [6621 0.611 [6031 2.88 [6530 0.498 [772 1.14 [5705 0.864 [2260 2.21 [3431 0.917 [7673 1.37 [6791 2.04 [5039 0.423 [4663 13.6 [1047 1.04 [867 0.457 [2342 0.739 [3768 0.843 [6853 1.71 [17 4.02 [2570 1.59 [5941 0.542 [811 1.51 [7623 5.61 [7512 5.56 [3 30] [5763 1.96 [7009 4.63 [5703 1.73 [896 6.85 [5673 1.11 [6074 3.76 [5472 3.45 [36 36] [13 65]] [13 91]] [36 66]] [2902 10.8 [2827 1.69 [36 46] [24 44]] [24 63]]] [13 100]] [6732 2.04 [13 87] [13 100]]] [36 100]]] [30 40]] [36 85]] [3 100]] [24 100]] [2490 2.16 [6449 4.12 [7335 2.16 [5703 1.31 [5198 8.24 [6544 2.18 [13 49] [36 100]] [36 92]] [13 100]] [13 100]] [13 100]] [13 100]]] [36 59]] [13 100]] [36 80]] [5198 6.81 [3765 0.487 [7092 1.13 [1069 0.915 [1521 0.975 [7665 6.75 [22 76] [6082 0.498 [13 83] [13 100]]] [13 100]] [13 100]] [13 100]] [13 100]] [13 61]]] [2456 3.04 [429 8.7 [24 91] [24 100]] [24 80]]] [4667 2.39 [429 21.7 [3 85] [13 63]] [13 85]]] [13 100]] [6264 3.05 [7696 0.849 [1079 0.595 [7698 2.18 [112 1.25 [17 2.08 [13 66] [13 100]] [13 100]] [13 80]] [13 100]] [13 100]] [13 56]]] [24 93]] [36 100]] [6205 1.02 [23 24.2 [6270 0.982 [3905 7.52 [17 3.31 [1911 2.05 [3429 1.21 [36 85] [36 100]] [36 100]] [4087 1.81 [13 60] [36 100]]] [36 100]] [36 63]] [13 71]] [36 100]]] [5692 13.1 [36 100] [36 90]]] [23 4.82 [24 77] [24 66]]] [5693 0.998 [429 28.8 [36 94] [36 66]] [36 100]]] [2763 3 [1391 0.797 [1429 27.4 [22 100] [22 81]] [22 100]] [5692 2.94 [22 66] [22 100]]]] [1899 2.04 [429 3.75 [13 77] [4154 1.78 [13 99] [1526 1.57 [13 60] [13 100]]]] [13 82]]] [5192 1.54 [3653 2.94 [2411 3.07 [4356 0.722 [24 96] [24 100]] [1783 2.7 [774 1.05 [24 88] [24 80]] [19 62]]] [2518 3.86 [4214 5.02 [19 47] [24 83]] [24 100]]] [7530 0.427 [7169 4.69 [4046 1.27 [24 80] [24 55]] [19 62]] [3666 2.61 [19 60] [19 62]]]]] [4615 4.65 [36 100] [36 88]]]] [6581 0.377 [7493 0.45 [7335 1.17 [5664 2.77 [7343 0.327 [429 3.6 [328 0.581 [24 71] [24 57]] [929 4.58 [7413 3.62 [3654 0.667 [435 2.86 [1253 4.33 [5736 16.8 [7472 1.21 [4338 6.48 [5480 0.949 [7399 1.11 [7512 13.8 [2793 15.5 [2993 0.539 [1436 13.1 [1078 14 [5812 12.5 [655 12.2 [6865 2.79 [4154 0.659 [5783 2.86 [3101 0.81 [24 82] [24 100]] [24 100]] [24 100]] [24 100]] [3008 3.19 [24 63] [24 100]]] [24 71]] [7512 6.49 [3008 19.8 [24 87] [24 100]] [24 100]]] [24 77]] [24 62]] [24 66]] [5574 6.94 [1240 34.9 [774 10.7 [906 5.97 [1783 1.51 [3101 21.7 [4154 25 [7665 20.6 [134 1.89 [7535 2.89 [1011 4.52 [24 100] [24 86]] [24 100]] [24 100]] [24 100]] [24 81]] [24 88]] [24 66]] [24 66]] [24 91]] [2526 18.5 [24 73] [24 100]]] [24 85]]] [24 100]] [18 50]] [4818 6.56 [1429 56.3 [1035 7.47 [1454 1.13 [4341 2.91 [4908 1.02 [5789 1.79 [2771 9.77 [6260 9.09 [4414 4.66 [4189 3.05 [4815 0.778 [6721 2.24 [5698 5.01 [7566 0.262 [5198 4.57 [3653 3.4 [3016 0.734 [24 98] [24 100]] [24 90]] [24 71]] [24 100]] [24 86]] [24 88]] [24 100]] [1906 0.351 [3636 0.384 [3652 1.56 [429 11.9 [774 0.978 [24 95] [24 100]] [24 100]] [24 100]] [24 100]] [24 100]]] [24 92]] [2909 5.35 [24 90] [24 100]]] [24 80]] [24 100]] [24 100]] [1899 6.29 [24 86] [24 72]]] [24 87]] [24 80]] [24 81]] [24 58]]] [24 66]] [24 71]] [24 55]] [24 27]] [7566 0.334 [5812 2.39 [2259 13.2 [3008 2.21 [24 94] [221 7.89 [19 50] [24 100]]] [5413 0.472 [4344 0.476 [24 89] [24 100]] [24 100]]] [24 100]] [3659 1.06 [24 100] [24 50]]]] [24 55]] [24 56]]] [429 29.3 [5192 1.39 [2280 0.266 [1078 3.59 [7343 10.6 [24 100] [24 83]] [24 64]] [24 88]] [24 66]] [2 25]]] [24 42]] [24 47]] [29 50]] [24 52]]] [663 0.179 [6959 0.462 [5350 0.898 [1899 2.65 [2939 14 [4820 14.2 [2558 2.3 [2412 0.244 [2029 1.81 [7512 35.8 [6 96] [16 66]] [221 21.4 [6 100] [6 87]]] [6 100]] [6 70]] [6 100]] [5397 1.6 [16 56] [6 71]]] [5964 15.2 [1364 6.95 [7281 7.69 [2023 1.1 [2649 4.09 [2752 3.01 [2406 0.0846 [6138 7.79 [2585 11.3 [6276 0.534 [2282 25.4 [7557 8.38 [5093 15 [5598 5.79 [4675 0.626 [1382 4.82 [6 100] [7512 8.27 [6 87] [6 100]]] [6 100]] [6100 4.48 [6 71] [4820 2.76 [6690 2.62 [221 2.82 [6 94] [6 100]] [6 100]] [6 83]]]] [6 83]] [6 85]] [6 88]] [6 100]] [16 57]] [6 71]] [2613 0.145 [2387 4.98 [6 100] [6 62]] [6 100]]] [6 58]] [4851 5.65 [6 100] [6 72]]] [6 77]] [2365 0.478 [6 82] [6 100]]] [2282 9.36 [7574 1.96 [2611 1.81 [6 100] [6 77]] [6 80]] [16 57]]] [16 57]]] [2279 8.17 [7540 3.61 [2406 0.944 [6 85] [6 50]] [6 100]] [16 57]]] [1919 5.71 [6831 0.162 [2526 24 [6 71] [6 66]] [5673 1.58 [18 57] [16 42]]] [6 84]]] [4840 0.373 [685 2.3 [6831 0.859 [6 70] [18 28]] [16 50]] [16 70]]]] [957 1.34 [7014 1.2 [6382 1.7 [6830 4.23 [906 0.403 [6269 1.35 [5900 3.44 [3603 4.85 [7729 1.34 [5637 1.5 [4744 8.98 [6960 1.78 [7076 0.891 [4507 9.48 [1646 6.88 [4200 1.6 [5534 5.21 [2488 4.27 [5673 5.88 [7665 15.2 [2178 1.1 [2202 2.24 [4897 9.24 [2241 3.5 [2081 19.5 [7255 18.3 [5536 4.02 [7737 2.79 [392 2.44 [2121 0.999 [4231 4.07 [4279 3.75 [7255 1.56 [19 47] [19 75]] [19 68]] [19 81]] [19 75]] [7 28]] [663 1.66 [896 0.489 [1256 4.9 [171 2.51 [7737 20 [7514 32.3 [19 82] [19 63]] [19 67]] [2259 18.3 [19 45] [19 100]]] [19 57]] [19 75]] [19 66]]] [19 40]] [7256 13.4 [16 28] [19 62]]] [19 33]] [19 80]] [13 33]] [35 42]] [1899 3.47 [6342 3.5 [19 88] [19 63]] [5345 1.53 [2181 1.9 [172 3.71 [19 70] [19 50]] [5 37]] [19 100]]]] [2023 15.6 [4876 11.1 [5130 0.59 [4218 11.3 [7169 3.82 [3675 28 [23 65.8 [19 40] [2052 6.83 [6436 0.682 [3463 2.65 [19 63] [18 62]] [14 50]] [19 84]]] [13 22]] [19 38]] [19 93]] [17 25]] [26 43]] [12 37]]] [1911 6.66 [19 77] [19 62]]] [13 100]] [13 60]] [19 42]] [18 66]] [18 50]] [13 28]] [18 50]] [13 100]] [7724 0.548 [3420 3.97 [7738 0.456 [7606 4.85 [7737 8.29 [7514 4.67 [19 45] [2993 0.575 [19 84] [19 100]]] [19 93]] [13 40]] [168 47.4 [19 80] [100 2.66 [19 87] [19 100]]]] [19 33]] [19 100]]] [14 25]] [12 54]] [7369 0.583 [19 46] [144 27.5 [18 100] [6 41]]]] [791 10.1 [13 75] [13 100]]] [13 66]] [14 67]] [14 71]] [13 86]] [5264 0.846 [18 36] [13 100]]]] [2987 1.91 [3333 6.3 [43 0.808 [5079 0.129 [1888 1.49 [1429 16.4 [7329 0.144 [2961 0.417 [6177 1.06 [1919 8.18 [3100 0.346 [7381 2.33 [6982 3.11 [4235 7 [25 70] [25 93]] [4 100]] [4 66]] [1 88]] [4 50]] [6189 7.14 [4369 6.95 [25 100] [25 90]] [25 100]]] [4 77]] [7309 0.363 [1783 7.52 [6189 9.79 [1849 2.52 [25 100] [25 83]] [25 75]] [25 100]] [25 100]]] [5432 0.379 [31 3.88 [6791 3.89 [2755 0.861 [6182 2.49 [202 11.5 [5692 7.35 [25 65] [26 71]] [25 55]] [25 100]] [2752 15.3 [26 60] [25 80]]] [25 75]] [19 33]] [25 100]]] [5431 0.575 [5848 0.405 [1400 1.71 [1081 1.53 [7169 2.75 [25 40] [4 41]] [25 50]] [38 41]] [4 100]] [26 100]]] [184 2.43 [25 100] [1432 2.08 [25 100] [25 66]]]] [4 100]] [1 100]] [4 100]]] [914 0.303 [5872 1.7 [6425 1.01 [4062 4.41 [6333 1.3 [1552 0.133 [3938 2.49 [6106 1.09 [6299 0.785 [2913 3.48 [4210 0.477 [4851 5.95 [3130 8.2 [5856 0.276 [896 0.246 [5403 1.47 [1888 0.366 [1783 0.775 [6696 5.85 [168 3.23 [826 3.14 [5871 1.47 [7615 6.74 [7665 15.6 [4353 5.18 [6320 0.982 [4056 6.17 [6436 9.34 [14 33] [14 100]] [32 100]] [14 40]] [429 37.9 [32 100] [32 80]]] [730 1.56 [5692 5.78 [6708 11.6 [7600 2.86 [1429 38.3 [14 50] [14 82]] [32 100]] [14 71]] [2752 13.3 [13 30] [14 93]]] [32 75]]] [3 84]] [14 93]] [32 92]] [28 46]] [7589 5.38 [14 77] [14 57]]] [5382 1.5 [2902 2.13 [1 2.72 [2081 0.505 [1078 1.73 [14 51] [4154 0.775 [28 42] [28 35]]] [429 17.2 [15 50] [3 42]]] [20 60]] [28 76]] [28 100]]] [1239 9.38 [7548 9.89 [1888 39.8 [7692 1.1 [5753 1.72 [14 61] [14 87]] [2752 16.7 [14 100] [14 73]]] [14 100]] [14 90]] [14 93]]] [3 82]] [6184 7.34 [695 0.492 [5007 1.75 [5693 4.47 [1400 13.8 [7600 2.02 [7520 16.1 [567 3.45 [6310 16 [14 81] [14 100]] [14 62]] [14 50]] [32 100]] [14 58]] [14 92]] [14 42]] [2910 2.42 [99 7.77 [6199 1.22 [2760 0.668 [2811 1.29 [1783 1.82 [14 87] [14 94]] [14 100]] [14 71]] [3905 0.45 [14 91] [14 100]]] [14 66]] [14 100]]] [14 57]]] [3 42]] [32 66]] [4163 3.18 [7354 6.06 [5605 7.25 [3558 1.73 [5776 3.45 [3008 1.29 [6449 1.83 [5211 19.1 [1745 3.31 [861 3.7 [4799 3.76 [4946 2.79 [7548 16.1 [613 7.46 [7722 1.08 [32 46] [14 84]] [14 88]] [3027 10.6 [14 55] [32 66]]] [14 100]] [32 100]] [32 100]] [14 57]] [30 100]] [32 85]] [14 82]] [14 85]] [14 100]] [14 90]] [32 95]] [32 100]]] [5443 4 [4282 1.49 [30 52] [3 100]] [30 100]]] [4212 1.36 [5439 1.53 [2846 4.46 [6613 1.23 [5368 1.95 [2914 0.978 [534 1.09 [4288 1.44 [7665 7.25 [5730 1.06 [30 59] [32 100]] [32 86]] [32 96]] [3 100]] [30 100]] [3 44]] [30 36]] [905 2.8 [3377 1.54 [628 2.26 [3008 2.15 [32 96] [32 100]] [32 100]] [32 100]] [32 100]]] [4851 3.13 [30 100] [30 42]]] [30 100]]] [30 96]] [32 100]] [32 100]] [32 100]] [5205 5.75 [7169 11.6 [6395 3.01 [32 96] [32 55]] [32 84]] [32 78]]] [2752 29.6 [4061 14.5 [1626 2.01 [30 50] [30 100]] [14 80]] [14 44]]] [14 38]] [14 96]] [889 2.78 [7512 18.2 [7314 1.9 [5753 0.797 [660 1.55 [828 0.743 [5412 0.901 [32 100] [32 92]] [32 100]] [32 80]] [32 66]] [32 80]] [3905 7.46 [7692 4.28 [32 77] [14 77]] [32 100]]] [32 100]]]] [964 0.0939 [5480 4.9 [980 0.0842 [7245 1.42 [144 29.8 [2466 0.799 [1062 3.83 [271 5.46 [2955 9.03 [4703 2.14 [5622 1.46 [7149 6.75 [5985 0.316 [4067 2.82 [6189 10.1 [5856 1.95 [4154 32.1 [2530 13 [7343 13.2 [1906 0.608 [6471 0.976 [26 40] [5753 5.84 [377 2.99 [5597 0.501 [7324 0.83 [5267 8.73 [663 1.8 [6471 23.1 [5776 19.9 [5692 0.532 [2951 5.84 [1696 10.6 [1429 39.2 [2749 0.695 [1239 1.69 [26 63] [2259 0.537 [26 76] [26 57]]] [26 97]] [26 44]] [26 100]] [26 93]] [3742 1.21 [5348 2.13 [5462 0.435 [7668 2.95 [2993 3.35 [6199 0.888 [7516 5.41 [26 100] [26 93]] [26 100]] [26 90]] [26 83]] [26 100]] [26 85]] [26 75]]] [26 47]] [26 97]] [7343 5.8 [5870 1.62 [6134 0.297 [6353 0.689 [26 96] [26 85]] [26 85]] [26 100]] [26 72]]] [16 28]] [26 62]] [26 40]] [26 82]] [26 42]]] [1906 4.23 [26 100] [26 90]]] [6471 7.39 [26 85] [16 50]]] [26 50]] [26 38]] [16 42]] [26 50]] [26 50]] [26 63]] [5801 3.45 [26 43] [26 66]]] [19 40]] [33 61]] [6472 0.409 [4457 1.22 [190 8.24 [26 62] [16 37]] [16 75]] [26 55]]] [18 50]] [6471 4.51 [18 75] [1980 5.05 [26 45] [26 64]]]] [2517 2.67 [3207 4.65 [1081 0.838 [2712 0.282 [5918 0.36 [663 2.31 [5480 3.16 [2951 0.455 [26 54] [26 78]] [26 50]] [7512 4.12 [18 36] [36 35]]] [26 27]] [16 71]] [26 91]] [36 45]] [24 85]]] [19 85]] [18 81]] [429 28.1 [7101 3.13 [5692 3.35 [5647 0.197 [6034 2.09 [1995 1.05 [7446 0.956 [26 81] [26 100]] [26 63]] [26 60]] [392 1.08 [1429 11.3 [26 100] [26 71]] [26 83]]] [221 0.158 [5632 0.745 [141 3.78 [724 3.16 [7552 8.39 [6068 2.17 [731 1.97 [1084 2.29 [6732 0.373 [6471 10.9 [26 100] [26 60]] [26 100]] [26 90]] [26 100]] [26 88]] [26 75]] [26 85]] [26 63]] [26 70]] [26 80]]] [19 42]] [26 50]]] [6732 5.23 [2259 4.55 [6585 0.91 [7210 3.73 [7354 5.44 [26 91] [16 27]] [26 52]] [4235 5.05 [269 11.7 [26 100] [26 88]] [26 100]]] [1661 0.676 [7241 0.275 [5012 5.19 [5799 1.93 [18 36] [19 50]] [6830 2.74 [18 54] [19 55]]] [18 76]] [16 44]]] [384 0.698 [5013 0.526 [26 74] [26 37]] [2915 0.241 [26 84] [26 100]]]]] [5160 0.921 [560 4.52 [6959 1.87 [2526 1.84 [19 50] [18 54]] [18 53]] [2526 3.96 [5692 3.47 [16 72] [18 100]] [18 83]]] [19 50]]]] [7107 0.541 [7174 0.609 [4084 0.444 [6764 0.425 [3459 0.635 [1593 0.945 [3113 0.335 [7512 28.4 [7411 0.165 [2808 0.797 [3431 1.39 [7571 0.583 [4369 2.99 [2251 1.54 [1405 1.27 [6260 1.48 [7704 0.53 [4424 5.32 [5472 1.12 [2259 0.458 [2143 3.28 [15 65] [32 62]] [2846 0.627 [5424 0.465 [429 9.29 [32 53] [4801 1.52 [4414 8.14 [4576 3.07 [2225 4.12 [32 92] [32 62]] [32 100]] [32 82]] [32 100]]] [32 75]] [435 0.852 [3485 0.62 [32 97] [32 100]] [32 100]]]] [36 91]] [15 82]] [32 100]] [3480 4.6 [36 55] [36 85]]] [36 78]] [36 84]] [3896 0.522 [2846 2.46 [286 1.52 [7600 2.56 [2259 5.12 [32 50] [2752 2.19 [32 60] [4799 0.898 [32 96] [32 100]]]] [32 100]] [32 60]] [32 100]] [32 100]]] [36 95]] [36 100]] [15 100]] [15 80]] [5789 1.33 [5472 2.89 [4279 2.49 [7623 9.09 [7233 7.17 [32 39] [32 100]] [15 57]] [32 90]] [896 23.2 [36 100] [36 72]]] [36 100]]] [32 100]] [2793 0.609 [2763 1.47 [36 72] [36 100]] [36 100]]] [15 100]] [36 100]] [36 100]] [36 100]] [36 100]]] [7287 0.0821 [5812 3.41 [5969 4.23 [2081 2.65 [6581 0.536 [2939 4.7 [1980 11.9 [5219 5.05 [8 86] [8 100]] [23 73]] [8 75]] [8 100]] [2021 0.15 [1094 1.58 [8 71] [23 75]] [23 77]]] [23 100]] [4 44]] [8 100]]] [7685 0.252 [6199 0.315 [6077 1.43 [510 1.03 [4851 0.36 [2936 0.666 [6471 0.34 [7747 0.96 [7512 37.2 [20 25] [5211 3.23 [23 7.04 [20 85] [6 33]] [20 96]]] [20 100]] [26 100]] [184 0.911 [25 88] [25 100]]] [269 2.46 [26 76] [26 100]]] [26 100]] [2 57]] [26 83]] [4235 55.3 [978 8.94 [2091 3.47 [5491 2.69 [4245 2.07 [20 73] [7085 0.467 [6282 0.975 [5211 4.68 [1078 18.8 [20 100] [20 66]] [2081 14.8 [3325 1.56 [7758 1.22 [20 98] [20 100]] [20 100]] [20 91]]] [20 100]] [20 100]]] [20 57]] [20 70]] [20 50]] [4066 0.5 [4414 17 [5769 0.64 [5134 20.8 [5876 1.34 [6621 14.1 [7099 0.77 [2199 13.5 [4650 7.69 [4259 0.57 [7101 0.888 [1062 3.51 [5773 1.36 [5110 2.41 [5646 0.805 [4266 32 [4294 0.882 [1899 0.843 [4699 1.43 [5360 3.18 [20 98] [20 100]] [4235 67.9 [2081 1.5 [5236 13.1 [20 100] [20 80]] [20 100]] [20 100]]] [20 100]] [20 100]] [7312 3.4 [20 92] [20 100]]] [20 100]] [20 83]] [20 100]] [20 92]] [20 100]] [20 100]] [20 92]] [20 71]] [20 100]] [20 62]] [20 100]] [20 75]] [20 100]] [20 88]] [20 87]]]]] [5734 0.448 [6549 0.152 [1463 0.327 [1813 0.794 [494 0.0763 [3480 0.292 [385 0.466 [2846 1.93 [5523 0.813 [3517 0.28 [7354 0.42 [2826 0.897 [7340 3.61 [5079 0.323 [1429 12.4 [2913 0.4 [6883 5.12 [2752 6 [701 2.35 [5412 9.43 [2628 2.91 [328 5.69 [5345 1.31 [957 0.989 [5406 1.92 [3732 4.95 [7185 3.18 [2470 6.08 [4414 0.478 [2526 17.1 [14 24] [25 50]] [33 22]] [4 64]] [7665 28.9 [4 30] [26 55]]] [17 84]] [31 100]] [10 40]] [7 25]] [26 32]] [2987 0.719 [31 26] [4 50]]] [24 36]] [7714 4.13 [31 81] [31 100]]] [5695 0.738 [4349 1.83 [429 6.15 [4253 1.01 [7043 1.67 [26 25] [25 100]] [25 85]] [598 1.48 [5654 3.71 [978 5.53 [184 0.566 [7588 3.4 [5692 5.85 [7665 5.03 [10 87] [2752 28 [14 17] [22 46]]] [4 22]] [26 33]] [4 44]] [573 1.04 [7381 1.86 [985 3.75 [1993 0.942 [25 23] [2 33]] [26 62]] [4 50]] [4 50]]] [2 42]] [25 100]]] [24 70]] [2911 0.239 [25 52] [26 100]]]] [791 6.47 [7665 22.4 [10 33] [5 100]] [5 84]]] [394 1.63 [7722 9.83 [7665 17.1 [1899 3.33 [2913 27 [328 24.6 [6178 1.49 [26 36] [25 100]] [26 55]] [25 85]] [25 66]] [7305 1.47 [7 45] [25 90]]] [7 50]] [26 79]]] [2526 2.25 [5900 4.47 [1646 0.77 [859 1.47 [6124 2.79 [782 1.55 [2701 7.72 [6269 1.31 [2488 6.91 [5681 0.938 [719 1.49 [6604 1.2 [6591 3.75 [7722 0.908 [6696 2.75 [404 4.31 [5330 1.18 [642 3.01 [2793 4.95 [5482 5.35 [1664 2.42 [4946 7.94 [5564 3.17 [6732 10.9 [5812 5.32 [144 29.7 [1094 2.37 [7695 3.02 [6031 1.31 [2259 8.24 [5 17] [4279 2.11 [2752 15.2 [14 27] [36 27]] [3 23]]] [22 85]] [30 94]] [10 77]] [5 100]] [5 55]] [6977 5.49 [19 37] [5 100]]] [14 100]] [5 62]] [32 57]] [18 100]] [24 87]] [5 63]] [30 100]] [7 50]] [4279 2.96 [30 66] [30 80]]] [7665 29.1 [1198 1.19 [7381 2.81 [5539 1.73 [14 61] [14 100]] [14 40]] [14 85]] [14 29]]] [17 53]] [30 100]] [4896 3.87 [2913 4.06 [7526 0.808 [6776 5.04 [1980 2.35 [1429 42.8 [4968 2.04 [14 34] [14 57]] [2259 3.67 [896 1.1 [5 57] [17 50]] [19 41]]] [14 64]] [7 60]] [4851 8.5 [17 46] [17 91]]] [719 11.7 [5 50] [7 62]]] [14 75]]] [5673 7.39 [18 58] [16 87]]] [13 93]] [13 100]] [29 100]] [3 56]] [12 100]] [2753 0.459 [5034 11 [30 84] [30 77]] [30 62]]] [30 94]] [18 85]] [1240 0.65 [3758 1.43 [3732 1.93 [2913 2.02 [5771 1.05 [6557 1.11 [5510 1.04 [7542 0.585 [2594 5.88 [7566 4.69 [2275 3.45 [3461 1.01 [6152 1.14 [7598 1.25 [2606 3 [5348 1.48 [7188 10.1 [4154 7.3 [2023 1.86 [2616 0.606 [17 22] [17 33]] [25 55]] [24 32]] [7 66]] [16 37]] [5 85]] [17 57]] [19 70]] [17 100]] [7 37]] [5 50]] [5 25]] [5 40]] [17 70]] [5 60]] [4 57]] [7210 0.752 [7185 5.06 [5 38] [7 60]] [5 37]]] [688 0.169 [5383 6.22 [896 5.86 [17 34] [1239 0.661 [17 64] [17 66]]] [16 75]] [17 76]]] [7 100]] [24 57]]]] [25 89]] [6909 1.08 [2753 3.81 [32 73] [5 28]] [32 100]]] [6581 0.479 [429 13 [1429 22.2 [929 0.671 [5170 1.71 [7600 4.2 [2616 1.82 [6619 0.894 [7585 3.65 [7566 3.47 [4164 1.87 [4307 1.44 [4624 3.14 [6184 6.85 [5316 9.62 [5654 0.747 [2915 3.81 [7512 16.8 [2752 40.1 [2755 8.15 [5431 0.652 [7149 1.18 [5693 4.79 [5412 0.81 [14 28] [14 50]] [17 37]] [16 33]] [26 66]] [25 61]] [26 55]] [14 51]] [26 83]] [26 50]] [32 61]] [25 72]] [14 100]] [32 100]] [32 100]] [26 55]] [14 100]] [25 100]] [5054 1.85 [5429 2.07 [719 4.12 [25 38] [4 57]] [26 60]] [4 100]]] [32 100]] [184 2.4 [7413 1.83 [266 0.974 [2755 12.2 [26 97] [26 80]] [26 100]] [26 60]] [26 75]]] [429 7.88 [26 100] [26 83]]] [2801 1.58 [5681 1.14 [728 2.94 [899 0.106 [5345 3.19 [2259 7.71 [673 2.39 [6544 2.09 [1761 0.764 [14 27] [14 100]] [1783 1.17 [14 100] [14 71]]] [26 72]] [14 61]] [5 52]] [14 87]] [144 6.98 [14 94] [14 50]]] [6 30]] [12 100]]] [7734 0.16 [5872 1.49 [6544 4.75 [7305 2.68 [2818 0.44 [1899 3.98 [3998 1.93 [2470 0.717 [899 1.92 [613 1.03 [1 6.41 [736 1.86 [4307 2.19 [828 5.47 [4154 15.5 [4381 1.23 [4111 1.36 [3899 1.34 [407 1.38 [6199 2.42 [2902 6.45 [723 2.77 [826 1.56 [5812 12.1 [4851 1.56 [2752 26.5 [1073 1.13 [2826 17.5 [7251 0.375 [7009 7.7 [4895 5.89 [17 31] [14 50]] [5 62]] [134 5.05 [17 31] [19 33]]] [14 32]] [38 75]] [21 3.11 [710 1.26 [5662 1.49 [957 2.09 [1011 4.78 [14 20] [5 46]] [14 83]] [4 28]] [14 90]] [7413 5.63 [5 33] [896 10.4 [19 100] [16 42]]]]] [5099 2.27 [14 50] [16 62]]] [7 68]] [32 42]] [3342 2.44 [5 60] [17 63]]] [17 72]] [7428 2.94 [2616 0.479 [112 11.8 [7512 7.88 [14 44] [14 79]] [14 44]] [7 33]] [5 42]]] [7 85]] [32 100]] [5 100]] [32 100]] [32 74]] [7 86]] [32 100]] [4571 0.688 [6230 21.2 [2939 3.04 [3317 5.62 [5007 3.35 [7188 11 [7324 5.37 [17 38] [5 77]] [18 55]] [5 40]] [5 40]] [663 4.91 [5 33] [5 30]]] [5 63]] [19 40]]] [12 66]] [2752 26.3 [14 91] [14 85]]] [3027 0.437 [4479 1.55 [1754 0.482 [7340 1.31 [7409 1.32 [7188 5.66 [7253 0.677 [600 0.617 [6445 1.35 [791 28.5 [3008 1.21 [14 69] [14 100]] [32 50]] [14 100]] [14 100]] [14 100]] [14 50]] [14 100]] [32 100]] [14 100]] [14 92]] [32 93]]] [1429 8.8 [731 1.09 [4 71] [4 92]] [4 55]]] [731 6.9 [5 66] [5 95]]] [5972 5.45 [6977 2.08 [710 1.27 [7665 18 [5873 1.88 [4338 1.04 [6944 1.5 [5819 3.02 [1011 0.491 [899 1.06 [1429 27.3 [2826 7.65 [7 47] [4 38]] [429 30.7 [1429 41.7 [14 40] [736 2.48 [7 23] [5 28]]] [1919 1.15 [896 0.51 [17 45] [5 50]] [17 83]]]] [14 78]] [695 5.87 [736 2.63 [7693 0.69 [728 2.5 [5155 0.686 [5 40] [5 57]] [17 55]] [17 66]] [17 57]] [17 61]]] [724 2.78 [5651 6.81 [4184 2.92 [17 64] [7 15]] [17 100]] [17 81]]] [32 100]] [2011 0.739 [7568 2.35 [4154 5.98 [6653 3.02 [5 52] [38 55]] [2526 15.9 [17 73] [7665 7.77 [5 90] [4 31]]]] [4 72]] [17 60]]] [38 92]] [7689 3.2 [2939 0.512 [4 42] [7712 0.512 [4 71] [4 42]]] [19 44]]] [14 100]] [5 79]] [12 90]]] [12 100]] [2426 1.28 [4154 7.09 [4629 1.42 [14 38] [12 100]] [4 46]] [12 100]]] [736 1.44 [3342 1.23 [2526 15.8 [6395 2.06 [663 11 [5692 5.82 [14 83] [14 100]] [32 91]] [19 38]] [17 83]] [7722 3.6 [5692 2.47 [14 76] [14 100]] [14 100]]] [17 60]]] [14 88]] [5673 3.03 [3558 0.958 [4110 0.904 [6524 1.06 [7722 3.77 [7 36] [5 25]] [7 93]] [5 85]] [7 73]] [38 38]]]] [6471 0.95 [2541 0.142 [5907 0.255 [3798 0.283 [5566 0.375 [7563 0.812 [5769 0.775 [3290 1.44 [3077 0.826 [1505 0.897 [3928 6.21 [4478 2.58 [2530 0.821 [7324 1.58 [3858 0.578 [7527 0.998 [5034 3.7 [1838 0.334 [4959 2.92 [5820 1.62 [1023 2.24 [3197 3.49 [2608 1.25 [1400 2.95 [5891 0.321 [6550 16.2 [3008 0.284 [7725 0.118 [5812 1.33 [4279 4.43 [1690 0.975 [1429 49.3 [6980 6.29 [2616 3.56 [5192 6.34 [5154 4.89 [2841 2.18 [6550 7.31 [5007 0.96 [6732 11 [1888 12 [5 29] [17 63]] [736 1.45 [19 63] [5 62]]] [17 37]] [6732 1.48 [5 57] [5 83]]] [5 81]] [6313 1.26 [17 100] [38 44]]] [17 90]] [6401 1.21 [4806 2.04 [1011 1.59 [5 41] [5 44]] [731 9.42 [5 100] [5 66]]] [5 57]]] [17 75]] [2591 2.56 [2628 5.67 [1078 27.7 [5 65] [17 55]] [5 87]] [5 88]]] [17 100]] [19 51]] [660 1.32 [4304 1.24 [4718 0.308 [1069 0.994 [4719 0.62 [2526 34.5 [5 37] [17 73]] [17 100]] [17 62]] [5 50]] [5 55]] [17 57]]] [17 61]] [7301 1.24 [988 1.23 [999 0.369 [2033 0.269 [726 4.09 [141 0.888 [978 12 [17 47] [17 76]] [17 88]] [19 61]] [17 84]] [17 71]] [16 62]] [19 50]]] [17 86]] [5154 2.89 [17 74] [17 54]]] [3931 1.77 [2752 6.19 [4 66] [978 8.54 [6585 1.21 [26 66] [26 100]] [26 95]]] [4 62]]] [5 72]] [17 100]] [2178 1.88 [17 72] [17 57]]] [4 100]] [4 100]] [3562 0.334 [19 53] [19 100]]] [14 100]] [5 100]] [35 100]] [5 67]] [26 88]] [1980 2.63 [3317 1.47 [3732 1.22 [7185 0.346 [1899 2.36 [17 46] [17 75]] [3196 1.03 [17 80] [17 100]]] [17 93]] [17 45]] [17 50]]] [3929 6.96 [7588 3.25 [5 100] [5 60]] [7534 5.91 [5 60] [17 83]]]] [2628 0.545 [5 86] [5 100]]] [3078 24.2 [791 11.7 [733 0.533 [7188 0.734 [5892 0.462 [2259 1.69 [6977 0.64 [6550 8.79 [17 50] [19 33]] [19 50]] [5413 6.05 [17 91] [17 57]]] [17 100]] [17 87]] [14 30]] [736 0.79 [2902 0.734 [17 71] [17 100]] [17 88]]] [19 54]]] [6977 1.59 [5 63] [5 100]]] [7766 5.61 [5054 5.15 [4 88] [4 77]] [4 50]]] [5 78]] [14 100]] [5522 1.58 [4003 0.959 [2987 0.948 [5462 0.592 [1885 0.644 [1429 43.9 [3008 7.23 [5851 0.268 [17 77] [17 33]] [35 33]] [7512 11.8 [6550 4.68 [3554 0.431 [978 13.8 [19 44] [7665 6.08 [19 41] [17 79]]] [19 50]] [19 69]] [7185 6.89 [6313 1.64 [7068 3.43 [5673 5.91 [17 70] [38 87]] [38 62]] [38 87]] [16 50]]]] [38 77]] [7588 0.327 [38 92] [17 44]]] [19 73]] [7185 2.35 [17 57] [5389 1.86 [17 44] [17 73]]]] [35 66]]] [2939 0.255 [791 10.4 [19 92] [19 75]] [19 100]]] [5390 5.76 [6388 1.08 [731 2.78 [929 0.264 [2636 3.98 [791 6.86 [17 44] [19 64]] [17 66]] [17 50]] [3928 0.373 [7417 0.142 [2826 2.43 [3905 2.58 [38 60] [19 66]] [3734 9.55 [733 1.74 [4083 2.48 [7682 2.08 [5192 1.18 [2541 4.07 [17 60] [4851 5.7 [17 60] [17 88]]] [17 60]] [5677 0.454 [1078 1.57 [17 85] [17 100]] [17 72]]] [17 100]] [17 63]] [17 26]]] [17 50]] [17 50]]] [2591 2.3 [978 12.8 [19 50] [38 77]] [17 63]]] [35 34]]] [7722 1.74 [26 57] [685 1.19 [26 80] [26 90]]]]]] [6555 0.65 [5472 3.17 [2913 0.462 [7381 0.0611 [3345 0.894 [4851 2.48 [5429 2.93 [6524 5.41 [653 9.09 [957 1.62 [3520 2.24 [7325 1.62 [7419 0.609 [7737 0.219 [5716 2.72 [2809 0.764 [4859 3.81 [6592 0.44 [685 1.21 [3223 1.11 [328 2.48 [1754 1.42 [5348 1.85 [7009 0.707 [6862 0.415 [5482 8.21 [6230 17.2 [18 35] [6732 15.4 [5 38] [5 70]]] [18 100]] [5516 0.415 [18 37] [16 46]]] [5 46]] [18 75]] [38 100]] [7188 7.23 [5662 1.22 [5637 1.74 [18 25] [19 62]] [18 80]] [18 88]]] [5 85]] [5007 2.7 [7693 3.86 [18 61] [18 44]] [18 37]]] [719 2.54 [791 6.26 [19 50] [18 70]] [18 100]]] [18 100]] [2752 16.6 [26 33] [18 58]]] [6230 5.44 [16 50] [16 83]]] [4154 11.5 [2951 2.37 [3515 3.78 [407 2.47 [7601 4.66 [6499 0.219 [4324 1.34 [2809 2.01 [4716 0.302 [791 2.92 [19 47] [6727 2.15 [18 71] [18 50]]] [18 88]] [16 70]] [19 66]] [19 30]] [18 50]] [22 44]] [19 75]] [16 63]] [18 54]]] [7203 1.35 [731 5.37 [5099 1.33 [978 2.89 [18 62] [5130 1.11 [16 76] [18 71]]] [19 33]] [5693 0.708 [1631 0.849 [18 50] [16 75]] [16 87]]] [7446 0.42 [19 50] [16 30]]]] [2826 4.18 [5 42] [736 1.28 [5 83] [5 66]]]] [19 100]] [5007 1.1 [5969 0.276 [5480 1.01 [7411 1.48 [6230 9.56 [32 40] [5 78]] [5 44]] [5412 2.61 [384 6.01 [4369 1.3 [397 1.88 [18 65] [18 62]] [18 42]] [18 100]] [18 62]]] [1078 14.3 [896 1.85 [18 87] [18 100]] [18 66]]] [18 37]]] [7325 4.59 [7 53] [5 87]]] [7 95]] [5 64]] [2753 0.688 [6074 1.4 [7588 1.66 [4154 11.6 [5007 4.11 [7210 0.935 [653 1.78 [647 1.57 [7 33] [7 92]] [16 42]] [18 29]] [7 100]] [32 68]] [7009 2.6 [5 59] [5 27]]] [7 78]] [5 33]]] [5 73]] [4486 1.47 [7413 0.785 [1557 2.96 [6216 0.548 [3773 0.421 [5412 1.64 [5873 11.4 [7325 0.456 [653 6.67 [6524 1.95 [735 8.09 [7665 22.5 [1783 5.68 [31 3.73 [642 1.2 [5 70] [5 100]] [5 50]] [19 36]] [2826 6.25 [5 66] [7 44]]] [19 57]] [7 100]] [7 42]] [5 93]] [5 71]] [731 2.2 [7 70] [38 35]]] [5 87]] [3969 0.548 [6230 5.68 [5 76] [5 33]] [5 77]]] [7 100]] [5 76]] [130 0.143 [7301 1.43 [2081 0.151 [5154 1.16 [10 37] [38 60]] [38 100]] [19 42]] [38 100]]]] [3205 1.3 [6074 1.41 [4969 0.412 [7563 0.824 [3520 1.79 [5316 2.15 [1078 11.4 [906 4.53 [899 3.7 [5480 3.83 [642 0.715 [543 2.95 [6732 0.675 [5 35] [573 4.38 [5021 3.14 [5 37] [5 66]] [5 83]]] [7 56]] [5 100]] [16 70]] [32 77]] [16 72]] [735 1.07 [5 51] [5 66]]] [32 55]] [1078 15.7 [19 57] [19 71]]] [6550 0.462 [5 50] [5 78]]] [7 100]] [2826 7.03 [7 100] [7 80]]] [5 93]]] [13 69]] [4533 0.678 [5 87] [5 100]]]] [1648 4.24 [2616 4.88 [2259 3.96 [6134 0.818 [719 3.1 [19 100] [19 87]] [19 83]] [19 77]] [19 70]] [19 66]]] [5647 5.22 [6591 4.13 [6724 1.82 [7333 0.509 [4806 1.06 [7682 1.53 [141 0.84 [19 80] [19 75]] [17 57]] [7665 15.7 [19 100] [19 84]]] [17 57]] [19 100]] [19 50]] [663 6.85 [6535 1.07 [19 75] [19 100]] [141 0.596 [1707 0.911 [19 98] [19 100]] [19 100]]]]] [6896 1.18 [392 0.531 [328 7.39 [3907 0.543 [6106 0.977 [978 2.03 [7695 1.61 [695 12.9 [2990 0.568 [6333 0.754 [877 1.13 [5972 3.31 [6696 1.45 [2259 3.91 [6732 4.36 [1239 7.57 [2199 1.98 [2628 0.888 [32 44] [2 37]] [14 66]] [17 33]] [14 47]] [4322 0.879 [3938 0.734 [1078 1.07 [7512 16.5 [32 84] [7548 2.62 [32 57] [32 66]]] [2466 1.43 [5730 1.27 [32 49] [32 83]] [14 50]]] [32 100]] [32 100]]] [14 100]] [12 100]] [22 100]] [1239 4.5 [1077 1.36 [1552 1.29 [248 0.994 [32 100] [32 83]] [32 100]] [32 100]] [32 90]]] [12 100]] [5972 1.2 [5412 2.16 [7185 13.5 [6732 5.56 [14 68] [14 100]] [12 50]] [14 100]] [12 100]]] [12 76]] [5812 1.01 [18 43] [6732 2.28 [5 29] [17 37]]]] [4851 0.651 [32 97] [32 100]]] [32 100]] [328 15.6 [14 39] [4414 13.7 [7512 17.4 [14 59] [14 96]] [12 66]]]] [5130 0.986 [7251 1.3 [7139 2.54 [1716 1 [2752 16.5 [14 34] [392 3.78 [14 36] [14 83]]] [6696 2.46 [14 80] [14 100]]] [18 72]] [14 77]] [5281 2.03 [16 47] [18 75]]]] [22 100]]] [3409 0.475 [2605 0.813 [4876 3.01 [421 1.27 [7566 0.461 [913 1.49 [6184 3.57 [727 6.34 [221 0.494 [1239 7.37 [510 5.23 [2616 5.21 [7251 0.994 [723 0.956 [423 0.568 [5695 0.732 [1400 22.5 [26 100] [1888 1.98 [26 90] [26 66]]] [26 100]] [26 100]] [26 100]] [26 100]] [26 80]] [26 60]] [26 44]] [26 61]] [19 42]] [26 53]] [26 100]] [26 100]] [26 100]] [26 57]] [6230 4.21 [26 62] [25 62]]] [25 80]]] [5647 1.22 [1552 0.385 [818 1.16 [3483 6.3 [7665 36.5 [5007 5.19 [3485 0.484 [660 11.2 [4326 0.345 [7169 6.21 [32 95] [32 85]] [32 100]] [32 85]] [32 100]] [32 93]] [32 71]] [3908 2.92 [7512 9.92 [32 81] [32 100]] [32 71]]] [32 80]] [32 100]] [2752 34.2 [32 100] [32 88]]]] [7214 0.484 [6977 0.0974 [494 4.52 [899 0.701 [3732 1.03 [685 0.852 [978 28.4 [6883 0.977 [2752 17.4 [4805 2.72 [6530 0.615 [5732 2.16 [17 1.84 [7381 2.84 [17 64] [17 100]] [35 53]] [6 28]] [7 100]] [35 41]] [7169 2.06 [2628 9.62 [3910 2.44 [3915 1.58 [19 34] [17 60]] [5 66]] [19 66]] [17 52]]] [494 3.04 [5 37] [7 50]]] [19 83]] [7 90]] [144 0.401 [6584 2.3 [719 2.88 [4533 0.285 [5693 4.64 [5520 0.218 [7665 13 [19 33] [19 81]] [19 100]] [38 62]] [38 42]] [38 33]] [38 62]] [5654 0.259 [19 69] [19 100]]]] [5693 1.64 [14 61] [14 100]]] [2591 0.768 [1025 5.21 [929 3.68 [23 15.2 [7 24] [2259 4.2 [14 63] [14 100]]] [17 66]] [17 83]] [17 69]]] [1704 0.0974 [5907 0.544 [7354 0.867 [134 0.4 [5804 0.328 [7598 4.32 [7598 2.17 [6228 1.87 [4630 0.382 [5812 1.4 [429 26.4 [17 39] [6732 0.541 [602 2.89 [17 95] [17 83]] [6588 2.4 [14 37] [19 33]]]] [17 79]] [14 77]] [14 90]] [14 56]] [19 90]] [3008 2.04 [35 62] [35 84]]] [3519 0.601 [6358 0.933 [3955 1.57 [957 4.37 [7244 0.695 [4571 1.31 [7188 0.957 [5393 0.666 [6396 4.88 [1078 15.6 [17 87] [17 50]] [17 100]] [17 60]] [17 62]] [17 70]] [4895 1.63 [17 100] [17 83]]] [38 55]] [17 62]] [6576 1.17 [35 100] [17 50]]] [19 100]]] [7 57]] [19 91]] [5883 17 [2752 4.77 [14 33] [3317 3.43 [4324 0.936 [3734 0.712 [6396 1.92 [17 100] [7588 6.21 [5462 1.11 [4414 3.37 [1078 1.01 [929 1.95 [17 100] [731 6 [17 100] [17 83]]] [17 100]] [17 90]] [17 100]] [17 81]]] [17 75]] [17 83]] [6584 4.08 [17 50] [17 66]]]] [17 57]]]] [4338 2.71 [1745 3.27 [2610 0.455 [3014 1.12 [5251 0.107 [5812 7.08 [2913 2.72 [5157 0.471 [3905 5.2 [17 75] [929 5.63 [1783 2.01 [17 50] [18 41]] [19 100]]] [19 68]] [7 88]] [17 91]] [17 83]] [4851 3.5 [5905 0.681 [5297 0.996 [2826 3.43 [3563 1.86 [7665 12.9 [17 86] [17 62]] [19 50]] [2259 1.27 [2968 0.79 [6184 0.206 [3519 1.46 [5878 0.178 [5952 0.169 [19 62] [17 50]] [17 66]] [19 90]] [17 57]] [19 100]] [19 100]]] [3113 0.597 [19 100] [19 80]]] [5693 1.18 [731 6.81 [19 100] [19 66]] [7595 0.212 [19 90] [19 100]]]] [19 36]]] [5439 0.879 [134 2.35 [719 1.26 [4414 1.9 [19 97] [19 85]] [19 100]] [5154 0.708 [17 50] [6724 2.91 [5007 0.335 [19 83] [19 100]] [19 75]]]] [19 85]]] [17 87]] [1899 6.26 [17 33] [17 85]]]]] [1783 20.5 [1400 1.01 [7722 3 [25 80] [14 57]] [5412 0.465 [7665 5.81 [25 98] [25 100]] [25 100]]] [25 61]]] [1919 4.55 [6231 0.987 [4629 0.879 [2426 0.654 [3928 1.43 [4457 3.9 [7428 2.65 [1517 2.36 [3604 2.14 [791 3.06 [5 91] [2570 6.98 [2968 4.2 [6152 2.34 [3742 0.613 [112 2.47 [4533 4.38 [1210 8.65 [5753 9.62 [2752 4.17 [5 77] [1783 1.48 [1980 2.76 [3591 1.36 [913 5.96 [3435 5.5 [4071 1.05 [7512 5.08 [5 71] [3058 0.797 [5155 0.397 [5753 4.83 [5 100] [5 85]] [5 100]] [5 83]]] [5 100]] [5 50]] [5 80]] [5 77]] [1993 0.639 [7381 0.879 [5753 1.68 [5 94] [5 100]] [5 100]] [5 100]]] [2752 23.4 [5 94] [5 60]]]] [5 44]] [5 75]] [5 50]] [5 40]] [5 60]] [5 28]] [2628 15.6 [957 4.21 [5 53] [5 50]] [5 96]]] [5 33]]] [16 62]] [791 5.32 [5 46] [5 91]]] [5 37]] [5 50]] [7413 1.73 [7009 14 [5694 0.437 [3058 3.57 [5430 0.539 [134 2.1 [4805 0.206 [5 67] [5 25]] [5 88]] [1078 2.96 [5 86] [5 100]]] [5 57]] [12 45]] [12 50]] [5 31]]] [12 85]] [12 100]] [12 45]] [6230 5.14 [5 85] [5 100]]]] [7705 0.381 [7600 0.976 [721 1.02 [3733 0.787 [4045 1.98 [6076 0.188 [5160 2.93 [2752 33.7 [7566 1.21 [7512 29.3 [3928 0.879 [5034 1.54 [7381 0.329 [32 58] [16 30]] [32 77]] [6575 2.23 [3798 0.91 [5999 2.12 [663 15.6 [1584 0.866 [2906 0.244 [5729 0.315 [2993 0.629 [5316 3.62 [5510 3.76 [4766 0.471 [5198 2.26 [2199 1.98 [435 1.66 [7682 0.325 [7192 0.253 [1011 4.85 [3929 5.56 [17 88] [17 100]] [17 75]] [17 100]] [17 57]] [17 57]] [17 81]] [17 100]] [17 100]] [17 50]] [17 62]] [17 57]] [17 100]] [17 100]] [723 1.73 [17 79] [17 50]]] [6599 1.31 [1704 8.13 [19 53] [17 80]] [19 57]]] [17 50]] [17 33]] [17 42]]] [32 38]] [6581 0.288 [17 64] [134 3.01 [978 9.01 [17 77] [17 60]] [17 100]]]] [36 38]] [14 88]] [7742 3.07 [3014 4.82 [2005 3.15 [1063 6.63 [1262 0.336 [3929 0.909 [17 41] [7428 1.55 [1884 4.33 [7502 0.162 [1239 5.91 [4158 2.11 [1564 1.01 [7241 3.56 [5300 2.12 [791 17 [1030 2.9 [7441 0.315 [1888 0.283 [6396 8.43 [17 100] [17 93]] [17 100]] [17 100]] [17 87]] [17 80]] [17 85]] [695 2.58 [17 85] [17 100]]] [17 60]] [17 91]] [7722 5.09 [17 100] [17 77]]] [17 100]] [14 37]] [17 75]]] [17 66]] [17 66]] [17 53]] [17 44]] [17 63]]] [4851 1.14 [5637 0.639 [19 58] [38 42]] [17 80]]] [3317 0.945 [2826 2.8 [17 91] [6729 0.294 [429 24.9 [19 54] [19 66]] [19 100]]] [19 100]]] [14 69]] [4369 8.45 [32 100] [32 55]]] [602 1.17 [32 88] [32 100]]]] [3287 6.62 [7 100] [7 90]]]] [4495 0.185 [2517 0.775 [4189 0.961 [6578 0.792 [4214 2.42 [2807 0.38 [978 3.27 [1713 2.62 [7672 1.51 [2846 1.91 [5484 0.467 [6853 14.9 [7382 0.766 [721 0.0847 [221 5.24 [5999 3.66 [7354 0.917 [1429 19.3 [6260 5.26 [36 47] [36 100]] [1997 7.08 [7210 9.02 [4288 0.766 [7677 4.62 [6091 6 [859 0.515 [1980 10.7 [7457 0.327 [1429 37.9 [16 1.14 [3431 1.05 [901 7.31 [751 1.12 [1025 1.23 [20 3.42 [2421 1.72 [5267 10.2 [36 93] [36 71]] [36 42]] [36 100]] [30 57]] [36 100]] [36 70]] [36 100]] [36 100]] [144 3.72 [2902 11.3 [36 97] [36 83]] [36 92]]] [36 100]] [36 70]] [30 70]] [36 62]] [36 50]] [36 64]] [36 50]] [36 50]]] [2753 2.66 [361 1.75 [1783 0.336 [2763 0.402 [1025 3.97 [2273 0.541 [4025 0.319 [4185 0.6 [774 1.68 [4612 0.45 [6134 0.522 [36 100] [36 80]] [36 100]] [36 92]] [36 100]] [36 100]] [36 100]] [36 80]] [36 100]] [36 100]] [36 92]] [1181 2.48 [3005 0.736 [5475 0.351 [6865 0.724 [36 85] [36 100]] [36 100]] [36 100]] [36 100]]]] [36 50]] [4154 0.975 [112 1.81 [5692 3.51 [30 91] [30 62]] [30 62]] [30 50]]] [6735 0.278 [6828 1.25 [2764 0.106 [731 0.371 [2337 8.1 [7305 2.22 [36 100] [36 85]] [36 94]] [36 90]] [36 100]] [36 83]] [36 66]]] [24 92]] [2628 2.81 [610 3.35 [4312 0.246 [3101 3.36 [2266 6.37 [7559 3.76 [1753 10.3 [1679 1.08 [975 1.13 [688 8.3 [7698 0.352 [6732 26.8 [5693 17.3 [2314 2.66 [683 2.57 [7382 1.92 [1601 2.82 [4612 0.497 [7695 1.36 [1769 10.3 [1174 0.945 [1239 11.6 [7241 2.48 [1 0.312 [7185 10.6 [1025 12.3 [1025 5.66 [5454 14.4 [4369 7.36 [5480 5.1 [5459 0.637 [7583 3.39 [631 9.09 [5267 16.1 [663 1.53 [5472 2.5 [7449 5.26 [896 6.25 [4851 6.66 [36 82] [36 100]] [7591 9.38 [36 100] [36 93]]] [36 57]] [36 100]] [3011 9.8 [7106 1.46 [5472 1.53 [36 90] [36 100]] [36 100]] [36 100]]] [36 84]] [36 100]] [36 100]] [36 100]] [22 40]] [36 80]] [36 92]] [36 66]] [24 62]] [16 40]] [5472 0.967 [899 1.58 [36 88] [36 100]] [36 100]]] [2434 0.994 [5192 1.01 [36 98] [36 100]] [36 100]]] [24 33]] [36 100]] [31 45]] [30 66]] [36 100]] [36 57]] [24 100]] [31 100]] [24 66]] [24 61]] [24 77]] [6852 0.426 [1408 1.34 [36 100] [7149 2.94 [36 100] [36 83]]] [36 100]]] [24 50]] [28 86]] [30 63]] [36 30]] [31 100]] [31 93]] [24 86]] [36 95]] [28 71]] [7106 2.2 [6732 11.2 [7512 18.2 [7373 1.6 [31 52] [36 100]] [31 86]] [36 100]] [36 100]]]] [2593 0.467 [18 66] [18 62]]] [7374 0.361 [5763 0.395 [1652 0.607 [22 52] [22 100]] [36 100]] [36 100]]] [24 80]] [31 100]] [2813 1.39 [2753 3.4 [4690 1.55 [7529 2.37 [5482 0.227 [3896 1.44 [2962 1.03 [4546 0.825 [2752 12.9 [7512 4.76 [26 42] [5693 0.971 [6077 1.88 [7701 1.08 [31 56] [31 100]] [31 100]] [24 53]]] [7354 0.647 [6732 3.92 [1047 0.655 [24 50] [24 100]] [24 61]] [36 71]]] [36 100]] [31 100]] [6173 2.13 [31 71] [31 100]]] [791 9.05 [18 44] [16 40]]] [1239 7.56 [24 88] [24 100]]] [8 100]] [36 94]] [18 77]]] [549 0.257 [859 1.25 [22 66] [22 100]] [22 100]]] [7693 4.41 [4191 1.53 [308 4.18 [978 0.986 [896 4.35 [896 0.678 [6853 9.8 [2795 4.18 [36 71] [24 100]] [24 96]] [24 70]] [24 100]] [24 100]] [24 71]] [24 100]] [24 75]]] [7693 1.58 [7461 1.08 [791 4.69 [3936 2.23 [2259 20.3 [31 66] [31 100]] [31 100]] [7665 16.8 [31 97] [31 100]]] [31 71]] [31 83]]] [978 7.18 [7722 14.3 [1 4.83 [4338 3.09 [24 60] [3644 1.29 [6265 3.93 [1602 4.3 [6386 5.34 [221 0.48 [2763 11.2 [7376 0.968 [5198 0.635 [4816 0.994 [5609 0.309 [2832 10.6 [7591 1.06 [7566 0.849 [24 99] [24 100]] [24 100]] [24 90]] [24 100]] [24 100]] [24 100]] [24 100]] [24 72]] [24 100]] [24 77]] [24 94]] [2341 2.22 [24 88] [24 100]]] [3644 3.26 [24 76] [5789 0.508 [24 80] [24 100]]]]] [36 87]] [24 40]] [24 81]]] [3207 1.32 [6471 1.27 [3102 1.42 [4492 1.15 [3642 1.16 [4957 2.35 [1035 2.62 [4299 8.14 [6994 0.313 [4027 1.15 [2456 5.72 [1738 0.195 [5719 1.86 [2515 6.1 [5694 6.73 [6342 3.82 [2628 3.64 [6869 1.12 [4154 33.5 [24 100] [24 90]] [24 100]] [24 85]] [24 88]] [24 85]] [24 80]] [24 100]] [24 100]] [24 75]] [4214 4.67 [24 100] [24 83]]] [24 85]] [24 66]] [1738 4.64 [1888 4.03 [24 86] [24 100]] [24 75]]] [24 88]] [308 1.78 [4518 5.03 [2456 0.467 [7722 0.208 [2454 0.38 [24 83] [24 100]] [24 100]] [24 66]] [24 64]] [24 52]]] [1035 0.316 [1025 17.6 [5694 1.1 [2526 5.77 [24 90] [24 100]] [24 77]] [19 69]] [19 63]]] [7566 2.22 [24 100] [24 90]]] [5007 1.78 [24 78] [19 60]]] [19 75]]] [6266 1.59 [7419 0.219 [1980 6.66 [4279 5.43 [1572 0.6 [6855 1.77 [24 100] [24 83]] [24 100]] [24 100]] [24 93]] [24 100]] [7734 0.407 [3660 2.53 [2518 0.929 [434 0.367 [6853 29.6 [24 100] [24 57]] [24 100]] [24 100]] [24 85]] [19 42]]]]] [5978 0.39 [178 3.92 [4967 0.574 [6397 0.467 [6177 5.36 [731 12.8 [7185 0.736 [721 0.949 [1400 0.971 [6945 2.59 [5692 8.8 [1001 1.27 [31 95] [31 100]] [31 75]] [31 100]] [31 100]] [31 100]] [31 100]] [2628 4 [31 100] [31 70]]] [25 80]] [31 100]] [31 100]] [31 53]] [31 100]]] [4373 1.35 [5820 0.566 [867 1.26 [7241 1.01 [5040 10.9 [6621 6.9 [5137 0.884 [7505 4.42 [7092 2.89 [7271 1.05 [3027 18.2 [13 87] [13 100]] [13 62]] [13 100]] [2 50]] [13 60]] [13 100]] [2 33]] [13 100]] [13 100]] [2 94]] [13 100]]] [2262 3.03 [383 0.119 [7373 2.6 [2628 0.184 [7675 0.289 [7520 0.699 [5679 2.2 [4569 0.688 [2268 12.6 [6717 1.05 [2091 0.654 [4889 7.82 [6287 0.5 [2419 0.994 [4514 0.521 [6 68] [6 100]] [6 100]] [2282 2.67 [6424 5.55 [7153 4.62 [6 100] [6 91]] [6 88]] [6 83]]] [2599 2.94 [1268 6.52 [7545 22.7 [7505 4.88 [434 7.2 [2275 3 [7419 29.1 [4889 8.57 [6 41] [896 2.08 [6674 23.7 [2549 1.02 [2223 2.18 [6 79] [6 88]] [6 93]] [6 71]] [6 35]]] [6 55]] [6 96]] [6 100]] [7512 14.7 [6 100] [16 57]]] [6 97]] [6 58]] [4822 4.56 [7580 1 [6 100] [6 60]] [6 53]]]] [16 20]] [36 71]] [16 70]] [36 66]] [4 66]] [1078 13.2 [18 44] [36 50]]] [5595 2.27 [6287 5.75 [5349 0.583 [7421 18.7 [2126 0.608 [5963 5.66 [2549 0.276 [2030 1.27 [6 92] [6 100]] [6 100]] [221 4.76 [6 100] [6 80]]] [6 100]] [6 72]] [5349 1.09 [6 63] [5962 2.98 [6 75] [6 100]]]] [7512 25.6 [5090 8.08 [1268 0.354 [6 60] [6 90]] [16 69]] [6 91]]] [6 66]]] [2730 0.39 [5090 1.3 [1783 1.57 [37 0.978 [7734 0.855 [7343 0.216 [896 0.517 [7505 0.659 [4731 0.469 [6 51] [6 94]] [6 100]] [6 33]] [16 35]] [18 83]] [16 70]] [5438 0.302 [2585 0.759 [6831 1.45 [75 0.424 [6933 0.861 [6 30] [2644 1.82 [16 80] [6 42]]] [16 90]] [5900 2.67 [16 86] [16 60]]] [6 76]] [26 66]]] [4713 2.13 [2396 0.0671 [7679 1.57 [6 90] [16 50]] [6 93]] [6287 1.49 [6 90] [6 100]]]] [187 4.07 [7 100] [7 83]]]] [4820 0.47 [36 66] [36 70]]] [187 1.9 [5692 1.24 [18 78] [18 100]] [6 35]]] [2628 4.09 [5381 2.05 [0 7.43 [299 21.6 [2585 0.636 [2005 0.0937 [2569 11.8 [2611 11.4 [1062 0.784 [1454 2.02 [6923 2.73 [6424 3.74 [1311 7.22 [7405 0.243 [1883 10.4 [2611 0.849 [5093 4.33 [6514 0.808 [2262 52 [5747 3.17 [2939 1.95 [5099 6.17 [6 94] [6 100]] [6 100]] [6 100]] [6 85]] [6 100]] [6 90]] [6 100]] [6 83]] [6 100]] [6 85]] [2142 3.39 [6 91] [6 81]]] [2436 9.09 [2210 0.555 [6 86] [6 100]] [6 63]]] [6 57]] [6 61]] [6 58]] [6 55]] [1335 0.561 [2275 6.51 [6 83] [6 100]] [6 58]]] [5778 5.81 [5962 0.381 [1078 3.43 [6100 3.16 [6 100] [6 70]] [6 81]] [5099 11.6 [4891 15.1 [1366 1.81 [6 100] [1283 2.49 [2370 0.485 [2412 6.77 [6 83] [6 85]] [6 100]] [6 100]]] [6 90]] [6 66]]] [6100 1.42 [6 85] [6 66]]]] [6 76]] [6 70]] [6 81]] [6406 2.73 [6074 0.488 [5999 0.152 [2955 12.5 [1895 0.544 [6 76] [6 50]] [16 60]] [6 100]] [6 33]] [16 58]]]]] [6260 21 [429 37.9 [13 100] [899 4.24 [13 98] [13 100]]] [13 71]]] [4959 0.56 [144 1.14 [4218 0.75 [2957 1.2 [3653 0.559 [7365 0.726 [5978 0.365 [6911 2.71 [2259 4.55 [6581 0.831 [639 1.56 [731 5.04 [4851 0.299 [6984 0.489 [1783 12 [7241 4.45 [2966 2.92 [3130 18.7 [4930 0.909 [5969 18.2 [223 9.77 [7702 0.262 [3130 2.93 [688 20.4 [7414 0.793 [7032 0.75 [7544 3.72 [139 4.4 [7385 1.07 [3905 1.26 [6925 2.07 [6537 7.81 [248 5.88 [4235 6.33 [7413 1.09 [2820 0.117 [1089 5.64 [6076 11.8 [4585 8.16 [2526 12.9 [2 41] [5769 1.14 [2553 4.87 [5819 2.33 [896 13.9 [4154 2.41 [2526 39 [2 80] [4 54]] [2 91]] [2 69]] [4 58]] [2 73]] [2 100]]] [4 37]] [2 72]] [2 55]] [2 100]] [2 76]] [20 66]] [25 36]] [2 96]] [2 40]] [36 37]] [7 42]] [2 100]] [4832 45.4 [2628 10.4 [4279 3.7 [7381 23.6 [2 69] [2 83]] [2 100]] [2 100]] [2 66]]] [4345 15.5 [5820 1.37 [5771 2.46 [573 2.72 [2 89] [2 100]] [2 100]] [2 100]] [2 81]]] [1253 9.68 [1909 0.984 [7413 9.13 [6537 0.536 [1899 2.35 [2 93] [2 100]] [2 100]] [2 93]] [2 87]] [2 81]]] [4 63]] [2 31]] [1078 28.2 [1025 5.94 [6186 0.363 [2 85] [2 100]] [2 100]] [2 85]]] [2 50]] [12 50]] [2 46]] [13 77]] [4 100]] [4 73]] [4594 3.13 [4 50] [4 83]]] [4 100]] [4 48]] [1078 7.28 [6230 2.56 [2 36] [17 25]] [7327 1.12 [7413 1.53 [4 53] [2 63]] [4 100]]]] [4 100]] [17 67]] [227 0.561 [5789 1.6 [5833 0.366 [5467 0.843 [2260 5.42 [6982 0.502 [6582 1.42 [5812 1.01 [328 12.9 [4601 0.956 [2143 2.97 [7414 0.351 [312 6.05 [4833 7.65 [31 22] [2 72]] [2 55]] [32 57]] [12 30]] [8 62]] [31 53]] [2939 9.23 [1094 0.766 [141 1.2 [4253 1.99 [7292 11.3 [2 55] [2 72]] [2 100]] [2 100]] [4 57]] [4 45]]] [4 100]] [4 62]] [17 75]] [12 100]] [8 70]] [24 81]] [24 100]]] [4 95]] [31 100]] [1078 9.78 [4 72] [4 96]]] [227 0.457 [312 0.962 [24 85] [24 58]] [24 80]]] [31 94]] [6544 0.695 [7253 1.21 [2968 1.34 [5383 1.25 [6989 0.928 [7030 1.93 [4414 0.465 [7665 25.7 [5819 0.574 [4 23] [4 68]] [2 71]] [4832 4.66 [4 50] [4 85]]] [4 80]] [2 100]] [17 87]] [5 62]] [19 80]] [17 94]]] [1584 0.157 [6186 0.425 [3056 0.253 [2270 1.3 [1644 1.42 [4930 2.61 [2826 0.175 [7241 1.09 [6230 1.59 [7176 1.24 [6977 8.11 [4832 4.07 [6184 1.14 [5820 0.325 [1899 3.65 [2 60] [4 73]] [4992 0.65 [221 1.91 [2 50] [2 88]] [2 100]]] [5819 3.75 [312 6.92 [4768 5.55 [3671 0.724 [5771 0.33 [2 57] [999 2.84 [791 12.6 [2 100] [2 81]] [2 88]]] [2 100]] [2 54]] [2 50]] [2 50]]] [913 0.968 [5574 23.8 [7677 6.07 [328 22.6 [5812 8.04 [5969 3.64 [4929 0.367 [4218 5.1 [719 6.58 [567 7.08 [5819 4.31 [662 2.5 [5368 4.48 [999 0.46 [134 0.709 [1906 1.25 [2 92] [2 100]] [2 100]] [2 100]] [896 4.93 [2 83] [2 100]]] [2 71]] [2 66]] [2 87]] [2 86]] [2 66]] [2 75]] [36 33]] [2259 2.1 [5883 20.4 [1173 5.38 [2553 11.6 [5411 0.724 [6184 0.803 [2 98] [2 100]] [2 100]] [2 83]] [665 1.09 [4226 6.62 [2 96] [2 71]] [2 100]]] [2 71]] [7594 0.846 [2 90] [2 100]]]] [2 75]] [2 66]] [2 70]] [2 100]]] [15 62]] [2 30]] [13 40]] [2 38]] [5155 1.02 [1190 0.175 [4 83] [4 42]] [19 66]]] [2628 9.11 [6537 3.36 [5769 1.37 [24 55] [4 85]] [4995 1.53 [2 100] [2 87]]] [5576 11 [2 66] [2 77]]]] [4 66]] [24 50]] [5 58]] [7006 0.332 [4761 1.03 [4838 1.47 [4324 11.5 [4968 1.61 [1047 6.39 [3670 3.76 [7737 1.42 [2088 1.98 [5343 2.02 [7665 4.47 [4833 1.39 [2 100] [2 90]] [1075 1.62 [2 100] [4279 3.85 [2 100] [2526 16.1 [2 83] [2 100]]]]] [2 88]] [2 85]] [2 90]] [2 66]] [2 85]] [2 80]] [2 85]] [2 83]] [2 66]] [2 50]]] [2902 0.652 [17 37] [4 55]]]] [2902 7.11 [1614 1.09 [1025 5.33 [4 100] [4 97]] [4 81]] [4 75]]]] [1909 7.75 [2959 7.47 [2011 6.18 [2100 3.75 [808 1.97 [5812 3.62 [1075 2.15 [1723 4.02 [4332 2.4 [7251 1.21 [228 0.229 [5368 25.8 [1906 0.701 [939 1.86 [4 97] [4 60]] [4 100]] [4 71]] [4 100]] [4 90]] [4 80]] [4 66]] [4 57]] [2256 0.181 [2526 8.09 [4 83] [2993 0.273 [5655 5.37 [2753 10.6 [527 0.244 [896 19.1 [2939 0.301 [1783 4.66 [731 17.6 [4 100] [4 90]] [4 83]] [4 100]] [4 83]] [4 100]] [4 85]] [4 87]] [4 100]]] [4 88]]] [4 75]] [4 57]] [4 75]] [4 77]] [4 75]]] [3677 1.52 [4968 0.206 [5509 10.8 [5482 0.548 [3436 2.52 [5673 10.5 [5386 0.541 [5368 6.71 [2470 3.08 [2966 2.45 [1031 0.501 [6743 0.408 [6328 0.42 [1995 2.08 [7149 5.19 [7141 2.18 [1497 5.39 [3291 12.5 [7566 8.07 [4746 0.811 [3905 14.2 [5641 4.79 [6445 4.62 [602 2.54 [6311 5.97 [5385 0.793 [3829 2.45 [4109 1.37 [4571 3.46 [2939 13.4 [6883 6.44 [1927 2.31 [1480 0.184 [2752 1.75 [5 93] [5413 0.253 [2826 4.33 [5 100] [3317 0.605 [2536 4.28 [4154 8.93 [7588 0.272 [7708 0.679 [7354 1.86 [5 98] [5 100]] [5 100]] [5 100]] [5 90]] [5 90]] [5 100]]] [5 100]]] [5 100]] [5 88]] [5 90]] [5 83]] [5 88]] [6334 3.13 [5 57] [5 100]]] [5 62]] [5 86]] [3313 3.76 [5 78] [5 100]]] [2968 0.483 [7188 1.08 [5 80] [5 91]] [5 100]]] [5 77]] [5 62]] [5 50]] [5 66]] [736 7.92 [6866 9.09 [5 57] [5 87]] [5 100]]] [5 42]] [5 62]] [5 80]] [5 71]] [5 55]] [5 62]] [5 66]] [5 50]] [5 61]] [4 37]] [5 71]] [5 70]] [5 42]] [5 60]] [18 40]] [19 57]] [5 64]] [19 50]]] [5198 0.506 [2657 0.276 [3653 1.1 [4718 0.126 [4519 0.914 [670 0.124 [929 2.11 [2740 0.707 [7016 0.403 [134 9.43 [1089 5.62 [2470 1.79 [2658 0.412 [899 1.03 [4253 0.367 [6977 0.852 [5812 3.25 [4414 2.69 [7210 2.77 [1919 3.54 [2526 12.3 [695 3.3 [1429 3.03 [2 60] [26 44]] [12 41]] [7665 9.4 [2 100] [2 53]]] [2 86]] [1899 1.59 [4 40] [4 75]]] [4 33]] [1239 8.46 [5887 3.96 [2259 11.7 [5655 0.728 [5411 1.99 [2 89] [2 76]] [2 100]] [2 50]] [2 75]] [4 44]]] [2 43]] [2241 1.78 [1094 0.886 [1993 2.95 [2 100] [2 80]] [1906 0.78 [2 100] [2 80]]] [2 72]]] [36 50]] [4 93]] [7520 2.12 [4 89] [4 71]]] [4 57]] [2616 1.78 [2 83] [6732 5.71 [2 100] [2 83]]]] [7544 0.358 [6537 0.64 [2 78] [2 100]] [2 100]]] [4 100]] [4705 0.918 [3959 0.596 [6581 0.513 [2470 1.48 [5848 0.528 [2574 0.184 [112 1.72 [6735 0.285 [4586 3.36 [17 2.4 [939 5.76 [682 4.31 [978 12.8 [1051 1.74 [1083 1.02 [643 0.99 [2939 1.27 [567 7.28 [7512 6 [2526 19.1 [2 85] [2 55]] [6732 2.38 [2 80] [2 90]]] [2 80]] [5574 3.54 [4 57] [2 58]]] [2 100]] [2 50]] [2 100]] [5461 4.21 [2 100] [2 87]]] [2 70]] [2 30]] [7127 9.2 [2 96] [2 100]]] [2 42]] [1072 3.88 [2 100] [2 66]]] [2 40]] [2567 0.189 [6991 0.113 [6653 3.5 [2 100] [2 62]] [2 100]] [2 100]]] [4 80]] [2616 5.68 [4 91] [4 66]]] [4 44]] [2 50]] [4 100]]] [1883 6.85 [145 2.33 [1640 2.09 [6537 4.81 [2628 2.76 [2 90] [2 63]] [695 2.41 [2 100] [2 91]]] [4159 0.251 [7568 0.124 [1911 2.2 [2 100] [2 71]] [2 100]] [2 100]]] [2 66]] [2 83]]] [24 100]] [7566 1.17 [7009 0.186 [2526 23.4 [4 90] [2 50]] [4 54]] [4 75]]] [24 92]] [896 5.14 [4 85] [4 100]]] [4184 13.4 [6983 0.536 [178 3.58 [2961 0.245 [5605 2.41 [7414 0.82 [7512 21.7 [7512 10.2 [377 0.555 [2553 0.266 [1995 2.91 [2 100] [2 66]] [2 100]] [2 75]] [4876 0.31 [4533 1.77 [7700 2.2 [1207 2.92 [1025 4.03 [1911 0.47 [2 87] [2 71]] [1899 7.29 [2 100] [2 91]]] [2 50]] [2081 0.883 [2 85] [2 71]]] [2 60]] [2 50]]] [2 46]] [6186 0.864 [1025 2.27 [7169 0.707 [2 100] [2 60]] [2 100]] [2 100]]] [2 54]] [4 100]] [2 33]] [4 93]] [2570 2.77 [2 53] [2 66]]]]]] [2618 1.17 [3921 98.1 [5799 6.84 [3027 6.55 [6865 0.618 [3158 0.532 [7505 0.186 [7428 0.919 [2241 0.694 [5637 1.02 [3907 12.8 [3088 10.6 [4063 1.04 [7449 0.343 [2752 53.6 [3360 4.39 [2775 2.56 [3715 4.27 [3905 0.271 [1980 0.238 [37 99] [37 100]] [37 100]] [37 95]] [37 88]] [37 80]] [37 66]] [37 100]] [37 100]] [37 84]] [37 83]] [37 75]] [37 85]] [37 83]] [37 50]] [37 100]] [3127 9.26 [37 100] [3294 0.487 [3982 5.62 [836 1.14 [37 99] [37 100]] [37 100]] [37 100]]]] [37 66]] [37 57]] [37 50]] [1475 0.6 [37 81] [37 57]]]] [1600 0.0611 [2562 1.03 [4673 1.9 [4338 8.59 [2951 0.952 [6809 0.58 [5264 0.34 [4867 0.164 [6416 0.131 [708 0.08 [6853 0.797 [569 1.12 [5034 1.03 [5047 0.649 [3003 0.134 [7516 0.294 [7512 0.214 [5234 0.0441 [2550 0.146 [7634 0.0453 [6665 0.178 [4114 10.8 [7176 1.36 [786 0.581 [3928 1.24 [5211 0.737 [5972 5.44 [2461 0.417 [526 0.207 [3332 1.03 [4398 2.66 [3716 0.249 [5040 3.92 [2526 4.15 [2081 2.02 [4501 0.417 [976 0.535 [3125 0.394 [5995 0.116 [5564 0.143 [1400 3.8 [663 0.0287 [968 0.585 [3262 0.682 [4538 8.99 [392 2.29 [2849 9.24 [3454 0.813 [802 1.94 [3884 3.92 [3359 5.9 [6484 0.241 [5539 2.39 [5941 0.134 [5481 1.27 [2808 1.17 [3295 3.79 [673 1.03 [4631 4.19 [3308 8.83 [3634 0.761 [6471 0.34 [6124 7.89 [5732 0.0623 [6647 0.106 [7357 1.14 [3921 0.928 [915 6.03 [3294 6.48 [5554 1.08 [233 1.77 [5809 11.9 [2701 0.44 [820 0.581 [4159 0.281 [6063 0.315 [6340 2.32 [3779 9.27 [6900 8.93 [6461 0.374 [6899 5.99 [5254 1.2 [5056 2.67 [1913 22.4 [1036 0.675 [5891 0.258 [695 3.91 [757 1.15 [2331 1.99 [248 9.32 [6848 1.37 [6230 1.81 [1700 1.07 [6606 0.548 [685 1.68 [957 36.9 [1888 0.925 [3073 2.18 [1623 0.867 [3747 1.79 [1 11] [11 95]] [11 100]] [26 88]] [328 14.7 [2897 12.7 [6544 8.19 [4 11] [14 50]] [18 44]] [18 24]]] [963 14.3 [5650 2.09 [4794 2.86 [6465 7.8 [27 76] [27 100]] [27 90]] [27 83]] [27 100]]] [5314 4.95 [1247 0.924 [6310 0.519 [2987 6.63 [4517 3.9 [23 22] [23 85]] [1429 19.1 [23 71] [23 100]]] [35 35]] [35 85]] [19 85]]] [7449 8.03 [1899 7.57 [28 73] [28 57]] [28 38]]] [25 100]] [2752 6.29 [5776 1.06 [429 2 [34 31] [1429 1.06 [3 14] [5 12]]] [4946 0.949 [30 92] [30 100]]] [144 3.33 [647 4.26 [1023 0.967 [3008 8.72 [1557 1.86 [685 9.14 [3798 7.95 [17 22] [38 52]] [7 47]] [17 33]] [30 70]] [7 38]] [17 39]] [5 28]]]] [6920 3.87 [328 2.27 [5160 2.41 [3514 1.39 [7488 5.38 [35 52] [38 100]] [35 75]] [38 50]] [35 78]] [35 41]]] [4392 6.67 [5073 4.59 [5495 3.07 [6784 7.19 [427 19.2 [2259 3.36 [7197 17.6 [4657 12.7 [978 0.462 [423 2.99 [33 36] [26 100]] [25 43]] [1 86]] [15 40]] [1684 7.38 [6998 1.14 [660 6.17 [1025 9.13 [33 27] [15 50]] [15 87]] [29 100]] [7210 7.56 [24 85] [24 100]]]] [1 90]] [31 100]] [2 51]] [29 92]] [26 90]]] [7354 2.7 [5679 3.94 [3908 3.82 [32 40] [32 89]] [32 100]] [36 52]]] [3 100]] [4677 1.64 [6364 4.4 [1567 2.3 [4781 19.2 [5619 16.8 [714 2.96 [5194 2.11 [6982 0.838 [4478 24.9 [5049 9.58 [2029 6.68 [7288 3.82 [7254 1.87 [28 14] [28 41]] [12 100]] [28 66]] [21 53]] [22 70]] [4 80]] [28 80]] [22 100]] [9 93]] [11 66]] [28 80]] [328 3.65 [28 66] [28 100]]] [36 100]]] [1436 4.17 [1959 3.48 [2178 7.6 [6155 2.08 [5844 9.06 [23 17.5 [3898 1.04 [2199 7.15 [3008 0.371 [7428 6 [5588 0.165 [2178 0.452 [6296 2.22 [2039 0.624 [17 52] [17 42]] [14 33]] [17 72]] [17 75]] [14 45]] [17 36]] [3 50]] [17 73]] [3 36]] [3 42]] [14 50]] [11 43]] [32 30]] [24 1.88 [1997 22.7 [1265 2.1 [17 25] [3 100]] [1 33]] [3 100]]]] [35 84]] [163 3.23 [978 2.96 [7210 0.963 [2228 0.213 [328 15.3 [7369 10.5 [6776 4.57 [2939 1.25 [3095 11 [2151 14.3 [3705 0.567 [5267 6.39 [1 19] [10 50]] [1 66]] [23 42]] [23 41]] [29 31]] [21 75]] [1429 63.5 [31 81] [15 20]]] [28 18]] [1078 0.986 [29 41] [29 60]]] [15 20]] [23 37]] [30 100]]] [429 1.02 [1448 3.7 [1391 19.6 [7 52] [15 100]] [7 100]] [2469 1.15 [2232 2.39 [3 68] [3 77]] [3 100]]]] [10 100]] [1452 4.92 [2178 1.99 [33 83] [33 60]] [33 44]]] [25 100]] [33 88]] [1078 35.4 [3393 16.5 [37 90] [37 100]] [37 80]]] [2628 6.17 [28 100] [28 83]]] [4768 3.37 [22 100] [3308 0.595 [22 77] [22 100]]]] [2470 11.8 [4159 45.2 [435 0.185 [2001 24.5 [1965 1.09 [2072 0.304 [796 0.808 [7497 3.82 [6997 0.354 [2011 0.739 [4158 8.85 [15 14] [4158 17.9 [28 56] [28 25]]] [2919 0.183 [695 13.9 [2161 6 [4235 8.3 [221 4.55 [5267 1.08 [3072 2.11 [56 1.64 [5528 2.06 [4161 0.627 [29 46] [32 37]] [15 100]] [29 100]] [26 91]] [15 81]] [28 52]] [23 28]] [29 50]] [28 33]] [26 100]]] [29 80]] [23 66]] [29 66]] [26 43]] [29 63]] [23 78]] [15 31]] [29 63]] [15 42]]] [440 0.931 [740 2.79 [820 46.9 [2244 0.577 [7441 1.32 [3953 1.66 [3443 1.55 [5830 7.11 [628 2.54 [1094 1.43 [3273 3.23 [939 1.35 [11 94] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 75]] [11 87]] [11 100]]] [7491 55.2 [144 1.17 [1668 5.38 [4197 12.1 [6799 1.23 [4414 30.1 [695 33.4 [2706 0.829 [6015 0.147 [6719 2.33 [688 3.17 [1995 0.722 [824 10.9 [4768 4.85 [540 4.85 [312 2.56 [794 3.31 [5013 1.9 [24 5.05 [5455 1.82 [6111 3.06 [6406 2.2 [3959 2.56 [2488 16.9 [1769 14.7 [29 60] [15 42]] [13 66]] [29 100]] [29 66]] [29 100]] [29 100]] [15 69]] [29 100]] [29 100]] [29 92]] [29 100]] [29 92]] [15 76]] [6871 5.59 [29 94] [29 71]]] [29 55]] [29 77]] [29 96]] [29 100]] [15 33]] [29 54]] [29 97]] [15 50]] [32 87]] [5454 2.54 [2701 7.68 [29 66] [5007 1.22 [29 93] [29 100]]] [29 100]]] [15 85]]] [4417 2.77 [15 65] [429 24.2 [15 85] [15 100]]]] [4809 7.53 [33 88] [33 97]]] [14 96]] [37 100]] [1783 8.14 [7318 8.47 [1078 3.07 [1312 12 [4154 4.12 [7085 2.35 [21 47] [21 73]] [4574 7.46 [3 76] [3 100]]] [9 84]] [1899 11 [29 26] [29 75]]] [3 100]] [1239 28.5 [3 78] [3 95]]]] [3614 1.86 [37 89] [37 100]]] [3525 15.9 [2029 3.68 [5023 0.577 [35 79] [35 95]] [35 61]] [35 57]]] [30 85]] [7614 1.81 [2828 2.67 [7185 17 [30 6.49 [178 2.7 [4205 2.35 [221 39.1 [6780 2.07 [7340 4.4 [1708 1.37 [3975 0.234 [6524 0.928 [6389 1.59 [6610 7.84 [1445 0.35 [893 6.25 [1888 3.53 [6413 1.85 [957 19.7 [1640 1.29 [4369 13.6 [28 50] [32 92]] [36 55]] [32 50]] [32 40]] [13 47]] [15 100]] [28 37]] [28 50]] [28 100]] [1783 20 [28 84] [28 61]]] [15 92]] [28 100]] [32 87]] [32 57]] [24 55]] [28 97]] [6 52]] [13 100]] [3 28]] [28 100]] [15 100]]] [2939 3.27 [12 68] [12 97]]] [221 13.7 [4920 20.6 [6184 8.25 [429 4.84 [6032 5.72 [2199 8.16 [1429 66.9 [7301 0.47 [1881 0.917 [2143 0.315 [5769 25.7 [6499 0.556 [26 84] [26 87]] [26 63]] [26 100]] [26 90]] [26 53]] [26 51]] [26 61]] [26 66]] [1239 26.9 [26 56] [19 25]]] [26 57]] [26 41]] [3527 19.6 [26 61] [16 70]]]] [3152 15.9 [2259 7.74 [35 82] [35 61]] [35 50]]] [23 8.64 [6017 4.85 [5812 4.02 [3960 4.85 [2470 24.6 [377 5.15 [6333 13.7 [929 3.94 [5732 5.26 [7009 22.7 [5753 9.1 [1980 12.9 [2274 4.5 [4154 22.4 [1980 1.13 [7324 3.88 [4364 12.2 [30 10] [32 100]] [23 100]] [7 17]] [2 21]] [17 87]] [11 19]] [2259 10.8 [23 87] [29 51]]] [12 56]] [15 33]] [23 75]] [29 57]] [23 30]] [30 83]] [29 100]] [4 66]] [29 90]] [4235 2.11 [29 50] [35 57]]]] [328 2.82 [816 1.34 [11 87] [11 100]] [11 100]]] [4603 5.35 [2259 10.5 [2178 7.82 [4655 6.08 [7664 6.93 [6472 0.849 [4279 1.66 [4827 27.1 [6182 6.85 [1696 0.6 [7472 4.88 [6294 6.2 [2963 4.67 [906 1.03 [6230 2.73 [6177 11.6 [178 20.8 [26 64] [25 52]] [25 100]] [26 81]] [26 89]] [26 81]] [25 50]] [38 100]] [26 100]] [25 100]] [26 100]] [35 36]] [26 100]] [26 54]] [1 100]] [1 77]] [4205 5.14 [5412 3.82 [178 1.85 [685 5.05 [1 27] [26 80]] [26 50]] [33 66]] [26 88]]] [19 53]]] [37 89]] [906 7.27 [6074 1.75 [15 89] [15 100]] [15 77]]] [5789 0.536 [2342 0.768 [22 37] [22 100]] [22 100]]] [250 0.444 [6879 0.179 [7314 1.45 [4943 7.89 [6076 1.14 [1659 0.745 [5125 1.57 [4630 22.7 [4916 1.68 [2628 2.17 [6074 6.67 [7428 6.51 [2270 3.14 [3008 4.78 [14 32] [3 37]] [695 3.14 [3 62] [14 100]]] [3 54]] [3 61]] [17 71]] [14 84]] [17 81]] [14 100]] [3576 0.458 [2048 0.253 [23 11.7 [7065 3.41 [1664 7.79 [3308 0.934 [17 29] [17 42]] [17 50]] [5892 4.76 [17 100] [17 54]]] [17 77]] [17 90]] [17 58]]] [5896 0.423 [4635 6.01 [17 89] [17 42]] [17 60]]] [3 100]] [3 77]] [3878 0.306 [17 65] [38 53]]] [2211 0.404 [3576 0.483 [6074 7.45 [5343 0.383 [4279 0.85 [3598 5.89 [5895 0.134 [17 77] [1997 1.49 [17 100] [17 85]]] [17 55]] [14 33]] [17 100]] [17 28]] [17 90]] [14 42]]]] [5295 9.63 [6976 0.402 [5343 3.83 [7428 10.9 [4154 17 [23 98 [4775 0.231 [5812 4.82 [7329 3.76 [1899 7.54 [4557 8.05 [1 3.64 [6914 0.316 [2178 0.521 [1239 15.4 [1634 0.686 [13 64] [7139 8.13 [5541 2.32 [13 98] [13 100]] [13 100]]] [1832 0.805 [5539 21.5 [13 92] [13 100]] [13 100]]] [13 100]] [13 100]] [13 50]] [13 85]] [13 70]] [13 100]] [13 46]] [13 100]] [13 42]] [13 52]] [13 54]] [13 100]] [13 60]] [13 45]]] [4630 4.22 [1769 0.319 [4895 12.3 [4630 1.16 [6031 1.29 [25 75] [25 100]] [25 66]] [3 42]] [4 44]] [2023 2.97 [5999 7.43 [25 88] [25 100]] [25 100]]]] [5637 2.15 [4517 5.05 [3839 1.86 [37 66] [37 100]] [27 50]] [23 40]]] [3989 0.715 [15 78] [15 40]]] [5937 15.2 [5065 1.6 [5928 2.33 [1757 1.17 [505 1.92 [1385 2.26 [4983 1.46 [589 0.907 [5111 10.1 [4810 1 [4948 6.08 [907 6.76 [4154 1.79 [7314 20 [112 0.743 [7411 3.07 [4218 3.5 [696 3.76 [791 30 [614 4.07 [1429 19.8 [1025 17.8 [5851 0.752 [5832 2.96 [688 9.07 [1315 1.41 [6803 1.88 [5368 22 [6181 10.3 [21 46] [9 88]] [21 100]] [9 100]] [9 61]] [21 100]] [9 94]] [21 50]] [21 89]] [9 17]] [9 100]] [7449 1.47 [373 3.31 [585 9.01 [1980 13.9 [4748 1.76 [5534 5.62 [429 119 [2752 2.67 [7139 3.4 [6294 0.68 [4917 15.3 [4478 4.76 [21 33] [9 37]] [21 90]] [21 44]] [21 71]] [15 28]] [806 16.1 [21 75] [21 100]]] [9 88]] [9 75]] [21 29]] [21 100]] [21 100]] [328 28.7 [915 2.86 [791 41.5 [15 33] [538 5.65 [21 28] [21 85]]] [21 70]] [21 100]]]] [9 100]] [15 55]] [15 83]] [9 56]] [3 80]] [4218 3.28 [1985 5.58 [4627 1.1 [3 55] [10 100]] [10 88]] [15 68]]] [5509 7.42 [507 1.72 [7077 2.2 [802 19.1 [21 58] [21 86]] [21 71]] [21 100]] [9 88]]] [3 100]] [645 1.96 [4917 1.9 [21 72] [21 100]] [21 100]]] [3 80]] [1078 5.83 [5972 1.41 [6082 9.26 [21 91] [21 74]] [21 100]] [21 57]]] [9 88]] [9 89]] [5050 0.543 [4703 9.46 [1312 23.8 [6150 5.66 [9 69] [1783 1.21 [9 88] [3 55]]] [9 100]] [21 80]] [9 80]]] [9 77]] [21 100]] [15 100]] [21 82]]] [11 100]] [4133 0.879 [7489 5.38 [2955 18.5 [3107 1.54 [6961 2.54 [1833 4.69 [4431 7.14 [97 0.915 [5174 9.26 [7150 2.92 [5100 0.08 [2714 0.291 [1980 5.04 [233 2.59 [112 1.29 [5491 11.9 [2866 7.07 [178 3.1 [2942 2.87 [4854 5.38 [5171 10.1 [4909 4.57 [90 2.72 [2628 4.99 [221 11.5 [2199 0.618 [7210 2.3 [5673 18.3 [429 11.9 [6537 4.22 [33 32] [33 100]] [29 52]] [16 60]] [19 35]] [18 16]] [33 65]] [1596 4.81 [7419 0.876 [7149 5.18 [1288 9.66 [3027 10 [2869 5.56 [2748 0.693 [2880 18.6 [190 18.4 [4940 7.54 [5626 16.6 [2656 6.28 [1355 4.2 [2259 27.7 [6152 9.62 [5099 9.07 [2983 11.2 [2939 21 [5637 11.5 [2628 29.2 [38 26] [38 46]] [38 75]] [16 33]] [7 23]] [6 40]] [18 70]] [167 9.45 [17 29] [19 42]]] [18 60]] [2656 33.1 [16 53] [16 88]]] [16 87]] [2663 27.8 [16 60] [6133 33.4 [16 100] [16 88]]]] [16 46]] [17 50]] [38 83]] [5673 5.87 [17 30] [16 41]]] [7 37]] [3 55]] [16 37]] [16 67]] [1820 13.5 [6 87] [6 52]]]] [16 80]] [38 100]] [33 84]] [5801 2.99 [2660 2.54 [1355 2.42 [2881 9.29 [16 26] [26 37]] [18 77]] [6 40]] [18 46]]] [6 72]] [178 15.6 [26 60] [2 18]]] [37 44]] [14 92]] [1239 18.3 [5007 2.58 [2849 42.4 [29 50] [1429 17.5 [11 66] [29 50]]] [29 75]] [18 50]]] [33 91]] [4131 4.16 [5209 7.04 [6490 3.36 [2280 8.28 [2752 12.1 [5647 10.5 [2466 5.75 [7726 3.5 [7370 5.81 [6406 1.96 [38 23] [16 28]] [38 84]] [14 44]] [7472 6.64 [16 44] [16 87]]] [33 44]] [29 31]] [33 50]] [29 100]] [2466 7.58 [38 91] [38 66]]] [38 100]]] [1239 13.5 [6134 12.7 [7611 5.62 [7260 20.5 [16 42] [8 25]] [28 100]] [26 47]] [5436 11.8 [16 29] [16 55]]]] [6942 16.5 [4431 1.92 [5010 7.9 [6380 1.93 [4457 1.74 [377 3.58 [6701 3.31 [5724 6.99 [5090 3.09 [1888 5.35 [5435 6.54 [1783 4.25 [4820 4.64 [4622 2.83 [5101 2.53 [5692 4.15 [1896 6.67 [6 36] [18 50]] [17 33]] [2940 38 [62 0.834 [6 100] [6 66]] [6 70]]] [16 42]] [6 60]] [16 34]] [16 42]] [16 63]] [18 36]] [28 40]] [18 75]] [26 63]] [16 54]] [16 100]] [16 50]] [6 87]] [6 77]]] [16 50]] [1429 4.85 [33 84] [33 55]]] [62 0.603 [2075 5.92 [5637 24.5 [6199 0.759 [7370 0.4 [2468 11.4 [38 71] [6824 15.2 [37 69] [5 69]]] [38 72]] [38 43]] [17 38]] [16 77]] [17 83]]] [4528 4.76 [4431 9.47 [2939 7.25 [6 57] [16 52]] [16 51]] [16 80]]] [13 100]] [5600 2.85 [60 12.8 [2644 0.825 [4431 10.7 [2466 2.7 [1078 2.52 [16 53] [16 93]] [1899 4.88 [4895 14.6 [4414 13.1 [5637 9.27 [5100 1.16 [4854 2.99 [6 44] [18 75]] [2466 10 [6 70] [16 57]]] [16 51]] [6 83]] [1783 49.5 [16 76] [16 50]]] [16 90]]] [5626 14 [16 100] [16 85]]] [18 55]] [6 75]] [16 81]]] [1895 1.32 [3582 8.07 [5 87] [5 50]] [5 65]]] [7619 3.65 [6 34] [18 60]]] [89 15.8 [38 97] [38 92]]] [6342 0.898 [38 75] [38 95]]]] [5106 1.92 [7354 1.27 [2913 9.77 [6524 2.07 [1184 0.726 [695 3.98 [1487 3.47 [5290 5.03 [3450 0.627 [384 0.388 [357 0.775 [5024 1.29 [3670 1.02 [3310 4.22 [5586 4.67 [5940 0.337 [383 7.07 [741 0.996 [850 1.07 [7449 19 [3438 1.61 [2306 2.65 [3849 0.174 [5455 2.83 [286 4.97 [4205 0.894 [1888 3.8 [436 3.69 [6300 1.42 [403 16.1 [3342 10.7 [1429 8.71 [2470 14.8 [23 12] [26 55]] [4558 3.61 [7441 5.78 [1679 5.69 [6621 2.02 [6134 0.52 [2260 2.69 [398 20.4 [7255 5.39 [532 1.73 [6031 10.5 [3327 5.05 [2753 1.83 [1084 15.6 [1892 8.2 [6375 1.32 [3130 12.2 [1597 11.3 [377 2.95 [28 24] [28 60]] [28 87]] [8 30]] [15 30]] [18 87]] [8 33]] [19 21]] [11 100]] [22 100]] [28 55]] [18 17]] [685 14.9 [23 40] [23 70]]] [19 41]] [25 31]] [28 75]] [30 100]] [11 66]] [14 83]]] [30 55]] [7 39]] [28 100]] [11 69]] [18 40]] [28 51]] [23 46]] [29 100]] [35 100]] [30 100]] [11 90]] [1078 34.2 [23 71] [23 66]]] [35 89]] [11 100]] [18 32]] [17 92]] [23 100]] [23 91]] [35 88]] [35 100]] [30 100]] [1062 3.57 [7734 8.07 [5838 5.18 [23 62] [35 75]] [18 64]] [23 37]]] [35 75]] [24 48]] [23 100]] [7085 1.18 [6653 2.18 [1899 1.17 [383 2.07 [28 52] [18 37]] [28 79]] [28 92]] [28 70]]] [11 100]] [6652 6.27 [978 1.56 [377 0.935 [5007 2.42 [28 50] [28 100]] [28 88]] [7 28]] [28 64]]] [6882 3.92 [144 9.7 [4414 0.726 [2920 10.3 [2927 8.12 [2914 2.96 [673 9.14 [6757 0.5 [221 6.75 [26 57] [25 63]] [30 87]] [26 90]] [30 77]] [26 52]] [30 100]] [26 83]] [30 100]] [26 100]]] [432 1.63 [1429 53.9 [284 1.89 [18 62] [19 37]] [16 47]] [26 81]]] [28 93]]] [7472 3.39 [4498 2.6 [7242 2.83 [1732 9.95 [3550 7.3 [38 82] [38 100]] [38 66]] [4762 0.85 [5641 0.985 [3819 1.04 [38 83] [38 60]] [2259 54.3 [38 87] [5379 5.66 [7161 0.355 [38 85] [19 42]] [17 50]]]] [17 37]]] [38 100]] [2707 5 [38 80] [1807 6.37 [2405 10.8 [38 100] [38 57]] [38 100]]]]] [6572 0.945 [3292 15.9 [6862 4.23 [4154 0.524 [4015 2.29 [3990 7.94 [807 1.32 [4611 7.2 [939 8.11 [2939 10.6 [1517 3.8 [4101 0.888 [429 1.77 [707 5.26 [37 86] [37 77]] [3492 15.4 [1587 1.47 [28 9.87 [435 3.36 [3498 1.04 [49 0.888 [3511 0.581 [1062 1.8 [3912 1.57 [3831 1.87 [3251 2.62 [37 96] [37 100]] [37 100]] [37 100]] [37 86]] [37 100]] [37 100]] [37 100]] [37 100]] [37 75]] [37 100]] [3085 20.8 [37 88] [37 100]]]] [37 100]] [37 72]] [37 70]] [695 4.07 [37 92] [37 80]]] [37 100]] [37 71]] [37 100]] [37 100]] [37 68]] [38 66]] [3295 15.8 [37 100] [37 87]]] [37 70]]] [6777 0.172 [5943 0.169 [2939 4.15 [418 0.151 [5647 1.88 [2761 0.545 [1750 0.633 [1999 4.04 [4631 2.56 [2064 0.0258 [1509 1.09 [5732 1.24 [1980 22.1 [3308 19.5 [5588 8.24 [1547 3.53 [6395 0.334 [2628 6.78 [3492 3.89 [5343 1.76 [685 5.79 [797 8.65 [6643 2.79 [4906 3.28 [4663 25.1 [3269 1.87 [1783 9.43 [7428 0.176 [1980 10.4 [6154 3.88 [2039 0.87 [1980 3.12 [28 39] [968 6.48 [28 50] [28 83]]] [12 33]] [28 100]] [1980 14.7 [11 50] [22 43]]] [4 26]] [1997 2.35 [4630 3.32 [33 21] [4 25]] [11 33]]] [17 23]] [15 77]] [3 33]] [28 85]] [11 35]] [28 98]] [26 16]] [28 100]] [4 60]] [11 72]] [429 14.3 [11 66] [11 94]]] [12 91]] [8 75]] [15 31]] [1995 3.14 [5462 22.4 [28 100] [28 77]] [28 77]]] [4012 20.4 [28 100] [28 80]]] [10 21]] [7305 2.73 [11 83] [11 100]]] [22 92]] [38 55]] [11 67]] [429 16.4 [12 28] [28 84]]] [6339 0.0505 [28 81] [28 100]]] [1980 14.2 [30 18] [4 41]]] [695 0.169 [28 96] [28 100]]] [7334 1.28 [4565 3.33 [1783 22 [5840 0.859 [2280 0.0916 [7189 0.352 [6076 1.88 [19 69] [35 81]] [7189 0.691 [38 55] [17 75]]] [17 40]] [3269 14.7 [19 100] [17 53]]] [18 36]] [17 66]] [19 81]]]] [1888 0.665 [1105 0.108 [3079 0.608 [4770 0.0287 [2384 4.69 [3006 0.377 [5462 0.244 [3310 0.754 [3297 1.8 [5485 2.97 [4569 3.71 [2786 1.22 [6669 0.2 [6808 1.52 [6714 1.76 [731 0.289 [124 3.37 [2393 1.19 [5412 2.53 [939 1.72 [5482 0.778 [6245 2.56 [1679 1.62 [1164 4.04 [4213 5.75 [2707 2.56 [7354 6.24 [1754 2.54 [5960 2.82 [6870 5.11 [5400 3.36 [6597 13.7 [3262 5.43 [3905 9.03 [248 1.85 [4774 10.1 [7441 9.71 [877 4 [6544 2.67 [695 3.93 [377 6.62 [4832 4.13 [5267 0.44 [3687 3.79 [6388 11.1 [4071 9.32 [1674 1.58 [1605 10.9 [3879 7.48 [5677 1.05 [3972 15.1 [2837 14.5 [5439 6.72 [36 5.15 [279 7.04 [6529 8.2 [1004 3.65 [5632 0.325 [32 8] [16 31]] [2 100]] [2752 30.2 [22 81] [22 66]]] [18 62]] [22 90]] [28 28]] [22 100]] [37 61]] [19 88]] [38 44]] [5 50]] [30 50]] [37 34]] [22 64]] [37 85]] [6342 1.37 [9 22] [28 50]]] [2 83]] [28 43]] [6353 1.19 [28 23] [28 100]]] [14 52]] [22 100]] [22 52]] [13 73]] [23 60.7 [26 31] [13 45]]] [4154 2.37 [17 35] [32 86]]] [37 80]] [17 41]] [13 92]] [29 100]] [32 100]] [38 77]] [5426 7.69 [13 17] [36 100]]] [16 37]] [12 100]] [13 88]] [30 64]] [22 100]] [18 36]] [2023 14.7 [806 7.41 [29 27] [32 55]] [29 63]]] [6006 0.792 [3027 0.849 [695 0.64 [4154 16.3 [28 28] [28 80]] [28 67]] [38 50]] [28 85]]] [28 100]] [32 100]] [7188 2.56 [3558 4.39 [5439 4 [7734 2.82 [2753 11.1 [3056 2.59 [1707 27.6 [5130 9.84 [2466 7.52 [2752 0.577 [5 34] [145 1.79 [7665 1.85 [649 9.58 [6363 1.22 [1078 13.6 [4895 2.67 [17 38] [17 42]] [17 66]] [7 36]] [17 33]] [17 61]] [19 34]]] [5 33]] [16 55]] [19 100]] [5 88]] [16 45]] [18 70]] [17 62]] [19 69]] [5 71]]] [22 88]] [1078 24.8 [32 100] [32 90]]] [6669 10 [28 100] [24 40]]] [29 100]] [28 76]] [1012 8.34 [429 22.3 [7186 3.98 [18 41] [278 15.9 [6 57] [16 44]]] [18 75]] [18 87]]] [7210 1.31 [4071 10.8 [2259 2.3 [2787 7.92 [37 72] [37 100]] [37 46]] [37 55]] [37 75]]] [3310 20.1 [29 100] [29 80]]] [7254 3.81 [3554 1.77 [1429 38.4 [6294 2.04 [2752 16.2 [29 17] [328 9.02 [28 27] [28 71]]] [28 81]] [28 61]] [35 40]] [28 62]]] [26 88]] [10 100]] [2180 0.0197 [2029 0.998 [29 99] [29 96]] [29 100]]] [3036 1.01 [3914 0.449 [3069 4.7 [1507 2.93 [312 25 [5412 1.97 [3838 2.22 [1436 3.05 [3588 16.2 [3771 2.93 [5662 7 [1980 6.45 [3170 4.1 [3191 5.39 [3879 3.84 [3725 0.732 [101 1.37 [7210 0.353 [3262 14 [37 100] [37 96]] [37 100]] [37 88]] [37 100]] [16 46]] [37 90]] [3086 7.31 [37 100] [19 50]]] [37 100]] [37 63]] [834 1.72 [37 72] [37 100]]] [37 77]] [37 63]] [37 100]] [37 75]] [37 78]] [38 53]] [37 74]] [3602 0.632 [5641 0.766 [3879 1.91 [37 93] [16 30]] [38 57]] [37 85]]] [37 62]]] [29 100]] [5037 5.92 [4926 0.57 [7428 6.66 [1429 12.1 [5170 2.79 [26 27] [26 75]] [5662 0.446 [2259 28 [6830 1.12 [5482 1.74 [1 0.35 [978 9.68 [2488 3.27 [7169 18.2 [32 16] [14 30]] [13 100]] [1062 6.82 [7210 10.7 [17 38] [17 80]] [17 45]]] [17 44]] [18 87]] [16 57]] [36 75]] [2527 0.821 [35 44] [18 50]]]] [12 38]] [18 71]] [13 87]]]] [1407 0.617 [4663 0.775 [7185 2.6 [1404 0.904 [5310 0.778 [6233 2.11 [3874 1.39 [1411 1.27 [510 1.8 [3554 6.61 [663 1.7 [3484 1.06 [4154 0.73 [828 1.79 [3338 4.76 [3111 6.37 [7491 27.3 [7449 20 [6230 2.64 [3492 1.6 [3572 5.15 [1888 1.75 [7343 21.4 [2470 2.65 [3616 6.8 [5641 8.51 [6177 2.54 [5431 4.63 [5267 6.9 [2752 2.36 [1079 7.94 [2398 7.46 [5480 4.02 [296 6.33 [2225 15.2 [7287 5.05 [642 0.388 [6959 0.938 [12 16] [26 45]] [21 66]] [12 100]] [2 38]] [10 100]] [21 55]] [12 100]] [10 62]] [7210 13 [1081 5.59 [1414 1.93 [5871 2.86 [2939 17.3 [12 21] [12 95]] [12 70]] [15 100]] [25 37]] [8 33]]] [12 55]] [26 100]] [25 81]] [25 50]] [10 100]] [4768 14.3 [4414 15 [1899 2.89 [978 2.22 [1510 1.73 [1405 6.37 [6342 10.8 [826 1.92 [6614 2.07 [328 4.07 [15 79] [26 44]] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [26 58]] [15 84]] [15 96]] [15 100]]] [12 40]] [5412 8.41 [1980 13.9 [7241 2.96 [12 48] [12 83]] [12 60]] [12 70]]] [10 100]] [15 96]] [4602 1.63 [5170 3.14 [2259 9.65 [6471 2.06 [2470 5.75 [26 45] [25 67]] [26 90]] [10 26]] [26 80]] [26 91]]] [15 68]] [15 87]] [15 97]] [15 87]] [893 0.945 [1769 6.17 [4851 2.07 [15 96] [15 100]] [15 100]] [15 100]]] [4424 0.998 [4414 2.49 [5462 2.26 [2915 2.99 [1239 11.9 [4332 4.61 [15 75] [4 55]] [3 16]] [26 55]] [26 33]] [1166 0.917 [7085 21.6 [3701 0.768 [7169 8.43 [5809 2.39 [7504 24.4 [15 95] [15 71]] [15 100]] [15 75]] [15 100]] [15 75]] [15 100]]] [15 100]]] [15 98]] [6342 1.78 [5439 6.54 [23 8.09 [26 34] [144 20.9 [957 1.92 [1400 19.2 [32 34] [1980 6.22 [32 37] [32 71]]] [32 71]] [32 75]]] [10 100]] [15 40]]] [12 50]] [26 95]] [2752 3.13 [7085 26.7 [15 89] [15 77]] [15 100]]] [12 97]] [25 100]] [10 100]] [15 100]] [5110 2.62 [394 1.51 [1062 1.25 [7168 3.42 [5812 3.14 [6103 13.9 [6401 2.56 [2902 0.761 [673 5.15 [2799 1.13 [26 35] [26 66]] [26 88]] [15 54]] [12 100]] [12 72]] [12 85]] [10 28]] [30 50]] [26 74]] [15 44]]] [7649 0.387 [731 5.15 [15 82] [4 40]] [15 100]]] [811 17.5 [2753 0.373 [4218 1.85 [15 96] [15 100]] [15 100]] [15 80]]]] [6199 0.132 [1516 7.56 [2402 2.79 [5566 0.402 [1653 0.287 [328 0.66 [14 98] [14 100]] [14 100]] [14 100]] [14 98]] [14 83]] [14 100]]] [2752 1.69 [29 84] [5007 0.116 [5995 11 [5994 9.62 [3667 1.9 [29 96] [29 100]] [29 76]] [29 100]] [144 23.6 [29 100] [29 75]]]]] [3726 0.307 [641 1.8 [1239 1.83 [3905 8.77 [3300 7.7 [3295 15.3 [3466 7 [3921 0.788 [4011 1.96 [3300 1.62 [37 88] [37 100]] [37 100]] [2787 0.835 [37 100] [836 0.788 [37 88] [37 100]]]] [37 71]] [37 66]] [37 71]] [4414 1.51 [3492 0.508 [37 96] [37 100]] [37 100]]] [37 89]] [37 70]] [37 85]]] [27 100]] [6184 1.23 [29 99] [29 100]]] [791 0.196 [4208 0.398 [2160 3 [2091 2.89 [7729 9.03 [1817 0.595 [168 0.609 [5528 0.366 [6844 4.14 [5073 0.488 [287 4.76 [3622 0.23 [2802 1.17 [5542 1.09 [906 5.37 [1585 1.62 [2020 4.67 [190 0.277 [6205 2.66 [1862 0.219 [4704 3.97 [429 0.142 [2862 0.176 [1617 1.42 [4159 0.381 [1696 1.15 [5170 3.33 [2752 0.255 [189 1.01 [42 1.57 [1899 34.6 [5258 2.13 [6497 1.23 [1843 2.56 [5629 1.06 [148 23.2 [7616 3.6 [5270 4.51 [2259 2.25 [7449 6.39 [2192 0.802 [5685 7.94 [2081 119 [957 12 [2001 3.08 [4778 4.05 [4369 2.2 [2081 14.3 [2851 0.724 [3251 1.08 [1251 2.62 [6199 3.86 [6959 3.18 [3527 7.1 [1949 0.415 [3047 10.1 [1239 25.9 [1437 42.1 [1457 2.21 [3227 13.8 [7255 3.24 [2132 4.53 [2241 12.2 [2064 10.8 [2187 1.92 [1 22] [1 52]] [22 40]] [1 42]] [29 45]] [12 71]] [10 42]] [1 50]] [2 45]] [2048 9.55 [1 15] [1 60]]] [1 100]] [11 36]] [1 100]] [18 38]] [35 26]] [23 33]] [1429 12.6 [29 45] [29 36]]] [16 53]] [2232 8.62 [1239 2.65 [2163 3.14 [4017 9.96 [1951 8.18 [1094 10.5 [2152 14.3 [3379 25.4 [1772 12.2 [286 113 [7606 7.91 [3576 19.6 [2212 12 [6040 6.17 [5574 8.55 [2199 53.3 [3675 3.27 [1 18] [35 50]] [2099 71.8 [1 27] [35 27]]] [1 69]] [33 95]] [35 85]] [15 83]] [19 50]] [1 75]] [33 50]] [1 72]] [35 58]] [1 52]] [1 50]] [35 77]] [35 66]] [6929 4 [1 18] [2 20]]] [1 21]]] [33 25]] [15 100]] [2062 17.8 [2136 3.35 [29 27] [29 57]] [35 35]]] [27 92]] [1 19]] [30 50]] [2212 4.33 [2215 2.68 [2055 1.46 [2048 2.25 [2216 1.6 [1980 21 [29 65] [29 42]] [1 57]] [1 55]] [1 55]] [1 54]] [25 25]]] [29 50]] [2128 7.64 [3282 20.4 [6610 0.699 [4920 0.639 [2048 37.3 [6375 11.7 [2143 0.503 [2105 16.3 [7401 2.63 [1997 13.3 [1895 3.45 [1950 1.57 [5267 2.22 [4896 2.18 [2408 2.54 [1078 71.6 [7665 18.1 [5368 6.77 [7369 8.93 [4444 9.07 [6375 1.06 [1841 6.17 [7428 5.41 [6883 4.98 [7449 9.86 [1742 0.693 [1 13] [1 53]] [33 40]] [25 42]] [14 17]] [33 28]] [30 55]] [1 60]] [16 37]] [10 26]] [3 54]] [1 33]] [33 62]] [14 63]] [22 20]] [1 50]] [38 55]] [14 20]] [14 57]] [29 66]] [2062 4.1 [1248 1.14 [1963 26.8 [1786 0.49 [4533 7.88 [2100 28.1 [2130 20.8 [1788 2.99 [2215 5.06 [7449 11.4 [5999 14.9 [2174 4.49 [7101 3.58 [2202 3.06 [1255 14.8 [2051 5.63 [4663 20 [1394 2.59 [1 15] [21 42]] [33 33]] [35 66]] [29 66]] [28 28]] [22 60]] [29 40]] [33 52]] [29 41]] [35 33]] [12 33]] [23 57]] [1 30]] [12 16]] [27 32]] [35 66]] [35 72]] [2072 1.56 [2131 1.07 [2251 5.74 [29 47] [2 22]] [29 30]] [4 18]]]] [35 41]] [35 83]] [7449 0.639 [15 47] [33 100]]] [28 80]] [27 100]] [35 41]]] [11 30]] [3 100]] [3 91]] [15 100]] [22 100]] [2093 3 [25 84] [25 100]]] [10 100]] [2167 2.5 [4663 9.9 [3931 0.756 [2054 17.3 [1246 1.21 [7499 3.28 [2931 5.08 [4743 2.56 [1108 0.348 [328 56.3 [2195 2.61 [5807 2.77 [2192 4.89 [1961 1.19 [7627 9.12 [3037 26.9 [2212 2.44 [3130 14.7 [3435 5.34 [2039 2.17 [2131 5.02 [1101 7.39 [2281 1.23 [1440 2.24 [2225 26.7 [1 24] [1 20]] [1 77]] [17 40]] [1 61]] [28 42]] [2235 5.08 [2143 3.75 [29 50] [1 43]] [11 41]]] [2225 6.18 [29 69] [29 33]]] [29 50]] [1 75]] [1 83]] [35 87]] [29 62]] [1980 17.5 [1 50] [29 60]]] [15 60]] [1 90]] [28 66]] [23 20]] [7 100]] [23 100]] [29 100]] [29 40]] [33 44]] [1 76]] [29 42]] [2151 1.16 [33 41] [33 50]]]] [3 79]] [5627 1.39 [6959 0.826 [1239 5.19 [2649 5.07 [13 37] [6 91]] [6 69]] [18 80]] [16 50]]] [3262 1.45 [1078 86.4 [1576 10.5 [1916 9.53 [5851 3.39 [2241 14.1 [392 4.2 [4556 2.62 [2099 9.09 [1451 5.55 [2900 1.42 [7449 23.8 [2259 5 [7449 4.95 [1939 1.14 [1997 22.5 [2181 11.6 [1391 6.45 [4158 3.14 [3008 3.54 [2764 75 [5267 1.14 [2752 65.5 [4663 31.3 [39 4.77 [7428 0.403 [1769 4.52 [4533 4.89 [2752 60.7 [2029 0.131 [6230 3.53 [23 10] [30 27]] [23 33]] [18 38]] [35 36]] [17 27]] [28 41]] [37 38]] [15 40]] [1788 5.05 [2 10] [1 75]]] [13 41]] [23 52]] [25 70]] [26 46]] [15 42]] [23 46]] [23 39]] [23 88]] [23 33]] [2039 7.86 [2232 0.556 [12 7] [11 19]] [1 41]]] [15 46]] [33 50]] [1772 0.861 [23 43.9 [1 37] [31 75]] [11 33]]] [3027 4.59 [2081 83.9 [23 22] [23 87]] [23 100]]] [23 94]] [28 41]] [2023 31.1 [23 48] [23 90]]] [35 22]] [23 70]] [2 75]] [2143 13.7 [27 47] [27 77]]] [37 81]]] [1742 3.45 [5171 9.09 [33 67] [33 100]] [1 55]]] [1984 2.26 [4235 3.14 [26 61] [26 71]] [26 86]]] [2000 13.3 [2055 11.6 [1769 20.5 [1948 4.58 [1104 5.69 [2793 23.2 [4218 0.609 [5618 3.75 [7255 6.2 [5753 7.56 [2002 19.9 [2004 9.25 [2913 29.6 [2765 1.52 [144 9.6 [1445 0.592 [5170 4.85 [2259 7.77 [1237 0.832 [29 31] [29 100]] [4161 7.37 [4160 8.95 [14 15] [32 50]] [6 33]]] [33 66]] [29 64]] [2 29]] [2 42]] [22 37]] [29 100]] [13 33]] [28 37]] [19 37]] [4 45]] [13 22]] [23 100]] [15 50]] [29 88]] [28 33]] [23 64]] [23 85]]] [10 100]] [6380 2.38 [2649 1.23 [16 33] [18 80]] [38 54]]] [2913 4.35 [5911 8.52 [1628 1.02 [4006 1.3 [7221 1.05 [1661 0.678 [3990 3.51 [2088 3.25 [398 2.22 [2941 4.09 [1094 3.67 [2147 3.87 [1239 9.67 [4214 6.85 [1696 0.395 [968 2.13 [429 53.7 [6297 2.53 [2701 2.07 [695 7.5 [1888 3.97 [939 6.14 [1454 1.44 [3 9] [23 30]] [27 37]] [17 18]] [28 41]] [4154 23.3 [29 100] [29 87]]] [4 44]] [328 16.3 [2086 2.89 [23 40] [27 36]] [23 66]]] [28 25]] [26 50]] [29 73]] [2181 6.65 [2093 0.675 [3 16] [6929 8.9 [3 13] [2 55]]] [14 33]]] [27 84]] [1991 2.96 [27 58] [23 77]]] [6 80]] [23 73]] [1101 1.73 [2241 2.33 [2752 14.4 [22 21] [17 45]] [23 83]] [23 42]]] [37 76]] [18 100]] [3 53]] [6157 8.26 [28 87] [28 100]]] [29 100]] [23 90]] [3 36]]] [2900 3.52 [2246 0.248 [5851 1.01 [2151 1.28 [1436 9.87 [33 57] [30 27]] [1 27]] [12 26]] [15 33]] [28 28]]] [30 80]] [1062 1.5 [1783 38.1 [7 21] [14 44]] [7 96]]] [5801 1.01 [4854 1.75 [2750 3.45 [2143 4.26 [38 47] [18 45]] [38 100]] [18 29]] [2628 27.4 [16 69] [19 28]]]] [1445 15.3 [35 57] [1 15]]] [14 100]] [2081 23.8 [3 25] [21 43]]] [13 93]] [29 72]] [2232 8.29 [2064 0.27 [2139 1.49 [29 89] [29 55]] [29 100]] [2002 0.752 [29 75] [29 85]]]] [32 100]] [29 66]] [33 72]] [2151 0.147 [15 93] [15 100]]] [2259 13.7 [2232 3.91 [19 56] [19 58]] [13 25]]] [3 100]] [4655 14.6 [1 57] [1264 4.85 [250 6.99 [251 25.8 [1 91] [1 50]] [1 100]] [1 100]]]] [2704 0.405 [2838 0.0777 [435 0.524 [6300 6.85 [2987 0.325 [4657 2.73 [4206 10.7 [3527 6.66 [2919 11.9 [957 0.924 [4770 0.057 [1116 5.56 [2127 33.7 [4889 1.25 [4353 1.47 [4680 17.2 [2143 22.9 [4331 6.76 [2199 5.35 [7623 23.7 [2259 12.2 [1239 9.01 [4663 21.7 [7665 7.73 [2802 2.28 [4159 0.509 [7449 12.2 [1104 7.59 [1 17] [28 19]] [32 66]] [29 28]] [29 100]] [19 50]] [23 40]] [1 31]] [2128 1.92 [28 8] [14 50]]] [30 50]] [2025 16.7 [2225 1.2 [2068 3.55 [2058 6.49 [2091 7.59 [3 42] [1 17]] [25 42]] [1 33]] [1459 0.73 [2081 9.09 [2023 3.17 [33 30] [27 50]] [4663 2.73 [2058 5.22 [28 18] [17 23]] [28 38]]] [1980 12.8 [6 36] [23 64]]]] [1 70]]] [27 58]] [15 14]] [1 91]] [15 35]] [19 50]] [8 62]] [3 53]] [29 100]] [4768 17.1 [27 79] [10 55]]] [25 50]] [27 66]] [15 88]] [1 100]] [15 44]] [28 100]] [7036 1.06 [2087 5.49 [515 0.657 [6406 1.77 [27 26] [29 57]] [29 100]] [27 100]] [29 100]]] [29 100]] [29 100]]] [2115 3.18 [2764 4.41 [4802 2.56 [35 63] [1 40]] [1 36]] [35 100]]] [29 98]] [3790 0.236 [1628 0.112 [4770 0.486 [3237 0.166 [7411 2.45 [5732 0.324 [907 1.78 [3235 0.538 [3305 0.803 [7340 1.23 [371 3 [7101 1.92 [4159 1.12 [7314 8.7 [1436 4.27 [4290 60 [3439 1.85 [2849 1.57 [3450 7.63 [384 0.534 [5539 3.11 [5171 3.43 [3492 0.297 [2524 0.393 [4207 1.21 [5941 0.598 [3464 2.37 [2416 0.712 [5524 0.967 [792 3.54 [5254 2.16 [6497 0.908 [3905 0.564 [4555 1.55 [2470 2.96 [3687 1.97 [2913 27.3 [1400 5.98 [809 2.47 [2007 5 [2705 0.564 [3079 1.18 [4631 0.705 [5333 0.29 [1032 2.33 [1780 2.06 [6711 1.12 [906 6.29 [448 5.78 [6493 0.608 [2752 5.27 [429 38.7 [793 21.2 [2289 1.47 [2254 0.168 [1104 2.51 [6772 0.726 [1429 64 [237 5.49 [4312 0.264 [6766 0.223 [5153 3.33 [5989 0.166 [2039 15.5 [33 12] [35 48]] [4583 1.23 [2 20] [2 62]]] [24 77]] [35 83]] [429 16.2 [3 50] [23 27]]] [34 72]] [791 11.9 [2466 0.597 [1445 7.37 [2939 1.13 [2192 0.112 [1453 2.25 [29 44] [33 33]] [1 50]] [29 95]] [15 30]] [17 50]] [2091 2.39 [1 12] [14 25]]]] [30 90]] [2199 7.28 [27 23] [1110 17.8 [29 29] [29 55]]]] [1 75]] [18 50]] [22 91]] [2091 2.96 [2055 1.96 [917 7.26 [7210 27.1 [4533 5.95 [504 25.7 [4017 3.7 [1997 0.624 [21 28] [9 24]] [35 100]] [15 35]] [20 30]] [1 58]] [21 86]] [11 41]] [27 18]]] [7449 6.41 [392 3.61 [23 0.561 [6184 45.3 [6753 1.3 [2763 9.5 [2155 10.5 [2252 1.93 [23 16] [29 55]] [23 75]] [2199 1.86 [11 28] [11 75]]] [29 100]] [15 87]] [2526 0.224 [429 43.9 [6621 3.83 [2701 0.801 [37 12] [29 100]] [29 55]] [29 64]] [26 45]]] [7210 0.864 [28 34] [28 50]]] [938 1.65 [1239 12.5 [29 33] [1062 5.39 [23 50] [23 75]]] [23 88]]]] [28 100]] [23 65]] [1980 49.9 [2701 3.31 [1913 3.6 [21 41] [29 33]] [29 93]] [21 70]]] [22 39]] [23 100]] [15 100]] [11 100]] [2143 1.29 [328 7.09 [11 81] [11 100]] [11 100]]] [2143 5.72 [37 86] [37 75]]] [29 100]] [10 60]] [22 62]] [1078 15.5 [1078 5.23 [429 13.8 [12 30] [21 41]] [3 33]] [4320 1.83 [10 20] [10 100]]]] [26 40]] [37 73]] [1 1.58 [791 18.8 [2178 8.38 [1253 0.418 [2241 2.57 [6582 1.87 [25 24] [4 58]] [11 33]] [25 41]] [15 70]] [15 48]] [11 87]]] [23 97]] [37 43]] [25 92]] [10 100]] [11 100]] [11 100]] [28 85]] [5647 3.34 [1239 4.45 [3295 0.615 [4414 2.78 [695 0.595 [2081 10.1 [37 83] [25 28]] [37 100]] [19 23]] [37 66]] [37 36]] [37 100]]] [1577 1.67 [2058 0.649 [4877 4.39 [2259 39.2 [4915 1.89 [2259 25.6 [14 53] [17 55]] [19 50]] [14 68]] [14 100]] [17 55]] [14 100]]] [4279 6.35 [29 100] [29 95]]] [6078 0.296 [2225 2.34 [3995 0.787 [24 83] [24 70]] [2023 2.51 [36 61] [24 50]]] [24 100]]] [2084 1.31 [1533 3.45 [37 58] [37 100]] [37 87]]] [5299 0.724 [33 71] [33 100]]] [13 94]] [7453 1.06 [328 8.12 [386 0.534 [328 2.33 [23 85] [23 100]] [23 100]] [2178 1.73 [23 57] [23 71]]] [23 100]]] [35 92]] [429 11.6 [2199 1.33 [33 34] [33 21]] [7419 1.44 [392 2.18 [248 15.3 [6653 0.371 [29 83] [29 87]] [29 40]] [29 45]] [29 100]]]] [11 100]] [429 30.9 [26 100] [26 85]]] [27 5.99 [5642 0.0247 [4462 0.197 [6773 0.679 [5529 0.243 [1783 71.9 [6495 0.621 [3572 0.668 [7331 0.538 [1783 45.6 [203 4.81 [1265 2.06 [1659 7.69 [1078 28.9 [3251 2.91 [1 2.61 [1769 0.328 [2227 18.2 [7324 0.566 [5593 1.1 [2913 4.68 [2628 1.23 [6382 3.12 [3130 11.6 [2122 7.14 [791 9.45 [29 15] [2225 7.26 [1457 4.91 [2083 13.7 [435 5.84 [2939 2.37 [2259 9.36 [2 19] [4 19]] [21 41]] [1 16]] [30 77]] [7 30]] [14 29]]] [31 50]] [3 40]] [14 75]] [10 60]] [30 54]] [29 54]] [4 37]] [23 40]] [15 50]] [13 55]] [36 36]] [4154 1.7 [1242 1.08 [11 43] [15 100]] [23 37]]] [17 61]] [3 90]] [3 100]] [221 1.63 [2 18] [2 54]]] [7 83]] [15 100]] [1902 1.32 [3 57] [3 100]]] [30 52]] [15 100]] [1769 1.12 [6773 11.9 [30 100] [30 77]] [30 100]]] [30 100]] [30 54]] [32 100]]] [6544 1.58 [2913 4.48 [3 22] [3 100]] [3 100]]] [2225 11.8 [1429 5.52 [26 32] [112 0.709 [6216 0.938 [2039 3.25 [2014 2.27 [4768 0.9 [4279 34.5 [4614 1.13 [2132 3.34 [1451 4.4 [3959 1.14 [1101 0.623 [3130 3.35 [5767 0.53 [29 29] [15 66]] [7 37]] [15 27]] [29 100]] [29 80]] [29 77]] [29 100]] [26 67]] [2013 0.952 [2701 1.3 [29 50] [29 100]] [29 87]]] [11 73]] [29 80]] [7470 0.975 [29 87] [29 100]]] [7449 0.889 [29 70] [29 100]]]] [3 25]]] [1239 4.04 [2785 1.69 [29 56] [29 100]] [29 32]]] [21 76]] [1911 3.4 [1429 12 [1429 4.97 [32 75] [12 53]] [814 1.47 [4369 1.45 [32 85] [32 100]] [32 100]]] [32 100]]] [10 100]] [11 100]] [2913 12.4 [507 0.635 [660 8.35 [21 72] [21 100]] [21 100]] [3 75]]] [6727 6.04 [4558 2.39 [2145 4.44 [6949 0.0986 [1239 2.48 [2752 6.16 [791 7.39 [15 25] [28 46]] [28 75]] [28 86]] [28 92]] [32 40]] [32 66]] [13 33]]] [4218 1.13 [4288 0.542 [1253 1.27 [2081 3.77 [35 75] [3905 6.69 [4533 0.768 [15 55] [35 44]] [15 100]]] [1078 14.5 [15 100] [15 57]]] [15 44]] [15 100]]] [1119 0.207 [3235 0.42 [2108 1.09 [11 100] [11 77]] [11 100]] [11 100]]] [29 100]] [5454 18.9 [806 0.763 [145 0.473 [1094 0.301 [7343 0.497 [6342 8.11 [29 100] [29 66]] [29 100]] [29 100]] [29 100]] [29 100]] [36 66]]] [1391 1.65 [1445 2.61 [28 85] [28 71]] [28 100]]]]] [673 1.63 [6178 0.864 [3155 0.882 [7413 0.336 [5752 0.792 [5239 3.07 [5170 2.35 [7008 1.56 [7038 1.56 [2081 2.3 [2752 4.76 [605 9.61 [7411 7.76 [538 1.15 [2512 1.41 [3462 3.99 [976 2.15 [2616 0.911 [3972 1.29 [96 2.52 [3450 1.93 [536 5.99 [371 2.32 [6285 25.5 [2470 12.3 [3292 1.57 [2537 6.67 [978 2.61 [6116 0.266 [1483 2.73 [906 2.31 [6380 2.41 [1240 9.93 [4725 9.2 [23 0.432 [892 6.33 [1429 51.1 [3672 4.59 [2259 28.4 [5858 7.04 [3273 3.82 [5462 12.8 [7305 29.4 [7210 3.38 [1025 54.9 [5299 7.03 [1812 5.15 [2225 5.97 [4533 15.2 [5999 12.6 [7009 21.1 [4456 5.49 [6457 4.5 [2624 2.82 [3714 9.09 [2913 12.2 [1783 8.36 [4967 15.2 [1980 3.86 [5412 26.9 [4832 27.4 [1078 33.3 [2588 13.5 [2526 104 [4 9] [1 21]] [17 90]] [8 28]] [2 50]] [33 75]] [5851 7.09 [5812 1.18 [35 12] [12 75]] [20 44]]] [31 100]] [328 21.9 [7329 2.41 [1783 61.4 [1 25] [33 50]] [21 42]] [35 50]]] [3 28]] [26 100]] [1 75]] [25 66]] [0 75]] [4 60]] [25 72]] [2 40]] [23 35]] [33 66]] [33 88]] [2526 63.6 [28 28] [24 53]]] [33 18]] [25 66]] [35 47]] [35 66]] [0 100]] [2607 3.69 [2108 0.646 [7343 3.23 [6920 15 [7354 12 [2939 13.2 [2321 10.8 [3130 1.86 [7421 12 [6098 5.49 [4929 8.2 [7019 7.69 [2268 3.7 [8 14] [34 76]] [8 100]] [8 100]] [6 75]] [6 100]] [1 33]] [8 100]] [21 61]] [8 97]] [6 83]] [2259 49.1 [21 45] [19 33]]] [1 28]] [8 100]]] [3629 12 [35 100] [35 55]]] [5412 0.711 [8 44] [8 24]]] [10 100]] [4854 1.1 [2913 11.5 [1277 2.1 [228 28.7 [4991 3.09 [33 11] [5110 4.42 [33 26] [33 100]]] [4 91]] [9 100]] [3 77]] [30 38]]] [6 88]] [24 85]] [5343 6.5 [5043 0.901 [1687 0.978 [17 40] [1 15]] [17 100]] [14 75]]] [21 39]] [8 100]] [6 92]] [6518 2.04 [147 3.5 [6537 2.35 [5673 3.23 [7255 7.87 [1007 1.54 [8 54] [16 25]] [0 83]] [34 26]] [2 88]] [2 57]] [0 80]]] [1 56]] [8 86]] [2673 4.42 [4 43] [4 100]]] [24 97]] [1980 2.68 [21 64] [21 85]]] [3 100]] [35 100]] [16 88]] [1980 3.65 [8 78] [8 85]]] [1173 2.02 [4 27] [20 50]]] [27 100]] [0 83]] [8 100]] [1325 0.727 [5851 5.5 [9 47] [21 75]] [9 42]]] [35 58]] [24 89]] [2491 5.93 [6982 0.778 [144 2.34 [4940 5.84 [4146 0.593 [435 2.89 [2752 31.1 [2426 3.4 [7356 0.82 [2977 2.56 [1025 0.47 [6717 3.4 [4927 2.51 [5812 3.88 [4508 8.56 [6471 5.09 [2526 67.2 [5632 1.8 [1239 13 [23 12] [2062 1.17 [2027 0.8 [1391 10.2 [7316 0.443 [4573 15.9 [5969 1.39 [3878 2.72 [8 12] [3 37]] [8 50]] [19 72]] [33 62]] [19 60]] [12 30]] [1 58]]] [1458 3.14 [2276 1.03 [685 4.39 [3208 15 [16 17] [16 38]] [7 50]] [16 57]] [17 20]]] [8 70]] [26 66]] [18 100]] [2398 2.56 [978 30.2 [2826 1.17 [5412 5.45 [2 51] [5660 21.2 [567 2.86 [4 60] [17 40]] [22 50]]] [17 61]] [17 25]] [12 77]]] [18 94]] [32 92]] [6089 1.03 [2616 2.83 [5911 1.02 [3308 5.74 [1640 8.99 [2793 1.41 [5692 1.48 [2029 0.967 [5662 7.53 [2764 3.18 [4 23] [23 30]] [4 72]] [24 55]] [2 40]] [24 66]] [2 75]] [23 83]] [23 75]] [2 62]] [1047 15.3 [2 100] [2 75]]]] [25 77]] [1023 4.27 [18 100] [18 83]]] [8 100]] [3086 2.2 [2205 2.21 [2813 2.76 [661 7.07 [3901 2.49 [4611 13.2 [328 16.7 [4086 12.2 [3033 4.35 [2804 4.59 [3671 5.56 [2531 2.24 [1913 1.87 [1400 1.19 [248 20.4 [7085 24.1 [5587 6.17 [6927 4.65 [1764 4.85 [4833 7.46 [3248 7.82 [2470 2.67 [6115 3.6 [6550 22.2 [2517 3.89 [429 33.9 [731 5.29 [1587 6.67 [1701 9.3 [663 5.84 [1993 9.26 [5815 4.27 [5662 5.49 [6342 15 [5662 0.994 [2586 10.6 [3660 5.62 [2005 34.6 [5883 15.8 [791 8.05 [7241 8.11 [5 10] [5 34]] [35 21]] [1 54]] [23 35]] [24 90]] [1 44]] [19 50]] [8 73]] [18 30]] [2758 6.49 [2 53] [2 75]]] [23 75]] [1078 9.51 [5 23] [5 45]]] [22 55]] [2752 40.8 [16 63] [16 33]]] [6230 10.6 [5 29] [1888 18.9 [5 59] [12 36]]]] [978 51.4 [2259 14.1 [731 2.96 [23 32] [731 18 [5 37] [14 27]]] [22 25]] [4 42]]] [24 69]] [17 57]] [23 100]] [4 78]] [5 100]] [2 81]] [8 60]] [2 65]] [23 100]] [23 66]] [25 50]] [2 26]] [2241 0.406 [23 35] [1 57]]] [23 83]] [2 67]] [8 94]] [23 69]] [5 100]] [23 40]] [5 66]] [5 100]] [23 78]] [18 86]] [23 38]] [37 93]]] [1226 4.33 [4279 7.3 [2752 25.5 [2470 2.26 [35 26] [4 37]] [1062 1.23 [23 69] [23 86]]] [27 62]] [23 100]]] [24 95]] [16 90]] [3262 1.65 [5771 3.11 [6074 0.416 [1025 5.59 [7331 7.35 [7354 6.08 [3056 2.65 [7665 8.62 [1517 1.14 [7185 12.6 [4573 1.04 [5509 3.01 [2 19] [17 58]] [37 28]] [25 36]] [5 87]] [2 72]] [5 77]] [5480 0.971 [5 41] [7734 8.26 [18 64] [18 33]]]] [19 58]] [2 58]] [4991 1.01 [2 75] [2 100]]] [2 100]] [37 82]]] [4 91]] [8 100]]] [4288 0.476 [981 0.227 [1094 2.84 [5312 7.44 [2674 0.497 [2931 1.01 [392 0.661 [660 2.19 [685 7.1 [3851 8.09 [6479 2.19 [5110 2.75 [822 1.43 [2005 6.54 [5681 1.49 [2096 2.78 [3667 6.06 [3379 3.29 [5396 10.7 [1917 2.18 [6182 2.54 [5820 3.25 [371 8.72 [5851 28.7 [4903 0.251 [4655 3.81 [6382 4.31 [1110 19.9 [5812 5.48 [5278 2.67 [2793 1.95 [1795 1.82 [2143 13.5 [435 4.81 [1547 2.21 [7254 2.56 [2768 3.45 [2199 7.43 [3008 5.7 [1391 14.8 [2227 5.16 [5962 2.77 [5462 8.16 [4832 6.85 [4840 1.27 [1259 9.4 [7419 4.86 [1025 0.607 [7305 5.58 [802 2.56 [2199 1.49 [8 9] [1 22]] [21 33]] [25 58]] [23 26]] [24 38]] [33 55]] [19 30]] [2 66]] [35 83]] [6 62]] [3 57]] [22 50]] [26 22]] [2178 4.24 [23 21] [23 45]]] [11 46]] [1 55]] [32 87]] [23 46]] [23 27]] [2259 48.3 [6035 2.62 [16 40] [7 20]] [19 36]]] [4154 61 [4160 7.92 [23 76] [23 69]] [27 85]]] [21 100]] [2616 1.36 [2143 12.2 [1025 8.76 [2 43] [2 75]] [4 31]] [4 71]]] [27 85]] [14 47]] [1 100]] [14 63]] [0 81]] [21 70]] [2 63]] [25 100]] [23 87]] [4 58]] [1 66]] [7101 9.81 [35 85] [35 83]]] [23 81]] [16 91]] [5812 3.6 [4154 2.07 [1429 35.5 [1 26] [1 40]] [1429 6.81 [23 42] [12 57]]] [2752 20 [12 78] [2 30]]]] [21 51]] [1078 7.43 [33 84] [8 54]]] [938 0.705 [23 68] [23 100]]] [35 90]] [23 68]] [1038 2.92 [23 53] [23 100]]] [2178 8.28 [7241 2.7 [23 53] [18 42]] [23 42]]] [2533 1.15 [1997 4.21 [23 100] [23 80]] [23 100]]] [2752 15.4 [2 100] [2 83]]] [21 86]] [1916 2.99 [2137 0.198 [7508 1.16 [5647 4 [2526 7.09 [20 31] [791 25.8 [2259 18.4 [23 57] [28 33]] [23 80]]] [11 30]] [23 100]] [1 87]] [23 100]]] [23 100]] [929 12 [429 1.77 [2 22] [23 79]] [29 45]]]] [5609 4.84 [4513 4.48 [2852 4.07 [1283 0.201 [4431 2.32 [731 0.867 [2871 5.03 [5999 7.2 [5350 0.96 [5681 2.54 [23 8.54 [1078 2.2 [6 48] [6 29]] [16 60]] [16 58]] [6 41]] [16 54]] [5681 4.61 [16 76] [187 1.13 [18 66] [16 40]]]] [18 57]] [16 75]] [6 75]] [16 85]] [16 62]] [6 57]]] [25 100]] [685 2.22 [429 8.85 [7210 7.16 [688 2.49 [791 8.08 [5668 1.95 [2530 9.8 [33 60] [26 90]] [33 96]] [33 68]] [23 26.4 [33 100] [33 83]]] [33 100]] [26 37]] [26 59]]] [695 6.63 [2526 61.1 [221 0.755 [4 93] [4 100]] [4 71]] [4 80]]] [23 95]] [23 16.1 [5891 1.05 [4682 1.85 [5820 0.256 [1047 1.02 [2559 0.486 [695 6.76 [5819 1.21 [1899 4 [7428 4.89 [2 23] [14 50]] [6342 0.457 [6537 2 [2 33] [2 100]] [2 66]]] [1023 7.51 [2 100] [2 54]]] [17 30]] [33 85]] [2 83]] [2 64]] [33 100]] [38 41]] [33 84]]] [3155 21.2 [2029 5.65 [2526 19.2 [3744 3.64 [3457 3.84 [35 61] [35 100]] [3152 1.56 [35 90] [35 80]]] [3336 1.45 [35 89] [35 100]]] [35 60]] [35 52]]] [182 12.5 [7397 10.2 [3971 0.813 [1420 8 [25 100] [25 97]] [25 100]] [978 5.15 [25 100] [7329 5.38 [25 90] [25 100]]]] [25 80]]] [4844 1.21 [680 1.81 [6364 2.05 [1597 0.274 [4704 0.472 [2005 3.07 [7396 1.73 [6619 2.16 [6472 0.565 [6177 2.97 [144 6.12 [1239 20.9 [423 2.7 [4854 7.52 [7301 2.73 [1011 7.06 [4235 9.05 [6528 4.27 [269 1.39 [5632 4.32 [939 1.68 [26 72] [26 71]] [16 57]] [26 78]] [25 83]] [25 37]] [26 100]] [26 87]] [26 53]] [1239 1.04 [26 93] [26 83]]] [3207 2.2 [26 68] [26 95]]] [26 47]] [25 95]] [7185 3.39 [995 9.08 [5692 0.938 [26 87] [26 85]] [26 50]] [26 50]]] [25 100]] [25 100]] [2570 4.88 [25 42] [1 100]]] [25 98]] [26 100]] [25 100]] [18 100]] [25 100]]]] [23 5.19 [1078 5.21 [4569 1.46 [6397 3.1 [2628 2.15 [663 10.4 [5246 0.645 [794 14.9 [747 0.746 [7305 2.26 [1883 10.4 [7491 1.5 [4564 3.51 [1769 29.6 [917 2.42 [1587 0.876 [906 1.63 [4810 5.05 [4851 4.77 [1062 3.45 [21 71] [2 50]] [21 50]] [21 100]] [535 4.58 [21 64] [6181 5.26 [1913 1.01 [6320 2.26 [923 3.11 [1239 30.1 [21 100] [21 98]] [21 100]] [21 100]] [21 77]] [21 90]]]] [26 44]] [2178 2.46 [5040 9.98 [21 94] [21 100]] [21 100]]] [2 50]] [30 50]] [21 99]] [2 30]] [21 50]] [21 97]] [2 43]] [21 96]] [2 40]] [2 35]] [21 66]] [21 100]] [21 28]] [5770 1.82 [223 2.31 [2199 0.963 [5534 4.62 [7015 1.45 [144 2.56 [6150 0.901 [5192 0.805 [4317 1.08 [517 3.31 [556 2.3 [1783 4.6 [6260 2.3 [5041 1.23 [21 65] [21 100]] [9 83]] [1429 16.6 [21 87] [21 50]]] [21 87]] [21 55]] [21 100]] [21 100]] [9 90]] [26 31]] [21 96]] [9 100]] [1986 2.88 [21 100] [21 87]]] [2 42]] [2 62]]]] [5626 1.12 [1429 2.92 [37 47] [1587 2.57 [3435 0.453 [3716 23.8 [5999 8.26 [3715 17.2 [7352 0.904 [115 0.873 [2029 6.28 [37 100] [37 82]] [37 100]] [37 66]] [37 91]] [37 71]] [37 66]] [37 100]] [37 66]]] [37 77]]] [356 1.26 [4405 3.78 [1862 0.0716 [5333 2.59 [4948 3.34 [1429 15.4 [3233 1.46 [1 3.62 [3851 3.23 [5809 1.04 [7285 3.82 [4798 0.307 [635 1.03 [4415 1.08 [6148 4.06 [6732 0.16 [6394 1.03 [404 1.09 [6521 0.198 [4703 2.96 [1783 3.8 [2342 3.65 [3457 0.846 [978 1.65 [7271 1.29 [6276 3.06 [7255 11 [6297 2.62 [4663 10.6 [5175 6.21 [1925 3.94 [3111 1.16 [429 19.3 [1400 5.3 [4279 7.51 [214 6.92 [4876 2.54 [4398 51.6 [2628 6.93 [5170 4.11 [2143 17.6 [2752 23.5 [33 40] [25 31]] [29 55]] [906 1.42 [33 80] [33 80]]] [25 28]] [35 27]] [31 36]] [33 88]] [4159 3.24 [31 37] [15 44]]] [15 91]] [4417 7.07 [15 44] [15 100]]] [15 92]] [15 69]] [33 100]] [15 78]] [31 100]] [3219 1.96 [15 54] [15 100]]] [1 23]] [2380 11.4 [31 66] [31 100]]] [2975 10.5 [25 37] [31 100]]] [35 68]] [15 85]] [6768 1.1 [6375 1.89 [7623 7.77 [33 40] [33 73]] [11 33]] [31 100]]] [33 84]] [31 100]] [15 91]] [15 100]] [791 1.77 [4781 3.36 [15 57] [15 100]] [7428 0.32 [1025 1.29 [15 85] [15 100]] [15 100]]]] [9 100]] [15 100]] [9 100]] [31 100]] [7285 35.8 [2939 1.96 [791 3.07 [30 57] [15 50]] [30 86]] [4 45]]] [15 100]] [35 94]] [5043 0.77 [30 41] [31 100]]] [3233 12.5 [35 88] [4408 1.2 [35 100] [35 41]]]] [345 0.495 [6982 0.987 [3763 1.03 [7151 1.99 [1710 2.23 [6342 4.12 [6899 5.02 [6960 6.06 [5629 1.99 [2004 6.03 [3209 0.975 [3708 1.02 [6767 0.451 [1359 2.45 [23 7.75 [5856 7.38 [5480 0.728 [5745 1.06 [7077 2.39 [6783 4.2 [232 4.12 [1698 1.36 [3051 0.792 [4364 4.68 [2259 11.7 [29 15] [5965 2.35 [1646 1.28 [7059 0.901 [5602 4.59 [31 15] [33 91]] [2 21]] [30 85]] [3 100]]] [28 36]] [30 100]] [25 62]] [33 76]] [31 100]] [15 53]] [15 100]] [1239 17.6 [4 52] [2 39]]] [9 90]] [112 0.32 [1342 1.72 [1429 39 [33 38] [33 36]] [33 58]] [29 57]]] [33 95]] [31 100]] [35 100]] [15 100]] [30 60]] [15 100]] [31 88]] [2259 63.6 [1783 2.89 [33 83] [33 96]] [33 100]]] [5252 1.19 [1253 2.11 [4291 1.33 [1379 4 [7261 2.89 [328 1.28 [31 48] [15 23]] [31 64]] [15 100]] [15 100]] [15 85]] [15 100]]] [30 100]] [1239 8.43 [11 42] [6331 9.96 [5618 3.18 [4964 4.95 [0 25] [4 100]] [11 37]] [11 42]]]] [15 100]] [7149 4.71 [1078 4.59 [6078 16 [31 95] [31 80]] [31 53]] [4 100]]] [15 100]]] [1818 1.77 [7271 1.2 [5871 1.51 [791 7.77 [31 92] [31 50]] [31 100]] [31 100]] [4 40]]] [11 100]] [1646 0.348 [1899 9.63 [30 100] [6635 0.175 [5501 16.5 [30 90] [30 62]] [30 100]]] [30 57]]] [5673 14.7 [5673 11.7 [441 0.746 [35 85] [35 100]] [35 70]] [35 50]]] [2470 3.29 [1980 0.365 [1429 25.8 [9 42] [30 100]] [2247 13 [30 100] [30 75]]] [356 5.26 [15 88] [30 76]]]]] [1687 1.64 [3905 0.724 [1463 1.39 [432 7.94 [4011 4.13 [2701 5.9 [6230 0.234 [2253 0.928 [6763 1.19 [2913 0.271 [850 0.931 [2939 41.7 [3388 0.564 [2753 0.624 [7472 1.52 [6445 4.28 [663 7.59 [3561 0.722 [5170 2.39 [3540 22.9 [2027 3.06 [6960 7.09 [5716 1.36 [3849 1.89 [380 0.938 [35 71] [27 50]] [2251 2.02 [4986 6.81 [4968 3.93 [7665 5.8 [443 7.41 [1400 4.67 [3444 2.26 [2766 1.8 [1055 7.6 [2628 21.7 [1533 2.86 [3045 1.37 [3099 1.42 [3851 6.2 [6353 18.6 [5281 2.36 [1936 12.7 [3710 21.6 [23 16.1 [4235 3.76 [1078 116 [846 2.74 [3027 5.01 [35 87] [35 100]] [35 100]] [35 53]] [35 53]] [35 28]] [28 44]] [35 63]] [35 66]] [35 62]] [3667 7.17 [35 96] [35 81]]] [35 95]] [6621 3.88 [1906 7.08 [906 17.3 [4181 1.59 [3711 4.08 [2628 6.1 [722 0.841 [831 29.6 [3953 0.95 [771 10.1 [3008 36.1 [3435 24.1 [740 7.53 [939 1.23 [1084 7 [6203 0.759 [2745 0.907 [3103 2.21 [791 1.42 [3045 51.8 [35 100] [35 87]] [35 100]] [35 77]] [35 100]] [35 77]] [35 81]] [35 100]] [35 81]] [35 66]] [35 61]] [35 83]] [35 100]] [35 80]] [35 66]] [35 76]] [35 98]] [1899 0.703 [35 78] [35 42]]] [35 77]] [35 78]] [35 57]]] [8 66]] [35 66]] [35 81]] [35 97]] [3852 1.47 [2108 1.58 [35 96] [35 87]] [35 100]]] [35 75]] [35 55]] [35 50]] [35 62]] [28 63]] [35 37]]] [35 33]] [13 62]] [1 66]] [4092 35.8 [35 100] [35 85]]] [33 68]] [30 100]] [112 10.6 [144 2.04 [26 35] [791 8.84 [37 57] [28 40]]] [37 61]]] [1980 7.75 [33 33] [25 37]]] [38 69]] [35 45]] [3332 7.61 [1078 9.92 [35 73] [5024 0.542 [4421 3.26 [791 25.5 [1986 0.332 [1906 2.02 [35 96] [35 71]] [35 100]] [35 81]] [35 77]] [35 100]]] [4398 4.27 [328 16.1 [7203 2.09 [6068 14.6 [4092 1.49 [35 92] [35 97]] [35 92]] [35 100]] [939 6.46 [3538 3.32 [35 91] [35 77]] [35 80]]] [35 100]]]] [17 35]] [4043 1.01 [35 94] [35 100]]] [2752 1.4 [30 55] [328 1.15 [30 50] [30 91]]]] [2752 21.3 [26 81] [26 75]]] [30 89]] [35 37]] [29 84]] [37 50]] [26 75]] [37 80]] [1453 2.46 [2081 2.4 [3978 1.51 [3725 0.998 [37 38] [37 100]] [37 87]] [19 25]] [37 100]]] [33 26]]] [6262 0.821 [1304 0.905 [6449 0.855 [5193 0.266 [5927 2.9 [4716 0.319 [2199 0.207 [7451 1.39 [4154 19.6 [21 87] [3 91]] [21 100]] [21 100]] [21 66]] [21 100]] [21 100]] [21 47]] [9 60]] [21 61]]] [2466 0.289 [2004 2.74 [1980 50.5 [6514 1.46 [1634 0.635 [6342 30.9 [1783 51.5 [2275 0.802 [5099 5.62 [429 6.37 [383 9.09 [27 53] [27 100]] [394 1.27 [2029 12.1 [1025 21.6 [6920 4.37 [436 3.01 [941 0.25 [23 2.3 [2072 1.61 [6441 8.39 [779 0.449 [2793 0.502 [6397 3.49 [1991 11.2 [7085 11.4 [5428 1.77 [791 41.3 [1068 0.68 [3527 1.02 [2093 8.43 [4279 21.4 [3227 1.82 [482 1.54 [3616 2.36 [1161 0.524 [939 1.19 [27 99] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 80]] [1788 6.17 [27 91] [27 100]]] [27 100]] [27 100]] [27 97]] [27 87]] [4154 0.917 [27 100] [27 71]]] [27 91]] [27 80]] [27 100]] [27 100]] [27 72]] [27 81]] [2461 4.42 [27 50] [1429 2.54 [27 75] [27 88]]]] [27 100]] [27 66]] [27 83]] [27 76]] [27 71]] [27 50]]] [16 42]] [0 25]] [1 28]] [1 33]] [27 55]] [6 33]] [2081 8.47 [28 45] [27 53]]] [23 25]] [27 21]]] [586 1.49 [2808 0.627 [580 5.43 [7354 1.13 [6544 1.11 [6082 2.98 [2470 0.894 [4612 3.4 [5831 1.93 [907 3.43 [4079 3.3 [1888 1.09 [2822 1.1 [2259 20.5 [6541 0.982 [826 0.467 [3872 2.67 [4413 4 [6655 1.52 [1400 1.89 [232 3.07 [6345 3.6 [5712 2.33 [978 15.9 [168 4.27 [4870 3.7 [7411 3.18 [7255 3.18 [6906 2.96 [5574 12.3 [3056 9.24 [3008 4.67 [29 11.6 [906 2.39 [2701 3.18 [5976 2.76 [112 4.45 [4876 1.12 [1 1.65 [2764 3.14 [7241 13.5 [2526 48.6 [2753 5.85 [5410 5.62 [1078 54 [7663 5.49 [6524 8.78 [1391 3.07 [4398 6.99 [3554 4.27 [1062 16.7 [5974 3.36 [535 5.62 [5851 4.59 [5797 14.9 [5412 19.4 [248 3.36 [2081 36.1 [3424 3.31 [12 68] [36 40]] [12 100]] [15 68]] [12 62]] [12 100]] [12 35]] [21 100]] [21 63]] [5972 48.2 [12 81] [12 100]]] [12 100]] [15 62]] [33 57]] [36 75]] [12 71]] [12 52]] [3 36]] [12 35]] [7663 8.77 [12 75] [12 100]]] [12 91]] [12 47]] [36 33]] [21 44]] [12 40]] [3 96]] [12 53]] [660 2.73 [554 2.39 [5040 4.42 [3 33] [21 100]] [3 100]] [21 85]]] [3 77]] [3 91]] [12 100]] [12 45]] [9 100]] [12 93]] [15 57]] [3 100]] [36 100]] [31 78]] [12 100]] [9 71]] [33 100]] [5469 3.7 [12 91] [12 100]]] [915 12.1 [21 33] [21 88]]] [12 100]] [12 100]] [4279 11.1 [12 90] [12 80]]] [12 100]] [2426 4.57 [1429 28.5 [728 2.73 [349 6.49 [4282 4.5 [7359 7.91 [2971 3.5 [5267 6.89 [2081 3.89 [4414 26 [12 47] [12 75]] [2766 10.6 [1429 5.15 [12 42] [12 100]] [12 55]]] [4445 0.975 [31 78] [31 100]]] [12 100]] [31 66]] [3 100]] [12 100]] [36 80]] [695 5.92 [36 59] [36 76]]] [12 98]]] [12 100]] [2698 0.852 [6260 4.13 [6543 0.549 [7428 5.11 [1980 9.04 [898 1.4 [2758 8.47 [3905 5.53 [5605 1.14 [291 2.59 [6175 1.25 [12 84] [12 100]] [12 90]] [12 100]] [36 66]] [31 100]] [12 100]] [7449 7.59 [7657 2.19 [12 64] [12 100]] [12 100]]] [5972 21.3 [12 100] [12 95]]] [12 100]] [36 100]] [12 100]]] [31 100]] [4918 1.14 [3989 2.79 [751 2.86 [6262 3.31 [4924 10.1 [2084 2.11 [1769 6.23 [7085 1.87 [915 1.98 [21 56] [21 85]] [915 3.75 [21 63] [9 60]]] [9 52]] [21 100]] [9 55]] [9 57]] [3 100]] [21 81]] [21 100]]] [5974 2.89 [2259 15.5 [9 100] [15 77]] [9 100]]] [36 100]] [682 2.99 [4761 0.913 [2641 6.99 [6173 2.86 [6983 1.82 [7169 6.44 [7623 24 [826 1.52 [5308 4.85 [2701 3.19 [6230 6.95 [1429 13.9 [15 79] [31 57]] [31 100]] [15 94]] [31 100]] [906 1.52 [15 67] [12 66]]] [12 91]] [15 57]] [31 100]] [31 100]] [31 100]] [31 100]] [31 100]]] [5871 3.7 [2259 12.2 [5975 3.55 [695 2.87 [21 65] [21 90]] [21 100]] [3 75]] [12 40]]] [4282 1.77 [2446 8.85 [1995 2.89 [1078 9.32 [3 36] [36 56]] [31 100]] [31 100]] [3 100]]] [36 80]] [21 85]] [15 94]] [5110 15.4 [5041 2.04 [21 94] [21 100]] [21 76]]]] [5662 0.177 [1025 0.569 [5731 0.328 [3052 0.241 [2453 9.28 [695 2.51 [4154 0.471 [1239 34.2 [6031 3.14 [2696 0.569 [5385 1.43 [2752 15.7 [2927 3.57 [47 8.14 [395 0.564 [4520 2.13 [7354 1.86 [5574 15.1 [7335 6.78 [3952 1.19 [7440 0.858 [6529 0.743 [221 5.43 [5845 4.27 [809 2.3 [663 21.4 [2306 1.18 [6830 16.6 [2394 5.25 [1679 0.69 [5812 6.23 [2019 8.45 [23 12.8 [1614 1.31 [3019 3.36 [6050 2.98 [7258 4.76 [7409 3.43 [1226 7.67 [2334 1.03 [5218 1.54 [2488 5.42 [3497 5.75 [6732 16.2 [6155 27.3 [6721 6.67 [6566 3.23 [7314 13.2 [4794 1.34 [1116 0.78 [2526 7.11 [5163 13.6 [1997 10.3 [5827 0.967 [2628 43.6 [939 2.17 [5226 5.38 [4630 1.54 [4799 6.7 [3279 13.1 [4603 3.82 [5221 9.09 [5692 3.32 [2695 10.2 [3771 4.9 [355 3.76 [915 3.18 [5330 4.59 [5856 1.42 [1429 34.2 [4690 2.06 [6342 5.63 [1013 3.27 [30 27] [23 62]] [1 22]] [35 27]] [30 40]] [35 44]] [30 100]] [21 75]] [30 71]] [37 100]] [30 100]] [23 34]] [2259 25.6 [37 100] [30 100]]] [26 60]] [33 38]] [23 66]] [25 15]] [11 90]] [11 46]] [30 89]] [11 100]] [18 19]] [301 7.94 [30 85] [30 100]]] [992 5.15 [8 44] [8 91]]] [355 2.22 [2435 7.04 [30 80] [30 100]] [30 100]]] [21 90]] [30 94]] [11 95]] [30 100]] [11 71]] [22 89]] [8 90]] [8 68]] [5692 0.84 [1769 5.49 [10 52] [8 55]] [10 100]]] [8 100]] [23 100]] [10 60]] [11 100]] [0 84]] [24 100]] [4 38]] [65 1.34 [7665 3.82 [7085 17.3 [5568 2.22 [1888 3.5 [6566 22.2 [6342 1.37 [30 43] [6342 18.4 [15 30] [24 37]]] [11 100]] [8 29]] [30 100]] [30 100]] [30 76]] [30 98]]] [8 100]] [4 60]] [30 100]] [0 77]] [33 84]] [7623 4.37 [30 93] [30 100]]] [0 26]] [22 100]] [10 100]] [429 26 [2178 3.38 [6879 0.632 [4895 0.522 [6970 1.38 [328 10.3 [5211 7.82 [30 38] [1783 3.27 [1611 4.07 [30 79] [30 88]] [30 55]]] [4210 0.745 [30 97] [30 100]]] [25 50]] [30 68]] [33 45]] [2 28]] [791 33.4 [10 50] [21 33]]]] [22 97]] [38 100]] [8 100]] [5121 1.29 [22 53] [22 100]]] [24 84]] [8 73]] [11 100]] [2253 0.4 [30 94] [30 57]]] [24 87]] [70 4.46 [30 100] [30 92]]] [6711 5.15 [5673 11.7 [820 2.24 [5412 1.19 [791 2.74 [726 4.42 [2764 14.5 [5163 1.51 [392 11.2 [5216 1.73 [4852 4.42 [4218 1.08 [3424 1.33 [1400 2.84 [3547 1 [1062 2.62 [4929 8.2 [7623 18 [2589 4.13 [4920 14.3 [8 26] [30 100]] [8 100]] [5225 2.65 [2259 20.5 [30 84] [30 71]] [30 90]]] [8 87]] [22 18]] [8 100]] [26 50]] [23 50]] [8 100]] [8 100]] [23 50]] [23 77]] [30 100]] [11 68]] [4 87]] [996 0.305 [9 6.13 [384 4.65 [1769 34.1 [6230 9.15 [1 2.3 [2470 1.66 [2526 29.5 [5192 1.31 [6848 0.585 [5090 4.67 [7441 5.54 [22 26] [791 15.4 [11 60] [11 100]]] [22 100]] [35 100]] [23 50]] [429 33.6 [8 100] [4851 14.9 [8 42] [8 100]]]] [11 56]] [11 100]] [30 88]] [8 76]] [23 100]] [11 100]] [23 76]]] [5692 3.38 [7210 5.62 [2847 5.05 [5420 5.05 [1995 13.6 [5887 1.68 [5753 11.1 [7453 3.07 [599 3.57 [429 34.6 [2752 30.7 [23 42] [23 88]] [5412 25.1 [23 100] [23 87]]] [23 100]] [23 100]] [22 76]] [23 96]] [22 42]] [22 40]] [22 100]] [23 100]] [2567 1.27 [23 50] [23 90]]]] [11 100]] [30 93]] [30 84]]] [8 100]] [2707 22.4 [429 9.09 [1895 1.18 [30 95] [30 100]] [30 100]] [30 76]]] [7009 1.63 [5647 1.74 [144 3.3 [6524 0.588 [22 86] [22 100]] [22 100]] [22 88]] [22 100]]] [7211 0.78 [9 23] [9 84]]] [5480 0.471 [5218 3.99 [1497 0.245 [2913 4.83 [5753 8.08 [5420 4.79 [5615 0.427 [6862 2.73 [5911 1.66 [5114 4.36 [558 1.31 [826 1.71 [144 0.637 [440 0.371 [4605 1.29 [3956 1.33 [4279 22.3 [5219 4.58 [1239 8.73 [4851 1.01 [6091 2 [2081 6.06 [3547 2.62 [7411 0.898 [2259 18.4 [30 43] [30 18]] [35 63]] [8 100]] [23 60]] [30 66]] [30 91]] [5851 0.589 [30 13] [33 40]]] [8 87]] [8 10]] [8 100]] [8 100]] [23 69]] [10 25]] [23 63]] [10 100]] [8 100]] [23 100]] [10 71]] [23 100]] [8 100]] [5911 10.6 [5765 5.38 [22 38] [22 100]] [22 100]]] [1925 1.02 [30 100] [30 66]]] [8 100]] [10 86]] [1980 5.49 [880 2.6 [6342 1.78 [23 50] [23 69]] [22 100]] [4235 0.829 [771 3.18 [7169 2.95 [5491 1.63 [906 5.92 [23 64] [29 55]] [23 45]] [23 91]] [23 66]] [23 100]]]]] [558 5.68 [1400 1.18 [3286 1.45 [802 2.44 [3262 2.49 [5509 3.64 [4781 1.96 [6505 4.07 [6294 5.41 [809 0.775 [2149 4.47 [5693 0.642 [5211 11.9 [6727 2.44 [1755 1.64 [22 67] [22 100]] [22 44]] [4533 3.18 [22 87] [22 66]]] [11 45]] [22 37]] [22 100]] [22 60]] [11 66]] [22 42]] [12 44]] [37 100]] [7210 3.17 [9 59] [9 55]]] [37 100]] [5439 1.33 [10 71] [10 100]]] [10 100]]] [24 92]] [429 0.241 [5069 8.27 [2434 2.44 [30 98] [30 100]] [30 98]] [30 100]]] [4520 0.693 [504 14.5 [11 100] [11 66]] [11 100]]] [7031 0.588 [998 0.308 [4520 0.45 [2531 0.418 [1993 0.57 [6662 1.14 [981 0.417 [5486 0.975 [2199 0.452 [791 21.2 [5730 0.849 [221 7.2 [1429 21.3 [23 1.09 [6956 1.73 [23 31] [23 70]] [21 20]] [22 27]] [5576 2.11 [1 21] [24 83]]] [11 100]] [1995 0.458 [883 1.77 [6572 6.13 [6435 0.879 [11 36] [11 100]] [5574 10.4 [463 2.83 [24 90] [24 100]] [24 100]]] [22 86]] [11 76]]] [6479 1.39 [1253 1.89 [5731 0.835 [1911 0.506 [2178 3.28 [22 31] [23 60]] [22 75]] [11 100]] [11 50]] [23 80]]] [23 100]] [23 100]] [11 100]] [23 90]] [23 100]] [11 100]] [23 97]] [6572 37.1 [24 87] [24 66]]]] [5412 0.71 [695 4.13 [5655 0.219 [4781 0.381 [7444 1.2 [2628 2.3 [807 0.397 [1227 0.963 [11 84] [11 100]] [11 72]] [30 45]] [11 100]] [11 100]] [6660 0.219 [5655 10 [1899 9.97 [1068 4.69 [11 100] [11 90]] [11 60]] [11 100]] [11 100]]] [11 51]] [144 0.213 [760 0.775 [7491 5.4 [5667 2.25 [384 0.391 [7507 0.754 [1078 8.77 [5652 1.23 [5412 9.64 [23 57] [4414 16 [23 98] [23 88]]] [23 60]] [859 3.07 [929 1.04 [23 49] [23 100]] [22 82]]] [23 97]] [23 100]] [22 94]] [7497 8.34 [5412 11.1 [23 100] [23 85]] [23 71]]] [2531 0.511 [1101 1.07 [5883 1.11 [23 100] [23 93]] [23 100]] [23 100]]] [22 75]]]]] [3292 0.886 [1710 0.805 [6080 0.62 [1239 12.4 [6544 2.26 [1888 0.473 [328 2.13 [839 0.271 [4351 4.79 [6230 1.24 [6791 0.508 [3905 4.13 [3089 2.07 [2752 8.95 [1481 0.227 [6068 6.19 [1659 2.21 [1673 1.73 [4634 5.09 [6333 7.07 [6365 2.53 [6342 1.75 [1899 30.8 [7255 11.4 [2081 2.61 [7665 3.31 [1544 2.63 [7210 3.8 [1605 2.45 [851 1.39 [5 20] [8 33]] [8 66]] [16 22]] [37 36]] [8 88]] [12 22]] [12 55]] [1 30]] [1 19]] [12 100]] [5 87]] [2408 0.78 [4154 7.11 [37 36] [5 50]] [5 50]]] [12 100]] [19 41]] [37 57]] [12 76]] [663 8.08 [3028 1.58 [2818 1.14 [2753 1.54 [3244 6.93 [5732 3.03 [2225 1.06 [434 1.82 [134 1.43 [12 68] [5 71]] [12 88]] [12 33]] [15 100]] [35 36]] [37 40]] [2793 1 [1400 12.1 [12 100] [12 72]] [12 100]]] [12 100]] [37 43]]] [37 97]] [1062 14.4 [851 15 [3687 2.62 [3458 2.44 [2408 3.38 [3915 3.11 [37 34] [12 44]] [5 33]] [37 50]] [37 96]] [5 75]] [5 38]]] [12 76]] [5345 8.43 [221 1.33 [2826 7.83 [1764 0.736 [2760 1.35 [2259 1.9 [1544 5.85 [1078 8.59 [12 71] [12 33]] [12 62]] [12 97]] [12 90]] [12 100]] [3458 15.2 [5467 1.93 [2841 4.57 [144 4.86 [7305 4 [12 57] [12 100]] [5 36]] [5 72]] [12 100]] [5 76]]] [5110 1.33 [12 75] [12 100]]] [5 40]]] [8 88]] [37 100]] [3687 0.368 [4790 1.55 [791 6.06 [1899 29.4 [2939 3.94 [4154 24.3 [392 7.13 [5 23] [18 28]] [26 50]] [12 76]] [12 100]] [3335 1.41 [2178 1.06 [1025 1.5 [3488 1.39 [6865 2.21 [1239 1.52 [3079 1.9 [429 32.6 [695 2.87 [1078 32 [5 26] [12 83]] [37 40]] [12 90]] [37 100]] [35 25]] [37 100]] [12 37]] [12 46]] [12 45]] [12 100]]] [37 44]] [3813 0.503 [37 91] [37 85]]]] [7185 22.9 [2526 8.32 [3930 0.403 [4530 1.99 [23 5.27 [1062 0.473 [2818 2.56 [12 66] [12 100]] [12 100]] [6155 1.18 [12 95] [12 100]]] [12 68]] [12 100]] [4611 0.838 [23 12.8 [12 45] [12 42]] [8 42]]] [5 88]]] [5904 1.44 [7722 0.599 [1704 1.27 [14 87] [132 1.73 [731 18.9 [5692 5.03 [17 78] [17 66]] [17 56]] [17 63]]] [17 100]] [19 71]]] [12 15]] [6791 8.9 [15 99] [15 88]]] [30 90]] [3314 0.27 [4154 0.48 [7411 1.19 [5999 0.402 [4876 1.65 [3088 15.8 [2488 2.29 [3308 4.72 [3332 2.76 [3675 4.56 [3494 4.04 [688 3.78 [3488 1.07 [722 0.508 [3555 5.38 [3205 2.1 [3243 0.213 [3587 0.342 [3299 0.433 [7210 2.83 [3841 2.26 [37 99] [37 88]] [37 70]] [37 100]] [37 100]] [37 100]] [37 88]] [37 90]] [37 100]] [37 87]] [37 87]] [37 83]] [37 93]] [37 88]] [37 80]] [37 55]] [3182 2.36 [37 84] [37 100]]] [7169 4.88 [37 100] [19 57]]] [3088 1.58 [37 44] [37 73]]] [37 46]] [1533 1.84 [37 50] [37 87]]] [3716 10.1 [312 0.418 [3972 6.26 [37 100] [37 99]] [37 100]] [3771 2.62 [3905 2.99 [3978 4 [1078 13.7 [37 71] [37 100]] [37 100]] [37 100]] [37 100]]]]]] [6184 7.38 [4664 1.2 [15 87] [2259 0.752 [15 96] [15 100]]] [5851 0.583 [2474 1.27 [429 35.2 [15 100] [15 80]] [15 100]] [15 100]]]] [5199 0.48 [2892 0.428 [5219 0.463 [3921 1.39 [5231 0.126 [7441 0.494 [5211 3.3 [7449 5.23 [715 0.228 [5361 0.362 [3195 0.513 [2902 0.669 [2936 2.62 [4682 0.724 [6602 3.66 [4155 0.879 [5692 2.22 [5883 0.921 [3140 2.18 [3086 0.517 [5989 1.01 [5049 2.06 [7737 1.84 [3675 0.266 [3423 2.89 [7623 0.472 [6114 1.28 [802 4.2 [7734 1.44 [4851 4.83 [1391 2.12 [6524 6.82 [37 8] [7 55]] [35 29]] [15 57]] [2752 13.7 [18 60] [7 70]]] [21 66]] [35 71]] [15 27]] [7 100]] [12 63]] [18 81]] [9 60]] [15 75]] [37 100]] [35 100]] [11 73]] [71 2.55 [6899 1.22 [2752 8.87 [3223 1.29 [2526 22.5 [5562 2.99 [4306 5.26 [4789 3.66 [849 2.46 [248 3.04 [5368 3.79 [8 27] [20 27]] [33 67]] [8 85]] [15 28]] [33 87]] [33 100]] [8 67]] [8 100]] [1068 14.7 [2471 2.2 [3079 7.46 [1068 5.43 [7255 0.824 [7661 0.644 [5664 1.22 [107 1.62 [1783 23.5 [3874 1.52 [5972 4.5 [1888 2.82 [5238 0.747 [248 26.3 [435 2.56 [2470 1.82 [1400 9.13 [8 35] [12 40]] [15 97]] [23 44]] [33 70]] [887 5.51 [11 71] [11 100]]] [8 44]] [1239 15.9 [3074 0.712 [429 53.6 [1980 6.84 [6294 1.5 [1776 2.13 [2752 32.5 [6541 2.92 [12 98] [12 100]] [12 90]] [12 100]] [12 100]] [12 83]] [12 80]] [12 100]] [12 50]]] [12 100]] [33 66]] [33 100]] [12 100]] [12 100]] [12 92]] [12 41]] [37 84]] [15 100]] [1 58]]] [5360 7.58 [33 90] [33 100]]] [33 97]]] [33 100]] [15 100]] [5851 0.816 [5299 13.4 [5647 2.17 [5072 5.03 [1429 17.4 [6176 1.18 [5192 9.01 [33 100] [33 91]] [33 100]] [33 84]] [33 71]] [33 100]] [33 85]] [33 100]]] [33 100]] [4841 0.767 [3177 0.617 [1319 1.61 [7480 3.24 [4398 6.72 [7210 0.163 [2471 1.11 [23 20.2 [4851 1.37 [2808 1.22 [11 24] [15 100]] [14 33]] [5196 1.39 [33 50] [7176 14 [33 100] [33 85]]]] [15 100]] [11 25]] [15 90]] [15 100]] [33 100]] [15 100]] [33 54]]] [12 100]] [5421 1.31 [4663 3.49 [2939 8.64 [1078 5.09 [5071 1.95 [1980 24.3 [4682 7.04 [1899 14.1 [1813 1.12 [4655 4.81 [7398 3.36 [33 100] [33 87]] [33 80]] [33 75]] [33 62]] [33 100]] [33 85]] [33 71]] [33 100]] [33 80]] [33 55]] [33 62]]] [15 94]] [1405 0.491 [2475 0.99 [5871 2.42 [1986 2.32 [2752 6.37 [33 38] [7116 0.722 [1429 7.95 [6310 1.82 [15 69] [15 100]] [1068 0.551 [12 79] [15 40]]] [15 77]]] [4221 1.48 [15 61] [15 100]]] [22 37]] [15 100]] [15 100]]] [6694 0.506 [429 46.6 [3332 3.15 [7180 2.92 [248 0.769 [1078 80.9 [7096 2.16 [6379 1.69 [570 0.797 [4601 4.4 [328 9.37 [6661 1.7 [5223 1.87 [1686 0.759 [5224 6.7 [5605 14.2 [1648 5.16 [6170 11.5 [7770 0.448 [5509 5.24 [5197 2.81 [6203 3.68 [7305 3.39 [6732 0.397 [5227 16.9 [1253 7.17 [5225 0.268 [4279 1.77 [6883 2.49 [1899 25.7 [2817 1.66 [660 1.76 [2763 5.38 [429 18.5 [22 89] [22 72]] [22 62]] [22 62]] [22 100]] [35 66]] [8 16]] [22 100]] [5345 9.62 [5480 0.876 [22 98] [22 100]] [22 90]]] [429 28.8 [22 54] [22 88]]] [22 40]] [6196 0.945 [435 0.382 [5655 0.914 [711 0.766 [1679 0.876 [2764 1.1 [4279 0.301 [6727 2.11 [1101 1.18 [4533 6.03 [5118 1.42 [6743 2.99 [22 95] [22 100]] [22 100]] [22 71]] [22 85]] [22 80]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]]] [22 71]] [22 77]] [22 44]] [22 54]] [4533 0.768 [22 98] [22 100]]] [22 71]] [22 58]] [22 44]] [22 50]] [22 100]] [11 100]] [11 100]] [4690 2.33 [6711 1.13 [663 8.91 [22 56] [11 40]] [1783 6.39 [22 100] [22 66]]] [8 57]]] [22 45]] [11 100]] [15 33]] [35 50]] [859 1.47 [11 80] [11 100]]] [1078 1.15 [33 85] [15 60]]] [33 70]] [35 80]] [112 2.39 [22 45] [22 100]]] [22 100]]] [1184 0.137 [791 3 [22 23] [5368 3.29 [1436 0.247 [939 4.49 [1025 1.22 [22 50] [11 87]] [11 89]] [5883 1.2 [11 85] [11 100]]] [6364 0.327 [5843 1.01 [11 50] [22 100]] [22 100]]]] [11 100]]] [11 100]] [144 2.32 [37 100] [37 71]]] [8 93]] [7169 3.43 [1783 0.861 [33 88] [2879 0.481 [5299 8.49 [33 100] [33 83]] [33 90]]] [33 75]]] [5655 0.871 [5345 0.146 [5192 8.02 [5238 0.982 [5967 1.77 [543 4.58 [4154 0.341 [2902 2.59 [7491 1.11 [22 63] [22 100]] [22 100]] [2259 1.25 [22 96] [22 100]]] [22 91]] [22 85]] [11 100]] [22 65]] [22 100]] [22 60]]]] [7184 0.801 [2764 0.867 [743 1.44 [1400 11.5 [7324 9.97 [499 1.06 [784 0.78 [168 1.27 [819 1.75 [4312 5.12 [7636 3.98 [1157 3.93 [5040 1.83 [7085 39.6 [939 7.33 [434 7.01 [2280 1.06 [4414 22.1 [3087 3.36 [23 1.93 [1913 6.11 [4331 7.69 [4329 2.96 [791 3.47 [2020 5.41 [27 22] [1 50]] [23 18]] [27 100]] [27 100]] [25 35]] [5170 5.75 [12 13] [33 50]]] [37 100]] [2259 5.15 [27 71] [1 20]]] [17 11]] [28 64]] [27 74]] [12 50]] [21 81]] [4326 3.83 [27 44] [1429 0.956 [27 84] [27 100]]]] [27 100]] [957 12.5 [4312 11.6 [27 100] [27 61]] [27 100]]] [27 100]] [19 33]] [27 100]] [802 5.75 [2081 15.2 [939 0.652 [4135 39.1 [2526 3.5 [1226 1.42 [4141 1.62 [5480 1.3 [4115 56.1 [27 75] [23 33]] [23 30]] [28 35]] [23 100]] [4135 19 [1159 2.22 [27 45] [23 44]] [23 68]]] [791 23.4 [1062 5.38 [1157 3.7 [27 93] [27 100]] [27 100]] [27 83]]] [5480 5.83 [7491 3.45 [4279 7.04 [1253 7.23 [1911 0.431 [2259 18 [2149 5.66 [791 11 [27 100] [500 0.675 [4326 2.06 [501 1.64 [3027 4.08 [27 97] [27 100]] [27 100]] [27 100]] [27 100]]] [27 83]] [27 55]] [27 100]] [1068 2.62 [5855 4.2 [27 91] [27 100]] [27 100]]] [4279 18.1 [27 78] [27 62]]] [27 85]] [27 40]]] [4149 6.59 [2178 10.3 [27 50] [27 58]] [27 66]]] [21 90]]] [23 90]] [7409 14.1 [1410 1.69 [1786 1.27 [10 59] [10 100]] [4326 1.69 [10 90] [10 100]]] [10 55]]] [21 77]] [5480 4.32 [23 31] [22 66]]] [23 52]]] [5972 1.69 [2259 10 [2179 1.4 [11 21] [11 100]] [22 42]] [1047 6.33 [5999 6.19 [1239 29.1 [2526 47.5 [2822 0.324 [7451 1.14 [5488 18.5 [2398 0.634 [7335 0.713 [5110 4.36 [6193 1.56 [1068 0.924 [12 99] [12 100]] [12 100]] [12 82]] [12 100]] [12 100]] [12 62]] [12 100]] [12 100]] [12 80]] [12 83]] [12 85]] [12 85]]]] [296 10.1 [7632 9.53 [3528 5.62 [1410 1.14 [2259 5.55 [3130 6.16 [976 0.294 [5393 0.334 [2488 3.36 [3621 2.75 [3404 0.0905 [27 88] [3404 15.7 [4326 0.81 [286 0.181 [27 87] [27 100]] [27 100]] [2526 14.4 [3405 10.2 [4166 10.3 [27 93] [27 100]] [2461 2.09 [3405 18.6 [27 100] [27 90]] [27 100]]] [10 60]]]] [27 100]] [10 72]] [12 50]] [27 100]] [27 98]] [286 9.55 [7623 12.2 [10 66] [7623 17.1 [27 50] [10 66]]] [27 100]]] [10 100]] [4320 2.92 [27 71] [10 81]]] [27 43]] [10 66]]] [3506 1.81 [3061 3.17 [3952 0.339 [5883 5.09 [3918 1.2 [7305 1.33 [5267 10.4 [2491 0.852 [1764 8.85 [7343 4.36 [7314 2.22 [5480 6.94 [4279 1.17 [685 0.734 [435 2.94 [930 5.86 [8 96] [8 81]] [8 76]] [8 100]] [8 100]] [1980 12.8 [2596 1.81 [8 91] [8 100]] [8 85]]] [8 88]] [8 57]] [8 81]] [8 100]] [8 63]] [0 69]] [0 50]] [8 57]] [8 100]] [0 50]] [0 78]]] [11 100]] [6926 0.0526 [2674 0.256 [7571 0.586 [2580 0.426 [5519 0.0891 [5769 0.963 [736 0.347 [5812 0.383 [1163 0.197 [5482 0.745 [7132 2.87 [1391 1.83 [6184 1.68 [3315 0.645 [177 3.23 [7583 0.259 [7603 1.06 [3019 0.982 [5480 0.187 [1521 0.935 [3056 3.23 [6098 1.29 [4690 0.62 [2259 12.1 [5473 1.27 [6471 1.66 [1704 1.18 [145 11.2 [7269 1.53 [7585 1.21 [5668 0.272 [7188 0.445 [5403 0.78 [1400 0.399 [6178 0.395 [7192 1.26 [639 1.33 [338 16.5 [6584 0.472 [5640 3.07 [7563 5.99 [655 0.501 [429 8.52 [7618 1.18 [2846 5.05 [7623 2.01 [4362 2.85 [4235 6.33 [23 50.5 [1161 1.9 [3333 0.849 [3480 5.1 [5170 3.9 [3653 1.13 [1980 0.15 [5871 17 [2483 5.35 [7025 2.37 [4218 4.33 [3092 6.06 [7742 1.96 [673 6.89 [6103 5.5 [7354 0.418 [2470 5.94 [2493 4.13 [4920 0.852 [5698 2.73 [3659 2.99 [5254 1.45 [5317 1.59 [4896 6.37 [5906 9.8 [7034 3.77 [7428 17.5 [5472 3.26 [5692 16.6 [2849 6.89 [5314 6.91 [7266 8.43 [405 7.46 [6333 2.36 [738 7.25 [14 18] [7 54]] [32 78]] [19 47]] [2 61]] [6 100]] [6 20]] [36 36]] [3264 4.95 [6732 2.06 [13 50] [13 100]] [36 66]]] [32 53]] [13 83]] [13 100]] [14 60]] [7 100]] [10 100]] [24 81]] [24 100]] [14 56]] [13 100]] [2939 3.53 [5605 9.09 [4 39] [4 55]] [4 42]]] [7665 55.6 [5732 3.44 [6732 5.71 [7139 2.46 [2628 15.8 [4414 6.71 [2259 2.58 [36 21] [25 42]] [5 37]] [5 41]] [7 20]] [7 40]] [7 85]] [36 70]]] [32 38]] [7566 10.8 [7354 3.4 [7343 5.14 [25 41] [26 85]] [26 83]] [26 70]]] [4 27]] [12 100]] [13 62]] [13 100]] [4 100]] [14 63]] [2108 0.369 [3099 1.46 [5618 0.21 [7512 25.1 [1238 0.713 [7520 2.51 [4308 7.15 [5287 0.464 [3928 3.72 [99 1.87 [7514 5.87 [5140 3.63 [4414 18.3 [23 22.6 [25 10] [16 20]] [1 61]] [33 50]] [19 69]] [14 70]] [12 50]] [37 100]] [1 75]] [4 29]] [1238 7.51 [10 100] [10 50]]] [5267 2.37 [1089 57.9 [10 17] [22 75]] [10 71]]] [28 53]] [1 100]] [2137 0.6 [22 28] [18 33]]]] [5267 1.13 [1429 3.94 [772 21.2 [24 63] [24 100]] [24 100]] [24 100]]] [896 0.695 [695 0.881 [33 46] [33 93]] [4738 3.48 [26 66] [26 92]]]] [15 67]] [5692 1.32 [1 94] [1 100]]] [10 66]] [176 0.173 [19 32] [2091 1.43 [7139 2.04 [175 8.94 [5363 3.82 [19 59] [14 46]] [31 27]] [19 62]] [19 75]]]] [20 70]] [10 87]] [4657 3.47 [2624 2.66 [392 2.15 [1104 1.64 [7176 1.51 [1611 2.33 [33 21] [30 100]] [33 95]] [30 66]] [30 64]] [10 57]] [1 77]]] [3424 1.31 [4200 0.306 [6199 14.5 [7739 5.68 [4279 31.9 [5799 2.96 [2259 2.22 [22 26] [12 16]] [14 60]] [1101 2.96 [22 77] [22 42]]] [2149 3.7 [22 80] [22 57]]] [22 63]] [22 97]] [2 23]]] [20 95]] [7340 0.236 [7381 1.39 [5972 0.975 [2488 4.9 [3371 2.03 [2807 1.75 [5065 2.13 [731 1.59 [2526 2.78 [4800 2.76 [6581 0.334 [3921 1.12 [3286 2.14 [4655 2.65 [2764 0.215 [5872 2.26 [6031 4.45 [2752 0.682 [7665 4.51 [1239 31 [4154 1.86 [7 11] [1161 8.57 [4326 1.05 [29 14] [27 100]] [10 44]]] [10 80]] [4159 0.422 [7542 3.5 [11 4.85 [435 11.1 [3932 3.36 [7034 3.65 [663 7.85 [6103 8.2 [3652 7.94 [978 3.36 [939 24.9 [4789 3.65 [168 15.5 [600 12.1 [7347 2.39 [2453 6.17 [2849 4.7 [685 3.65 [5154 9.94 [7620 4.5 [5424 7.46 [14 16] [32 69]] [13 55]] [7 43]] [14 67]] [16 46]] [24 80]] [16 100]] [29 54]] [19 62]] [17 55]] [31 100]] [5 17]] [24 100]] [31 54]] [32 23]] [13 100]] [13 100]] [26 36]] [31 100]] [32 63]] [444 0.949 [26 63] [26 100]]]] [819 1.38 [328 5.41 [3374 1.89 [791 15.8 [906 10.6 [7512 16.2 [1505 5.45 [377 2.17 [3867 1.44 [6524 6.57 [3262 3.8 [7009 1.78 [6103 1.04 [7241 2.44 [1094 2.05 [2763 2.35 [4205 5.06 [131 5.94 [5491 10.9 [1198 5.11 [20 4.76 [5732 5.08 [5 14] [14 71]] [13 62]] [35 33]] [5 42]] [29 44]] [26 57]] [22 40]] [29 69]] [14 20]] [18 25]] [5 59]] [37 100]] [7 45]] [660 2.33 [5 33] [5 83]]] [14 54]] [5 80]] [2841 6.54 [10 16] [19 25]]] [5 53]] [4414 46 [3687 1.82 [999 11.1 [2701 1.77 [978 1.73 [435 13 [3308 1.02 [1980 17.6 [4154 6.18 [3905 13 [14 22] [14 66]] [15 20]] [22 34]] [13 33]] [14 75]] [5 23]] [29 50]] [2 71]] [37 100]] [15 75]]] [37 83]] [1783 0.735 [23 1.29 [7203 1.56 [286 12.1 [328 10.8 [1429 4.59 [2 50] [23 33]] [5693 4.87 [328 50.7 [14 33] [23 36]] [18 72]]] [23 100]] [23 71]] [3905 2.73 [429 15.2 [28 50] [22 33]] [37 42]]] [7665 4.88 [28 84] [7 35]]]] [27 100]]] [7101 1.48 [22 73] [22 100]]] [14 100]] [2764 10 [23 43] [22 24]]] [1 100]] [37 100]] [37 100]] [3597 8.74 [1429 7.36 [1888 16.1 [5 44] [7520 22.3 [5 78] [5 58]]] [5753 1.24 [1783 4.61 [5 31] [3905 4.2 [2752 24.7 [16 33] [19 72]] [17 62]]] [19 60]]] [19 55]]] [32 100]] [3102 2.2 [567 1.29 [5662 0.62 [6581 3.15 [7601 1.29 [1641 0.917 [2005 0.24 [2517 2.44 [1059 8.96 [7413 3.57 [384 0.889 [7742 3.01 [1546 3.69 [2760 2.85 [4202 3.76 [2770 6.69 [7110 7.46 [1011 17.2 [5429 1.78 [1533 3.82 [5969 2.92 [248 12.4 [3429 4.13 [3554 7.04 [7241 0.321 [6936 8.56 [6313 1.3 [3667 9.04 [1240 2.44 [7254 5.79 [4158 2.29 [4 23] [4 68]] [2 60]] [24 100]] [2 57]] [17 27]] [16 33]] [7 23]] [7 80]] [24 100]] [25 54]] [7 25]] [5 100]] [5 61]] [7 64]] [24 100]] [25 85]] [1 100]] [2259 1.11 [1239 0.967 [5 42] [2 40]] [24 40]]] [5 88]] [5693 2.06 [4 27] [4 42]]] [286 1.52 [394 0.677 [7 30] [23 85]] [23 100]]] [6363 6.64 [2 31] [25 87]]] [26 76]] [24 82]] [1 21]] [24 66]] [5 37]] [5 44]] [5660 1.47 [2081 1.86 [5412 7.73 [23 54] [23 42]] [23 70]] [978 6.92 [18 42] [16 41]]]] [2526 38.2 [1 52] [5693 3.45 [7561 10.6 [2 41] [1 57]] [2 75]]]] [24 93]]] [6230 2.29 [5240 2.01 [5647 9.23 [5510 2.46 [6616 1.68 [3554 3.04 [5 27] [17 29]] [17 37]] [17 76]] [567 6.86 [18 46] [2 33]]] [4 100]] [3423 2.26 [3220 2.56 [4479 0.732 [5462 5.1 [5907 1.09 [3823 3.71 [429 28.3 [2571 1.01 [1754 1.54 [5368 1.01 [3829 2.17 [3381 3.48 [3252 2.16 [4806 3.73 [429 10.9 [5 68] [2939 11.2 [2526 1.5 [21 1.87 [5 41] [18 55]] [5673 1.76 [429 13.9 [19 33] [5 73]] [5 44]]] [5 30]]] [5 40]] [5 83]] [19 72]] [19 60]] [5 100]] [38 71]] [5 90]] [1009 0.978 [931 6.62 [3342 1.29 [6230 10.1 [723 1.56 [17 32] [2752 25.2 [5 72] [5 50]]] [791 15.4 [19 44] [5 27]]] [17 27]] [7 37]] [7601 2.43 [5 83] [5 38]]]] [38 37]] [19 79]] [5 84]] [7693 0.732 [7 57] [19 57]]] [5 94]] [7 100]]]] [4424 4.48 [15 96] [15 100]]] [22 100]] [37 88]] [112 3.5 [896 1.8 [7343 25.5 [1919 4.39 [5368 2.16 [13 92] [8 50]] [13 100]] [13 70]] [13 100]] [13 100]]] [2005 5.75 [978 2.95 [2990 1.69 [828 7.52 [12 35] [31 94]] [12 100]] [31 89]] [12 71]]] [7722 0.711 [5239 0.935 [7176 2.21 [1919 6.85 [4997 1.56 [3794 4.03 [7382 1.66 [7413 3.44 [1580 1.18 [7314 2.67 [5833 1.93 [3008 0.901 [4154 22.6 [5281 12.1 [2841 4.46 [4611 3.98 [7354 7.74 [7735 1.44 [4479 2.39 [7210 6.28 [724 7.82 [31 3.47 [5412 5.33 [1077 11.1 [224 1.35 [7369 1.36 [1101 1.15 [695 15.4 [6557 3.35 [3929 22.9 [2608 2.31 [1769 35.5 [5509 5.05 [2616 2.26 [7512 13.3 [5 50] [4 21]] [429 21.5 [5 55] [4 52]]] [7 55]] [16 36]] [4 43]] [5 57]] [5 72]] [7 22]] [4 57]] [4 66]] [2 60]] [5 100]] [5 83]] [35 58]] [17 60]] [7 33]] [7 47]] [7 45]] [2826 8.18 [7 39] [7 72]]] [5 73]] [5 88]] [17 37]] [2 52]] [731 3.43 [719 13 [4851 3.4 [2628 2.67 [17 48] [19 62]] [17 37]] [17 75]] [18 26]]] [494 17.6 [17 27] [3 42]]] [7 41]] [791 8.49 [17 85] [17 40]]] [2 60]] [24 100]] [7595 0.724 [17 66] [38 52]]] [7 100]] [4 56]] [7 100]] [4 100]] [6524 1.01 [4478 1.42 [728 2.72 [2763 7.89 [3205 0.778 [4684 1.17 [2526 6.59 [3905 2.23 [1025 19.4 [134 14.7 [6334 1.08 [6936 3.77 [719 9.54 [6977 1.75 [719 5.08 [7665 21.4 [5 68] [17 17]] [5 58]] [5 76]] [14 34]] [7 45]] [5 90]] [24 42]] [4 50]] [2826 5.83 [17 30] [14 54]]] [4588 1.27 [957 1.71 [2470 4.35 [6866 2.94 [2526 10.6 [5 80] [7248 1.32 [5 26] [5 50]]] [5 90]] [4 100]] [5 100]] [5 78]]] [5 55]] [31 0.894 [1429 29.3 [5 57] [5 100]] [5 100]]] [4 80]] [17 43]] [7 52]] [7 100]]]] [1429 14 [7340 10.2 [32 62] [7600 4.15 [906 4.85 [32 56] [32 100]] [32 93]]] [7254 1.11 [435 1.1 [6342 0.321 [791 3.64 [695 3.8 [32 69] [32 100]] [2752 1.29 [13 29] [5345 3.39 [812 2.83 [32 93] [32 50]] [32 70]]]] [32 63]] [32 98]] [32 100]]]]] [772 1.65 [4332 0.364 [7373 0.861 [24 56] [24 90]] [24 69]] [772 12.6 [24 81] [24 100]]]] [1888 17.3 [5 78] [5 40]]] [1429 80.7 [429 46.3 [6031 3.5 [978 3.67 [4109 1.35 [906 1.24 [5640 19.2 [899 0.623 [13 95] [13 100]] [13 100]] [13 100]] [13 100]] [13 42]] [22 100]] [7 57]] [17 36]]] [6883 3.81 [6358 1.57 [3977 1.63 [7526 2.41 [4098 1.71 [1720 0.942 [5892 6.99 [2928 9.9 [3008 1.82 [5348 1.74 [1151 12.5 [3998 0.725 [2536 17 [17 40] [17 100]] [5 75]] [19 37]] [5 71]] [17 56]] [5 55]] [494 1.33 [17 85] [17 100]]] [16 62]] [7722 7.89 [5 38] [5 100]]] [896 12.2 [4533 3.44 [17 60] [19 66]] [7381 5.22 [17 87] [17 100]]]] [5 87]] [3008 5.53 [38 35] [7381 5.26 [38 70] [7512 23.2 [6575 5.88 [17 40] [17 50]] [17 70]]]]] [5 64]]] [791 5.71 [332 0.559 [2752 24.4 [25 93] [25 66]] [25 100]] [25 66]]] [5692 1.73 [4 96] [4 100]]] [6238 1.36 [6708 15.2 [3558 0.747 [6310 14.6 [1580 6.33 [7210 5.68 [3519 2.53 [6708 4.87 [17 60] [17 94]] [19 87]] [14 33]] [17 87]] [17 40]] [17 100]] [17 47]] [19 84]]] [7169 0.763 [7742 20 [1239 1.18 [429 16.2 [25 100] [7742 4.42 [2755 4.13 [25 91] [25 100]] [25 100]]] [25 100]] [25 75]] [25 100]]] [4320 0.61 [4799 3.26 [7659 1.12 [2616 2.12 [6092 0.565 [7665 16.6 [7412 0.392 [5879 1.36 [5972 1.8 [2471 1.27 [7381 0.472 [791 7.81 [5198 0.751 [1219 9.13 [1888 4.48 [2081 10.5 [6177 2.09 [6199 10.8 [5732 3.55 [25 26] [15 66]] [14 33]] [25 100]] [14 36]] [4 28]] [10 80]] [26 91]] [4114 11.6 [7456 3.55 [2913 1.57 [29 2.49 [312 3.95 [10 34] [2 63]] [12 90]] [15 35]] [12 66]] [10 100]]] [4 84]] [15 100]] [2913 2.46 [2474 0.728 [3698 0.741 [7665 9.9 [2470 3.8 [7009 0.914 [12 97] [12 100]] [15 68]] [12 59]] [12 100]] [15 100]] [15 76]]] [12 100]] [15 100]] [5007 7.46 [7314 5.26 [701 2.56 [248 14.5 [6936 4.5 [7665 46.8 [899 16.4 [7561 1.06 [14 39] [14 37]] [14 100]] [14 94]] [13 28]] [25 54]] [1980 1.67 [36 87] [10 55]]] [26 66]] [15 66]]] [7661 0.99 [12 44] [12 100]]] [1025 2.47 [25 38] [4 56]]] [12 100]] [2081 0.664 [2701 6.82 [5345 3.11 [6350 1.93 [663 2.86 [10 50] [10 55]] [10 100]] [10 88]] [15 100]] [7449 1.21 [10 47] [15 44]]]] [10 100]]] [2081 11.2 [2565 0.78 [2470 7.68 [31 82] [5846 3.12 [6579 1.43 [7722 3.31 [7512 11.2 [31 85] [31 100]] [31 100]] [31 100]] [31 100]]] [31 100]] [2 37]]] [6074 1.37 [1239 4.74 [144 4.13 [7192 1.43 [4851 3.41 [6589 2.86 [6581 3.73 [7176 5.15 [1769 4.48 [6732 2.26 [7512 8.76 [12 47] [7188 12.8 [5 85] [5 36]]] [5 17]] [19 50]] [7 54]] [3905 3.7 [5515 1.49 [5 40] [5 61]] [791 8.78 [17 25] [6583 8.08 [6206 2.98 [1429 33.2 [17 80] [17 50]] [17 81]] [7512 35.7 [19 50] [17 58]]]]]] [5 87]] [6554 1.47 [480 2.33 [4929 12.3 [7009 1.92 [1429 25.3 [7598 1.92 [7 37] [7598 17.1 [19 48] [5 22]]] [7 44]] [5 78]] [7 100]] [17 75]] [17 41]]] [2752 19 [17 50] [17 85]]] [2849 6.97 [17 60] [19 40]]] [7520 0.924 [7 21] [7 50]]] [7 64]]] [7241 0.949 [7101 0.824 [2902 0.461 [233 2.04 [1078 10.5 [4308 2.16 [12 24] [12 52]] [906 1.85 [5757 2.19 [4154 12.1 [29 26] [1 100]] [29 93]] [29 100]]] [33 100]] [2091 1.44 [7722 10.9 [29 77] [1 40]] [29 54]]] [29 80]] [12 92]]] [896 12.9 [429 16.7 [5871 6.14 [11 2.54 [4851 0.832 [6230 1.92 [14 32] [31 66]] [2259 2.79 [14 85] [14 100]]] [31 100]] [14 97]] [31 46]] [14 95]]] [6581 2.35 [3931 2.88 [5851 0.412 [5 58] [5 55]] [5 66]] [1429 48.5 [1198 0.754 [896 4.44 [5 59] [5 86]] [5 100]] [5 55]]]] [7542 2.45 [6375 4.65 [2913 0.921 [7009 14.2 [1161 3.11 [134 13.5 [5343 2.24 [5969 2.11 [328 9.12 [1452 5.2 [2902 1.12 [5037 1.03 [100 4.85 [2130 8.67 [1451 4.16 [4414 14.3 [6015 12.6 [112 1.5 [144 89.9 [2058 0.232 [7354 4.87 [83 4.35 [2794 2.3 [1701 10.9 [168 3.82 [1982 1.12 [663 12.3 [5 14] [19 50]] [22 33]] [83 2.09 [203 18.4 [2466 9.94 [1982 19.9 [7245 10.9 [2241 3.45 [173 6.86 [1786 1.37 [7665 27.2 [5898 7.8 [5346 2.52 [19 75] [19 54]] [19 55]] [7514 29.4 [13 45] [7737 3.45 [19 60] [14 33]]]] [19 100]] [19 50]] [19 89]] [33 50]] [15 25]] [19 50]] [18 41]] [18 43]]] [22 62]] [14 55]] [7256 7.09 [7245 1.54 [1436 2.76 [7514 7.55 [19 50] [4327 5.15 [1429 23.6 [19 78] [19 50]] [19 80]]] [19 58]] [19 50]] [19 65]]] [36 45]] [2137 0.305 [19 95] [19 100]]] [22 29]] [5753 2.4 [19 21] [29 37]]] [14 57]] [14 31]] [13 45]] [13 64]] [2213 0.0639 [7687 16.9 [5918 6.43 [7606 10.1 [6131 2.57 [2093 1.62 [57 1.34 [5412 0.606 [7722 19.7 [19 79] [14 50]] [19 100]] [19 100]] [19 85]] [19 75]] [13 42]] [5 42]] [32 50]] [19 71]]] [22 37]] [14 40]] [26 35]] [14 40]] [18 41]] [14 78]] [17 28]] [10 100]] [19 34]] [30 22]] [13 66]] [32 100]]] [7251 5.38 [4806 3.07 [6548 0.642 [989 3.54 [112 12.7 [6395 13.2 [5744 1.53 [17 64] [14 44]] [17 81]] [38 33]] [17 65]] [3732 1.9 [7085 1.39 [134 19 [5895 2.85 [3989 1.41 [1888 10.8 [4478 7.19 [4154 2.54 [1704 16.1 [2526 20.6 [728 4.82 [17 94] [17 88]] [17 66]] [17 57]] [17 27]] [17 66]] [17 100]] [19 57]] [17 75]] [3 33]] [17 100]] [17 41]]] [17 40]] [17 95]]] [1223 4.98 [5368 11.2 [6342 1.66 [5637 7.49 [673 1.85 [26 71] [2748 7.14 [7520 4.47 [6034 0.888 [1899 6.02 [663 1.46 [26 94] [5079 1.21 [26 77] [26 85]]] [26 77]] [26 100]] [26 71]] [4426 0.611 [2749 22.6 [26 100] [26 87]] [26 100]]]] [19 33]] [26 46]] [26 100]] [26 50]]] [7622 0.697 [144 13.8 [1475 1.2 [719 6.18 [6091 2.06 [5472 31.5 [1783 1.72 [7698 5.75 [1526 1.69 [5398 1.85 [13 93] [13 100]] [13 100]] [13 100]] [13 100]] [13 83]] [13 100]] [13 100]] [13 100]] [13 55]] [13 100]]] [2966 2.53 [5409 0.333 [7340 1.99 [2616 5.26 [2488 4.5 [6260 0.159 [2962 5.02 [2752 10.5 [957 2.54 [6550 5.65 [145 5 [7421 0.552 [5472 1.39 [811 0.3 [328 7.14 [4445 0.234 [968 10.8 [7526 9.2 [7032 4.06 [2630 1.89 [1078 46.8 [5412 4.13 [148 0.585 [1231 1.61 [7234 12.9 [1240 1.22 [6173 0.666 [7155 13.2 [4549 3.5 [7224 2.56 [7554 0.25 [6842 0.54 [2417 3.25 [6768 1.17 [7354 10.9 [1265 0.448 [5926 0.626 [2752 1.01 [144 20.1 [7624 0.65 [1 7.09 [7381 3.21 [7588 4.22 [4659 15.7 [7623 23.7 [7569 2.96 [4939 12.6 [6546 7.69 [2913 6.68 [5110 16.5 [5316 11.6 [5299 0.149 [2272 6.73 [772 3.5 [7222 4.83 [7585 2.19 [5099 5.14 [4865 2.44 [7615 2.46 [19 11] [3 81]] [3 100]] [6 53]] [6544 28 [31 57] [14 90]]] [30 70]] [24 92]] [26 70]] [10 37]] [32 77]] [30 91]] [32 58]] [31 100]] [6 86]] [14 100]] [30 61]] [1 100]] [4 51]] [5 39]] [7665 23.8 [7665 15.7 [31 43] [6 66]] [31 93]]] [30 100]] [19 43]] [1451 0.377 [5643 0.283 [2911 1.34 [100 3.34 [5368 0.898 [2280 6.72 [1955 2.43 [7334 0.0418 [5007 7.35 [2023 3.41 [1436 1.1 [328 2.99 [6310 0.823 [14 17] [14 33]] [19 28]] [12 54]] [14 50]] [18 31]] [14 28]] [35 55]] [19 44]] [14 33]] [18 53]] [10 100]] [19 36]] [14 26]]] [20 83]] [3 75]] [36 68]] [31 100]] [4 92]] [7766 1.53 [26 50] [26 100]]] [10 81]] [6 92]] [31 100]] [19 72]] [31 100]] [24 89]] [6 97]] [10 95]] [30 80]] [540 7.69 [2251 2.22 [1429 56.1 [6199 1.14 [5412 10.5 [1400 2.33 [31 31] [31 75]] [5692 4.27 [5412 14.7 [5267 2.41 [29 41] [31 92]] [1888 22 [4279 14.1 [29 21] [32 62]] [4 37]]] [29 64]]] [7665 6.11 [21 87] [19 71]]] [17 47]] [7665 1.31 [31 83] [31 92]]] [29 100]]] [695 3.3 [10 32] [10 91]]] [30 100]] [7308 2.65 [3726 5.15 [701 1.75 [31 81] [31 100]] [31 100]] [31 100]]] [3368 3.88 [7722 5.88 [36 89] [6 62]] [36 91]]] [2289 0.217 [2966 0.838 [2628 0.154 [221 0.34 [5941 3.93 [6970 0.75 [478 0.827 [4637 1.31 [19 54] [19 85]] [429 26.8 [17 54] [6681 1.36 [19 61] [35 45]]]] [17 33]] [2259 58.3 [17 71] [17 71]]] [6 50]] [38 72]] [38 80]] [38 62]]] [31 100]] [5005 1.29 [4574 1.28 [6382 3.4 [5110 1.85 [7241 2.44 [7354 4.26 [5314 1.23 [2526 0.346 [1646 12.5 [1078 12.7 [3099 4.2 [896 13.4 [2470 2.18 [4573 3.55 [791 1.04 [4895 1.12 [1783 9.18 [5673 3.18 [4326 6.94 [2916 1.31 [1899 15 [6205 12.8 [5999 5.17 [1078 3.6 [6 20] [6 42]] [18 37]] [18 78]] [28 33]] [30 57]] [19 33]] [14 20]] [2259 48.7 [18 59] [18 34]]] [14 45]] [2939 1.11 [14 25] [19 33]]] [30 53]] [1078 4.14 [10 27] [30 57]]] [14 85]] [1 100]] [1116 13.5 [788 2.56 [364 4.6 [144 1.88 [7203 3.36 [30 27] [19 75]] [30 57]] [19 33]] [19 37]] [30 94]]] [7665 3.45 [18 68] [7 64]]] [7665 10.5 [1 13] [7 55]]] [19 81]] [18 51]] [5716 3.54 [2260 7.15 [7665 3.36 [18 55] [791 0.356 [19 34] [19 55]]] [19 57]] [30 44]]] [7305 0.932 [30 71] [15 83]]] [14 100]] [2298 0.638 [14 88] [14 50]]] [7 100]]] [5313 1.82 [31 57] [15 100]]] [7677 8.29 [2260 4.33 [1899 3.65 [939 7.65 [1769 9.22 [646 2.73 [1025 2.67 [4789 1.25 [2336 3.65 [5472 4.07 [36 87] [7722 14.3 [7068 4.07 [4851 2.13 [791 2.09 [3905 6.02 [36 94] [36 100]] [36 100]] [36 100]] [36 100]] [36 95]]] [36 100]] [36 100]] [13 62]] [36 100]] [36 66]] [36 71]] [36 92]] [2260 17.2 [13 55] [36 71]]] [36 57]]] [791 17.9 [2611 12.2 [2351 0.578 [2260 1.96 [6 51] [18 57]] [6 100]] [6 90]] [7421 17.9 [6 75] [6 100]]]] [2026 8.03 [1933 2.98 [1400 2.52 [3971 3.14 [4231 3.97 [5753 3.05 [168 33 [695 8.17 [6036 1.55 [4327 1.07 [7738 7.45 [5641 18.4 [203 7.32 [19 29] [3 23]] [19 77]] [7724 2.65 [78 0.843 [19 45] [19 57]] [19 80]]] [1079 8.52 [19 53] [19 85]]] [19 100]] [14 71]] [7203 1.95 [2127 1.15 [2241 0.348 [5205 3.97 [7665 28.7 [19 84] [1 30]] [18 45]] [19 87]] [5 28]] [19 81]]] [19 100]] [19 78]] [10 33]] [32 42]] [19 70]] [19 100]]] [7520 2.22 [2591 3.31 [4 68] [4 100]] [4 42]]] [1219 0.787 [6959 1.65 [7695 3.33 [4320 1.55 [896 2.54 [1888 2.04 [10 52] [31 30]] [7 39]] [10 88]] [30 100]] [31 100]] [10 87]]] [5478 0.173 [5782 1.95 [2426 0.499 [695 6.16 [6960 8.74 [7601 0.803 [2913 1.86 [1219 0.726 [3067 0.821 [6124 1.26 [772 5.33 [2793 4.81 [6921 0.59 [663 2.9 [3806 7.14 [2957 1.26 [826 1.5 [7665 20 [5970 3.71 [6173 3.31 [3251 5.81 [2897 0.0468 [1069 3.3 [6494 1.69 [7245 8.69 [2995 1.3 [3929 0.867 [5972 1.66 [1400 4.34 [4326 1.93 [1429 26.7 [4929 4.74 [6122 1.46 [6981 3.75 [134 0.956 [2753 3.18 [2004 4.73 [2055 1.87 [394 10.2 [2445 2.79 [7255 12 [2526 3.11 [791 3.57 [10 18] [2846 1.39 [7512 13 [36 25] [32 23]] [28 43]]] [24 29]] [12 33]] [19 32]] [19 50]] [24 40]] [23 55]] [7512 9.22 [26 41] [36 42]]] [16 57]] [36 80]] [23 50]] [1025 6.02 [4 33] [4 55]]] [2846 24.9 [7514 0.282 [1587 9.59 [1025 1.87 [788 1.18 [2466 6.89 [30 18] [22 28]] [18 54]] [17 28]] [7 54]] [24 44]] [27 75]]] [18 40]] [10 55]] [5403 1.08 [36 45] [31 100]]] [17 62]] [10 100]] [18 73]] [14 80]] [10 70]] [17 29]] [14 38]] [31 100]] [5421 0.882 [7565 6.17 [23 52] [23 100]] [23 100]]] [6977 8.02 [6581 24.5 [6205 6.1 [2259 62.5 [5198 5.02 [2766 8.38 [7514 6.17 [4799 22.4 [7722 5.47 [1995 1.81 [4851 22.7 [6544 5.75 [36 29] [36 62]] [32 50]] [10 50]] [2259 33.8 [2526 1.39 [14 48] [14 60]] [36 68]]] [36 90]] [14 40]] [36 37]] [36 72]] [12 27]] [7665 27.3 [16 54] [18 37]]] [19 80]] [14 92]]] [23 41]] [12 54]] [10 100]] [221 1.3 [4319 2.02 [36 20] [10 100]] [10 38]]] [5662 1.77 [23 87] [23 100]]] [5007 1.1 [3917 2.42 [1980 7.4 [4308 3.5 [14 57] [14 100]] [30 36]] [14 94]] [14 40]]] [896 6.99 [24 100] [24 75]]] [7512 8.9 [12 75] [12 100]]] [36 100]] [10 67]] [5007 2.25 [5211 1.01 [2846 1.27 [5322 9.55 [30 21] [30 80]] [221 3.23 [30 71] [30 100]]] [1587 1.01 [30 100] [30 81]]] [7 50]]] [1925 2.39 [4154 26.3 [5732 3.76 [2526 4.27 [3905 19.2 [36 97] [36 57]] [36 45]] [36 54]] [32 75]] [36 100]]] [31 100]] [7665 9.2 [7665 0.838 [10 24] [2259 37.4 [36 27] [36 78]]] [7680 5.02 [144 11.9 [134 1.36 [6077 7.25 [7722 13 [1997 3.36 [2752 21.4 [36 49] [3641 2.37 [7722 8.21 [36 73] [36 70]] [36 100]]] [36 50]] [36 49]] [7 88]] [141 6.65 [14 40] [7 62]]] [14 31]] [10 100]]]] [12 82]] [36 100]] [36 100]]] [2103 1.43 [791 8.27 [4404 1.32 [1899 12 [4426 2.56 [3931 3.75 [7722 2.59 [31 48] [31 30]] [31 94]] [31 100]] [31 57]] [31 100]] [31 88]] [10 100]]] [4270 0.596 [6791 1.22 [3644 1.88 [1025 4.69 [850 0.433 [2199 0.443 [392 2.39 [7108 1.31 [36 82] [36 100]] [30 84]] [36 62]] [36 100]] [24 82]] [899 1.18 [4342 1.36 [36 62] [19 50]] [36 100]]] [13 90]] [5693 0.699 [36 90] [36 100]]]] [899 1.19 [6791 2.46 [7512 4.2 [8 57] [3675 3.31 [4369 8.37 [13 98] [10 42]] [13 100]]] [13 100]] [13 100]]] [1047 1.51 [6230 1.85 [7742 6.25 [7587 4.42 [5309 1.32 [7711 1.72 [7404 4.19 [7009 2.24 [6129 13.5 [7032 3.11 [7667 7.94 [5314 2.67 [2100 1.63 [6743 2.99 [7566 1.96 [6 71] [4 25]] [17 33]] [2 33]] [6 100]] [2526 47.6 [6 100] [6 91]]] [31 50]] [16 52]] [5 37]] [6123 13.9 [2577 3.88 [4891 4.35 [1429 46.2 [7237 2.96 [6 96] [6 94]] [6 62]] [6 100]] [6 100]] [6 71]]] [2993 3.65 [4851 11.3 [5 27] [5 75]] [5 80]]] [19 54]] [31 100]] [4 81]] [4741 1.99 [695 15.8 [3905 1.82 [2616 7.56 [4 44] [7586 2.73 [17 21] [5 57]]] [7 42]] [5 75]] [5 33]]] [6732 4.35 [24 71] [24 100]]]] [899 1.87 [4079 1.07 [4154 3.31 [7457 2.65 [5211 1.15 [6791 8.23 [4799 1.96 [2526 1.35 [5316 3.82 [32 62] [32 100]] [12 63]] [32 92]] [32 100]] [12 63]] [12 50]] [32 86]] [31 100]] [32 96]]] [1919 9.53 [407 11.3 [144 2.01 [1 0.139 [5577 16.2 [6920 11.6 [7301 18.7 [7255 0.78 [6959 16.7 [6801 0.222 [7040 10.5 [2268 1.17 [6 98] [6 100]] [6 90]] [6 100]] [6 77]] [6 87]] [6 100]] [1364 15.6 [6 64] [299 7.94 [6 92] [6 100]]]] [6 75]] [6 100]] [6 73]] [2616 10.2 [6 81] [16 50]]] [6 42]]] [3905 4.84 [31 59] [36 55]]]] [5030 2.67 [2536 0.726 [5267 1.73 [5969 2.99 [927 1.73 [4651 0.713 [7665 23.4 [7747 0.242 [5412 1.33 [996 1.63 [20 63] [8 95]] [2976 0.797 [4 66] [4 100]]] [20 100]] [5288 1.01 [2062 5.9 [7737 5.11 [5364 14.2 [1996 3.46 [7142 1.39 [4699 0.325 [4 57] [848 6.64 [2199 16.5 [3543 1.83 [4876 15.1 [7758 0.773 [7311 21 [6936 8.16 [5211 0.325 [20 91] [791 13.1 [3989 8.62 [20 100] [20 85]] [20 85]]] [20 83]] [5802 0.975 [1899 1.64 [20 88] [20 100]] [20 100]]] [20 100]] [20 80]] [20 66]] [20 77]] [20 88]]] [20 100]] [20 87]] [20 63]] [20 71]] [20 57]] [20 100]]] [4 66]] [27 44]] [4 30]] [20 42]] [8 62]] [8 100]]] [5409 9.84 [2452 0.0468 [1997 8.49 [4414 1.8 [7512 32.5 [2627 6.16 [1382 1.35 [5873 3.5 [2387 8.28 [1919 51.9 [2419 6.68 [2081 1.31 [978 6.28 [4726 0.879 [2566 1.83 [6 92] [6 100]] [6 100]] [6 70]] [6 83]] [5598 9.07 [6 76] [6 100]]] [6 57]] [6 75]] [6 41]] [6 100]] [6 100]] [6 72]] [7255 2.99 [2038 2.31 [6 69] [6 100]] [16 55]]] [20 57]] [6 37]] [6920 6.19 [6 70] [299 5.13 [2262 11.2 [6 87] [6 55]] [6 50]]]]] [866 2.07 [6708 1.44 [3905 2.34 [4611 7.46 [5851 6.63 [1062 4.79 [4897 0.657 [1463 0.901 [5 23] [4681 1.02 [3597 1.19 [2488 1.99 [929 0.345 [3929 7.81 [906 9.23 [7009 0.736 [5145 3.33 [5 83] [5 83]] [5 75]] [5 60]] [5 43]] [6732 0.69 [2752 13 [5 66] [5 94]] [5 100]]] [13 66]] [5 50]] [5 62]]] [5 46]] [23 10.6 [1062 7.08 [19 77] [5 21]] [5 72]]] [5 46]] [31 54]] [6865 0.595 [3262 1.77 [5 72] [37 100]] [37 90]]] [13 33]] [13 100]]] [791 26.9 [13 100] [13 96]]] [1238 2.87 [7711 1.26 [6581 1.05 [233 0.579 [2847 0.427 [7734 2.16 [896 3.41 [673 2.03 [107 0.835 [2764 0.79 [5999 3.58 [978 0.847 [5488 0.748 [6031 1.2 [2081 1.02 [286 5.92 [5851 1.29 [5484 0.107 [2259 1.61 [7169 16.4 [5211 7.9 [6471 4 [18 26] [26 100]] [22 93]] [26 58]] [5472 0.782 [6199 4.31 [248 6.32 [1052 0.443 [18 24] [10 100]] [4 30]] [18 58]] [36 100]]] [279 21.6 [18 51] [16 55]]] [5480 10 [2023 0.671 [5753 1.86 [2752 3 [29 30] [36 33]] [21 40]] [22 28]] [33 23]]] [6 41]] [5170 2.21 [731 0.863 [1451 0.2 [1899 0.326 [22 27] [10 37]] [19 30]] [18 69]] [33 100]]] [6502 0.357 [1764 2.07 [7236 0.722 [93 1.31 [22 89] [22 100]] [22 100]] [22 100]] [22 100]]] [12 100]] [4547 2.01 [1899 6.41 [4926 0.0807 [2005 0.184 [1738 2.7 [5484 3.2 [1995 3.18 [18 38] [18 90]] [5647 2.04 [18 60] [18 50]]] [38 50]] [38 42]] [5484 0.0807 [18 93] [18 100]]] [18 52]] [6 87]]] [584 3.36 [10 79] [23 85]]] [4488 0.258 [2259 0.254 [4160 0.285 [22 54] [22 83]] [7352 0.174 [4414 0.957 [23 38] [23 60]] [29 54]]] [22 100]]] [33 90]] [4602 0.659 [384 0.579 [248 20 [26 36] [2526 14.4 [896 0.778 [26 90] [26 85]] [26 50]]] [26 76]] [26 100]]] [4235 1.52 [7419 1.11 [2749 1.57 [2755 1.59 [1081 9.13 [647 12.6 [7601 2.55 [2567 0.339 [5605 10.2 [248 8.64 [6791 7.03 [663 0.281 [1888 19.7 [1883 0.475 [429 20.5 [2707 6.46 [5851 0.921 [18 58] [4 42]] [16 30]] [18 67]] [2 44]] [7665 25.1 [4 29] [26 45]]] [2260 0.112 [5198 4.83 [5641 0.994 [18 61] [16 42]] [13 50]] [18 75]]] [1 16]] [1400 4.42 [673 9.65 [26 28] [26 65]] [26 100]]] [14 40]] [18 100]] [284 2.79 [4325 4.11 [2763 4.9 [1906 3.29 [5971 3.76 [5413 0.773 [18 63] [18 100]] [18 58]] [19 33]] [1888 5 [2752 34.2 [18 93] [18 83]] [18 61]]] [15 33]] [19 66]]] [22 35]] [26 75]] [26 58]] [26 84]] [16 47]] [1 30]]] [2470 15.4 [2753 4.08 [5484 2.75 [728 3.94 [685 6.67 [18 41] [896 7.58 [7520 1.34 [5693 1.2 [18 71] [18 77]] [18 83]] [18 30]]] [18 100]] [5007 9.9 [7693 2.09 [187 10 [1429 70 [2199 0.808 [5346 12.4 [5090 8.12 [4977 1.99 [5623 2.44 [6740 10.3 [397 22.9 [560 42.4 [724 13.9 [719 7.34 [663 1.2 [18 44] [5647 6.05 [18 93] [18 100]]] [383 11.8 [18 83] [282 24.2 [7245 7.92 [18 77] [18 72]] [18 62]]]] [16 50]] [6 42]] [18 51]] [16 37]] [5623 11.3 [6 71] [18 63]]] [18 52]] [16 40]] [7 45]] [18 85]] [7185 16.8 [2259 11.1 [978 9.68 [7 35] [7 50]] [16 44]] [16 38]]] [6833 11.6 [18 83] [18 100]]] [5692 11.3 [4645 4.61 [18 56] [18 100]] [16 55]]] [18 58]]] [16 40]] [26 95]]] [22 96]] [791 5.63 [33 100] [33 71]]] [7009 7.92 [7373 0.574 [7188 0.505 [1060 3.55 [5851 1.5 [2526 1.02 [26 85] [26 74]] [26 66]] [26 96]] [38 66]] [26 76]] [26 45]]] [429 8.49 [2616 0.864 [6733 2.84 [26 92] [26 100]] [26 100]] [26 66]]] [2259 3.91 [10 55] [10 100]]]] [7526 8.98 [3637 13.5 [2456 7.92 [5575 8.07 [7382 4.2 [24 84] [24 100]] [24 100]] [24 100]] [24 58]] [24 64]]] [1783 8.06 [2628 0.762 [7665 22.3 [1995 0.966 [1311 6.86 [6100 6.55 [2241 0.546 [2280 0.219 [2283 0.924 [2564 1.39 [2259 18 [22 75] [6 91]] [6 100]] [6 100]] [6 100]] [6 66]] [7549 1.24 [2037 3.55 [2569 14.9 [6 82] [6 70]] [6 50]] [6 50]]] [6 57]] [22 57]] [7405 0.211 [5983 1.85 [4889 10 [5609 0.485 [6 87] [6 100]] [4 33]] [2611 1.63 [6 83] [6 100]]] [6 100]]] [6 47]] [22 55]]] [7735 0.484 [2232 0.259 [3100 0.357 [899 2.52 [5198 1.87 [112 9.03 [3278 1.29 [721 0.581 [2143 4.5 [1899 7.81 [1813 1.39 [7177 1.63 [5316 0.562 [251 1.95 [248 19.4 [567 2 [3579 1.13 [6525 4.59 [7354 8.2 [6524 5.72 [1 36] [5732 5.51 [4658 1.6 [7 62] [33 60]] [7 100]]] [6529 1.68 [7 75] [7 100]]] [25 50]] [7 100]] [29 61]] [5692 1.55 [25 42] [25 75]]] [4655 9.48 [1 60] [1 100]]] [7 100]] [7 100]] [25 65]] [5753 1.99 [1 66] [1 52]]] [1 69]] [36 90]] [4682 1.52 [1 93] [1 50]]] [36 85]] [99 1.44 [5249 1.79 [5705 6.02 [5472 2.54 [5693 11.2 [25 37] [1 87]] [36 100]] [36 100]] [36 50]] [25 57]]] [2993 3.17 [1181 1.72 [36 78] [36 100]] [36 90]]] [6524 14.7 [1911 1.81 [248 27.2 [1 100] [250 5.11 [1 75] [1 100]]] [1 100]] [1 87]]] [5413 3.05 [2143 2.04 [6528 7.66 [1 60] [1 88]] [1 100]] [1 76]]] [7 100]]] [5154 0.352 [5672 3.08 [6920 1.34 [4956 2.41 [2488 2.96 [6674 1.58 [248 0.366 [7354 3.66 [5480 3.27 [1678 0.21 [39 3.66 [7514 36.8 [2342 7.83 [4896 2.63 [1259 0.263 [64 0.375 [4198 7.03 [2143 8.03 [1948 5.55 [7724 7.22 [1239 16 [791 8.41 [7321 2.04 [7301 7.89 [1932 4.46 [19 77] [19 44]] [38 50]] [19 100]] [19 50]] [19 85]] [19 63]] [18 50]] [3 20]] [19 94]] [177 32.5 [19 91] [19 66]]] [19 100]] [32 62]] [19 60]] [19 96]] [19 56]] [14 62]] [10 33]] [19 41]] [25 36]] [5 33]] [13 100]] [19 100]] [22 33]] [19 100]] [18 41]]] [1503 0.635 [2753 4.74 [2536 2.96 [913 3.7 [5 91] [18 33]] [5 57]] [5 100]] [5 100]]] [4320 0.457 [5211 2.39 [234 0.126 [6665 0.356 [674 0.722 [23 2.32 [7552 1.13 [7698 2.3 [4802 0.545 [6269 2.18 [5413 0.49 [5972 1.73 [4844 3.88 [1436 1.16 [150 1.92 [6524 5.4 [6350 3.94 [3100 0.818 [6045 2.62 [6537 1.38 [7675 4.35 [3905 2.16 [2493 0.93 [7542 4.92 [392 1.05 [999 2.7 [3765 2.44 [695 10.4 [5843 4.9 [1400 8.21 [6621 0.913 [2225 2.04 [2039 0.559 [7722 9.32 [221 14.4 [2 14] [4 54]] [13 25]] [10 45]] [12 41]] [5 16]] [31 22]] [10 66]] [13 45]] [13 100]] [2 50]] [5353 0.849 [2259 7.98 [7512 6.6 [23 35] [18 30]] [18 60]] [23 71]]] [13 100]] [13 100]] [2826 2.01 [15 22] [17 54]]] [6 100]] [2 71]] [13 80]] [1 100]] [10 100]] [2251 8.01 [7515 0.852 [5299 1.08 [5429 3.38 [25 71] [25 94]] [1 36]] [25 100]] [1 83]]] [10 100]] [10 51]] [25 100]] [3874 4.39 [5647 19.5 [31 61] [31 88]] [12 100]]] [939 1.01 [4832 1.54 [663 3.11 [110 1.6 [2902 0.52 [1 26] [2 47]] [1 83]] [2 46]] [2 75]] [29 70]]] [13 88]] [29 50]] [13 100]] [26 94]] [7576 0.509 [183 0.882 [426 1.25 [896 10.4 [2936 0.686 [23 22.2 [7683 0.484 [2748 0.198 [7176 0.233 [6187 0.361 [7583 1.57 [248 3.65 [4369 3.72 [7657 1.13 [1079 1.11 [1986 1.4 [3008 0.952 [1239 1.86 [4 27] [1078 5.53 [14 22] [31 36]]] [17 55]] [18 54]] [10 27]] [12 100]] [13 54]] [7414 1.54 [1081 1.27 [6342 1.77 [25 35] [33 28]] [5192 0.773 [25 66] [26 71]]] [25 88]]] [5198 0.477 [25 66] [25 100]]] [5267 1.3 [667 1.36 [2 34] [13 50]] [13 60]]] [5480 0.867 [33 56] [33 100]]] [5198 2.41 [26 100] [26 80]]] [1 100]] [5360 1.17 [1587 7 [5198 3.93 [4017 0.843 [94 1.11 [2488 8.98 [4895 1.82 [5178 2.33 [291 1.46 [6199 6.45 [6524 8.8 [168 16.6 [5413 1.56 [33 20] [29 44]] [19 46]] [25 65]] [1 66]] [12 62]] [33 100]] [19 55]] [13 88]] [19 69]] [26 50]] [25 80]] [13 72]] [5753 0.858 [4704 1.62 [33 81] [33 100]] [33 100]]]] [184 1.31 [25 86] [25 100]]] [2081 2.05 [4279 1.68 [25 63] [1 50]] [25 50]]] [107 1.24 [5170 1.56 [1 76] [1 50]] [1 61]]] [25 100]] [6949 6.5 [25 100] [25 72]]]] [1 94]] [3554 0.557 [12 95] [12 100]]] [7397 0.126 [2752 3.94 [33 61] [7502 1.08 [1301 1.5 [663 5.92 [25 98] [25 66]] [1 85]] [25 81]]] [25 100]]] [811 0.302 [2005 4.53 [4239 1.25 [896 1.05 [996 0.551 [4799 2.79 [6185 1.23 [6031 1.96 [1980 8.7 [10 34] [23 75]] [22 100]] [22 44]] [10 95]] [23 100]] [25 32]] [20 100]] [1 71]] [10 91]]] [10 100]]] [6298 0.518 [3576 0.897 [3905 0.267 [6524 1.28 [2831 0.221 [3606 0.37 [248 2.68 [4942 0.835 [4690 0.329 [3027 2.43 [1680 0.514 [791 2.21 [6201 1.36 [2939 4.16 [939 2.86 [1997 6.12 [4517 0.907 [5377 0.107 [22 39] [1 25]] [22 66]] [14 27]] [10 33]] [10 25]] [18 33]] [4414 8.77 [2610 3.07 [5480 0.265 [7737 1.22 [22 26] [22 94]] [4533 0.663 [5228 0.57 [2143 0.555 [6033 1.03 [22 85] [22 100]] [22 60]] [22 100]] [22 100]]] [2 75]] [2752 28.3 [15 72] [22 66]]]] [22 100]] [20 43]] [20 71]] [22 100]] [99 1.41 [33 43] [33 83]]] [15 100]] [22 100]] [5420 0.2 [1400 1.34 [22 77] [25 47]] [22 100]]] [5267 1.99 [3908 0.963 [4369 1.07 [15 68] [15 100]] [15 95]] [15 70]]] [6080 0.47 [5 40] [15 100]]] [31 100]]] [2445 1.01 [7734 5.18 [6982 3.8 [7267 1.48 [999 0.904 [1646 5.17 [1078 4.63 [4929 11.4 [2648 3.12 [7722 5.84 [1783 2.26 [26 32] [7 40]] [7 64]] [4 100]] [4 100]] [4851 9.59 [13 27] [4 93]]] [13 45]] [7 30]] [6552 0.234 [7267 23.4 [4 100] [4 92]] [4 100]]] [7265 7.14 [4 100] [4 88]]] [18 52]] [18 42]]] [6017 0.312 [6111 0.799 [4571 2.2 [5454 0.297 [7449 5.13 [645 1.06 [532 1.85 [731 0.902 [7188 5.32 [719 2.01 [6033 0.27 [7057 0.69 [2701 0.754 [7417 1.42 [1023 2.22 [5873 10.5 [5233 1.44 [7301 1.22 [6042 0.496 [1630 1.89 [5215 0.901 [7250 1.26 [2911 6.36 [6036 5.23 [5345 1.17 [6031 1.95 [685 0.38 [906 8.05 [1078 61.3 [663 6.21 [7185 1.54 [4851 11.3 [383 2.09 [2259 1.17 [1980 4.18 [5904 5.15 [18 52] [19 57]] [10 28]] [18 64]] [18 100]] [4 33]] [18 42]] [6040 7.64 [7734 3.59 [29 30] [18 60]] [13 33]]] [22 62]] [29 63]] [413 0.38 [5904 1.01 [248 21 [6043 2.04 [6230 11.6 [4205 0.432 [2813 6.17 [18 67] [18 36]] [18 50]] [18 33]] [18 60]] [26 57]] [18 57]] [18 77]]] [22 95]] [5482 6.97 [18 78] [18 56]]] [21 54]] [7566 10.3 [18 100] [18 85]]] [35 50]] [22 100]] [1239 1.68 [18 90] [18 100]]] [7512 26.9 [18 80] [18 44]]] [4926 7.97 [1671 1.45 [5673 0.741 [18 54] [19 50]] [18 80]] [19 85]]] [22 100]] [19 52]] [7512 9.23 [663 6.57 [7737 2.39 [7512 3.85 [18 100] [18 77]] [18 100]] [18 100]] [1011 1.32 [1671 5.7 [1648 5.18 [18 69] [18 62]] [18 50]] [18 47]]]] [22 88]] [7566 5.45 [7731 0.469 [2225 0.544 [7512 2.83 [29 75] [29 100]] [29 100]] [29 100]] [29 66]]] [19 40]] [22 100]] [5267 4.39 [719 4.36 [282 2.7 [663 14.3 [7737 3.02 [7149 2.56 [7241 0.421 [18 84] [18 50]] [18 60]] [2813 1.17 [18 50] [16 77]]] [16 66]] [19 50]] [2268 12.4 [6830 1.55 [4154 6 [7731 7.05 [392 12.7 [6342 2.41 [685 6.71 [6659 3.43 [695 6.34 [18 84] [18 89]] [18 50]] [978 5.48 [1899 2.22 [18 92] [18 66]] [18 50]]] [4 37]] [18 100]] [18 76]] [18 100]] [18 62]] [18 55]]] [18 48]]] [1899 6.55 [7737 2.84 [788 10.7 [18 91] [18 42]] [663 6.51 [18 58] [18 100]]] [18 44]]] [7302 2.46 [2809 0.321 [1557 1.09 [6833 0.414 [1666 0.279 [7722 11 [6022 0.404 [5480 2.79 [18 30] [5386 3.26 [6959 7.31 [2466 2.2 [3604 1.16 [7354 13.6 [647 3.56 [7155 0.823 [5099 9.27 [1429 59.8 [160 1.58 [5612 4.53 [1911 2.44 [7255 3.11 [1219 2.11 [5609 3.95 [5753 0.606 [7537 3.72 [6294 0.444 [2616 5.99 [737 16.5 [134 6.5 [4645 6.25 [5693 4.85 [4540 1.03 [1078 25.9 [5157 1.14 [4154 2.62 [1023 1.29 [7590 0.618 [18 93] [18 100]] [18 100]] [18 85]] [18 100]] [18 77]] [18 100]] [18 86]] [18 88]] [4859 3.78 [18 80] [18 90]]] [18 63]] [18 50]] [18 100]] [18 60]] [23 7.04 [18 100] [18 75]]] [18 60]] [18 28]] [7737 0.69 [18 77] [18 66]]] [18 60]] [18 70]] [18 57]] [7520 1.11 [18 43] [18 100]]] [16 46]] [18 42]] [18 100]] [5130 3.22 [1429 11.3 [18 35] [2570 1.17 [18 85] [18 66]]] [19 63]]] [19 70]] [7566 1.11 [18 56] [19 54]]] [16 81]] [18 100]]] [18 100]] [19 40]] [19 57]] [16 50]] [18 43]] [18 59]] [187 1.52 [18 33] [16 41]]]] [7590 7.58 [6043 11.9 [6023 1.04 [1783 8.29 [2705 0.699 [6910 1.42 [1078 39.6 [1662 0.273 [404 1.1 [791 9.58 [7210 3.78 [5011 2.62 [18 57] [7737 1.11 [1062 2.07 [19 80] [18 53]] [19 69]]] [19 66]] [7742 0.62 [18 57] [18 88]]] [18 64]] [7512 10.4 [19 75] [2259 20.5 [18 54] [19 71]]]] [392 6.89 [18 87] [18 88]]] [23 1.68 [18 57] [18 100]]] [29 100]] [4509 2.07 [2445 4.18 [2726 1.84 [2385 4.9 [429 34.1 [19 48] [19 82]] [1078 18.3 [284 7.8 [19 87] [19 77]] [19 100]]] [19 55]] [18 66]] [5007 14.2 [18 50] [18 60]]]] [18 90]] [32 28]] [19 92]]] [7183 1.01 [22 60] [22 100]]] [4645 1.57 [7601 0.707 [7176 0.377 [4197 6.77 [4684 1.47 [429 27.6 [18 30] [5799 2.81 [5692 16.7 [1078 15.5 [7354 5.59 [899 4.59 [29 69] [29 100]] [18 55]] [4663 14.4 [2939 5.54 [2199 3.06 [23 9.84 [23 0.544 [1980 24.2 [5480 11.9 [5482 9.1 [29 100] [29 83]] [29 100]] [22 40]] [29 100]] [29 85]] [29 62]] [29 85]] [29 83]]] [29 50]] [29 100]]] [18 50]] [22 42]] [22 100]] [18 48]] [18 63]]] [2132 1.38 [899 0.462 [7210 1.62 [29 100] [19 42]] [5011 0.423 [29 87] [29 100]]] [29 77]]] [248 4.12 [7665 12.3 [5637 1.66 [4017 2.95 [19 61] [18 72]] [429 15.8 [18 64] [19 46]]] [7331 2.89 [19 90] [19 66]]] [18 70]]] [3959 0.537 [7665 10.2 [29 100] [29 71]] [29 100]]] [429 37.1 [1239 0.312 [6015 8.83 [29 100] [29 87]] [29 100]] [29 100]]]] [7578 0.234 [2629 4.21 [2131 0.204 [7169 1.04 [10 99] [10 100]] [10 100]] [1221 10.6 [10 57] [10 100]]] [10 100]]] [494 0.354 [6581 0.413 [7133 0.179 [6596 0.379 [705 0.313 [5473 0.858 [7255 3.5 [7584 0.685 [7544 1.5 [6251 6.83 [5736 1.18 [6187 1.62 [3558 1.24 [6983 0.682 [2493 1.18 [2488 0.829 [3328 0.362 [7583 1.69 [1173 0.737 [685 2.21 [5155 1.05 [3768 1.23 [5472 13.5 [1482 0.271 [3928 0.378 [2398 1.7 [223 0.713 [6550 1.03 [3917 0.904 [6336 1.61 [3652 0.486 [4218 2.54 [470 4.86 [665 1.7 [6740 0.688 [7383 2.4 [3667 2.49 [7593 2.87 [7601 7.69 [3287 3.62 [4931 2.06 [6871 6.34 [7032 4.93 [7354 0.864 [4699 0.857 [3659 2.65 [5819 2.97 [7365 0.971 [4960 0.549 [1429 21.3 [1899 7.98 [2081 14.1 [3357 1.19 [7665 4.68 [2 26] [2752 20.5 [4 38] [4424 17 [4279 13 [5821 3.36 [5413 4.82 [7292 2.13 [2259 2.98 [2526 40.1 [2616 7.62 [2 38] [2 68]] [4 47]] [24 38]] [2 100]] [4 83]] [4 50]] [14 75]] [4 55]]]] [4 69]] [14 16]] [4414 9.83 [7009 5.03 [1918 1.9 [7665 39.4 [2570 20.8 [5412 8.77 [2616 1.72 [1400 0.357 [2 46] [4 71]] [7512 8.95 [2081 5.76 [2 95] [2 57]] [6076 13.2 [2 51] [1 44]]]] [4 36]] [2 100]] [7 47]] [24 50]] [26 62]] [4 57]]] [221 0.426 [4851 0.336 [2552 2.81 [3548 0.639 [2091 1.23 [2005 4.66 [3998 2.94 [1993 0.755 [5251 0.459 [3905 0.241 [731 8.84 [1400 3.27 [5 22] [12 77]] [4 69]] [17 52]] [17 50]] [17 36]] [5 100]] [2 33]] [4 37]] [5 85]] [4 80]] [7 44]] [7 37]]] [435 1.86 [4 100] [4 41]]] [4 96]] [5605 6.18 [1429 20.5 [1059 19.4 [5413 15.2 [1919 9.29 [2470 1.74 [1906 7.45 [6732 7.88 [567 5.07 [2574 3.93 [4 63] [2 20]] [2 35]] [2 80]] [2 50]] [4 100]] [7413 1.73 [4 28] [2 80]]] [5660 8.72 [4 75] [4 23]]] [9 71]] [7413 1.67 [17 40] [17 64]]] [2 50]]] [24 80]] [20 100]] [2939 4.64 [4279 1.27 [2628 7.82 [2526 10.7 [16 23] [7 39]] [5 87]] [13 40]] [5 46]]] [5660 1.99 [6920 1.63 [1888 7.06 [2 63] [2 47]] [2 69]] [2 100]]] [12 100]] [2628 1.36 [4 56] [4 83]]] [6230 4.47 [2 42] [38 80]]] [7 93]] [4 78]] [6749 1.13 [429 28.1 [19 3.24 [2763 2.98 [4 52] [4 80]] [2 50]] [19 4.62 [2570 1.34 [4 52] [2 92]] [2 83]]] [2 85]]] [5198 0.858 [2 66] [2 100]]] [6342 3.36 [5812 6.27 [4 60] [7248 6.1 [4 66] [4 100]]] [4 44]]] [6539 3.43 [134 2.9 [6817 6.05 [2 80] [2 60]] [2 89]] [2 100]]] [1079 1.53 [22 89] [22 100]]] [1429 10.5 [2081 16.4 [2 43] [17 44]] [4221 1.58 [5 42] [17 50]]]] [24 97]] [1078 2.28 [24 100] [24 66]]] [14 51]] [3905 4.38 [7693 0.913 [7169 1.65 [17 1.3 [7009 1.47 [5 46] [5 66]] [38 50]] [5 75]] [17 60]] [17 55]]] [2 80]] [1899 0.885 [2426 2.77 [31 66] [12 100]] [731 1.8 [1062 1.68 [12 72] [12 77]] [38 91]]]] [7534 3.14 [5368 1.42 [3072 0.411 [1783 2.79 [5660 6.16 [7009 1.32 [2939 0.359 [6184 0.717 [17 46] [17 50]] [17 53]] [5 61]] [17 91]] [5 33]] [12 100]] [5 100]] [17 90]]] [7677 0.589 [1888 6.31 [5 92] [5 78]] [5 75]]] [13 92]] [13 100]] [7593 0.55 [3585 0.952 [3978 1.19 [7381 0.942 [4 32] [5 82]] [5 100]] [5 100]] [5 100]]] [328 3.58 [392 11.6 [3225 2.62 [7 59] [7 100]] [14 50]] [7 30]]] [5818 13.2 [4992 0.521 [2 69] [2 100]] [7512 28.4 [2 28] [24 50]]]] [7 67]] [2752 20 [7693 0.743 [2 95] [2 85]] [2 72]]] [13 95]] [13 100]] [5659 0.227 [4 89] [4 100]]] [2966 3.33 [2259 6.11 [5 52] [828 0.813 [7 63] [7 100]]] [7 50]]] [6537 0.816 [2 52] [5812 22 [1047 1.49 [2 97] [2 85]] [2 74]]]] [24 93]] [2902 7.64 [5013 1.92 [2 71] [2 55]] [2 90]]] [5692 9.46 [7210 6.33 [7000 3.2 [292 0.818 [178 4.11 [4768 1.83 [4154 6.76 [2 76] [7413 0.978 [2 95] [2 100]]] [5647 3.4 [2 75] [2 55]]] [2 92]] [2 100]] [2 100]] [2763 1.57 [2 50] [2 60]]] [2 50]]] [429 45.6 [6537 30 [2760 4.04 [827 2.47 [110 4.23 [2764 5.79 [4832 2.06 [5396 0.26 [1072 3.44 [2 86] [2 100]] [2 100]] [6184 1.11 [2 87] [2 100]]] [2 66]] [2 75]] [2 53]] [2 37]] [2 40]] [2 33]]] [7568 2.11 [7449 3.27 [2818 0.568 [4213 1.71 [7241 7.35 [2752 13.8 [13 87] [5972 1.43 [4663 2.89 [7019 3.5 [12 66] [12 100]] [12 47]] [12 100]]] [7 30]] [12 100]] [12 100]] [7032 8.61 [12 89] [13 100]]] [2 31]]] [739 0.357 [5735 0.867 [3027 12.3 [4326 4.93 [7185 1.51 [802 0.879 [7197 2.97 [13 93] [13 100]] [13 100]] [13 100]] [13 75]] [13 57]] [13 100]] [13 100]]] [7210 2.29 [6216 0.166 [1 1.12 [6885 0.237 [7703 2.77 [7705 0.666 [12 94] [12 100]] [12 83]] [12 100]] [12 100]] [12 100]] [12 72]]] [134 2.3 [1899 4.54 [4 95] [4 100]] [4 87]]] [7032 1.02 [4 98] [4 100]]] [7214 0.44 [3743 1.18 [4959 0.732 [2470 4.1 [6883 2.2 [2617 0.525 [5429 0.245 [1400 1.88 [1535 0.645 [4833 2.04 [1704 0.978 [3197 2.21 [2541 0.479 [2588 6.06 [5390 0.903 [5892 0.247 [1429 6.71 [6589 11.9 [5767 0.227 [4851 2.11 [1059 5.24 [17 41] [26 37]] [7380 3.31 [7568 6.18 [929 1.22 [2616 16.1 [4 57] [5 43]] [4 37]] [4 38]] [4 100]]] [17 71]] [5 94]] [1666 0.608 [1580 0.449 [5673 1.89 [2606 0.204 [5729 0.27 [3905 0.417 [4931 4.09 [4154 2.06 [2902 4.22 [6588 1.82 [312 6.54 [2628 16.3 [2616 9.26 [791 7.41 [17 55] [1429 37.3 [4851 1.64 [5 46] [5 61]] [5 41]]] [17 28]] [5 62]] [4 62]] [5647 9.09 [5 60] [5 85]]] [2628 3.99 [5693 13.4 [5693 2.37 [5 40] [5 64]] [5 83]] [2913 2.2 [5 83] [5 85]]]] [4718 4.88 [1906 3.33 [5 66] [2902 1.3 [5 88] [5 75]]] [5 100]]] [12 46]] [1557 1.21 [4338 2.41 [17 40] [19 71]] [17 61]]] [17 90]] [3972 0.449 [5 73] [5 91]]] [19 38]] [7381 0.449 [17 50] [14 35]]] [38 66]]] [5662 0.247 [17 77] [17 57]]] [3078 2.91 [4895 0.57 [7185 2.1 [7665 13.8 [17 66] [17 55]] [7595 1.8 [2760 4.62 [17 36] [38 66]] [19 90]]] [17 68]] [38 66]]] [2536 1.96 [1919 1.36 [6586 2.94 [7586 5.31 [17 50] [17 66]] [17 66]] [17 76]] [17 60]]] [3251 1.29 [1078 16.4 [2752 4.64 [6732 0.51 [19 72] [17 42]] [6310 2.99 [17 50] [17 90]]] [17 83]] [19 45]]] [6581 6.43 [17 81] [17 100]]] [4414 0.532 [3732 3.55 [7568 3.72 [17 89] [17 57]] [38 57]] [17 100]]] [4 100]] [5 95]] [4 76]] [1482 1.8 [7326 3.55 [5 95] [5 83]] [5 80]]] [2616 1.17 [4 98] [4 100]]] [3435 8.6 [1911 2.62 [3251 2.76 [2764 0.967 [7169 4.24 [602 1.29 [6590 1.39 [5 63] [2594 45.1 [3252 4.03 [2968 8.46 [2753 4.6 [6586 0.686 [5 88] [3526 0.686 [5 95] [5 100]]] [5 71]] [5 75]] [5 50]] [5 44]]] [5 100]] [5 56]] [2767 0.975 [5 72] [5 100]]] [5 100]] [17 62]] [5 58]]] [6199 4.29 [639 4.05 [7032 3.25 [2591 0.904 [4 96] [4 100]] [4 80]] [4 93]] [4 80]]] [201 0.215 [2740 11.9 [1899 7.96 [4 100] [4 88]] [4 87]] [4 100]]] [35 81]] [1888 8.86 [929 1.95 [2526 8.72 [728 2.3 [3 20] [19 63]] [17 53]] [17 62]] [38 58]]]] [5413 1.89 [3858 1.06 [4587 0.301 [7343 4.22 [4478 3.68 [688 3.45 [6544 6.17 [2962 0.248 [7009 0.281 [7424 0.446 [17 68] [17 83]] [5 55]] [17 50]] [17 42]] [7 55]] [7 27]] [17 26]] [23 16.4 [2760 0.301 [2178 0.416 [5662 0.768 [5742 0.626 [4588 6.25 [5799 1.36 [17 73] [17 100]] [17 61]] [17 100]] [17 100]] [2526 7.94 [17 83] [17 100]]] [17 100]] [17 66]]] [35 93]] [7384 0.19 [17 70] [1745 0.257 [1062 4.72 [4332 2.91 [4218 2.99 [17 100] [6396 6.62 [17 66] [17 85]]] [17 100]] [17 100]] [17 100]]]]]] [6074 0.0664 [2385 0.913 [5904 0.237 [1584 0.32 [6584 0.197 [5480 1.24 [610 0.472 [1533 0.385 [3461 0.229 [704 1.34 [6544 0.881 [1696 1.24 [1703 0.398 [4932 1.03 [7742 2.48 [3008 2.63 [6022 2.37 [5695 1.56 [7214 0.414 [7583 1.36 [663 1.48 [2841 6.72 [6241 0.397 [7021 0.59 [6230 1.68 [7132 0.978 [957 1.14 [4681 2.13 [978 19.9 [3667 0.739 [1239 2.84 [5316 0.787 [4718 7.94 [7665 23.5 [2987 0.179 [312 1.11 [5 25] [4 60]] [5 40]] [662 4.95 [5429 2.51 [7535 22.7 [1011 7.27 [2259 37.2 [5 31] [4 63]] [5 66]] [5 83]] [5 90]] [5 58]]] [5 87]] [7185 0.787 [17 50] [7 85]]] [4 28]] [4 70]] [4 42]] [5 61]] [5 57]] [4 76]] [3905 4.75 [738 0.359 [3798 1.08 [7251 5.07 [2470 2.75 [3391 0.824 [1190 7.12 [7708 3.18 [4851 16.2 [1783 9.2 [695 24 [2570 6.26 [1025 4.63 [7722 23.5 [5155 4.44 [514 1.55 [552 3.18 [4898 1.03 [4414 3.45 [6708 3.92 [736 25.5 [5007 0.575 [6550 7.88 [6310 16.8 [1517 4 [3554 3.54 [2902 3.67 [1210 0.912 [2913 3.83 [5 93] [5 66]] [5 100]] [5 76]] [5 50]] [5 66]] [5 66]] [5 76]] [17 50]] [5 50]] [5 62]] [5 100]] [5 100]] [5 62]] [5 100]] [5 50]] [5 63]] [4 50]] [5 36]] [5 43]] [12 50]] [7 58]] [5 100]] [5 37]] [5 100]] [4 76]] [5 18]] [6891 2.53 [38 62] [19 66]]] [17 64]] [17 52]]] [5 100]] [2526 1.99 [5 62] [5 91]]] [429 32 [7241 12.2 [5 88] [17 62]] [5 93]]] [669 3.31 [2753 0.262 [4719 1.41 [2470 1.82 [5316 0.888 [642 0.942 [5251 3.44 [6184 0.552 [3675 2.73 [7325 7.63 [7512 6.43 [5 20] [2947 1.49 [4154 10.8 [3204 1.77 [5693 1.15 [5 44] [5 50]] [3205 17.9 [5 90] [5 60]]] [16 37]] [5 75]]] [38 66]] [5 100]] [2 38]] [17 70]] [458 2.75 [2526 1.01 [5 76] [5 96]] [5 85]]] [7 60]] [4 75]] [17 64]] [6581 4.38 [3317 0.45 [2616 1.73 [1980 4.17 [5 96] [5 63]] [5 37]] [5 95]] [5 33]]] [35 66]]] [7 100]] [17 47]] [26 57]] [7 100]] [7734 0.347 [6550 7.07 [5267 1.55 [4218 0.937 [3226 0.8 [17 41] [7 100]] [35 50]] [5 33]] [17 93]] [3732 2.45 [16 38] [722 0.808 [731 11.9 [17 67] [19 45]] [17 50]]]]] [4851 4.03 [5154 1.24 [4 35] [17 55]] [4 90]]] [4932 6.9 [4 100] [4 85]]] [3094 1.99 [458 5.58 [144 2.15 [112 0.155 [6313 1.21 [17 59] [6535 7.58 [19 40] [17 77]]] [19 57]] [19 48]] [17 91]] [19 58]]] [19 57]] [458 1.61 [134 13.5 [6396 0.508 [31 40] [662 1.26 [1899 3.4 [2526 2.94 [5157 0.847 [17 66] [17 60]] [17 100]] [5660 3.8 [17 55] [17 85]]] [17 100]]] [17 33]] [17 42]]] [4 100]] [2628 0.941 [4414 3.46 [17 59] [17 42]] [19 43]]] [735 0.382 [663 6.2 [913 1.22 [2752 28.4 [1899 3.26 [5 100] [5 85]] [5 73]] [5 62]] [1429 50.1 [5 87] [5 100]]] [5 66]]] [3602 1.73 [5412 2 [6334 0.282 [5 61] [2574 0.197 [4611 2.57 [2753 10.6 [7009 17.3 [906 1.37 [429 29 [4105 0.646 [1062 3.48 [5 100] [1128 1.8 [5 93] [5 100]]] [5 97]] [6230 10.7 [5812 0.505 [5 96] [5 85]] [5 88]]] [5 92]] [5 83]] [5 83]] [5 80]] [5 100]]] [978 2.5 [5 88] [5693 1.15 [5 58] [5 81]]]] [5 50]]] [5812 0.0754 [4235 0.956 [1239 0.606 [7187 2.37 [2813 15.1 [6311 0.736 [5692 15 [2831 1.84 [5267 4.94 [7722 17 [4781 0.805 [6585 4.64 [7169 2.47 [6230 8.45 [4859 3.4 [7699 5.88 [18 44] [16 42]] [18 81]] [978 7.93 [18 88] [18 85]]] [16 43]] [26 86]] [4 81]] [26 81]] [26 53]] [18 100]] [719 2.02 [18 85] [18 60]]] [5 50]] [18 88]] [7512 13.1 [26 92] [26 100]]] [1239 21.5 [284 1.6 [7497 0.0573 [4851 0.777 [7446 0.145 [7244 0.605 [5673 1.3 [1068 0.225 [736 6.94 [4154 0.184 [1899 1.57 [18 79] [18 100]] [18 100]] [5480 6.98 [18 90] [16 25]]] [18 100]] [18 45]] [26 57]] [16 36]] [26 50]] [16 58]] [35 40]] [6 70]]] [6471 0.693 [26 61] [26 100]]] [4154 1.02 [4 28] [5 57]]]] [7270 0.42 [5510 0.997 [3476 2.68 [1535 0.162 [5654 2.29 [6724 3.87 [724 0.489 [7711 3.98 [978 6.07 [5892 0.795 [6589 1.16 [17 57] [19 57]] [17 100]] [5692 3.17 [6358 6.65 [7566 0.26 [4765 0.486 [3929 6.38 [4895 2.11 [3915 0.978 [2752 22.3 [2939 3.79 [1909 0.515 [5157 0.872 [1919 0.444 [663 5.17 [2826 3.51 [719 0.599 [17 83] [17 92]] [17 50]] [17 100]] [17 83]] [17 100]] [17 100]] [17 41]] [17 42]] [38 40]] [17 45]] [19 70]] [23 50]] [17 53]] [38 62]] [1721 1.69 [7253 1.34 [5969 0.471 [3798 0.315 [5 52] [6358 2.15 [17 44] [38 93]]] [17 62]] [17 42]] [17 75]]]] [7009 1.35 [7682 0.371 [5 42] [6310 0.276 [1429 26.4 [17 80] [17 100]] [17 42]]] [5 88]]] [929 0.914 [2628 0.968 [7693 1.84 [6358 4.75 [738 0.611 [17 63] [19 50]] [38 42]] [791 7.47 [17 100] [17 87]]] [1740 0.454 [17 38] [16 40]]] [6557 1.06 [2628 2.57 [17 54] [567 0.711 [17 100] [17 60]]] [17 100]]]] [19 72]] [5 63]] [5 77]] [5 63]] [7722 1.34 [3734 4.56 [19 100] [19 83]] [3562 1.59 [602 1.27 [6586 0.794 [1723 0.268 [17 80] [19 41]] [1648 2.17 [38 46] [6047 1.21 [6586 1.25 [19 100] [19 77]] [19 61]]]] [17 63]] [17 60]]]] [3204 0.477 [5 66] [5 100]]]] [6597 2.59 [1686 2.62 [5480 0.169 [999 3.56 [2742 1.88 [3929 2.12 [1094 0.77 [1647 1.68 [145 2.75 [1262 2.69 [1889 1.38 [7067 1.97 [5953 0.356 [7241 3.9 [5819 1.58 [584 1.46 [2947 0.863 [7551 1.88 [4338 0.325 [5384 0.492 [725 1.98 [17 44] [16 50]] [17 100]] [17 69]] [6310 6.03 [17 88] [17 66]]] [38 75]] [19 62]] [7 28]] [17 93]] [17 100]] [16 30]] [35 55]] [19 77]] [429 22.4 [7 58] [17 48]]] [16 85]] [35 62]] [7722 2.05 [2826 3.4 [17 80] [695 2.37 [17 100] [17 85]]] [5753 4.12 [7251 1.22 [17 70] [1584 4.66 [17 95] [17 75]]] [17 60]]]] [4 100]] [4 38]] [4870 1.87 [38 60] [18 33]]] [4 66]] [1063 1.83 [35 54] [35 100]]]] [5907 1.37 [1567 0.698 [685 1.36 [6879 0.168 [6584 2.46 [6575 1.63 [4806 0.4 [3905 1.55 [731 8.53 [5 40] [19 75]] [19 92]] [4051 2.04 [695 1.81 [2752 12.6 [19 80] [6535 0.195 [19 88] [19 100]]] [7551 0.791 [19 50] [19 90]]] [19 80]]] [6230 5.16 [19 83] [19 100]]] [19 45]] [17 44]] [18 41]] [6977 0.249 [4851 1.33 [19 90] [19 100]] [19 100]]] [4897 1.73 [7722 3.69 [6186 0.93 [4851 3.86 [202 0.282 [19 100] [19 85]] [19 83]] [19 100]] [19 57]] [19 70]]]] [5632 0.496 [7302 0.253 [7301 0.186 [1899 0.721 [18 78] [2268 1.32 [18 100] [18 83]]] [18 55]] [7302 4.08 [134 1.2 [7302 3.04 [18 50] [18 50]] [18 83]] [18 75]]] [18 50]]] [6588 0.0974 [736 5.49 [978 10.4 [3069 1.35 [7384 0.43 [1740 0.303 [7520 1.31 [5110 0.213 [4 51] [4 87]] [5692 2.96 [2573 3.09 [2 41] [38 50]] [19 50]]] [19 55]] [7 87]] [5 100]] [4253 1.57 [4594 0.192 [1666 0.0664 [7 28] [2636 0.302 [6804 3.52 [6581 5.39 [17 58] [17 87]] [38 71]] [19 64]]] [4 85]] [2 66]]] [7742 2.82 [6804 0.652 [1919 6.03 [5321 6.9 [6531 3.8 [7384 1.17 [6545 3.6 [5403 3.23 [4832 3.27 [7 48] [4 85]] [31 100]] [31 100]] [7 68]] [7 100]] [31 100]] [2 36]] [17 40]] [4 63]]] [7067 1.63 [4876 1.7 [2636 1.35 [5892 15 [7255 0.415 [1986 1.97 [144 15 [7192 4.16 [7534 8.98 [7333 1.22 [2005 1.77 [1023 0.12 [7682 0.571 [509 1.76 [985 1.94 [7677 0.832 [3342 1.46 [2573 0.609 [6555 0.623 [6581 9.03 [17 100] [17 90]] [17 80]] [17 100]] [17 87]] [17 85]] [4588 1.37 [17 60] [17 100]]] [17 77]] [17 78]] [17 100]] [17 69]] [17 100]] [17 45]] [7210 1.27 [5892 0.975 [17 80] [17 81]] [17 87]]] [17 80]] [17 75]] [17 42]] [17 57]] [7722 1.7 [17 33] [17 100]]] [16 55]] [17 47]]]]] [5239 0.362 [2628 3.45 [4239 0.673 [7526 2.61 [392 1.12 [2913 2.72 [296 0.627 [6156 1 [6552 0.252 [1640 0.251 [228 0.785 [7681 0.99 [4587 0.891 [7722 8.64 [4895 10.8 [26 19] [17 71]] [14 47]] [26 88]] [26 100]] [4 79]] [7584 1.51 [5576 1.32 [2151 0.116 [2535 1.34 [4768 1.13 [2811 0.251 [5770 28.4 [4585 2.16 [223 16.3 [2616 6.25 [2902 1.81 [5820 2.61 [221 19.5 [4 85] [4 100]] [4 85]] [4 71]] [7605 4.2 [429 30.4 [4 78] [2 56]] [4 100]]] [2 71]] [4 66]] [2526 19.7 [2 58] [2 100]]] [4 100]] [2 44]] [2 50]] [2 61]] [4929 0.844 [5040 2.28 [2 27] [2 100]] [23 27]]] [4235 3.57 [2 100] [2 33]]]] [4 100]] [10 100]] [7081 1.17 [10 76] [10 100]]] [30 46]] [7665 15.2 [4338 0.642 [384 0.635 [30 25] [26 66]] [18 62]] [7722 5.57 [14 41] [14 33]]]] [6 81]] [20 87]] [291 5.12 [5917 0.556 [5847 1.05 [477 0.257 [7081 0.38 [4353 0.765 [7712 5.38 [7133 0.375 [4832 16.5 [5576 4.55 [4564 3.59 [5654 3.62 [362 0.931 [5812 0.136 [429 19.9 [4 71] [2617 1.25 [4 91] [4 100]]] [7255 1.76 [5693 5.7 [2570 1.97 [7512 28.6 [5817 0.764 [7718 3.01 [2081 0.308 [6077 2.54 [25 11.3 [429 22 [4 100] [4 94]] [4 85]] [4 100]] [4 100]] [4 83]] [4 100]] [4 85]] [4 92]] [4 87]] [4 75]]] [4 50]] [2 46]] [4 62]] [6074 1.08 [4 33] [5576 16.6 [7702 0.581 [6537 7.58 [719 8.41 [978 21 [695 2.89 [4 58] [2 60]] [2 87]] [4 50]] [2 25]] [2 57]] [2 100]]]] [2628 9.78 [2 85] [2 46]]] [7586 0.514 [1706 1.47 [1011 5.87 [4 100] [4 85]] [4 85]] [4 100]]] [4 92]] [29 64]] [2 58]] [1640 5.16 [4 85] [2 81]]] [978 16.1 [5509 6.77 [312 0.602 [6216 14.3 [825 0.942 [4848 7.31 [2180 0.557 [2745 1.34 [5886 1.15 [5396 1.93 [6216 2.8 [4 94] [4 100]] [4 100]] [4 90]] [4 100]] [4 100]] [4 85]] [4 83]] [4 75]] [4 100]] [4 71]] [2617 0.867 [4 83] [4 100]]]] [2 100]] [2 27]]] [1436 2.77 [2478 16.2 [7363 7.19 [6983 28.5 [4 100] [4 97]] [2005 0.416 [6595 0.657 [4 85] [4 100]] [4 100]]] [4 93]] [4 93]]]] [5288 1.6 [1707 7.66 [3094 1.89 [4279 1.48 [543 0.179 [155 3.06 [2588 4.07 [5729 0.297 [6920 0.638 [5677 1.89 [19 100] [736 5.23 [19 100] [19 88]]] [4535 0.209 [19 100] [19 80]]] [573 1.03 [19 85] [19 100]]] [19 90]] [6199 1.71 [19 57] [19 77]]] [19 77]] [19 89]] [4588 0.425 [19 90] [17 60]]] [23 2.29 [19 63] [19 100]]] [19 77]]] [6460 0.397 [5198 4.02 [2470 17 [178 0.715 [4154 2.75 [25 100] [1011 1.06 [25 95] [25 100]]] [25 100]] [25 98]] [2834 2.49 [25 100] [25 87]]] [25 100]]] [7354 0.769 [3111 0.669 [6839 1.27 [874 0.328 [1011 0.334 [2340 0.803 [713 0.642 [5110 1.08 [7149 2.79 [5978 0.97 [2526 0.521 [1 3.06 [2309 0.864 [5454 1.28 [112 1.59 [2331 2.42 [3895 2.09 [6230 1.64 [5472 0.468 [901 2.78 [2939 0.686 [2926 1.45 [31 65] [31 100]] [31 100]] [36 85]] [3647 4.42 [36 91] [36 100]]] [31 100]] [1078 2.76 [31 90] [31 100]]] [36 70]] [36 79]] [36 100]] [36 100]] [12 49]] [663 4.49 [5973 0.778 [1218 1.22 [6164 2.67 [682 1.06 [7571 8.19 [1239 5.24 [2698 2.37 [31 96] [31 100]] [31 80]] [2259 11.6 [7665 13.3 [18 46] [31 100]] [6544 4.95 [31 93] [31 81]]]] [31 100]] [31 100]] [31 100]] [12 100]] [31 83]]] [5978 6.94 [1899 0.914 [134 1.59 [6074 6.29 [31 100] [31 80]] [31 100]] [31 100]] [31 100]]] [36 93]] [731 2.04 [7731 0.561 [6230 1.32 [6677 1.82 [7251 1.54 [12 65] [4154 1.57 [36 83] [36 100]]] [12 100]] [12 91]] [12 100]] [31 100]]] [12 73]] [31 100]] [1993 3.14 [6199 0.726 [7176 0.334 [7697 0.316 [957 0.574 [4422 1.06 [1218 0.631 [7305 0.99 [31 97] [31 100]] [31 100]] [31 100]] [31 100]] [31 100]] [31 90]] [31 85]] [31 94]]] [7659 0.335 [3093 1.33 [682 0.551 [6514 1.05 [2826 0.47 [6524 1.48 [2628 0.952 [1723 0.824 [7571 4.88 [36 55] [36 83]] [36 90]] [12 80]] [36 100]] [12 100]] [36 100]] [31 100]] [12 100]] [12 100]]] [4817 1.12 [36 84] [36 100]]] [36 100]] [6374 3.59 [2763 1.72 [5198 1.33 [7693 1.29 [7108 0.894 [6732 12.9 [957 3.86 [791 1.68 [36 82] [36 100]] [36 87]] [36 78]] [36 100]] [36 88]] [36 100]] [4369 0.888 [36 100] [36 66]]] [36 76]]]] [6983 0.295 [5142 28.4 [7248 3.53 [7725 3.06 [5461 3.32 [2567 3.83 [7324 0.466 [724 2.67 [3527 9.21 [7584 18 [5462 3.82 [5856 3.31 [5575 6.25 [4595 13.2 [435 5.4 [4929 5.92 [1106 0.412 [5820 18.5 [3027 9.09 [2571 5.38 [4991 24.1 [6047 17.3 [7459 1.9 [7512 31.7 [2739 3.97 [7032 3.56 [7061 19.7 [4586 10.3 [6604 4.75 [134 0.245 [1993 0.835 [2939 18.7 [5815 10.5 [2763 0.633 [147 1.98 [228 6.25 [6732 4.77 [2 100] [2 88]] [2 100]] [2 100]] [2 100]] [2 80]] [1899 1.95 [2674 12.3 [2 100] [2 80]] [2 100]]] [2 100]] [2 100]] [2 95]] [2 85]] [2 80]] [2553 4.86 [2 100] [2 88]]] [2 80]] [2 77]] [2674 1.91 [2 75] [2 100]]] [2 75]] [2 92]] [2 89]] [2 71]] [2 77]] [2 93]] [2 68]] [2 76]] [2 57]] [7381 9.3 [2 80] [2 57]]] [2 84]] [2 78]] [7665 19.6 [2 62] [2 85]]] [22 71]] [5820 2.47 [2 66] [2 83]]] [7327 0.273 [2 87] [4 88]]] [5648 5.85 [1062 3.84 [2 100] [2143 1.93 [2 57] [2 66]]] [2 37]]] [2 64]] [4 80]] [2 53]] [2 50]] [7365 0.295 [4960 1.23 [4 72] [4 100]] [4 100]]]] [4960 0.218 [7584 0.578 [4929 1.99 [6582 0.245 [978 23.1 [2674 0.0526 [5396 10.1 [7590 1.26 [6732 0.408 [7169 12.8 [7413 0.815 [7255 4.59 [5396 0.121 [2616 0.282 [2629 0.585 [2199 0.446 [978 20.6 [2005 0.928 [1049 1.49 [5665 1.74 [1083 0.994 [2570 2.93 [2 60] [2 90]] [134 1.21 [4 37] [4 100]]] [2 100]] [2 85]] [2 100]] [22 46]] [2 100]] [2 100]] [6184 6.24 [7665 8.27 [2 73] [5660 5.23 [2 85] [2 41]]] [2 100]]] [4 55]] [4 83]] [667 0.891 [567 0.89 [7414 2.71 [2 100] [2 83]] [2 100]] [2 100]]] [4 50]] [3327 0.562 [1240 0.476 [7241 2.36 [1077 1.87 [2592 9.18 [791 14.4 [4748 4.39 [4992 4.06 [4834 1.17 [2902 2.96 [5767 0.213 [731 3.34 [1919 0.803 [2 78] [2 100]] [2 44]] [2 75]] [5412 0.351 [2 95] [2 100]]] [2 100]] [24 57]] [2 57]] [2 98]] [2 50]] [2 50]] [4 100]] [2 50]] [2 100]]] [3670 1.72 [4832 2.08 [2 61] [4 44]] [4 75]]] [4349 0.263 [24 33] [2 40]]] [2616 7.83 [6990 0.0526 [5576 2.43 [2 87] [4324 4.44 [2 100] [2 85]]] [2 100]] [573 0.578 [1906 0.441 [2943 5.18 [2 100] [2 71]] [2 100]] [2 100]]]] [6088 0.587 [6989 0.52 [5692 5.07 [5007 0.666 [929 1.71 [4 54] [4 72]] [4 100]] [2 88]] [2 100]] [1089 0.397 [2 88] [2 77]]]] [4 100]] [2264 0.727 [5574 4.66 [4 44] [2 81]] [2 100]]] [1911 2.08 [6997 3.86 [6000 0.244 [4583 1.83 [1047 3.74 [724 1.62 [362 2.12 [731 8.62 [7004 3.3 [2587 3.44 [5299 5.89 [223 5.34 [2 100] [2 71]] [2 80]] [2 83]] [2 83]] [2 75]] [2 85]] [2 90]] [2752 8.01 [2 76] [2 100]]] [2 60]] [2 100]] [2 78]] [1436 0.521 [286 2.82 [2 69] [2 100]] [4 63]]]] [6363 0.226 [1400 1.03 [429 39.6 [6927 4.55 [4 100] [6927 7.92 [4 75] [4 100]]] [2 75]] [2902 2.3 [4 100] [4 87]]] [4 100]]]]] [2813 1.38 [7322 0.313 [598 0.154 [4844 0.208 [6457 0.129 [6230 1.03 [6791 5.72 [1899 9.07 [1400 3.7 [575 0.239 [2770 0.336 [7681 0.194 [4205 1.37 [2526 20.3 [6585 0.193 [771 1.28 [4218 3.21 [980 1.9 [7576 0.502 [5431 0.985 [695 1.46 [1429 16.7 [2241 2.37 [2445 5.15 [5412 5.38 [26 46] [1 58]] [17 33]] [26 37]] [253 0.41 [1239 8.09 [2434 3.14 [5007 10.4 [403 3.11 [896 4.39 [26 25] [18 81]] [18 100]] [19 55]] [18 50]] [685 5.33 [18 22] [18 85]]] [16 50]]] [5480 6.33 [112 0.399 [26 75] [16 33]] [5888 0.44 [7516 14.7 [1783 0.736 [18 72] [18 100]] [26 57]] [18 71]]]] [26 69]] [25 100]] [432 0.826 [7668 1.14 [328 4.39 [26 51] [2752 19.3 [26 55] [26 100]]] [26 100]] [26 100]]] [5170 1.12 [26 83] [26 80]]] [25 100]] [5480 14.8 [26 100] [26 85]]] [25 58]] [377 3.01 [1783 12.6 [429 13.2 [408 7.21 [724 0.867 [4154 0.793 [7693 0.419 [26 90] [26 100]] [26 100]] [26 66]] [19 62]] [7241 2.58 [26 80] [26 55]]] [26 40]] [7516 10.7 [26 33] [26 100]]]] [1011 0.194 [2753 5.53 [3332 1.01 [178 0.761 [26 86] [26 100]] [26 100]] [26 66]] [26 95]]] [7343 0.951 [25 89] [25 50]]] [7260 0.412 [4414 0.239 [5694 1.21 [7314 1.8 [26 90] [26 66]] [26 100]] [26 100]] [26 55]]] [5897 5.87 [2913 34 [5904 4.43 [6528 0.986 [2759 16.8 [6581 0.278 [1078 9.43 [5368 2.75 [2526 23.1 [1415 15.8 [2530 7.11 [1429 25.1 [1888 0.345 [5870 1.39 [7722 5.13 [999 1.85 [913 0.209 [3008 4.13 [1400 47.2 [23 3.9 [7681 1.74 [26 96] [26 100]] [26 83]] [26 73]] [25 50]] [26 100]] [26 100]] [429 4.93 [26 82] [26 66]]] [26 100]] [5170 9.5 [26 100] [26 88]]] [26 64]] [26 88]] [26 70]] [25 60]] [26 66]] [257 3.88 [338 6.67 [5692 8.16 [26 69] [26 50]] [26 100]] [19 50]]] [5595 4.8 [2178 1.12 [181 1.25 [2199 1.87 [7343 7.64 [5511 8.51 [1025 51.2 [4807 1.21 [6581 1.51 [26 80] [5348 0.297 [421 0.759 [6311 3.85 [4478 1.54 [2748 0.0984 [2755 0.703 [26 90] [2526 0.928 [26 95] [26 100]]] [26 100]] [26 100]] [26 71]] [26 100]] [26 100]]] [26 57]] [26 85]] [26 75]] [26 100]] [26 81]] [26 72]] [26 50]] [26 54]]] [26 50]] [26 55]] [19 53]] [26 62]] [25 80]]] [324 0.32 [1980 6.96 [4205 0.334 [2616 11.3 [5381 2.44 [2745 1.59 [1078 9.18 [201 1.04 [25 40] [25 72]] [2913 2.82 [184 2.74 [23 1.27 [26 62] [26 80]] [25 57]] [26 87]]] [1 75]] [36 71]] [26 87]] [26 77]] [5480 0.441 [328 4.19 [25 43] [25 85]] [26 62]]] [26 65]]] [978 3.29 [25 73] [6068 0.421 [5192 1.94 [26 50] [26 44]] [25 62]]]] [183 1.02 [182 0.539 [7693 6.85 [1429 22.8 [1980 3.85 [3849 1.62 [5626 2.66 [6499 1.95 [7310 0.304 [4369 1.56 [7665 0.843 [26 73] [4806 3.93 [1420 1.35 [5482 0.977 [392 14.5 [4235 35.5 [5480 0.463 [6230 8.2 [1078 0.754 [26 83] [2915 1.1 [2616 0.487 [5695 0.87 [26 95] [26 100]] [26 100]] [26 100]]] [7665 15.1 [26 100] [26 57]]] [4389 1.66 [2536 3.52 [2023 0.893 [723 0.312 [5851 0.287 [1429 16.3 [23 0.381 [6732 2.18 [26 100] [695 10.9 [26 100] [26 85]]] [26 100]] [26 91]] [26 100]] [26 100]] [26 88]] [26 88]] [26 80]]] [26 85]] [26 81]] [26 75]] [25 100]] [26 85]]] [25 77]] [25 100]] [26 71]] [18 57]] [7722 1.19 [26 73] [26 75]]] [2849 0.938 [2919 0.537 [7210 1.2 [2005 3.42 [6732 0.654 [26 51] [26 80]] [26 88]] [26 66]] [25 75]] [26 85]]] [4154 1.72 [23 2.59 [248 36.3 [26 100] [26 60]] [33 23]] [18 47]]] [25 55]] [25 100]] [25 100]]] [25 100]] [25 100]] [384 0.211 [2770 0.925 [25 100] [6294 0.125 [25 100] [25 80]]] [5412 2.2 [25 100] [25 70]]]] [5435 0.228 [2466 3.4 [1919 0.156 [676 3.21 [1400 33.8 [4851 0.682 [4205 2.07 [26 92] [26 100]] [26 100]] [26 91]] [26 87]] [26 57]] [19 50]] [26 100]]] [5007 1.36 [5192 1.8 [2813 6.85 [18 100] [18 90]] [18 80]] [5345 4.69 [18 100] [18 90]]]]] [2092 0.154 [2795 1.45 [2011 1.74 [939 1.67 [1 1.82 [2004 0.574 [1166 1.09 [906 2.67 [5871 1.56 [4991 1.09 [3282 1.14 [957 0.177 [27 99] [27 100]] [27 100]] [27 100]] [27 87]] [27 85]] [27 100]] [27 93]] [27 93]] [27 100]] [27 100]] [27 100]] [27 78]]] [4663 10.3 [6184 0.482 [659 0.301 [4317 0.69 [5241 9.84 [6871 1.59 [5491 0.963 [4414 0.615 [6131 10.9 [6544 0.808 [751 1.36 [791 1.47 [5502 5.15 [7449 5.62 [5952 3.03 [4154 1.99 [3 94] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 91]] [3 100]] [3 100]] [3 100]] [3 75]] [3 100]] [3 100]] [3 100]] [4179 1.54 [4282 1.71 [3 77] [3 100]] [3 100]]]] [4379 0.356 [2320 0.557 [730 0.215 [5047 0.741 [3008 12.8 [861 0.326 [6260 0.502 [968 1.05 [7340 1.82 [4312 5.53 [7480 8.39 [7665 2.03 [5513 1.09 [2917 8.09 [6918 1.63 [4210 1.9 [237 0.911 [802 3.63 [6643 7.69 [2914 1.37 [859 0.147 [148 6.49 [221 16.1 [2752 1.22 [7615 1.9 [3051 1.93 [7316 4.85 [6342 0.682 [2902 3.45 [3071 10.2 [2068 1.54 [1907 8.47 [2081 1.6 [5296 0.921 [1648 3.47 [126 2.67 [30 31] [3 100]] [30 100]] [17 85]] [3 59]] [3 100]] [1 41]] [30 100]] [30 83]] [3 37]] [3 100]] [30 100]] [3 100]] [7731 2.42 [7499 4.99 [695 2.64 [5222 2.02 [5007 22.5 [6604 0.967 [6724 6.86 [6713 3.94 [5412 0.931 [5192 3.07 [1626 5.24 [2759 5.62 [7009 1.28 [31 7.96 [14 69] [14 92]] [12 27]] [14 91]] [30 50]] [30 90]] [1980 2.77 [14 45] [28 53]]] [30 100]] [5642 2.26 [14 94] [14 100]]] [30 94]] [14 30]] [30 89]] [248 1.22 [5322 1.92 [2902 7.58 [1638 2.04 [1618 2.92 [6544 2.62 [7139 6.16 [14 86] [14 66]] [14 100]] [14 100]] [14 100]] [14 100]] [14 45]] [14 87]]] [30 77]] [32 46]]] [5211 2.41 [28 43] [1239 7.69 [30 89] [30 71]]]] [3 100]] [5192 4.69 [30 91] [30 77]]] [30 93]] [3 94]] [4279 2.86 [3 76] [3 96]]] [534 6.43 [3 85] [3 100]]] [534 1.15 [7169 8.31 [30 96] [30 90]] [3 100]]] [6919 8.26 [757 1.63 [3 80] [3 100]] [3 100]]] [4279 1.72 [3 94] [3 100]]] [3 100]] [4171 3.03 [3726 1.72 [859 0.444 [5871 0.196 [4307 2.41 [5211 5.65 [7233 3.81 [23 0.68 [3554 9.71 [828 1.46 [1552 3.14 [2331 5.02 [4517 10.9 [4451 13.2 [2366 4.48 [802 1.67 [3031 1.86 [6549 11.4 [4627 3.36 [3053 4.13 [6401 2.67 [7692 0.492 [7685 1.98 [328 3.65 [4322 2.18 [7354 3.64 [7531 5.88 [567 9.75 [5692 4.21 [4716 3.32 [7414 2.44 [6708 5.69 [702 1.99 [899 20 [4611 2.18 [5034 4.09 [14 41] [5410 13.2 [5605 16.2 [4799 9.48 [4288 1.65 [7512 4.26 [14 62] [1630 1.47 [14 87] [14 95]]] [32 57]] [32 83]] [14 58]] [14 59]]] [14 96]] [14 63]] [14 100]] [14 52]] [14 100]] [2752 16.4 [32 75] [14 87]]] [14 91]] [14 100]] [32 100]] [32 85]] [32 100]] [7428 8.18 [7449 7.72 [6152 0.772 [392 4.77 [14 92] [14 97]] [14 100]] [14 83]] [14 66]]] [20 100]] [5034 27.2 [1638 1.58 [2225 0.246 [14 96] [14 100]] [14 100]] [7722 2.39 [14 74] [14 100]]]] [32 93]] [32 100]] [32 80]] [32 69]] [32 100]] [3 44]] [3 68]] [32 88]] [32 50]] [32 100]] [32 100]] [899 5.43 [32 89] [32 100]]] [32 67]] [6547 0.68 [328 2.02 [77 2.92 [42 22.3 [899 10 [906 8.07 [6230 1.86 [201 1.92 [7677 1.39 [6708 3.46 [534 2.96 [1980 18.7 [1783 13.5 [7449 8.07 [695 28.8 [4154 9.72 [2616 0.713 [2902 1.68 [5034 3.97 [14 50] [14 84]] [14 91]] [22 28]] [14 77]] [14 57]] [14 71]] [14 33]] [14 57]] [3 95]] [32 72]] [14 100]] [14 30]] [4061 16 [6332 3.36 [14 98] [14 66]] [14 85]]] [32 52]] [6544 8.34 [7548 5.98 [14 77] [14 57]] [32 55]]] [3 100]] [14 40]] [7585 2.58 [5910 1.23 [2434 0.366 [7693 0.142 [221 2.91 [5034 3.57 [14 75] [4279 7.75 [6342 0.861 [23 15.8 [14 100] [7169 5.91 [7512 18.4 [14 85] [14 100]] [14 87]]] [14 100]] [14 85]]] [14 62]] [14 100]] [14 100]] [14 55]] [14 80]]] [721 5.27 [7585 5.22 [14 100] [14 98]] [14 91]]]] [32 88]] [4242 2.62 [2752 3.18 [5122 1.36 [429 22.3 [2470 1.53 [30 80] [30 100]] [30 62]] [30 100]] [1783 4.1 [2259 31.9 [3008 3.55 [1239 1.17 [30 79] [30 40]] [30 100]] [30 58]] [30 41]]] [20 100]]] [32 100]] [4799 0.994 [5316 5.2 [5673 13.8 [4943 2.3 [2280 4.08 [7369 3.19 [5566 1.67 [3008 3.49 [663 15.3 [4517 2.72 [5007 10.5 [5767 0.312 [5246 0.441 [6199 0.106 [6732 0.664 [1062 1.85 [4154 1.46 [5165 0.768 [7428 1.22 [3905 2.62 [7585 3.7 [14 97] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 75]] [14 100]] [14 85]] [14 83]] [14 72]] [14 88]] [5160 4.01 [14 88] [14 100]]] [7512 16 [14 77] [14 100]]] [14 83]] [14 55]] [14 72]] [32 63]] [32 44]]] [30 81]] [855 1.72 [32 96] [32 100]]] [32 100]]] [32 94]] [2260 1.83 [7722 4.36 [5034 49.2 [7298 2.09 [1429 13.2 [907 1.05 [4159 11.8 [7512 2.7 [3 65] [32 86]] [3 100]] [3 100]] [30 30]] [30 100]] [3 100]] [2826 8.74 [32 80] [14 100]]] [896 1.83 [4312 15.6 [14 60] [30 83]] [14 87]]]] [7512 2.38 [32 66] [4517 0.664 [328 9.85 [1557 0.592 [4288 16.7 [6550 7.05 [434 12.5 [3905 38.1 [3554 31.2 [663 8.18 [3720 3.7 [1400 8.22 [5753 7.81 [32 100] [32 91]] [32 94]] [3520 3.5 [32 85] [32 100]]] [3579 7.9 [6031 0.75 [32 96] [32 100]] [32 88]]] [32 85]] [32 66]] [32 88]] [32 78]] [32 86]] [14 66]] [32 60]] [7665 15 [32 80] [32 57]]]]] [6696 1.06 [4568 0.305 [4170 0.441 [503 0.986 [896 1.39 [286 0.42 [695 0.186 [973 0.766 [4418 1.17 [5753 2.83 [6103 1.42 [3113 2.11 [4056 1.42 [2332 0.722 [4307 1.65 [3726 2.58 [1239 13.6 [5381 1.62 [6091 2.15 [4288 2.3 [5323 2.67 [5034 6.49 [28 67] [2913 1.86 [4369 5.05 [5605 6.02 [3905 3.27 [392 3.77 [28 59] [28 90]] [32 94]] [28 91]] [32 100]] [32 100]]] [32 66]] [32 92]] [32 85]] [28 100]] [28 96]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]] [32 91]] [5194 3.87 [663 1.08 [5412 4.48 [28 43] [6524 6.78 [28 86] [1078 24.2 [1429 8.78 [28 83] [28 83]] [28 60]]]] [28 100]] [28 46]]] [28 82]] [28 87]] [7340 1.46 [7197 0.566 [906 5.13 [1899 4.86 [5192 2.76 [28 77] [28 64]] [2199 1.75 [4011 4.55 [28 94] [28 88]] [28 85]]] [28 100]] [28 100]] [32 91]]] [5462 4.56 [1429 1.16 [28 66] [28 95]] [28 87]]] [7722 7.94 [32 94] [32 100]]] [32 100]] [4375 1.14 [7600 2.14 [695 0.949 [1400 8.15 [32 100] [32 75]] [32 100]] [2846 2.85 [32 69] [32 100]]] [32 100]]] [2178 5.41 [7197 1.92 [939 0.826 [5967 0.666 [4414 0.701 [4011 0.724 [28 88] [28 100]] [28 100]] [28 96]] [28 100]] [28 77]] [28 75]]] [28 100]]] [2526 4.42 [6264 0.683 [1679 0.867 [7316 1.29 [2752 7.42 [3 63] [4288 6.91 [30 82] [30 100]]] [3 83]] [30 100]] [30 76]] [3 76]]] [3728 0.326 [5732 7.6 [32 100] [32 92]] [32 100]]] [42 1.37 [6413 0.499 [7512 24.1 [6732 12.1 [5589 2.15 [2916 18.3 [695 1.88 [1980 11.9 [5154 3.66 [2939 5.16 [144 4.21 [2913 35 [613 0.491 [5904 27 [4218 5.46 [1239 5.89 [867 1.04 [30 91] [30 100]] [30 63]] [30 90]] [30 85]] [7645 19.6 [4607 7.25 [5225 7.61 [5211 15.6 [6910 4.14 [30 95] [30 93]] [4332 0.599 [6550 2.53 [30 100] [4312 12.3 [30 100] [30 80]]] [30 100]]] [30 100]] [30 100]] [30 94]]] [30 70]] [30 60]] [30 33]] [30 60]] [30 64]] [14 46]] [30 62]] [30 66]] [28 63]] [14 76]] [14 75]] [3 84]]] [221 1.5 [7210 11.5 [3 100] [3 75]] [3 83]]] [5673 12.5 [2846 1.84 [504 3.06 [791 0.921 [2752 20.7 [728 5.45 [28 63] [28 84]] [1078 3.11 [28 73] [28 100]]] [7690 2.92 [5967 10.6 [730 10.9 [4012 1.54 [1062 4.64 [2752 25.2 [7197 0.495 [4533 6.07 [6074 0.601 [5732 0.322 [4611 1.48 [28 92] [28 100]] [28 100]] [28 100]] [28 85]] [28 100]] [28 100]] [1995 2.7 [28 96] [28 71]]] [28 76]] [23 21.8 [429 17.9 [28 100] [1062 2.42 [4564 5.49 [28 90] [19 50]] [28 77]]] [28 69]]] [28 75]] [32 100]]] [28 66]] [939 0.754 [32 88] [32 100]]] [32 77]]] [5732 7.39 [2091 5.74 [4312 0.174 [512 1.13 [5509 7.06 [32 100] [32 88]] [32 100]] [32 100]] [429 41.5 [32 100] [32 77]]] [5730 0.745 [32 100] [32 90]]]] [1783 3.76 [2752 2.9 [32 85] [968 4.53 [32 100] [32 92]]] [32 46]]]] [29 0.457 [4626 2.18 [518 0.223 [1361 0.514 [1342 1.5 [1312 5.32 [5879 6.19 [538 0.446 [554 0.528 [6194 3.24 [6672 0.592 [642 3.99 [536 2.35 [3111 0.927 [513 0.492 [1017 1.5 [933 0.911 [593 12.4 [7424 1.44 [7665 0.935 [907 1.94 [7009 0.599 [374 8.33 [4664 16.6 [7085 7.78 [1980 14 [6310 1.22 [6353 0.84 [5034 1.47 [4703 0.797 [5768 3.11 [5246 7.25 [2752 1.64 [616 2.35 [5938 6.41 [5851 4.74 [21 50] [3 25]] [21 100]] [3 100]] [15 30]] [9 87]] [3 100]] [21 44]] [3 100]] [3 18]] [21 96]] [7493 7.04 [1986 3.18 [747 4.85 [3 48] [21 92]] [4154 3.94 [766 3.7 [21 90] [21 100]] [3 50]]] [21 100]]] [1980 9.45 [21 69] [21 100]]] [917 12.4 [21 100] [21 75]]] [5938 5.46 [375 15 [21 100] [21 85]] [21 100]]] [12 43]] [225 0.568 [616 2.86 [2259 13.2 [1783 11.3 [541 0.84 [2994 7.71 [21 72] [21 96]] [21 100]] [3 42]] [3 64]] [3 100]] [21 100]]] [7512 1.87 [1429 3.96 [3 62] [3 71]] [32 29]]] [3 30]] [9 100]] [3 100]] [7210 0.692 [1783 1.23 [2083 0.661 [5972 2.92 [3 76] [3 97]] [3 90]] [3 100]] [3 84]]] [21 100]] [15 92]] [3 84]] [6375 1.56 [802 6.98 [21 62] [21 92]] [21 90]]] [3 100]] [580 1.71 [21 68] [21 100]]] [6676 0.642 [6726 2.51 [429 111 [3 100] [3 72]] [3 100]] [3 100]]] [7425 1.19 [574 0.695 [6199 6.44 [6892 0.529 [6191 1.92 [6260 0.578 [2526 10.7 [21 86] [21 80]] [1899 4.84 [907 2.11 [21 88] [906 10.7 [9 100] [21 86]]] [21 84]]] [21 96]] [589 2.3 [21 100] [21 85]]] [21 45]] [594 1.81 [699 4.23 [9 85] [9 100]] [9 100]]] [9 76]]] [21 100]] [9 90]] [9 72]] [3 100]] [6342 1.93 [6791 4.64 [6949 0.879 [429 77.3 [4917 0.484 [21 73] [21 100]] [21 100]] [21 90]] [907 10.4 [21 100] [21 66]]] [535 0.512 [688 0.629 [21 84] [21 66]] [21 100]]]] [4279 0.775 [21 53] [3 100]]] [7241 0.675 [611 1.93 [5370 0.931 [747 2.58 [5976 0.624 [634 0.293 [5647 0.48 [6837 0.48 [5938 7.8 [5249 0.942 [561 0.928 [9 53] [9 60]] [9 58]] [21 80]] [9 100]] [21 55]] [21 70]] [3 100]] [21 100]] [23 10.3 [9 57] [9 100]]] [9 100]] [3 88]]]] [7354 1.01 [5403 1.32 [959 0.345 [1409 1.6 [4908 0.944 [5509 1.05 [3067 0.398 [7176 0.272 [4006 0.0999 [4678 0.416 [6998 0.264 [4338 1.03 [1116 0.891 [6854 0.821 [6907 0.474 [1240 3.86 [6260 2.22 [5211 2.45 [2331 1.04 [6404 0.509 [5345 0.628 [6230 2.74 [404 0.183 [975 0.192 [7751 1.44 [392 0.488 [5034 0.298 [112 2.61 [7373 3.41 [5472 2.64 [377 2.04 [153 1.23 [791 12.3 [6959 8.84 [3015 2.18 [1575 1.01 [5626 2.26 [6471 1.69 [3004 3.11 [2526 5.13 [660 8.21 [4364 3.92 [1400 4.62 [5151 1.05 [2488 5.05 [435 0.42 [1429 19.7 [24 27] [719 6.13 [36 28] [31 77]]] [10 42]] [34 100]] [31 100]] [25 44]] [7169 2.02 [34 73] [34 91]]] [36 53]] [24 33]] [36 100]] [26 100]] [1783 15.5 [19 71] [19 66]]] [24 100]] [25 100]] [5267 1.6 [16 50] [31 100]]] [7032 1.98 [1628 4.65 [2526 5.22 [36 43] [24 37]] [36 100]] [2 60]]] [28 100]] [28 67]] [6524 2.26 [874 1.22 [2259 1.66 [36 52] [36 100]] [36 100]] [36 100]]] [695 1.27 [36 74] [36 100]]] [7449 7.95 [36 82] [36 60]]] [7591 1.43 [1177 8.02 [4200 2.84 [2466 1.11 [6920 7.78 [6974 2.4 [4279 18.9 [5605 6.1 [7251 5.58 [4279 4.77 [1062 5.54 [28 94] [28 80]] [28 83]] [28 55]] [28 81]] [28 46]] [28 66]] [28 60]] [28 75]] [28 54]] [28 66]] [32 100]]] [2605 1.11 [2913 0.921 [4218 1.37 [4414 5.11 [2178 0.47 [791 0.894 [28 58] [3178 0.84 [4851 1.37 [221 1.29 [28 83] [28 100]] [28 100]] [28 100]]] [28 80]] [28 75]] [28 55]] [26 52]] [25 100]]] [24 94]] [5776 2.42 [3008 3.72 [4611 2.45 [3604 0.804 [685 6.58 [2759 4.79 [939 0.267 [6856 0.576 [1567 4.48 [28 95] [28 66]] [883 1.07 [28 100] [28 71]]] [28 100]] [28 90]] [28 82]] [28 80]] [28 90]] [28 87]] [28 64]]] [6347 0.412 [5673 0.539 [6856 0.723 [1077 0.55 [5851 0.121 [5034 1.66 [28 57] [28 85]] [28 80]] [28 100]] [28 100]] [28 100]] [28 71]]] [34 27]] [7722 2.39 [1429 20.5 [34 26] [6922 1.16 [1899 23.2 [36 79] [36 66]] [36 100]]] [2811 0.327 [36 91] [36 100]]]] [36 100]] [36 76]] [4398 2.68 [6945 0.861 [2029 0.231 [5833 1.34 [883 0.469 [1751 0.852 [248 0.606 [809 0.711 [5226 1.01 [6820 1.38 [5482 1.62 [1611 0.873 [4702 3.03 [6375 3.17 [7665 8.54 [4312 6.64 [3105 0.515 [6949 1.73 [429 25.7 [6791 1.36 [30 80] [22 64]] [859 15.2 [30 45] [22 71]]] [30 100]] [30 100]] [30 42]] [30 43]] [22 76]] [30 100]] [30 100]] [22 100]] [22 100]] [22 94]] [22 100]] [30 90]] [22 88]] [884 9.18 [5480 6.12 [22 85] [22 100]] [22 75]]] [11 66]] [22 86]] [10 80]] [30 36]]] [5222 0.644 [1062 5.33 [2847 2.16 [4279 14.7 [2488 2.02 [1995 1.45 [2178 1.16 [2827 6.22 [2518 2.79 [7210 7.92 [4815 1.66 [2763 3.37 [4611 1.12 [6269 1.72 [7512 5.62 [5412 0.979 [36 62] [36 55]] [1899 1.53 [7067 2.27 [36 89] [36 100]] [36 100]]] [36 100]] [36 100]] [22 45]] [36 100]] [22 85]] [24 44]] [36 46]] [36 54]] [36 100]] [34 100]] [24 60]] [22 77]] [34 38]] [30 100]]] [7156 0.697 [24 85] [24 100]]] [7583 0.474 [1081 0.766 [1078 8.82 [25 100] [25 83]] [25 100]] [25 100]]] [10 100]] [7169 0.412 [4701 1.04 [5034 3.1 [30 71] [4200 2.73 [144 0.75 [30 99] [30 100]] [30 100]]] [30 100]] [30 100]]] [2793 16.2 [434 2.8 [4841 0.309 [5605 2.18 [3026 31.3 [4046 2.27 [17 2.62 [2628 7.29 [1997 4.75 [4324 4.73 [7665 5.61 [6922 1.39 [24 86] [24 100]] [5654 0.512 [3648 4.12 [791 9.29 [3018 0.164 [24 93] [24 100]] [24 100]] [24 88]] [24 88]]] [24 62]] [24 85]] [24 66]] [24 50]] [24 70]] [24 37]] [24 53]] [24 57]] [24 100]] [24 58]]] [883 0.132 [28 94] [28 100]]] [1723 9.27 [7373 3.25 [1400 1.31 [36 85] [36 100]] [36 97]] [36 62]]] [6606 2.71 [221 0.126 [28 90] [38 50]] [6161 1.45 [4895 1.12 [3790 1.56 [722 0.637 [4251 1.33 [6607 12.4 [28 100] [28 87]] [28 100]] [28 66]] [28 77]] [28 60]] [1913 0.741 [7189 1.87 [1841 12.8 [2521 4.71 [28 100] [1708 6.9 [28 83] [28 100]]] [28 87]] [28 85]] [28 100]]]]] [5972 3.84 [328 2.51 [6970 3.57 [6859 0.0917 [22 84] [5871 1.91 [1913 0.164 [5693 0.423 [883 4.56 [2081 0.62 [22 90] [22 100]] [22 83]] [22 100]] [22 100]] [22 66]]] [22 66]] [5226 0.964 [6353 0.877 [2827 0.316 [5225 0.598 [28 50] [22 100]] [22 90]] [28 33]] [22 100]]] [12 55]]] [6524 1.52 [36 100] [4612 0.775 [36 100] [36 60]]]] [403 8.2 [6858 0.499 [5034 1.08 [5942 0.176 [7591 0.534 [5972 1.56 [6918 1.8 [6530 1.43 [22 16] [22 100]] [28 85]] [36 38]] [19 28]] [6417 1.46 [28 75] [28 100]]] [2383 0.276 [7314 2.46 [791 1.05 [28 66] [5511 8.72 [1911 0.044 [5036 0.353 [5435 3.45 [957 3.31 [6396 0.332 [7169 2.06 [730 0.38 [28 77] [28 100]] [28 71]] [28 83]] [28 91]] [28 100]] [28 100]] [28 100]] [28 58]]] [28 61]] [28 100]]] [25 100]] [25 87]]] [1025 2.61 [7425 5.2 [726 0.542 [5457 1.47 [1429 73 [4908 7.26 [36 98] [36 100]] [36 69]] [36 90]] [36 80]] [36 81]] [24 66]]] [36 100]] [10 100]] [2268 7.18 [1888 2.64 [2232 6.55 [5673 15.1 [4478 12.3 [31 100] [31 93]] [31 83]] [31 81]] [31 100]] [31 75]]] [855 0.928 [602 0.705 [7735 0.47 [3223 2.01 [1011 0.807 [5482 2.19 [6719 2.81 [1025 13.5 [7329 0.172 [978 2.64 [685 0.274 [6031 0.889 [4943 4.31 [2752 59.6 [4545 17.1 [5907 1.27 [2628 11.6 [3879 9.42 [2846 11 [7376 0.212 [2905 2.12 [5904 12.7 [1025 12.1 [4841 5.46 [1719 13.3 [203 0.201 [7085 4.97 [2571 0.499 [1206 6.17 [1602 0.376 [5472 0.216 [7067 1.86 [5716 0.99 [1899 0.835 [7571 1.16 [144 1.71 [2752 17.8 [36 96] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 87]] [36 71]] [36 88]] [36 100]] [36 81]] [36 88]] [36 80]] [36 80]] [5412 1.08 [36 100] [36 87]]] [36 100]] [36 88]] [36 83]] [36 93]] [207 2.6 [36 78] [36 66]]] [36 77]] [36 42]] [5198 0.347 [631 1.16 [3644 0.528 [3008 2.57 [36 70] [36 100]] [36 100]] [36 100]] [36 100]]] [36 66]] [18 28]] [36 62]] [25 30]] [36 41]] [36 70]] [18 53]] [7188 2.33 [896 4.46 [4545 0.534 [36 92] [36 100]] [7512 14.7 [36 55] [18 66]]] [18 100]]] [8 100]] [18 50]] [19 50]] [32 55]]]] [2897 3.06 [1474 0.614 [5154 1.2 [3576 9.35 [7085 5.08 [5767 0.477 [1152 2.62 [3085 22.7 [1532 3.22 [6955 7.81 [3990 4.98 [4065 25.3 [4111 0.0734 [3780 5.75 [708 32.4 [328 0.258 [663 0.288 [429 47.2 [3990 0.238 [791 2.82 [37 95] [37 100]] [37 100]] [37 71]] [37 100]] [37 100]] [37 88]] [37 97]] [37 100]] [37 83]] [37 100]] [37 90]] [3079 13.4 [37 100] [37 63]]] [37 77]] [37 83]] [3288 0.285 [37 100] [37 71]]] [37 83]] [37 71]] [1463 0.0749 [3288 0.377 [5158 15.8 [37 100] [3292 22.3 [37 100] [37 80]]] [37 100]] [37 100]]] [5158 9.74 [37 100] [3777 6.89 [37 100] [37 71]]]] [37 60]]] [248 2.65 [6581 2.82 [2605 5.15 [6074 14.3 [7032 0.286 [7354 0.428 [6261 0.678 [6643 0.507 [1104 0.956 [4871 0.596 [519 1.16 [722 0.515 [5400 0.263 [144 8.22 [13 100] [1783 6.76 [13 80] [13 100]]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [2091 3.82 [5401 7.25 [13 97] [13 100]] [13 100]]] [25 100]] [13 63]] [2913 0.297 [221 2.15 [25 68] [25 100]] [25 100]]]] [7085 4.81 [4282 0.173 [1436 0.17 [1986 0.225 [4587 7.67 [3 100] [2081 2.79 [3 77] [3 100]]] [3 100]] [3 100]] [3 100]] [3 98]]] [685 0.482 [7389 0.332 [6441 2.31 [13 100] [13 83]] [13 100]] [13 87]]] [6183 0.1 [2218 1.03 [1948 0.264 [5891 25.2 [929 0.546 [3520 7.68 [4947 0.566 [7329 0.29 [1451 8.68 [2993 6.24 [1659 4.89 [1995 14.6 [695 3.98 [32 100] [3480 1.23 [6811 1.02 [2826 2.18 [32 96] [32 100]] [32 100]] [32 100]]] [32 97]] [3899 0.731 [6938 0.205 [250 4.47 [2093 0.327 [7333 4.93 [32 100] [32 85]] [32 100]] [32 88]] [32 100]] [32 100]]] [32 87]] [32 95]] [32 90]] [32 96]] [32 77]] [32 85]] [32 67]] [23 0.452 [19 37] [32 100]]] [32 75]] [32 45]]] [5723 0.53 [2696 1.53 [1807 0.0886 [1726 0.345 [7282 0.834 [2717 0.243 [2750 0.0578 [2951 45.9 [2688 0.832 [2880 0.862 [6370 4.55 [3775 0.29 [3435 2.15 [6431 5.46 [4205 1.85 [3581 0.503 [7231 0.76 [2671 0.785 [2951 20.4 [5955 0.864 [6409 1.29 [2714 0.804 [1239 12.4 [2628 28.2 [6199 0.635 [2187 0.093 [3834 7.87 [193 2.36 [4104 0.572 [187 7.53 [3006 1.38 [6959 1 [4279 8.85 [7486 0.784 [1628 0.454 [4398 6.71 [7449 11.3 [6825 2.72 [7390 6.48 [2978 9.99 [4851 4.29 [791 7.39 [6342 4.18 [2851 8.36 [2752 3.86 [38 21] [1429 30.3 [38 23] [16 48]]] [5 62]] [16 50]] [37 25]] [2752 10.3 [18 30] [32 42]]] [16 41]] [16 70]] [38 62]] [5 53]] [13 57]] [29 100]] [38 50]] [29 71]] [16 95]] [26 80]] [2869 0.894 [7391 7.06 [2199 0.754 [16 43] [18 33]] [14 44]] [6 53]]] [3107 4.48 [7476 5.17 [5 76] [37 44]] [5 81]]] [6 44]] [26 100]] [16 100]] [2826 3.22 [6544 0.979 [4807 0.874 [112 1.23 [5673 9.94 [1429 33.6 [4939 0.079 [6959 1.93 [7101 0.161 [7306 0.687 [7169 4.04 [5799 1.93 [7169 1.89 [6875 1.03 [144 0.803 [7009 3.36 [38 42] [38 85]] [28 40]] [38 50]] [17 40]] [16 50]] [16 33]] [38 85]] [1 66]] [16 90]] [16 80]] [4478 6.44 [1436 1.6 [7474 7.32 [38 28] [38 75]] [17 35]] [5 53]]] [16 58]] [32 57]] [38 84]] [17 46]] [19 50]]] [1687 0.492 [2656 2.52 [2952 2.72 [5626 0.858 [1429 5.2 [192 11.8 [7480 36.4 [4708 5.15 [1980 2.04 [23 29.8 [4538 10.5 [2687 18.5 [6 30] [38 83]] [38 100]] [38 53]] [38 61]] [38 50]] [1983 0.901 [38 81] [38 100]]] [6 46]] [6761 1.87 [2939 18.7 [94 13 [1899 1.29 [17 24] [38 29]] [16 100]] [6294 9.44 [7372 1.78 [7445 2.7 [2468 7.95 [5875 16.7 [2881 8.26 [4648 6.95 [62 5.38 [3399 1.78 [37 3.76 [7210 4.2 [95 7.88 [38 18] [17 83]] [38 45]] [1900 0.978 [190 1.99 [2628 36.9 [37 46] [12 31]] [2939 30.6 [2955 8.06 [5 54] [5 77]] [5 33]]] [5 69]]] [5 90]] [14 46]] [14 50]] [16 50]] [38 100]] [12 37]] [38 55]] [16 87]] [16 88]]] [6 71]]] [2640 10.4 [6 35] [2709 27.4 [16 71] [6 33]]]] [38 75]] [16 40]] [7390 7.08 [1997 2.68 [38 64] [38 100]] [16 27]]]] [2426 3.1 [1897 1.46 [4940 1.57 [7132 9 [7486 0.764 [4859 2.34 [1355 0.719 [7480 0.194 [1429 20.8 [1400 0.985 [2282 2.37 [6220 22.7 [5010 0.488 [7176 0.733 [4879 26.4 [2853 4.47 [5103 3.29 [7041 8.18 [5435 4.14 [4414 25.8 [4937 2.23 [7343 5.07 [5090 0.32 [2259 45.1 [1783 22.8 [166 1.08 [5626 8.32 [6 25] [18 36]] [2707 11.9 [17 33] [38 61]]] [25 38]] [38 33]] [5090 13.5 [6 62] [6 42]]] [16 33]] [6761 5.36 [6 62] [30 37]]] [187 8.58 [6 42] [16 90]]] [2955 1.38 [6 37] [16 64]]] [4513 6.18 [6 62] [16 57]]] [4939 14.3 [18 25] [6 63]]] [16 90]] [6 95]] [33 60]] [6129 1.92 [5099 39.1 [2259 8.5 [6353 1.21 [194 4.72 [16 55] [6 81]] [18 66]] [16 76]] [6 58]] [30 50]]] [18 81]] [5673 1.93 [16 87] [16 88]]] [26 87]] [7472 5.38 [4746 1.17 [2039 0.384 [429 13.2 [6937 5.9 [1896 4.27 [1671 0.456 [6471 0.638 [1932 1.62 [1260 1.13 [6383 1.08 [2752 1.34 [17 11] [32 33]] [16 25]] [6 22]] [38 71]] [16 42]] [17 50]] [17 41]] [16 87]] [2955 2.15 [3 37] [16 60]]] [16 33]] [5 53]] [17 60]]] [7150 1.02 [5568 0.752 [6 69] [6 60]] [18 50]]] [18 77]] [1429 2.11 [7 33] [6152 1.36 [18 57] [18 100]]]] [1253 1.62 [6825 1.86 [17 26] [38 75]] [28 37]]] [7 89]] [5593 7.62 [16 81] [16 50]]] [429 5.06 [2466 1.18 [83 1.66 [1897 11.7 [38 36] [17 35]] [18 26]] [16 27]] [16 50]]] [38 83]]] [1696 0.6 [2646 2.9 [7762 0.319 [5368 3.16 [6517 1.65 [16 38] [5103 2.25 [16 40] [6 33]]] [19 30]] [2955 6.09 [18 55] [26 33]]] [26 52]] [2849 49.7 [16 75] [26 58]]]] [23 4.97 [7343 2.67 [7210 8.01 [16 35] [16 63]] [25 44]] [663 2.37 [6471 6.56 [2891 1.82 [2939 26.1 [2727 2.01 [45 0.485 [7150 3.01 [18 25] [6 66]] [18 50]] [16 87]] [2667 15.4 [7149 7.8 [2978 5.53 [62 2 [16 34] [62 7.14 [16 50] [16 76]]] [16 86]] [25 25]] [16 87]]] [7 40]] [26 35]] [18 84]]]] [5956 0.675 [2638 3.52 [38 100] [38 66]] [38 70]]] [2725 2.15 [5100 1.11 [3418 9.88 [6181 17.8 [2710 0.87 [2670 24.6 [6942 3.13 [6959 6.66 [2102 6.68 [2902 4.65 [7206 15.5 [6199 23.9 [7222 1.26 [3238 8.16 [1932 0.327 [6220 2.47 [1953 3.72 [4105 1.23 [1429 11.5 [6294 6.14 [7512 6.01 [2714 1.27 [4762 5.18 [6839 49.4 [2851 4.48 [1262 0.758 [5983 9.01 [1338 1.17 [5187 2.54 [2877 5.99 [3008 4.51 [2707 8.49 [16 15] [1783 26.5 [4889 9.47 [2656 12.4 [4991 9.88 [187 9.8 [6824 1.1 [2712 2.65 [5577 38.9 [1395 10.5 [6791 0.754 [7132 16 [194 3.46 [2862 0.449 [38 56] [38 75]] [10 20]] [7 66]] [16 33]] [38 55]] [16 83]] [7 37]] [38 44]] [7474 2.07 [38 70] [38 87]]] [38 100]] [16 83]] [16 40]] [38 50]]] [10 30]] [7 27]] [38 92]] [17 23]] [7255 4.44 [6 44] [16 54]]] [9 33]] [38 86]] [16 50]] [16 55]] [16 42]] [6 58]] [13 33]] [2709 2.1 [2659 3.52 [2948 2.1 [4896 2.06 [7206 0.73 [3008 15.9 [2691 6.08 [6825 0.495 [1913 1.68 [3207 4.87 [7322 3.02 [5626 7.32 [6208 15.9 [2752 25.1 [2466 7.08 [38 30] [38 64]] [5 50]] [17 50]] [16 57]] [16 57]] [5 69]] [8 27]] [4897 1.49 [38 66] [14 27]]] [37 58]] [5 43]] [38 80]] [17 31]] [38 60]] [38 100]] [16 50]]] [37 71]] [14 75]] [187 9.95 [15 30] [16 77]]] [38 76]] [16 73]] [16 70]] [95 7.99 [38 66] [6 22]]] [16 44]] [12 29]] [2667 9.55 [16 27] [16 70]]] [16 68]] [2707 15.3 [16 63] [6 37]]] [17 70]] [2081 4.13 [17 41] [2951 41.6 [14 50] [14 50]]]] [7 75]] [5 100]] [7222 5.54 [6224 0.99 [7132 1.58 [4854 25.5 [6256 3.1 [2867 2.29 [7149 6.23 [3993 1.9 [6 36] [16 71]] [16 38]] [28 30]] [18 73]] [6 68]] [7 66]] [6 55]] [6 83]]] [7 100]]] [1601 0.429 [6687 1.5 [5413 0.829 [2671 10.1 [7722 0.529 [7601 2.71 [2707 16.6 [7259 2.2 [279 2.78 [91 3.09 [4762 9.35 [2846 2.8 [7241 1.98 [5485 4.4 [1396 3.06 [392 1.73 [5007 1.59 [2849 16.8 [18 53] [328 1.13 [5894 4.56 [7343 0.379 [16 81] [16 55]] [18 90]] [16 71]]] [16 41]] [18 53]] [26 50]] [18 100]] [16 35]] [38 57]] [18 75]] [16 56]] [16 42]] [19 64]] [6942 0.956 [6406 7.42 [16 51] [16 77]] [18 50]]] [1661 3.52 [2526 6.17 [4717 0.511 [16 62] [16 100]] [1239 0.773 [16 50] [16 62]]] [16 27]]] [83 1.3 [7427 0.78 [7737 3.41 [18 54] [18 45]] [26 83]] [18 50]]] [5673 11.8 [2881 11 [2671 34.2 [2868 4.71 [18 60] [6658 3.03 [7512 5.82 [7512 2.46 [18 38] [18 36]] [26 28]] [18 100]]] [16 40]] [18 36]] [16 87]]] [18 100]] [2863 1.99 [7206 2.89 [1980 5.05 [2881 1.62 [16 58] [6 80]] [2868 2.86 [16 63] [2241 1.35 [6833 0.955 [18 63] [18 72]] [6 40]]]] [16 67]] [14 33]]] [429 8.24 [19 62] [19 50]]]] [187 7.32 [5673 0.912 [5110 3.16 [6230 2.06 [7619 9.72 [5753 2.29 [62 5.25 [5170 2.07 [7122 78.8 [3421 0.391 [16 60] [5 62]] [16 36]] [2951 22.9 [26 81] [18 33]]] [6 45]] [1429 25.9 [38 26] [18 40]]] [13 71]] [5 28]] [30 100]] [5801 6.02 [7232 17.8 [4154 2.94 [5192 0.928 [5681 0.506 [695 1.57 [30 25] [26 62]] [4431 0.763 [1429 16.8 [62 2.47 [5598 0.634 [2733 2.53 [18 50] [18 83]] [16 40]] [16 41]] [18 28]] [18 71]]] [26 37]] [16 57]] [18 72]] [16 60]]] [7343 17.9 [5753 6.86 [4427 4.7 [2955 6.93 [16 26] [791 4.31 [167 2.23 [16 61] [6 55]] [16 30]]] [6 43]] [18 71]] [18 44]]]] [2161 1.02 [3196 0.402 [2691 2.64 [2852 1.56 [5 62] [5 88]] [5 40]] [5 57]] [2951 8.91 [5 71] [5 100]]]] [429 7.67 [2913 4.55 [7516 0.448 [192 3.11 [414 3.16 [5192 1.34 [2951 24.4 [4851 0.454 [26 92] [6517 0.341 [26 43] [26 100]]] [7 57]] [26 50]] [26 60]] [26 50]] [26 100]] [26 55]] [5198 0.652 [16 29] [26 90]]]] [2102 0.775 [6199 4.54 [7343 1.39 [7 85] [7 100]] [6 55]] [7 71]]] [5103 2.74 [2951 23.6 [2707 40.6 [3089 0.274 [6825 1.94 [1587 0.678 [4851 1.59 [3675 4.23 [5801 0.913 [192 8.08 [2643 1.34 [38 40] [2037 0.0597 [1239 4.26 [7149 1.97 [2876 0.552 [5099 8.69 [3878 0.767 [3544 16.4 [6334 0.982 [37 57] [5 88]] [5 40]] [5 58]] [37 100]] [37 90]] [19 33]] [37 62]] [37 50]]] [5 58]] [16 50]] [5 37]] [6778 16.4 [673 1.98 [5962 3.02 [6778 10.2 [3436 4.35 [5 42] [2939 28.2 [3972 0.515 [6 71] [6 42]] [18 63]]] [1429 4.26 [4623 16.7 [5 50] [16 55]] [16 71]]] [6 62]] [26 85]] [37 51]]] [1239 4.94 [16 25] [38 66]]] [38 85]] [37 100]] [38 61]] [4513 1.36 [4623 5.49 [38 57] [7241 1.11 [16 40] [37 50]]] [18 50]]] [2955 4.89 [5 36] [16 75]]]] [429 0.219 [7449 0.394 [5 37] [3419 3.93 [2327 2.84 [1783 2.94 [5 96] [5 70]] [2707 25.4 [37 1.36 [5 75] [5 87]] [5 50]]] [5 71]]] [37 50]]] [1648 0.378 [2956 0.0842 [2955 23.3 [299 0.499 [6287 1.6 [3902 0.393 [7241 10.8 [4154 11 [2006 8.79 [2707 27.8 [190 18.1 [193 2.14 [3867 0.393 [2951 26 [2749 0.599 [2876 1.97 [6372 17.9 [2259 1.25 [18 43] [16 46]] [26 50]] [16 88]] [26 100]] [16 61]] [83 1.12 [2955 4.76 [18 88] [18 54]] [18 57]]] [16 75]] [16 62]] [7343 31.7 [6920 1.63 [5568 2.86 [2881 1.68 [23 0.963 [16 46] [2143 4.64 [16 83] [16 50]]] [6 42]] [16 100]] [16 80]] [16 53]]] [16 72]] [30 53]] [16 33]] [16 100]] [83 4.31 [16 94] [16 62]]] [28 50]] [6 34]] [26 84]] [18 45]]] [6152 0.216 [6134 2.21 [4754 1.18 [14 42] [17 87]] [17 31]] [14 71]]] [1800 1.48 [7185 3.12 [7231 16 [4947 13.7 [6962 0.444 [1295 0.4 [6207 8.65 [7041 3.6 [4154 0.898 [38 99] [38 100]] [38 83]] [312 0.669 [38 92] [38 100]]] [7370 0.2 [7123 12.9 [38 100] [38 85]] [38 100]]] [38 66]] [38 85]] [38 75]] [38 63]] [38 83]]] [2733 1.38 [2691 0.549 [4610 2.97 [5102 0.99 [2259 29.4 [2676 11 [5985 13.8 [2955 2.51 [38 46] [3843 0.245 [5593 8.42 [6409 13.8 [5438 2.79 [2722 19.7 [7401 7.52 [7203 16.8 [2640 31.9 [2752 2.47 [5933 20.3 [2648 12.7 [2117 4.03 [2732 3.68 [3616 0.103 [4716 8.94 [6838 3.67 [7210 0.252 [6208 58.7 [1247 0.177 [5874 20.2 [5637 1.58 [2227 0.34 [5683 45.1 [2161 0.918 [38 80] [38 96]] [14 37]] [38 77]] [38 63]] [38 100]] [38 100]] [38 66]] [38 100]] [38 66]] [16 57]] [38 100]] [38 75]] [38 33]] [17 33]] [38 33]] [38 47]] [16 55]] [38 100]] [19 57]] [16 66]] [7 30]] [7149 13.2 [16 47] [13 42]]] [16 33]] [38 100]]] [16 43]] [36 36]] [38 39]] [6 62]] [1899 11 [14 46] [17 76]]] [2628 59.6 [7371 11 [32 60] [1980 5.46 [32 50] [14 83]]] [38 58]]] [2667 0.961 [16 57] [6 28]]]] [6882 1.43 [1429 27.6 [37 6.48 [6572 4.91 [4009 0.63 [4601 3.44 [791 2.17 [6383 4.56 [95 0.984 [1338 7.38 [4573 1.57 [1445 0.517 [2123 3.93 [2853 1.37 [2242 12.8 [2102 0.144 [2130 0.208 [2241 3.97 [5130 0.597 [7304 1.63 [6347 0.581 [4807 1.98 [7134 1.44 [2137 0.56 [2868 0.218 [2048 4.54 [7010 1.96 [7446 5.68 [4131 1.32 [38 94] [7472 3.57 [38 100] [38 83]]] [38 92]] [2111 2.39 [38 66] [38 93]]] [38 90]] [38 100]] [38 66]] [38 83]] [38 75]] [38 57]] [38 70]] [38 69]] [3095 1.99 [38 83] [38 100]]] [1783 1.78 [38 100] [38 87]]] [2259 3.73 [38 95] [38 100]]] [38 75]] [2748 2.76 [2939 30.9 [38 40] [38 73]] [38 94]]] [38 66]] [38 68]] [6 50]] [3 27]] [199 1.21 [38 66] [38 55]]] [2948 1.07 [5189 0.486 [1239 17.9 [7331 2.48 [1262 5.83 [38 88] [14 37]] [38 50]] [38 31]] [38 100]] [14 58]]] [38 46]] [7472 2.12 [24 71] [38 60]]] [1997 1.43 [38 77] [7445 4.47 [38 100] [7500 3.65 [38 100] [38 71]]]]] [38 46]] [2427 0.592 [6574 5.71 [6981 1.82 [6879 0.27 [2111 1.16 [2869 0.4 [7369 4.95 [38 84] [1783 8.11 [190 2.89 [37 38] [38 37]] [38 44]]] [12 23]] [2849 35.7 [38 50] [38 100]]] [37 33]] [17 71]] [5 50]] [38 100]]] [23 28.1 [5090 3.26 [2951 17.3 [6131 2.7 [7065 0.843 [5180 1.14 [7347 1.78 [4897 3.72 [199 5.38 [5673 3.37 [7665 1.1 [5632 1.57 [2469 8 [38 64] [1429 34.2 [38 100] [38 75]]] [38 75]] [17 30]] [38 50]] [7475 8.73 [38 41] [38 62]]] [38 31]] [17 33]] [17 66]] [17 66]] [17 37]] [5570 2.6 [7241 4.32 [6199 6.19 [4895 1.26 [38 82] [38 63]] [4050 3.13 [4897 0.551 [38 100] [38 91]] [38 90]]] [5 54]] [14 46]]] [17 66]] [5673 14.7 [7242 0.512 [38 19] [5641 0.512 [38 37] [37 12 [17 45] [17 40]]]] [12 83]]]] [6208 4.27 [10 33] [16 62]]]] [4009 0.165 [7736 0.547 [7491 0.538 [311 3.61 [6959 0.58 [7619 3.97 [2607 2.37 [4390 0.608 [5414 4.67 [2714 0.15 [1783 12.2 [4946 0.242 [2749 0.193 [1384 4.17 [2871 0.858 [4977 2.2 [5692 1.18 [2526 15.2 [2163 0.555 [719 7.14 [5462 0.463 [5635 0.557 [38 71] [7232 26.6 [2732 12.1 [4854 8.34 [3993 11.8 [16 61] [7 23]] [5102 4.18 [19 27] [16 40]]] [16 33]] [38 44]]] [16 38]] [18 77]] [16 100]] [2259 23.7 [6 53] [16 63]]] [978 4.3 [2716 1.15 [25 20] [16 57]] [1888 2.8 [16 77] [25 44]]]] [16 56]] [2663 5.3 [16 95] [16 66]]] [6 80]] [26 67]] [14 90]] [97 4.13 [2707 10.1 [30 40] [1897 3.19 [5891 1.11 [6409 8.11 [6133 1.89 [1980 8.12 [16 56] [6 45]] [16 80]] [16 35]] [16 30]] [6 50]]] [17 61]]] [7242 0.456 [2764 0.918 [2713 0.15 [3675 0.505 [2689 4.61 [2656 0.532 [16 30] [4017 0.218 [2654 2.08 [16 37] [16 78]] [26 50]]] [7 23]] [17 37]] [2466 2.2 [2868 0.59 [37 62] [5594 2.27 [16 40] [16 83]]] [5673 2.3 [6 57] [37 63]]]] [6 50]] [5099 3.19 [37 76] [6 66]]]] [38 85]] [424 2.7 [1429 10.1 [2656 0.701 [26 87] [26 100]] [16 50]] [26 50]]] [18 68]] [3239 5.7 [13 72] [13 62]]] [5900 0.496 [94 5.79 [1253 0.359 [7154 1.29 [2983 0.267 [16 91] [16 88]] [7512 1.49 [18 62] [2809 1.18 [16 36] [16 83]]]] [16 70]] [16 100]] [165 3.5 [5732 2.96 [5904 1.46 [4724 1.45 [112 0.162 [5597 1.79 [6831 4.9 [5894 0.73 [16 45] [1895 1.4 [788 0.57 [2081 0.958 [13 28] [18 90]] [18 37]] [7206 1.56 [16 85] [37 50]]]] [4717 3.09 [1837 2.84 [18 88] [18 42]] [2076 0.971 [7665 2.87 [4940 0.99 [2671 5.94 [18 78] [5901 7.13 [16 52] [18 73]]] [18 90]] [18 50]] [16 55]]]] [6833 1.95 [4897 2.62 [16 100] [16 88]] [3239 2.35 [16 33] [16 83]]]] [16 87]] [5100 4.58 [18 33] [16 50]]] [19 76]] [2649 1.13 [7 70] [7 62]]] [16 83]]]] [28 87]] [1974 0.312 [1078 6.45 [16 100] [16 85]] [16 100]]] [6749 0.303 [5007 3.52 [964 3.35 [6136 1.78 [5900 1.91 [18 33] [18 73]] [18 46]] [18 100]] [16 44]] [19 62]]] [5162 1.58 [5414 1.94 [1899 7.12 [38 88] [38 66]] [38 42]] [38 100]]]] [2737 2.58 [2979 3.31 [896 1.24 [6133 1.39 [2680 3.65 [429 5.44 [6791 0.186 [193 2.45 [5753 0.554 [2466 2.5 [1400 0.621 [6130 3.15 [23 35 [2679 4.74 [2861 0.516 [2955 17 [6761 0.317 [2983 33.7 [6941 8.27 [6 32] [26 41]] [13 33]] [6 75]] [37 0.327 [5635 5.8 [6 48] [16 50]] [16 60]]] [16 66]] [16 83]] [16 45]] [6 50]] [26 77]] [16 70]] [18 52]] [5873 24.9 [5962 0.887 [1078 0.493 [2849 51.2 [1429 7.4 [16 50] [6 50]] [6 68]] [16 62]] [6 100]] [6 80]]] [18 50]] [26 29]] [7 85]] [2939 35.5 [16 70] [16 63]]] [6833 0.354 [7679 4.22 [7354 1.53 [19 33] [7 37]] [5 50]] [19 63]]] [2006 3.66 [5393 3.92 [6129 4.45 [5594 1.89 [4497 0.683 [5627 4.94 [1253 1.1 [5681 1.12 [4426 2.12 [2979 35 [6941 2.1 [6 56] [16 62]] [16 70]] [194 6.87 [6 81] [6 92]]] [5345 1.29 [4937 1.4 [6749 1.13 [1429 5.93 [23 7.57 [6 63] [6 45]] [16 55]] [16 69]] [6 75]] [16 66]]] [6 58]] [16 50]] [16 75]] [2707 35.7 [16 70] [6 66]]] [6 65]] [16 50]] [6 55]]] [38 100]]] [7301 8.04 [7348 2.27 [6449 0.464 [2881 1.33 [7474 6.81 [2202 0.156 [2227 0.502 [2691 2.08 [2143 2.84 [4903 0.0454 [1749 6.72 [6952 11.8 [2849 54 [62 1.36 [2707 27.2 [7065 4.55 [17 83] [17 83]] [17 100]] [17 100]] [17 81]] [17 80]] [17 44]] [17 100]] [17 75]] [17 55]] [17 71]] [17 81]] [38 33]] [17 94]] [17 69]] [17 100]] [14 50]]] [2431 2.89 [6933 1.39 [6915 0.351 [4537 10.5 [4535 26.9 [38 57] [1940 0.123 [1563 8.55 [1897 3.26 [3551 3.37 [1997 2.71 [5673 17.1 [1587 2.49 [2357 1.68 [38 96] [38 75]] [38 100]] [2392 7.39 [17 66] [38 79]]] [5148 2.61 [38 60] [199 6.8 [38 90] [38 83]]]] [2432 0.57 [1808 3.28 [38 85] [38 77]] [17 66]]] [7473 1.73 [38 100] [6824 3.13 [38 57] [38 94]]]] [38 61]] [7473 0.246 [19 57] [38 75]]]] [38 59]] [17 50]] [38 100]] [2870 1.18 [38 100] [38 64]]]] [2663 0.525 [2695 0.342 [7354 0.183 [83 2.07 [1980 2.3 [2628 36.6 [2694 1.12 [429 7.33 [30 91] [30 85]] [30 42]] [30 55]] [30 33]] [18 40]] [16 33]] [4557 3.39 [191 3.62 [5983 13.9 [5122 3.91 [30 100] [6406 15.4 [30 100] [30 75]]] [30 60]] [30 100]] [30 77]]] [16 71]]] [194 8.4 [6848 5.36 [5723 1.25 [2640 2.11 [6471 2.7 [2671 0.514 [190 2.47 [16 41] [7203 0.186 [16 90] [16 33]]] [7206 0.205 [16 66] [16 100]]] [26 62]] [18 36]] [5415 3.68 [791 1.19 [2713 1.61 [5753 3.3 [2406 3.28 [75 0.985 [5100 1.3 [5632 14.5 [7185 1.54 [1661 0.166 [248 0.64 [1660 9.8 [7169 1.66 [6207 0.382 [5983 35.3 [978 2.68 [4851 8.62 [4623 3.01 [4717 7.03 [2951 38.2 [16 32] [38 47]] [16 100]] [37 66]] [6 47]] [16 83]] [6 76]] [30 23]] [16 91]] [90 11.7 [16 67] [16 40]]] [26 57]] [6 58]] [16 38]] [1783 2.65 [16 41] [1660 6.11 [16 55] [16 100]]]] [2667 0.736 [2939 25.2 [7 42] [16 71]] [16 100]]] [1429 8.29 [5597 4.24 [6 42] [4527 4.16 [16 76] [6 50]]] [7149 2.39 [5627 2.08 [2081 0.22 [2644 5.6 [16 94] [16 80]] [16 100]] [96 2.28 [16 100] [16 41]]] [16 57]]]] [6 69]] [6 34]] [5673 5.59 [78 3.86 [2984 6.51 [7203 7.8 [2867 1.16 [64 0.268 [6347 0.171 [4426 4.16 [2850 0.154 [4431 6.06 [6199 7.82 [7041 9.56 [6 69] [16 53]] [16 62]] [16 75]] [1997 0.154 [16 55] [16 42]]] [1980 0.813 [2466 2.58 [5721 1.77 [16 48] [16 66]] [16 88]] [6 50]]] [16 55]] [1374 0.356 [2691 3.88 [6761 1.22 [7038 1.16 [18 70] [16 54]] [6 72]] [6 37]] [6 83]]] [26 70]] [2653 0.609 [2707 20.2 [6 40] [16 84]] [16 83]]] [6 93]] [18 80]] [6207 3.92 [2661 3.71 [2978 8.01 [2259 0.788 [64 0.561 [1896 2.25 [16 49] [6 71]] [16 66]] [6499 2.38 [6749 0.394 [16 76] [16 87]] [16 70]]] [6 45]] [6 61]] [18 54]]]] [5626 2.24 [2897 0.376 [5894 1.19 [1631 0.489 [16 41] [16 92]] [18 60]] [19 30]] [5673 1.56 [26 89] [18 45]]]] [26 83]]] [190 2.97 [26 50] [5681 1.95 [38 100] [38 50]]]] [6199 1.56 [6 64] [16 40]]]]] [7067 0.407 [58 1.89 [6335 0.93 [5170 2.84 [5771 0.462 [5692 2.39 [2184 1.65 [3652 0.242 [2081 9.26 [4349 2.79 [2488 10.4 [4960 1.05 [6189 1.87 [2548 0.317 [312 3.25 [4338 14.4 [4214 0.485 [22 3.4 [7665 3.2 [2199 1.89 [5641 2.07 [7032 5.05 [1899 38.4 [6853 2.26 [2161 1.68 [2752 39.2 [208 2.33 [2760 4.59 [2793 2.16 [7354 5.38 [5 12] [18 40]] [24 27]] [11 28]] [24 68]] [23 64]] [23 70]] [24 90]] [23 100]] [2 61]] [19 54]] [23 63]] [4198 3.23 [4832 1.14 [5405 1.66 [5819 1.04 [6524 1.16 [2793 3.14 [610 1.01 [5673 1.13 [17 16] [26 37]] [5 100]] [24 46]] [25 100]] [4338 9.21 [17 62] [5812 17.7 [3 27] [4 50]]]] [31 100]] [2526 10.7 [2 62] [4351 4.59 [4338 9.37 [2 83] [2616 1.65 [2 86] [2 100]]] [2 100]]]] [18 31]]] [31 100]] [4338 8.91 [19 50] [1888 1.99 [213 0.994 [144 10 [1078 38.8 [24 81] [24 90]] [24 66]] [24 69]] [208 4.13 [4519 4.14 [24 70] [24 100]] [24 88]]]]] [4493 0.544 [286 7.21 [7354 2.22 [5405 7.25 [2517 2.84 [7265 9.18 [1980 28 [5040 19.7 [4158 1.08 [1047 5.55 [7373 3.52 [2225 3.68 [248 1.61 [5819 3.82 [2518 1.69 [4600 31.2 [4669 5.75 [2039 3.59 [4519 5.96 [1572 4.5 [6582 7.25 [2574 11.9 [1436 3.74 [384 4.48 [6859 10.1 [5753 14.1 [2752 5.61 [24 31] [2259 17.1 [24 23] [2341 6.49 [24 70] [24 100]]]] [31 30]] [6853 57.9 [24 98] [24 91]]] [23 87]] [24 100]] [2 100]] [4 100]] [24 100]] [2411 5.12 [24 94] [24 100]]] [23 41]] [23 50]] [4 50]] [24 91]] [4 36]] [394 19.5 [25 51] [25 75]]] [23 34]] [24 100]] [24 92]] [2 23]] [2 80]] [660 7.46 [23 63] [23 83]]] [2 94]] [2275 6.77 [3638 0.907 [4897 1.19 [5637 1.33 [7210 4.05 [24 90] [24 68]] [24 50]] [19 54]] [6853 4 [24 91] [24 100]]] [24 62]]] [31 100]] [18 30]] [23 52]] [2795 1.4 [24 97] [24 100]]]] [2 36]] [2453 7.95 [4546 0.843 [5053 2.59 [2777 7.92 [208 9.66 [7373 0.492 [978 12.7 [6853 3.55 [1899 3.97 [24 90] [24 100]] [24 100]] [24 90]] [24 100]] [24 77]] [24 75]] [2752 42.7 [24 100] [24 80]]] [24 100]] [1389 5.95 [24 96] [24 87]]]] [25 84]] [4 95]] [8 88]] [2470 2.35 [1919 6.96 [6852 1.15 [2755 9.68 [2341 0.797 [6184 10.2 [6853 2.1 [1389 1.9 [6077 11.8 [7535 5.23 [1927 0.726 [5267 1.78 [7343 17.8 [24 37] [31 30]] [24 61]] [25 18]] [24 95]] [31 75]] [23 4.61 [24 97] [24 75]]] [3662 1.85 [7301 7.1 [7382 5.38 [24 93] [6860 1.79 [7373 9.81 [24 99] [24 87]] [24 100]]] [24 88]] [24 80]]] [24 71]] [24 100]] [26 100]] [2411 0.971 [24 96] [24 100]]] [6853 1.17 [2029 3.5 [7561 1.71 [4 43] [4 63]] [4 42]] [24 90]]] [4 71]]] [1925 4.72 [1011 7.94 [4160 0.797 [1239 11.4 [957 4.61 [4518 2.96 [2342 2.51 [5211 1.65 [2526 36.2 [23 34] [23 73]] [23 85]] [31 44]] [24 100]] [27 53]] [23 67]] [1239 10.9 [4428 6.49 [2251 2.7 [896 1.79 [2091 11.9 [2 28] [2091 26.6 [23 41] [27 50]]] [5 33]] [23 57]] [2 57]] [1 57]]] [31 55]] [4 40]]] [7009 0.288 [5192 1.59 [2574 0.242 [312 5.54 [3207 2.29 [3666 3 [3666 2.53 [1980 12.9 [1048 6.3 [5732 8.36 [4340 17.3 [5673 2.18 [5851 0.891 [7026 9.92 [1429 7.82 [573 1.59 [24 82] [24 100]] [2411 6.45 [573 0.75 [24 98] [24 100]] [24 85]]] [24 66]] [24 100]] [2265 1.19 [429 10.1 [3644 0.928 [24 96] [24 60]] [24 100]] [24 65]]] [24 100]] [24 75]] [24 71]] [24 66]] [24 77]] [1783 7.5 [24 58] [19 46]]] [7445 2.58 [19 83] [24 83]]] [19 75]] [24 100]] [24 47]] [24 51]]] [23 96]] [6949 0.569 [7382 0.195 [2259 6.18 [5140 4.05 [4519 0.986 [144 0.801 [5246 1.45 [2892 9.37 [7512 4.74 [7176 8.83 [4 20] [33 63]] [7516 4.46 [6859 2.39 [3928 0.768 [4159 3.3 [6074 2.94 [1023 2.72 [1240 2.2 [1025 1.17 [4742 1.63 [5192 7.29 [17 23] [2 25]] [5 44]] [5693 6.23 [24 51] [2 50]]] [24 100]] [2 36]] [2 64]] [17 30]] [17 86]] [24 100]] [26 92]]] [33 72]] [25 86]] [6538 0.34 [2 55] [2 100]]] [24 93]] [33 100]] [3208 1.83 [4690 6.81 [4414 10.9 [4253 2.22 [6184 2.66 [4414 1.19 [5718 5.24 [5509 2.26 [7414 1.96 [4571 4.63 [227 0.457 [2846 0.763 [6374 0.427 [4908 7.47 [2526 4.24 [6861 5.27 [4895 2.41 [6266 1.44 [6223 0.415 [5792 0.472 [24 89] [24 95]] [24 80]] [24 100]] [24 44]] [24 71]] [2081 4.82 [4344 9.43 [1919 2.35 [1888 12.7 [4147 3.7 [1023 0.219 [2453 1.44 [4154 10.1 [7566 4.9 [24 100] [24 71]] [24 100]] [24 100]] [24 100]] [24 95]] [24 71]] [5812 3.88 [24 100] [24 69]]] [24 75]] [24 80]]] [24 83]] [24 78]] [18 57]] [24 72]] [24 70]] [24 30]] [24 62]] [24 71]] [203 2.85 [4342 2.06 [24 52] [24 100]] [19 62]]] [24 44]] [4 33]] [31 37]] [8 100]] [3640 2.52 [24 62] [19 87]]]] [7735 0.351 [7665 3.89 [24 64] [6265 3.87 [3659 11.2 [688 1.89 [4326 2.64 [5368 2.97 [5809 1.65 [5425 0.334 [4518 3.24 [3662 0.315 [6851 8.87 [7700 0.524 [1011 0.761 [1919 0.387 [2616 13.4 [24 100] [24 71]] [24 100]] [24 100]] [24 100]] [24 85]] [24 100]] [999 0.195 [7722 3.11 [24 100] [1888 1.23 [24 97] [24 92]]] [24 80]]] [24 93]] [24 85]] [24 71]] [24 69]] [24 70]] [7693 1.68 [24 84] [19 41]]] [5851 0.967 [24 80] [19 28]]]] [1899 1.42 [24 62] [24 83]]]] [25 68]]] [4325 2.16 [5820 4.28 [4929 0.429 [6988 0.279 [7665 8.43 [2 38] [2526 26 [4 71] [4 100]]] [4326 1.78 [4288 0.838 [2 91] [2 100]] [2 85]]] [2574 0.489 [4 55] [4 100]]] [6539 2.56 [6077 10.6 [719 4.84 [6988 4.72 [2 87] [2 100]] [2 68]] [4 75]] [2 100]]] [2 100]]] [4962 1.2 [7665 9.71 [2241 1.08 [33 87] [33 100]] [33 55]] [33 100]]] [5654 0.909 [5209 2.49 [4605 0.112 [6374 2.16 [1034 6.85 [7168 0.751 [5789 4.15 [6852 5.38 [7106 24 [7203 1.61 [655 0.283 [4342 17.8 [896 0.414 [1738 5.69 [2517 13.1 [24 100] [24 94]] [24 94]] [24 100]] [24 71]] [24 100]] [24 94]] [24 83]] [24 71]] [24 86]] [24 62]] [24 81]] [24 74]] [19 50]] [19 57]] [5660 1.06 [4154 11.2 [24 100] [2526 7.58 [24 75] [5819 4.71 [19 75] [24 66]]]] [4279 18.9 [6336 11 [7722 0.709 [24 90] [24 100]] [24 78]] [19 50]]]]] [221 1.08 [33 82] [33 100]]] [5061 0.683 [6337 2.44 [1754 1.14 [5090 2.11 [5588 0.169 [463 0.181 [6449 7.03 [6869 3.05 [5793 9.32 [7351 0.782 [5067 2.65 [1738 1.76 [5641 2.36 [1602 4.31 [896 13.5 [6738 6 [7381 9.5 [24 100] [4189 2.01 [5675 0.96 [24 97] [24 100]] [24 100]]] [24 88]] [24 83]] [24 95]] [24 83]] [6199 0.497 [1240 6.67 [7512 8.29 [24 91] [24 100]] [7379 3.18 [19 50] [24 100]]] [24 100]]] [24 62]] [24 76]] [24 75]] [24 85]] [24 80]] [24 100]] [24 75]] [24 55]] [24 87]] [5637 1.47 [3666 0.241 [308 0.928 [24 100] [24 75]] [38 42]] [19 90]]] [2909 0.331 [7101 0.402 [7156 1.33 [24 100] [6859 3.98 [24 87] [24 100]]] [24 85]] [4347 0.352 [24 77] [5575 1.14 [24 71] [19 100]]]]]]] [6031 1.35 [2405 1.36 [1240 1.87 [7405 0.53 [7169 0.0908 [2707 1.51 [7497 1.16 [731 0.472 [1327 2.3 [4198 1.93 [5192 0.679 [4279 1.96 [1239 12.2 [7419 9.03 [4977 5.01 [2526 21.8 [1980 4.79 [7038 3.84 [1783 1.41 [6 36] [36 25]] [16 87]] [16 18]] [1783 0.917 [2602 7.38 [6 92] [6 66]] [6 100]]] [18 84]] [5597 12.2 [6 73] [2616 11.4 [6 80] [6422 2.39 [7421 25 [6 100] [6 83]] [6 100]]]]] [6883 1.02 [906 2.09 [4450 16.2 [7197 0.162 [2083 1.29 [1980 21.1 [5093 15.6 [5397 5 [5987 8.76 [2939 11.2 [2297 3.29 [0 33.8 [328 19 [4891 14 [6005 2.18 [5623 2.14 [6501 12.1 [91 2.59 [7574 10.4 [5381 1.17 [2295 1.33 [2616 40.1 [1769 2.76 [2275 6.28 [791 4.95 [6276 11.5 [2207 0.0436 [5396 4.52 [6801 0.0601 [1429 4.28 [6 95] [1701 18 [6933 0.39 [5774 1.68 [7419 2.11 [6 95] [6 100]] [6 100]] [6 100]] [6 94]]] [6 100]] [6 42]] [6 100]] [6 86]] [1386 7.68 [6 93] [6 81]]] [1275 4.06 [5999 4.53 [4414 1.41 [1919 19.6 [6933 7.7 [221 16 [5721 7.12 [1078 22.2 [6690 0.864 [2436 8.4 [6 100] [6 83]] [6 100]] [6 87]] [6 84]] [2549 7.04 [6 85] [6 93]]] [6 71]] [6 100]] [6 60]] [6 85]] [6 82]]] [6 76]] [6 66]] [4434 0.354 [4727 4.77 [6690 1.85 [6 100] [2419 4.3 [6 60] [6 100]]] [6 75]] [7149 3.44 [6 85] [6 50]]]] [1316 2.64 [6 100] [6 37]]] [6920 1.75 [6 100] [6 60]]] [6 50]] [6 63]] [7459 0.246 [6 99] [6 88]]] [6 86]] [7665 8.01 [7512 23.3 [6098 3.02 [6 83] [6 90]] [6 62]] [6114 6.17 [2370 3.06 [2616 14 [6 100] [6098 4.77 [6 88] [6 76]]] [1239 47.8 [6 100] [6 66]]] [6 42]]]] [6 28]] [6 50]] [6 60]] [1919 4.1 [5597 1.65 [6 59] [6 55]] [6 100]]] [6 66]] [2558 1.26 [1701 0.213 [5396 5.36 [16 53] [1349 3.6 [1429 6.72 [6289 1.48 [1919 1.95 [6422 1.01 [16 55] [6 66]] [6 71]] [6 100]] [2616 9.9 [2223 0.971 [6 89] [6 55]] [6 100]]] [6 100]]] [7153 3.87 [5595 3.09 [16 61] [6 100]] [6 88]]] [7667 4.31 [6 97] [6 81]]]] [5090 20.9 [6 62] [6 58]]] [6 50]] [6 43]] [6 40]] [6 44]] [9 71]] [9 73]]] [429 17.3 [6 41] [3 72]]] [18 36]] [18 81]] [9 100]] [1239 5.7 [17 35] [18 61]]] [29 88]] [2943 0.478 [7232 0.964 [4622 0.795 [5899 3.06 [7574 1.23 [7540 2.53 [7224 7.93 [94 0.299 [7149 2.07 [5148 1.75 [2616 1.78 [5170 0.775 [1436 0.879 [2602 1.45 [189 4.08 [5593 3.06 [7041 4.43 [5985 2.46 [7416 1.42 [5100 9.72 [38 34] [6 84]] [6 37]] [6 71]] [7041 5.81 [16 87] [6406 12.1 [2436 9.48 [6923 2.58 [6 50] [16 80]] [6 33]] [6 70]]]] [16 70]] [6 100]] [6 86]] [16 38]] [26 62]] [4449 0.49 [6399 0.429 [7540 0.517 [2649 7.65 [6 62] [6 100]] [6 77]] [6 75]] [6 100]]] [38 100]] [2275 2.38 [5964 0.994 [2649 1.1 [4712 0.876 [7255 1.04 [6 27] [16 57]] [6 28]] [16 53]] [16 90]] [6 86]]] [299 0.263 [6961 0.216 [1078 1.33 [26 37] [16 62]] [16 80]] [16 90]]] [1899 8.35 [16 57] [16 90]]] [221 15.6 [4717 1.79 [4851 12 [2752 1.29 [2849 23.3 [6 88] [6 42]] [6 33]] [6 100]] [23 11.8 [4889 8.42 [6 77] [6 42]] [16 88]]] [6 100]]] [2549 2.55 [6 73] [1311 1.4 [6 100] [6 85]]]] [16 81]] [37 68]] [6383 0.689 [2654 0.975 [6514 0.504 [2678 5.21 [1374 0.671 [16 46] [16 87]] [6 75]] [16 63]] [16 100]] [16 66]]] [2549 9.9 [2526 21.3 [6 28] [6 87]] [6 100]]]] [4799 0.227 [2275 3.38 [2628 2.67 [6701 3.65 [4583 2.6 [2368 1.09 [2282 0.885 [1883 5.48 [4764 3.32 [1436 1.12 [6581 1.79 [4673 2.82 [16 43] [7734 1.65 [1888 5.69 [6 10] [24 44]] [18 50]]] [17 55]] [18 42]] [30 38]] [6 100]] [6 75]] [6 90]] [37 44]] [6 100]] [2526 1.07 [429 0.386 [6207 1.78 [6 44] [38 77]] [6 37]] [4891 0.697 [5693 0.932 [16 58] [19 40]] [1239 10.7 [16 50] [5673 0.486 [16 60] [16 100]]]]]] [2080 1.03 [1919 2.01 [6 42] [6514 5.99 [434 0.307 [7665 11.4 [6 84] [6 50]] [6 62]] [6 100]]] [2080 1.67 [6 80] [6 90]]]] [36 86]]] [2653 1.51 [5397 3.93 [2279 9.61 [5635 0.471 [4732 3.9 [2259 60.3 [5408 0.457 [2005 2.95 [6287 0.446 [4653 3.07 [5623 0.323 [6 98] [6 100]] [6 90]] [2295 0.668 [6 93] [6 71]]] [6 75]] [1386 1.01 [4651 0.359 [4726 8.67 [4517 3.09 [7675 1.61 [6 95] [6920 0.959 [6 91] [7224 1.02 [6 66] [6 66]]]] [6 63]] [7404 7.34 [6 55] [6 60]]] [7512 4.37 [6 91] [6 100]]] [6 55]]] [2551 9.48 [1355 0.44 [4725 0.359 [4889 0.882 [7234 2.62 [6 93] [6 100]] [6 100]] [6 100]] [6 100]] [221 11.8 [6 71] [6 100]]]] [6 100]] [6 72]] [6289 1.64 [6 100] [16 55]]] [2079 2.3 [7301 1.1 [7421 10 [6 88] [6 75]] [6 100]] [6 53]]] [6 75]]] [24 84]] [7169 4.02 [2885 2.38 [4897 1.09 [37 5.46 [2367 3.07 [38 66] [38 92]] [19 40]] [5345 3.57 [2951 1.78 [2887 9.28 [2631 0.382 [38 90] [38 100]] [38 69]] [1395 3.22 [6384 4.65 [1808 4.54 [38 100] [38 80]] [38 80]] [38 85]]] [38 66]]] [2707 4.17 [4536 2.35 [2864 0.555 [5673 14.4 [38 77] [5147 6.06 [38 83] [2392 10.2 [38 100] [38 83]]]] [38 100]] [2750 1.2 [38 83] [38 60]]] [69 3.55 [166 0.405 [7157 2.93 [38 68] [17 38]] [38 77]] [17 71]]]] [17 54]]] [1239 25.1 [6828 0.365 [5199 0.345 [112 5.7 [5192 0.722 [7229 0.262 [22 96] [22 100]] [22 100]] [22 89]] [22 100]] [22 100]] [9 44]]]] [2081 2.74 [2561 0.964 [2583 0.813 [4456 4.88 [4852 0.11 [5699 0.797 [3054 0.699 [2752 22.3 [1429 2.2 [2534 2.2 [3830 0.323 [1888 1.79 [5225 2.98 [3880 0.867 [1914 7.5 [6581 2.22 [1899 9.38 [6732 6.75 [8 54] [1078 4.13 [0 73] [0 87]]] [8 75]] [968 3.14 [2321 5.42 [2568 1.95 [8 94] [8 100]] [8 100]] [8 100]]] [0 53]] [8 100]] [23 64]] [2526 20.1 [8 66] [2526 56.5 [2628 1.86 [3891 0.921 [8 94] [8 100]] [8 100]] [2536 2.22 [8 72] [8 100]]]]] [392 1.87 [2426 0.631 [4014 1.78 [8 94] [8 100]] [8 100]] [8 100]]] [0 100]] [2394 1.5 [2526 8.33 [144 0.978 [2764 0.695 [2752 3.82 [8 33] [23 53]] [22 55]] [22 70]] [6155 2.07 [1442 0.778 [2913 5.33 [312 2.92 [5803 3.99 [6320 11.4 [3700 3.79 [6524 3.78 [3497 15.5 [3576 3.67 [6603 3.18 [4630 1.06 [4893 0.758 [2004 2.67 [5482 2.95 [2426 0.488 [939 6.94 [7343 0.231 [7411 4.93 [955 3.74 [2628 32.7 [4690 0.548 [7251 1.42 [8 51] [8 100]] [3113 18.4 [5658 0.472 [1068 5.24 [7176 0.362 [1078 7.14 [3424 23.4 [3952 0.917 [1517 1.3 [1888 22.2 [1009 1.38 [1980 9.81 [8 99] [8 91]] [8 100]] [8 85]] [8 100]] [8 100]] [8 90]] [8 100]] [8 100]] [8 95]] [8 100]] [8 88]]] [8 71]] [8 85]] [2526 36.4 [35 55] [8 100]]] [8 94]] [8 84]] [8 100]] [8 75]] [8 70]] [8 77]] [5824 0.575 [7179 1.17 [8 87] [8 100]] [8 100]]] [35 71]] [8 72]] [8 69]] [8 75]] [8 75]] [35 70]] [22 50]] [8 52]] [0 61]] [0 50]] [30 40]]] [0 100]]] [2004 0.472 [6068 3.81 [144 0.707 [1783 0.421 [7413 1.08 [7255 7.18 [2804 3.45 [5828 2.82 [2526 53.9 [5480 1.47 [7176 0.233 [23 58] [8 45]] [5211 17.7 [22 64] [286 12 [978 6.34 [23 69] [23 78]] [23 100]]]] [8 91]] [8 77]] [8 100]] [8 96]] [7169 1.96 [23 70] [23 100]]] [2562 3.09 [22 91] [2752 37.9 [23 87] [23 100]]]] [4488 0.428 [22 88] [22 100]]] [23 84]] [23 100]]] [0 100]] [4533 4.21 [791 12.4 [0 77] [0 100]] [0 42]]] [930 1.8 [5070 11.4 [7139 2.08 [8 100] [3594 0.649 [8 80] [8 100]]] [8 77]] [7287 0.412 [8 55] [8 100]]]] [2562 11.3 [2526 48.4 [8 90] [0 85]] [6556 3.18 [6560 2.79 [0 88] [0 100]] [0 100]]]] [0 100]] [7307 0.527 [328 2.93 [23 45] [328 9.65 [8 63] [23 81]]] [0 100]]] [3548 0.686 [5647 0.348 [6561 0.347 [1888 1.55 [1534 2.03 [5229 0.606 [7197 0.661 [7255 0.559 [2603 0.945 [5199 0.381 [968 0.971 [5692 3.87 [4154 17.5 [791 5.83 [23 71] [5753 3.13 [2259 18.6 [1065 0.276 [1913 4.41 [2178 0.709 [7508 0.428 [5970 1.49 [23 93] [23 100]] [23 100]] [23 100]] [23 83]] [23 100]] [23 45]] [0 50]]] [8 63]] [2004 4.53 [5753 0.801 [2562 5.41 [7210 2.22 [5480 2.85 [23 93] [22 77]] [8 33]] [1062 5.25 [8 64] [2259 4.27 [23 53] [8 50]]]] [23 66]] [23 87]]] [8 93]] [23 96]] [8 100]] [8 53]] [2526 12.4 [22 50] [23 92]]] [0 100]] [0 100]] [2512 0.606 [1429 7.44 [8 62] [2555 0.17 [8 96] [8 100]]] [8 83]]] [8 100]] [5303 0.123 [5422 1.4 [4158 2.37 [6732 1.57 [4690 1.03 [1980 6.35 [22 37] [1253 7.89 [827 1.81 [4288 0.224 [5799 0.695 [1783 6.03 [438 0.78 [23 98] [23 100]] [23 97]] [23 83]] [23 100]] [23 71]] [5647 36.2 [23 100] [23 77]]]] [1062 2.24 [8 100] [8 75]]] [23 36]] [1899 13.5 [8 50] [8 83]]] [23 100]] [23 100]]] [4184 0.408 [1062 6.78 [8 100] [8 81]] [8 100]]]]] [5187 0.525 [6230 0.266 [6417 0.323 [2064 0.249 [6078 0.428 [407 0.677 [5403 0.27 [2752 21.6 [7 100] [7 62]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]]] [3079 1.93 [6582 0.0927 [2802 0.411 [2616 0.22 [5403 1.07 [5219 2.08 [7698 0.184 [6853 0.824 [3332 3.07 [5827 0.0795 [907 1.79 [2755 0.6 [7434 0.145 [4699 0.585 [7411 1.77 [2764 0.833 [6416 0.131 [7233 0.0904 [5972 4.42 [7475 0.117 [4997 0.37 [190 0.0508 [5482 0.502 [5041 4.39 [6809 0.503 [6529 0.0986 [4655 1.32 [4326 5.93 [4120 0.864 [3480 0.232 [6471 1.3 [1812 0.723 [6230 1.62 [5225 0.397 [5473 0.406 [6269 0.647 [7370 0.118 [4005 0.2 [2955 1.12 [384 0.371 [6063 0.121 [537 0.457 [6350 0.15 [2471 0.996 [6031 7.31 [5211 2.8 [1400 2.71 [2461 1.8 [2752 2.44 [7514 0.0878 [2394 2.15 [7405 0.757 [5333 0.29 [205 2.13 [2849 4.76 [4210 1.34 [534 0.618 [1617 0.182 [1581 0.169 [5170 2.32 [6457 0.2 [538 0.115 [2526 5.72 [6382 0.535 [4865 0.592 [7665 1.5 [4290 19.4 [5040 1.07 [2259 0.245 [7628 2.72 [3576 1.47 [5454 0.0494 [791 0.367 [1429 9.44 [1980 1.08 [635 3.14 [394 1.45 [1157 2.26 [512 2.42 [978 4.21 [3182 61.7 [7656 4.21 [276 2.2 [7442 1.43 [6758 9.01 [2701 3.7 [1287 6.48 [5673 12.8 [6982 12.8 [3779 30.4 [7734 13 [357 21.7 [5099 25 [7176 7.83 [3634 9.9 [6660 6.49 [4778 6.67 [4318 6.02 [976 0.741 [112 6.54 [1 20] [3 22]] [27 100]] [3 100]] [15 100]] [11 68]] [35 81]] [33 50]] [16 36]] [30 100]] [18 59]] [37 82]] [4 74]] [35 33]] [33 66]] [29 48]] [38 100]] [27 82]] [18 54]] [35 27]] [37 96]] [3155 3.36 [383 4.85 [560 24 [338 3.55 [2088 12.6 [4154 24.6 [4833 19.5 [4832 1.81 [4 20] [2 47]] [2 51]] [2 62]] [2 40]] [25 80]] [18 93]] [18 61]] [35 85]]] [27 87]] [27 82]] [26 31]] [9 78]] [3675 2.79 [7623 28 [171 0.71 [435 0.535 [7499 31.8 [4480 9.43 [4373 1.61 [7505 1.81 [2628 26.7 [2053 1.44 [4665 1.47 [4214 4.95 [4571 3.65 [2184 21 [1017 0.675 [1995 7.44 [3521 4.12 [3435 6.3 [1899 250 [1954 1.78 [2232 0.377 [2214 1.78 [5673 2.62 [5071 8.47 [2001 7.48 [1 19] [1 21]] [33 78]] [2241 2.62 [35 55] [35 57]]] [29 61]] [5322 3.31 [29 28] [29 40]]] [29 65]] [23 39]] [2081 117 [35 56] [29 75]]] [1 42]] [2072 0.952 [4292 12.4 [1 19] [15 30]] [28 50]]] [4154 14.1 [15 81] [3 71]]] [2064 19.1 [23 19] [28 37]]] [10 95]] [29 54]] [1106 12.3 [4768 6.94 [25 33] [1 48]] [27 68]]] [29 45]] [38 31]] [2199 0.914 [29 37] [29 61]]] [27 100]] [9 66]] [9 100]] [941 10.5 [27 58] [15 33]]] [19 79]] [23 3.65 [2199 38 [35 58] [35 26]] [33 46]]] [2002 6.49 [35 48] [35 90]]]] [7254 2.29 [6485 1.3 [5347 3.14 [3311 5.88 [5769 20 [5498 14 [1237 2.35 [5531 10.1 [2039 0.407 [2491 6.85 [4159 1.15 [397 11.4 [3872 19.9 [1913 22.3 [1722 5.67 [6772 5.03 [1429 99.4 [5541 2.57 [5496 9.72 [3435 2.24 [7734 7.24 [2489 5.26 [5539 5.72 [6606 1.18 [695 7.11 [4118 1.67 [1 10] [27 100]] [4414 18.7 [37 18] [13 50]]] [28 72]] [13 94]] [2093 4.76 [13 53] [32 100]]] [18 56]] [35 31]] [2 70]] [13 100]] [3472 28.6 [5564 9.09 [2059 1.47 [3130 4.1 [1442 0.835 [2143 1.46 [1783 17.6 [1459 17.9 [2628 8.49 [33 12] [28 36]] [1459 59 [1 55] [1 77]]] [33 14]] [7623 44 [1457 8.37 [7445 21 [1 20] [33 75]] [1 46]] [29 50]]] [35 54]] [1 49]] [1 48]] [14 100]] [37 90]]] [30 91]] [4414 18 [33 85] [33 81]]] [1953 4.31 [2132 3.78 [3379 2.78 [4235 46.1 [1250 11 [1429 151 [2003 0.73 [1391 0.655 [1934 21.1 [1062 8.46 [5889 4.27 [7499 1.06 [1 24] [29 100]] [3 62]] [11 33]] [1 55]] [15 28]] [1429 107 [29 50] [29 81]]] [23 24]] [1 66]] [12 75]] [1 76]] [29 47]] [1 61]]] [12 88]] [18 76]] [29 43]] [1429 34.8 [8 53] [8 100]]] [2108 0.374 [2072 3.32 [1259 5.55 [1917 2.23 [4279 3.55 [221 2.46 [1953 4.06 [2178 4.83 [1769 4.42 [1 38] [28 33]] [1 35]] [29 38]] [1 52]] [8 33]] [29 52]] [23 25]] [2132 3.52 [2227 3.37 [1899 16 [29 33] [1 45]] [29 45]] [29 50]]] [1089 4.76 [2041 1.62 [1913 43.8 [29 36] [29 73]] [1 37]] [1 66]]]] [5532 20.8 [13 37] [13 79]]] [29 100]] [30 100]] [4 35]] [23 100]] [27 95]] [25 100]] [663 6.02 [1453 9.2 [2039 1.9 [5110 4.42 [221 22.6 [5617 4.27 [5561 5.26 [33 34] [1 47]] [33 58]] [1 47]] [33 100]] [1 26]] [33 100]] [13 20]]]] [2913 15.9 [978 1.59 [5995 1.47 [126 2.84 [688 5.01 [3743 0.792 [429 66.8 [6713 1.75 [3670 9.72 [663 1.92 [3783 5.03 [7357 0.523 [3928 6.54 [4280 4.76 [3769 2.49 [5400 1.04 [630 1.61 [802 8.48 [6897 0.504 [2226 9.27 [4154 1.08 [2488 2.99 [3804 4.83 [3763 0.276 [2703 1.82 [6660 10 [7381 19.1 [35 8] [24 48]] [11 72]] [29 100]] [15 100]] [11 85]] [13 77]] [1957 1.83 [957 0.785 [7493 2.16 [6773 3.82 [7009 13.2 [5025 2.87 [29 23] [35 55]] [13 37]] [30 85]] [29 54]] [27 57]] [30 80]]] [2225 15.7 [29 50] [29 70]]] [9 84]] [2121 13.7 [4279 12.7 [6148 8.78 [21 35] [9 61]] [3 59]] [31 100]]] [35 100]] [13 93]] [13 100]] [29 90]] [3603 0.937 [37 27] [12 63]]] [1980 0.523 [5813 11.2 [35 63] [35 100]] [35 91]]] [37 100]] [6214 5.26 [132 4.95 [682 2.35 [6537 6.33 [29 20] [2 50]] [13 100]] [13 67]] [29 100]]] [3633 31.9 [35 47] [35 76]]] [9 54]] [1995 0.768 [5938 2.39 [2488 8.91 [4924 11.5 [439 1.15 [7357 4.76 [4282 3.65 [2143 11.1 [5619 9.71 [802 5.26 [7258 1.64 [4781 18.6 [440 6 [434 2.28 [2199 7.8 [6184 45.5 [2939 14 [660 41.9 [6294 4.95 [1429 37.2 [27 12] [28 16]] [3 35]] [23 35]] [21 72]] [11 70]] [1980 17.6 [11 41] [21 71]]] [27 27]] [35 100]] [11 100]] [11 83]] [438 1.01 [699 5.65 [616 9.09 [569 17.6 [21 38] [21 90]] [3 75]] [9 62]] [17 33]]] [9 100]] [2083 16.2 [21 47] [21 31]]] [3 93]] [35 81]] [35 40]] [2081 12 [21 92] [21 57]]] [13 77]] [21 86]] [32 20]]] [35 67]] [5154 17 [791 21.7 [21 20] [5692 3.23 [2993 4.59 [1429 60.2 [21 70] [21 100]] [21 100]] [21 30]]] [21 58]]] [7211 1.63 [3 27] [9 100]]] [1943 4.18 [29 95] [27 58]]] [4533 5.95 [439 2.35 [3450 2.82 [3452 10.7 [7623 1.03 [7352 10.5 [436 0.972 [1012 11.9 [2939 3.14 [663 3.82 [5999 6.17 [35 30] [23 69]] [19 31]] [4 23]] [7 87]] [35 100]] [35 100]] [4 45]] [35 63]] [35 95]] [35 77]] [8 30]]] [802 6.61 [2913 41.5 [2229 0.609 [1913 1.7 [2099 9.09 [4369 4.76 [3 27] [32 33]] [2099 33.4 [3 75] [3 55]]] [3 36]] [11 50]] [7241 3.98 [392 4.42 [3 34] [26 88]] [3 58]]] [3 61]]]] [2183 0.77 [791 1.26 [29 42] [7491 6.45 [2031 1.56 [29 93] [29 100]] [29 100]]] [29 100]]] [2232 0.979 [5629 8.85 [15 66] [15 100]] [15 96]]] [2106 28.4 [2020 3.09 [35 44] [1899 41.1 [35 67] [35 38]]] [35 82]]] [3598 0.133 [5892 0.355 [5532 6.09 [6328 1.39 [1428 0.559 [2008 5.42 [2920 0.4 [5900 1.72 [5629 0.147 [5812 0.202 [3335 0.137 [5011 0.0197 [2475 1.63 [1708 0.548 [1788 12.9 [6306 2.06 [2697 0.485 [5632 3.88 [5762 1.18 [2371 4.18 [906 2.89 [560 0.354 [1722 4.41 [6767 1.71 [4673 4.99 [1862 0.219 [4549 5.24 [788 9.1 [4851 3.48 [3305 0.55 [177 2.83 [1 7] [19 50]] [10 96]] [2417 9.8 [6155 1.55 [30 17] [8 81]] [4 100]]] [7301 5.05 [18 49] [19 83]]] [1078 1.69 [5267 16.7 [31 100] [31 90]] [31 100]]] [1876 0.219 [2093 2.49 [30 94] [30 100]] [30 100]]] [2275 0.437 [6 72] [16 53]]] [6784 1.75 [6175 5.59 [4445 0.994 [7255 15.1 [7085 5.67 [4305 2.28 [4398 2.33 [31 81] [31 100]] [31 100]] [31 83]] [31 77]] [31 100]] [31 100]] [31 100]]] [33 86]] [18 78]] [3308 8.77 [6085 3.65 [4592 3.56 [3159 1.14 [1888 3.14 [4414 2.71 [7449 42.2 [4369 7.64 [7512 9.97 [4533 5.3 [21 24] [21 56]] [31 55]] [32 62]] [3 100]] [4430 12.1 [21 48] [21 100]]] [13 33]] [21 62]] [9 71]] [21 86]] [29 56]]] [5618 1.22 [33 69] [33 100]]] [1052 0.978 [1899 11.1 [4 26] [22 90]] [10 100]]] [7245 1.89 [7403 1.96 [896 1.85 [3251 1.45 [5776 2.11 [5632 34.2 [7 22] [1646 40.6 [16 38] [16 61]]] [13 27]] [16 26]] [18 90]] [7401 5.35 [7 85] [1448 2.89 [7 97] [7 100]]]] [7 84]]] [30 100]] [1078 13.7 [2081 4.02 [3 90] [3 72]] [31 63]]] [791 0.271 [1788 31.3 [27 56] [27 91]] [27 56]]] [1841 5.83 [6417 0.928 [6294 2.22 [7210 1.62 [2939 1.61 [28 79] [28 87]] [28 71]] [28 70]] [28 100]] [28 100]]] [31 92]] [2204 0.546 [29 66] [29 100]]] [12 100]] [2002 0.627 [6982 0.838 [4832 4.3 [1391 1.4 [5447 0.517 [429 8.39 [29 22] [5138 0.0698 [4 25] [19 37]]] [4 60]] [31 44]] [2 42]] [4 100]] [29 100]]] [429 1.45 [7210 13.6 [15 100] [15 90]] [15 100]]] [2227 0.444 [392 0.384 [1646 0.0927 [42 3.64 [18 59] [3 87]] [7 35]] [18 85]] [18 100]]] [7314 22.8 [30 100] [30 71]]] [11 93]] [1980 2.13 [2055 0.581 [24 72] [2470 7.87 [24 100] [24 88]]] [2216 0.677 [2470 0.346 [1958 1.42 [7255 1.71 [24 62] [36 63]] [36 71]] [24 96]] [36 62]]]] [4876 0.124 [2235 0.475 [5540 1.09 [1799 1.4 [3513 0.441 [1899 7.29 [2008 1.36 [5539 10.8 [2521 10.5 [6328 10.1 [3695 1.19 [2 20] [4 27]] [11 32]] [4 63]] [13 100]] [11 100]] [2050 0.414 [1242 5.42 [2259 11.7 [2 42] [11 27]] [15 90]] [15 100]]] [11 91]] [24 57]] [13 100]] [15 81]] [3136 0.858 [2628 4.14 [24 39] [4 71]] [31 60]]]] [6380 0.65 [1078 8.02 [6483 1.77 [13 72] [13 100]] [13 56]] [13 45]]] [6333 2.04 [4630 13.2 [6970 0.632 [2004 4.3 [4282 0.626 [3077 1.78 [1689 0.776 [5567 0.48 [3910 1.8 [7334 3.76 [2329 0.527 [1796 1.52 [3 22] [17 33]] [1078 1.92 [14 57] [14 73]]] [7169 0.407 [7352 2.51 [14 37] [14 100]] [14 100]]] [14 88]] [14 100]] [19 78]] [14 100]] [3 37]] [3 66]] [3 33]] [2402 3.4 [1673 0.38 [17 45] [3576 4.83 [7009 2.44 [17 91] [17 100]] [17 100]]] [14 54]]] [14 76]]] [4564 0.195 [4764 1.97 [4851 0.867 [17 70] [14 50]] [6159 2.01 [3 27] [17 100]]] [252 0.127 [1256 7.3 [6388 5.74 [3597 2.08 [5941 1.18 [16 37] [19 53]] [7085 0.186 [5892 3.55 [17 41] [5290 0.632 [17 73] [17 71]]] [17 57]]] [19 76]] [38 85]] [19 75]]]]] [921 0.411 [6015 3.62 [5368 1.2 [112 0.901 [6184 34 [979 16 [5574 3.13 [224 0.293 [526 4.27 [693 2.92 [806 8.31 [695 0.79 [4917 1.03 [7078 5.26 [2023 19.2 [4418 3.4 [4663 8.12 [24 1.78 [739 2.07 [1899 4.95 [1025 19.6 [5969 9.8 [21 50] [21 100]] [2 57]] [2 45]] [21 100]] [9 100]] [21 100]] [2 70]] [2 50]] [21 100]] [21 100]] [21 61]] [21 92]] [21 100]] [21 100]] [2 31]] [2943 2.1 [21 32] [2 41]]] [2 83]] [21 91]] [9 52]] [9 55]] [2993 2.99 [21 96] [21 100]]] [21 100]]] [26 92]] [7622 1.29 [5402 1.39 [2340 3.88 [5623 1.38 [5480 4.22 [228 1.77 [5472 1.01 [5833 3.43 [4154 2.17 [7457 8.34 [6334 6.61 [2448 20.7 [6544 4.33 [6103 8.72 [4851 1.66 [7009 37.4 [1240 2.39 [2527 0.971 [2936 2.14 [7601 5.49 [4369 5.07 [6578 2.92 [6248 0.617 [7255 17.2 [7234 28.4 [7133 4.57 [2282 2.61 [6178 1.08 [2627 4.76 [429 17.3 [7529 7.25 [5345 1.63 [2453 13.9 [2436 3.03 [14 8] [6 87]] [24 96]] [39 1.63 [328 12.1 [19 37] [18 40]] [38 71]]] [24 100]] [6581 0.454 [5757 1.05 [978 2.2 [663 9.37 [14 9] [5 16]] [4681 3.14 [4 20] [5 90]]] [5757 19.2 [29 92] [29 50]]] [5 33]]] [6 76]] [25 100]] [6 82]] [3931 20.7 [4 90] [4 100]]] [6 100]] [13 65]] [20 100]] [31 100]] [3015 2.79 [5429 7.38 [13 27] [25 81]] [25 66]]] [36 86]] [25 93]] [6876 1.12 [1783 1.68 [6 84] [6 100]] [6 57]]] [772 14.4 [24 87] [24 100]]] [13 85]] [7067 2.7 [6199 18.3 [134 2.35 [429 2.44 [3432 9.09 [14 31] [36 100]] [774 3.5 [7620 10 [6587 6.02 [6413 8.87 [2628 20.7 [2268 7.92 [14 21] [7 88]] [978 6.17 [5 38] [4 66]]] [14 100]] [5 83]] [14 60]] [24 100]]] [5 55]] [14 80]] [7 27]]] [1769 6.98 [1980 5.26 [31 42] [32 58]] [32 66]]] [2199 8.95 [1888 16 [328 19.5 [99 4.52 [14 34] [14 100]] [99 1.08 [392 7.04 [14 84] [14 85]] [14 100]]] [14 61]] [31 83]]] [13 79]] [5 91]] [31 70]] [210 7.27 [7176 0.935 [1980 0.736 [4034 6.13 [1389 2.35 [5377 4.46 [4898 3.8 [7382 3.36 [248 1.02 [7529 5.75 [5345 2.14 [4266 5.26 [3027 7.38 [665 2.18 [5675 11.1 [5135 8.47 [4017 2.65 [7022 2.89 [6581 8.27 [144 2.49 [7583 7.94 [663 3.76 [4171 9.9 [2445 2.18 [1011 12.2 [13 10] [4 40]] [10 29]] [32 100]] [6549 3.76 [32 90] [32 100]]] [1 50]] [19 37]] [5 44]] [13 100]] [13 44]] [20 100]] [24 83]] [2 100]] [32 50]] [20 94]] [26 17]] [24 100]] [7665 25.7 [25 30] [16 27]]] [24 82]] [20 35]] [14 50]] [24 100]] [24 100]] [5692 1.73 [7535 2.54 [5267 2.52 [7687 1.63 [7665 16.6 [2241 1.13 [7739 0.543 [1986 4.27 [144 1.47 [29 44] [22 25]] [29 85]] [25 38]] [25 62]] [13 11]] [19 53]] [10 73]] [791 23.1 [4 25] [793 19.9 [26 85] [26 100]]]] [791 14.3 [1239 20.1 [29 47] [22 42]] [2081 8.39 [24 41] [14 25]]]]] [33 65]] [26 93]]] [13 32]] [3011 1.71 [5078 10.3 [1526 3.5 [6643 1.17 [4034 1.73 [906 2.04 [695 36.1 [2331 3.31 [7009 2.62 [645 1.01 [6732 3.65 [4038 2.96 [36 52] [36 100]] [13 91]] [13 100]] [13 100]] [36 100]] [36 52]] [13 90]] [36 100]] [13 100]] [13 100]] [36 100]] [36 100]]] [429 43.5 [896 21.2 [1883 4.71 [1079 1.51 [6990 2.01 [655 4.13 [1078 24.5 [4 45] [2 43]] [2 88]] [2 100]] [2 78]] [2 70]] [31 37]] [4 70]]] [278 2 [1884 2.77 [788 1.96 [7169 22.9 [1429 7.14 [1888 22.7 [7185 14.9 [7588 3.89 [26 28] [26 100]] [26 46]] [18 42]] [5110 2.3 [7722 11.1 [112 1.77 [18 48] [13 28]] [26 50]] [18 42]]] [36 40]] [18 72]] [26 85]] [18 83]]] [6515 0.824 [5032 0.78 [978 12.4 [6 97] [1429 4.72 [6 62] [6 100]]] [6 87]] [6 100]]] [31 100]] [13 100]] [5833 1.29 [13 84] [13 100]]]] [3 100]] [1659 11 [7352 2.78 [1714 0.147 [5607 9.79 [1783 6.9 [695 0.15 [1899 2.37 [2058 1.94 [2081 19.6 [5564 0.332 [4861 9.12 [5462 1.37 [6877 1.16 [1745 8.08 [14 30] [17 50]] [14 46]] [32 50]] [3 77]] [14 100]] [32 71]] [17 50]] [4630 11.3 [392 2.4 [1725 2.14 [32 37] [32 100]] [14 93]] [7 70]]] [14 90]] [5891 0.743 [1965 2.09 [7615 1.33 [7441 8.31 [429 4.99 [6294 2.36 [2241 0.802 [1913 8.05 [32 33] [17 42]] [14 83]] [14 71]] [2466 5.8 [2259 5.93 [3 25] [4214 2.52 [14 53] [3 100]]] [3 90]]] [3 100]] [3 100]] [19 66]] [4640 2.98 [2199 3.14 [4684 0.466 [1899 0.92 [248 1.29 [14 62] [14 40]] [17 52]] [19 75]] [3 66]] [791 10.9 [19 44] [38 50]]]]] [17 80]] [1239 11.2 [7066 1.55 [7220 0.737 [2143 0.426 [1638 1.13 [15 44] [14 100]] [14 87]] [14 100]] [14 37]] [4783 0.168 [1662 0.324 [791 10.7 [19 33] [10 28]] [19 90]] [19 100]]]] [14 92]] [3162 0.278 [478 0.0687 [2193 0.727 [5341 0.513 [971 12.5 [6382 14.8 [23 0.818 [4764 1.61 [5447 0.275 [1577 0.974 [4279 0.971 [7334 1.1 [2259 27.8 [17 41] [14 66]] [17 70]] [14 63]] [14 57]] [17 80]] [17 57]] [14 47]] [1565 2.25 [5640 0.819 [2526 0.16 [2219 0.111 [5412 2.37 [3898 0.474 [17 53] [17 87]] [14 71]] [17 62]] [17 60]] [17 65]] [14 87]]] [19 90]] [17 80]] [14 76]] [1783 13.6 [1655 1.1 [1239 1.2 [5895 0.231 [4537 0.689 [7065 1.02 [17 36] [6952 10.7 [5893 23.9 [17 52] [17 86]] [17 100]]] [38 77]] [7402 0.35 [1997 0.144 [17 50] [17 44]] [6952 5.35 [17 55] [17 100]]]] [1429 147 [1673 0.48 [5940 2.1 [17 90] [14 50]] [14 61]] [17 63]]] [14 100]] [6682 0.876 [17 53] [6777 1.33 [38 50] [19 42]]]]] [5564 11.4 [1678 0.868 [14 100] [14 83]] [14 100]]]]] [6982 0.956 [4675 0.736 [5660 0.982 [4674 1.61 [4725 4.54 [535 1.13 [2532 1.34 [1239 17.4 [5448 1.25 [4690 1.09 [5812 0.596 [3008 7.05 [2586 1.3 [3055 0.983 [6584 1.96 [5151 1.67 [7132 7.16 [4870 0.599 [4154 9.62 [1429 59.8 [5140 3.19 [2936 9.8 [3497 3.07 [5963 11.1 [6619 6.33 [3857 4.13 [3726 7.46 [1640 0.431 [3336 0.882 [7008 4.2 [2589 3.18 [2526 148 [7032 5.45 [1888 1.42 [4832 10.9 [2540 2.1 [7609 7.2 [8 14] [8 94]] [23 30]] [2 70]] [6537 5.62 [2993 1.05 [429 11 [4 22] [8 46]] [8 24]] [2 100]]] [2 41]] [1 40]] [8 92]] [25 100]] [2488 6.55 [35 54] [35 100]]] [4 45]] [31 100]] [35 91]] [25 100]] [6 100]] [8 51]] [25 100]] [33 84]] [1239 3.18 [1542 7.94 [851 0.997 [2005 1.4 [7324 15.2 [6380 3.23 [695 2.56 [1483 1.55 [8 59] [8 100]] [18 44]] [14 33]] [5 62]] [8 26]] [17 50]] [5 87]] [1253 3.45 [5343 2.02 [25 17] [17 100]] [20 50]]]] [685 2.72 [8 23] [8 100]]] [25 69]] [4 100]] [31 85]] [2627 3.6 [1429 89.5 [5892 6.85 [1429 23.4 [17 48] [7512 31.3 [38 44] [6581 33.8 [17 57] [17 45]]]] [17 66]] [17 83]] [5 45]]] [0 100]] [25 100]] [7590 2.87 [4414 11.3 [1011 2.46 [1078 19.3 [17 18] [24 66]] [17 37]] [25 88]] [17 83]]] [6584 3.18 [7324 1.66 [3917 4.48 [156 6.26 [2 44] [2 93]] [7 55]] [4 46]] [7722 10.6 [6554 3.18 [6581 35.2 [17 66] [5 50]] [17 37]] [17 75]]]] [3829 0.659 [7176 2.22 [5480 0.324 [8 86] [8 66]] [8 90]] [8 100]]] [2913 4.85 [32 89] [32 100]]] [2566 4.11 [7382 6.96 [107 6.72 [1011 2.65 [7224 6.87 [2488 6.17 [7512 7.55 [2913 4.07 [7421 6.02 [2069 0.252 [4903 8.34 [5918 5.68 [791 5.24 [1684 2.13 [2212 0.101 [2600 7.46 [1 15] [33 100]] [23 50]] [22 33]] [5202 2.12 [7085 6.29 [1986 7.14 [5412 4.38 [4611 0.271 [23 34.7 [3 24] [21 76]] [35 30]] [33 44]] [9 57]] [9 66]] [9 91]]] [33 66]] [14 100]] [1 52]] [5598 6.02 [6 87] [6 100]]] [3 78]] [2536 5.15 [7564 8.62 [7419 19.6 [6 38] [6 90]] [6 100]] [24 38]]] [8 85]] [6 93]] [6 88]] [33 81]] [24 95]] [1364 13.5 [4820 3.31 [6 80] [6 50]] [6 100]]]] [21 67]] [21 95]] [6 81]] [6 87]] [13 90]] [2080 2.72 [6701 10.5 [6514 9.14 [6749 5.78 [2368 4.09 [6422 5.71 [221 0.902 [6 81] [6098 0.739 [6 100] [1919 0.361 [6 100] [6 83]]]] [6 88]] [6 100]] [6 71]] [6 61]] [6 100]] [6 100]]] [7327 0.397 [5239 2.2 [1888 3.94 [2259 18.5 [4 91] [4 50]] [4 100]] [4 100]] [4 100]]]] [429 94.8 [6048 1.36 [1308 0.35 [920 0.621 [4663 43.8 [5534 0.602 [739 5.38 [6655 8.34 [1906 9.72 [5370 0.885 [580 2.9 [371 1.48 [1373 7.96 [6082 16.5 [1338 4.41 [556 20 [4918 2.31 [1429 20.5 [4914 1.29 [6082 1.46 [9 59] [9 71]] [9 100]] [21 70]] [21 100]] [21 90]] [9 80]] [21 87]] [9 100]] [21 75]] [9 100]] [9 100]] [21 83]] [21 78]] [21 86]] [9 90]] [21 100]] [21 90]] [9 90]] [21 100]] [21 88]]] [5618 13.2 [2103 0.483 [7139 48.9 [4279 11.3 [429 21.2 [5368 14 [2521 26.9 [1899 34.4 [5641 4.07 [1253 1.52 [978 17.6 [1293 0.0821 [7428 0.283 [25 99] [25 100]] [25 100]] [25 85]] [1813 0.289 [25 94] [25 100]]] [25 88]] [25 81]] [25 80]] [25 66]] [25 84]] [25 70]] [25 80]] [25 85]] [25 55]]] [6406 20.9 [134 4.69 [896 1.18 [407 18.9 [5632 9.64 [1429 23.3 [71 0.308 [5637 5.8 [1813 25.2 [5695 9.09 [1239 1.39 [7722 4.95 [2893 2.62 [4215 4.67 [33 77] [1 57]] [33 100]] [26 70]] [4235 39.7 [1913 0.253 [7491 1.13 [2228 0.492 [429 15.9 [6613 4.68 [5799 14.8 [1722 2.01 [107 0.808 [67 0.888 [5753 11.9 [2081 11.5 [7665 6.3 [285 1.59 [3130 2.96 [3694 1.6 [6199 2.25 [1391 9.26 [1813 6.45 [3008 2.02 [2628 2.86 [4414 24.2 [6844 2.15 [33 92] [33 100]] [33 80]] [33 100]] [33 64]] [33 76]] [33 80]] [33 100]] [33 80]] [33 100]] [33 100]] [7665 15 [33 100] [33 93]]] [33 83]] [33 79]] [33 100]] [33 100]] [33 100]] [33 66]] [33 66]] [33 66]] [33 50]] [33 76]] [33 57]] [33 61]]] [26 80]] [25 28]] [33 45]] [33 100]] [1620 2.37 [1658 16.5 [46 3.42 [791 17.5 [5491 9.53 [2259 30.6 [1436 7.87 [5491 1.18 [2181 7.04 [7646 5.46 [5110 2.07 [5618 3.42 [7210 6.08 [33 67] [33 50]] [33 57]] [33 92]] [33 92]] [33 66]] [33 100]] [30 37]] [33 34]] [33 66]] [1 30]] [33 45]] [14 33]] [8 21]]] [16 50]] [26 75]] [26 70]] [4 33]] [26 63]]] [3 100]] [7753 18.2 [10 100] [10 81]]] [5110 8 [4416 18.4 [4876 5.04 [7116 1.47 [42 1.31 [2526 32.9 [7512 21.3 [2199 11.1 [4292 2.15 [4898 1.78 [5034 56.9 [534 8.6 [3 97] [4414 4.35 [6544 4.5 [429 84.8 [1664 3.03 [112 4.33 [6199 5.05 [2143 4.67 [3 99] [3 100]] [3 100]] [3 100]] [3 100]] [3 97]] [3 100]] [3 100]]] [3 80]] [3 90]] [3 100]] [3 94]] [14 62]] [3 91]] [3 100]] [3 100]] [3 87]] [3 83]] [3 88]]] [4533 1.28 [5267 5.68 [7212 8.09 [6544 4.42 [5568 0.624 [5019 0.69 [5034 1.34 [2348 2.89 [6199 7.16 [4292 0.503 [2004 2.82 [6294 8.27 [1429 12.4 [7210 1.81 [3 71] [3 75]] [3 38]] [33 72]] [3 90]] [3 92]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [34 72]] [3 50]] [33 33]]] [2649 1.65 [6961 0.496 [2259 51.7 [2939 0.396 [1301 5.58 [6687 12.4 [1851 0.508 [6653 1.42 [107 2.54 [285 3.07 [5799 6.16 [5174 3.88 [3713 5.49 [4704 7.91 [5723 2.67 [4622 9.72 [1742 2.86 [181 4.5 [26 13.4 [4154 6.13 [6848 21 [37 11.9 [1823 3.36 [3677 3.4 [3208 16.1 [3107 0.612 [939 11.2 [3008 15 [2868 4.13 [6937 2.54 [165 10.8 [33 13] [38 56]] [26 44]] [7154 10 [16 50] [16 36]]] [17 67]] [29 80]] [5 71]] [16 36]] [5 31]] [33 45]] [6207 33.7 [16 29] [3 42]]] [38 84]] [6 17]] [33 90]] [25 72]] [33 68]] [37 47]] [16 61]] [33 91]] [26 100]] [33 97]] [16 42]] [248 7.69 [33 61] [33 100]]] [5701 2.54 [33 95] [33 100]]] [1348 3.94 [33 85] [33 100]]] [13 100]] [76 21.3 [37 18 [6687 14.3 [6 42] [6 82]] [6 50]] [6 40]]] [33 100]] [4739 7.13 [2889 6.6 [6279 14.5 [167 4.51 [2940 3.27 [7048 3.28 [957 1.84 [5933 18.8 [5692 6.56 [5607 4.35 [1896 17.1 [2392 2.51 [5753 10.5 [2891 1.51 [2640 2.57 [23 64.5 [7150 4.3 [165 25.3 [7488 5.8 [4427 7.86 [7123 19.6 [5888 2.85 [6207 28.4 [5799 20.5 [5673 15.3 [187 11 [6778 2.28 [16 24] [5 39]] [4854 8.69 [3435 17.6 [5632 23.5 [2722 23 [38 31] [16 26]] [16 70]] [37 66]] [7149 10.6 [2628 39.1 [16 58] [6 53]] [3 36]]]] [18 27]] [16 70]] [38 48]] [16 80]] [26 20]] [4427 16.1 [16 90] [16 50]]] [38 100]] [38 53]] [16 72]] [5 21]] [16 43]] [7 63]] [18 46]] [38 100]] [2939 8.4 [38 100] [2868 5.15 [38 51] [16 66]]]] [17 66]] [4851 10.3 [16 48] [5632 19.7 [16 62] [16 90]]]] [16 90]] [4859 6.71 [18 60] [16 57]]] [4457 3.29 [16 48] [28 56]]] [7166 1.56 [2241 2.35 [2717 1.32 [6 38] [16 63]] [6 54]] [16 61]]] [165 13.6 [14 22] [38 56]]] [38 100]] [37 7.52 [5 66] [5 33]]] [16 64]]] [2178 0.414 [7343 15.1 [4538 17.1 [38 35] [6199 2.89 [61 50.6 [38 93] [2872 26.3 [5956 3.64 [38 86] [38 100]] [17 60]]] [38 100]]] [16 37]] [6 25]]] [4564 1.04 [7454 0.945 [2143 6.04 [94 8.61 [5799 4.06 [5642 5.53 [6959 27.6 [62 13.6 [165 6.8 [2942 1.04 [16 67] [6 42]] [16 45]] [30 33]] [18 41]] [6 57]] [18 62]] [16 72]] [18 93]] [16 63]] [18 100]]] [4724 1.54 [7623 0.922 [5900 0.839 [5983 12.3 [2913 11.3 [5101 3.68 [189 7.59 [2577 2.04 [5693 5.8 [301 12.8 [6177 8.63 [1896 13.2 [83 7.33 [4427 4.94 [2102 10.7 [6514 3.7 [165 8.77 [5724 11 [5102 31 [299 0.799 [5007 28.6 [2849 79.7 [4457 0.478 [2619 6.99 [7139 7.94 [16 32] [16 62]] [7421 4.2 [18 53] [6 66]]] [26 37]] [18 100]] [16 50]] [16 81]] [6 46]] [6 61]] [7 40]] [6 40]] [18 70]] [18 61]] [18 75]] [35 42]] [7 33]] [2713 14.5 [30 77] [30 87]]] [26 46]] [16 53]] [6 66]] [312 0.0968 [91 1.4 [2259 3.78 [6256 1.66 [2941 14.9 [5681 17.5 [6 93] [16 71]] [6 67]] [18 57]] [16 50]] [1 28]] [16 71]]] [2913 24.1 [30 80] [16 28]]] [2734 3.21 [6 100] [6 81]]] [5931 0.522 [4431 0.826 [1997 0.469 [18 45] [1783 38.7 [18 93] [18 62]]] [18 83]] [6 62]]] [304 0.461 [30 56] [30 100]]] [2093 0.842 [6 81] [16 40]]]]] [7665 0.378 [4861 0.444 [2232 0.808 [6751 0.967 [39 1.11 [3 36] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]]] [3309 2.44 [5496 0.761 [11 99] [11 100]] [11 100]]] [2368 4.19 [6940 1.77 [1335 1.01 [6923 3.24 [5753 1.03 [2628 3.43 [5408 1.41 [7149 1.55 [1384 2.56 [5716 1.75 [6328 2.09 [7234 2.68 [7513 3.45 [6 84] [6 90]] [6 96]] [6 100]] [6 100]] [6 100]] [6 50]] [6 100]] [6 75]] [6 46]] [6 70]] [1276 1.83 [1913 0.368 [6923 0.42 [6166 12.7 [7222 9.26 [6 100] [6 95]] [6 92]] [6 100]] [6 100]] [1384 0.395 [1089 1.01 [6 89] [6 100]] [6 75]]]] [6 71]] [4414 3.33 [6 95] [6 50]]]] [4446 1.06 [1116 5.43 [248 3.32 [5851 9.1 [1452 0.099 [1255 0.418 [4781 9.05 [6074 10.8 [3905 2.3 [2975 11.1 [1014 1.09 [2289 0.448 [1710 4.25 [30 34] [30 92]] [30 100]] [30 100]] [31 50]] [30 53]] [30 57]] [22 62]] [1 40]] [2069 0.608 [30 100] [30 90]]] [0 80]] [30 62]] [10 55]] [31 100]]] [5129 3.94 [7737 1.07 [6093 2.39 [6034 11.4 [107 1.69 [131 1.82 [2201 8.07 [6449 0.448 [5622 3.23 [6708 0.309 [2199 20 [144 24.2 [5462 0.0878 [7139 14.1 [2093 0.435 [144 23.6 [5034 1.66 [4154 28.9 [42 20 [791 1.22 [5673 4.92 [7665 80.5 [1899 28.9 [104 3.88 [4198 2.09 [5345 10.8 [19 57] [13 28]] [19 76]] [19 66]] [26 57]] [8 25]] [19 86]] [32 26]] [19 48]] [19 80]] [3 50]] [28 44]] [19 28]] [36 27]] [19 87]] [1944 0.455 [1078 5.5 [217 12 [6199 17 [19 60] [19 86]] [3 58]] [1429 29.1 [19 80] [19 40]]] [19 100]]] [26 44]] [12 37]] [33 40]] [4154 5.26 [1 50] [13 50]]] [13 37]] [13 39]] [19 29]] [3 41]] [13 81]] [663 1.08 [1391 0.221 [4716 1.36 [1982 19 [1436 2.18 [5368 10.9 [171 8.05 [7063 1.36 [7605 2.76 [5617 1.72 [23 48.9 [19 32] [1899 23.3 [4991 4.83 [4231 11.5 [42 56.5 [1933 11.9 [6333 0.336 [1587 9.84 [791 3.52 [2256 0.295 [7343 0.732 [4895 8.73 [5776 6.09 [1951 0.724 [4279 5.81 [19 80] [19 73]] [168 58.8 [19 75] [19 100]]] [18 33]] [19 50]] [176 36.7 [144 26.9 [19 92] [7687 7.86 [19 88] [19 36]]] [17 44]]] [19 50]] [18 38]] [1079 2.87 [19 96] [19 100]]] [19 100]] [19 50]] [19 53]] [7514 22.1 [19 69] [30 28]]] [19 60]] [19 47]]] [19 37]] [19 46]] [19 57]] [19 55]] [28 42]] [19 49]] [19 35]] [18 31]] [5 41]] [1079 6.72 [1980 1.52 [13 76] [13 71]] [19 63]]]] [6616 1.42 [23 102 [14 54] [14 85]] [14 100]]]] [1240 1.71 [5462 1.52 [5995 0.364 [3464 6.53 [6074 0.685 [6301 0.657 [3659 1.73 [2795 0.173 [2704 0.405 [503 0.735 [4799 1.58 [7397 0.805 [6926 2.45 [6656 0.632 [3768 1.23 [4205 0.468 [6124 7.18 [6866 2.59 [2081 7.25 [3905 1.34 [4929 1.42 [7665 3.06 [5333 0.535 [6524 1.12 [1429 18.1 [2547 18.8 [2517 5.05 [4405 3.11 [5366 0.202 [5034 0.873 [4832 0.757 [4336 1.56 [3452 0.535 [432 1.22 [7340 2.5 [6017 2.34 [4092 0.392 [673 1.17 [7480 8.09 [3475 2.56 [7255 15.2 [338 3.92 [4556 2.54 [2707 2.46 [4306 1.09 [7508 1.31 [3886 5.49 [1157 3.45 [910 3.48 [6584 2.51 [5812 3.52 [23 14] [2 31]] [17 53]] [7461 1.85 [29 75] [7449 17.9 [29 100] [29 85]]]] [7623 12.9 [27 82] [27 100]]] [15 100]] [23 100]] [33 100]] [4513 0.396 [328 5.8 [16 36] [18 27]] [16 76]]] [23 95]] [25 65]] [2977 23.9 [4213 7.94 [12 49] [12 100]] [31 85]]] [15 100]] [826 2.54 [1239 4.67 [15 82] [15 90]] [15 96]]] [1911 0.69 [2752 22.8 [26 44] [2259 1.01 [26 65] [26 90]]] [26 31]]] [2939 1.69 [35 72] [35 90]]] [29 67]] [32 49]] [26 70]] [2225 2.66 [7210 0.367 [2023 10.8 [3632 0.551 [3453 3 [11 90] [11 100]] [11 100]] [11 75]] [11 100]] [11 90]]] [4154 33.3 [35 89] [1094 2.46 [35 100] [35 90]]]] [4414 12.7 [392 5.75 [23 0.379 [2 60] [2 86]] [2 41]] [2 56]]] [203 8.11 [5871 1.2 [5422 2.99 [28 37] [28 100]] [3 28]] [14 100]]] [2752 13 [23 66] [23 97]]] [4398 98.8 [35 95] [35 75]]] [4154 53.5 [3653 2.51 [24 75] [2259 10.9 [24 100] [24 80]]] [24 100]]] [27 97]] [731 0.28 [4210 9.44 [5753 4.1 [4541 3.4 [6153 3.3 [624 5.12 [4044 0.766 [5013 0.966 [5090 7.35 [4338 6.58 [377 2.02 [1900 9.64 [3921 3.99 [1684 5.36 [3514 2.39 [3588 3.55 [3960 1.41 [7752 0.677 [1485 4.86 [906 0.594 [6808 4.39 [221 4.68 [6484 0.108 [2143 3.31 [738 5.89 [3004 14.3 [28 7] [36 82]] [18 78]] [7470 1.97 [6639 0.128 [23 16] [23 90]] [506 2.93 [29 75] [29 100]]]] [25 73]] [4943 0.75 [6449 7.36 [2939 5.72 [5345 0.634 [28 20] [30 66]] [33 24]] [28 75]] [14 75]]] [32 90]] [3262 0.8 [1559 2.25 [7428 3.24 [7512 3.98 [791 4.19 [28 14] [4611 3.54 [28 30] [29 100]]] [32 38]] [28 45]] [36 100]] [37 92]]] [37 67]] [10 100]] [29 100]] [37 89]] [35 96]] [11 41]] [37 72]] [1783 5.15 [31 63] [31 62]]] [4159 1.03 [5368 29.4 [7441 1.27 [7139 2.59 [4896 2.13 [5776 5.15 [1769 8.83 [28 50] [22 33]] [28 91]] [14 83]] [30 45]] [28 93]] [11 36]] [28 50]]] [1769 2.96 [4158 4.85 [24 57] [23 45]] [33 33]]] [328 7.69 [1913 3.14 [22 90] [22 100]] [16 55]]] [2774 1.28 [7139 1.52 [6363 3.31 [29 44] [28 90]] [29 57]] [29 100]]] [35 87]] [28 77]] [2259 13.2 [392 17.9 [28 95] [28 72]] [28 70]]] [18 100]] [4568 1.47 [1078 10.2 [5420 3.55 [1685 2.28 [2902 0.87 [2202 1.15 [7185 7.92 [1062 5.05 [5007 19 [28 22] [29 75]] [1062 15.3 [28 66] [30 27]]] [18 23]] [25 80]] [28 76]] [28 85]] [28 58]] [5767 4.48 [6353 3.66 [791 36.1 [248 4.08 [957 0.778 [1106 6.03 [1995 2.65 [3281 3.76 [7449 13.5 [2081 4.9 [3310 3.11 [28 49] [29 62]] [23 45]] [29 88]] [10 100]] [23 28]] [28 80]] [28 57]] [29 84]] [11 87]] [3 37]] [24 60]]] [377 1.52 [5999 4.42 [1239 7.77 [28 89] [28 77]] [28 60]] [28 100]]]] [30 97]] [685 1.12 [429 39.8 [5485 1.31 [6982 0.739 [1909 0.967 [1740 11.2 [5662 0.0932 [5345 6.41 [2756 3.55 [1630 13.7 [2526 30.1 [4061 1.68 [3185 8.08 [4338 1.16 [724 17 [3928 1.27 [23 17.5 [328 1.95 [939 1.8 [2526 13.1 [5 24] [5 42]] [5 42]] [16 33]] [5 17]] [17 55]] [17 60]] [5 50]] [38 45]] [35 37]] [5 78]] [16 66]] [18 88]] [17 54]] [17 29]] [18 71]] [429 25.3 [17 50] [24 50]]] [4 94]] [18 80]] [5389 10.6 [17 30] [38 55]]] [23 8.22 [18 40] [18 85]]]]] [6732 0.575 [619 1.77 [2526 6.22 [5191 0.861 [695 0.623 [221 23.5 [2752 58 [6189 2.22 [28 56] [25 100]] [15 38]] [25 44]] [1068 0.631 [328 1.37 [1587 2.06 [5753 0.654 [28 60] [28 95]] [8 44]] [7169 2.12 [2752 11.4 [28 57] [28 94]] [28 83]]] [28 100]]] [28 100]] [4424 7.1 [202 4 [7009 9.43 [25 84] [25 100]] [25 100]] [25 70]]] [28 85]] [883 0.761 [4568 0.288 [1783 1.19 [1239 2.17 [2259 12.6 [28 100] [28 77]] [28 71]] [28 66]] [28 100]] [28 93]]]] [11 100]] [178 4.15 [7381 1.16 [978 1.49 [1611 2.04 [6177 6.28 [5668 0.519 [5265 1.6 [4171 2.26 [2526 4.79 [5480 1.33 [2505 2.09 [4190 3.99 [663 5.53 [4235 18.7 [1078 12.5 [731 8.03 [6384 1.23 [5812 31.3 [5566 2.06 [2913 1.68 [7501 1.92 [7600 1.46 [7068 0.336 [5054 0.375 [5510 2.15 [1 6.41 [7579 1.05 [4817 10.3 [6486 2.7 [14 32] [32 100]] [23 100]] [1429 16.4 [32 100] [32 87]]] [36 73]] [5510 9.18 [14 100] [14 90]]] [14 92]] [1 3.4 [695 8 [36 77] [36 100]] [36 100]]] [429 10.6 [32 91] [32 100]]] [32 92]] [5632 10.4 [32 50] [32 100]]] [14 100]] [12 100]] [22 100]] [7601 4.95 [5 25] [5 60]]] [826 2.24 [4041 3.82 [4373 1.35 [1391 16.7 [3835 5.26 [883 2.59 [5412 7.2 [814 4.87 [377 0.473 [899 1.27 [2149 2.86 [968 5.85 [2470 20 [1783 1.54 [14 14] [28 21]] [15 80]] [32 91]] [10 37]] [2913 2.26 [36 25] [5034 3.72 [32 66] [32 77]]]] [14 45]] [13 63]] [32 28]] [13 77]] [26 42]] [15 76]] [13 62]] [36 100]] [32 81]]] [20 76]] [4154 6.02 [7700 7.03 [685 1.69 [5692 0.623 [721 3.26 [126 3.13 [5316 2.87 [1023 2.42 [7340 9.57 [14 39] [32 100]] [29 50]] [6413 7.47 [6333 1.77 [32 81] [32 100]] [32 66]]] [32 69]] [14 33]] [2259 20.7 [13 19] [36 100]]] [14 90]] [14 62]] [32 69]]] [13 100]] [13 100]] [560 10.5 [896 4.47 [18 28] [18 60]] [18 61]]] [7588 4.76 [1931 6.41 [5662 7.69 [5429 3.73 [7185 15.5 [7154 2.09 [2488 2.16 [5267 9.42 [2259 45.6 [5198 7.26 [6550 6.24 [1631 6.56 [2846 4.86 [383 10.5 [7664 5.07 [1075 5.02 [5110 12.7 [394 7.95 [1239 6.54 [248 13.9 [18 15] [25 75]] [33 23]] [14 83]] [15 33]] [4 69]] [18 30]] [18 85]] [12 25]] [18 83]] [7665 24.5 [2541 6.75 [17 50] [17 85]] [18 40]]] [5 31]] [12 77]] [19 63]] [13 100]] [18 69]] [18 54]] [5 83]] [567 11.2 [1668 3.4 [1073 22.7 [4 33] [7 25]] [18 36]] [2 36]]] [1 75]] [5 81]]] [32 94]] [13 96]] [4611 1.46 [29 63] [29 100]]] [25 71]] [791 1.13 [7512 12.4 [30 57] [14 90]] [1899 5.34 [14 93] [14 88]]]] [4235 0.975 [673 1.23 [6544 8.09 [932 3.18 [6040 1.26 [328 9.68 [7343 4.75 [6186 4.35 [7734 0.821 [3667 1.87 [665 1.36 [4524 2.92 [5904 2.67 [4569 1.55 [2913 1.54 [5034 15.5 [5396 4.61 [2525 2.13 [6178 3.36 [5661 1.33 [573 4.11 [731 9.18 [5647 2.44 [5698 1.25 [2966 2.62 [5 15] [5 75]] [24 100]] [18 19]] [728 4.67 [17 19] [17 41]]] [7365 2.7 [5 30] [4 80]]] [5 37]] [25 100]] [24 75]] [4 77]] [14 100]] [695 2.36 [5 51] [5 77]]] [16 53]] [7665 9.72 [19 71] [19 92]]] [6 100]] [2 100]] [2 54]] [791 11 [978 18.1 [18 71] [16 50]] [5 16]]] [2 83]] [18 56]] [5485 1.68 [5692 2.22 [2759 3.82 [18 31] [18 42]] [18 50]] [18 57]]] [6310 1.26 [18 79] [17 33]]] [5 100]] [17 72]] [23 0.894 [2799 1.33 [25 43] [26 100]] [25 55]]] [1078 16.4 [5662 1.47 [6538 3.82 [2 21] [2 84]] [4235 6.91 [2 100] [2 54]]] [2 68]]]] [7689 0.37 [2264 0.865 [1704 0.199 [7292 1.6 [7009 1.1 [1429 25.2 [520 1.72 [4338 12.1 [4832 2.09 [7512 40.4 [1253 0.202 [5034 3.07 [6584 6.34 [2628 17.3 [2571 1.79 [7677 1.93 [5110 1.66 [7693 5.65 [2 35] [24 66]] [4 30]] [4 28]] [4 50]] [7512 14.6 [4 85] [4 45]]] [17 92]] [14 100]] [2 87]] [5 31]] [144 4.91 [2 71] [2 75]]] [2526 15.5 [24 87] [24 66]]] [2 90]] [6557 7.36 [5673 3.7 [5851 6.72 [1429 80.4 [5784 3.94 [957 7.09 [6310 7.23 [899 3.31 [7568 2.44 [17 39] [2 42]] [14 50]] [21 1.82 [5 60] [5 75]]] [19 50]] [17 86]] [5 20]] [14 70]] [7722 3.44 [38 56] [17 41]]] [6557 11.2 [5 72] [17 57]]]] [2259 3.47 [5 71] [5 100]]] [2 90]] [1078 6.42 [17 90] [17 50]]] [6538 2.99 [2 87] [2 100]]] [17 65]]] [5561 2.35 [1849 0.583 [107 1.56 [2846 1.45 [7381 1.09 [4897 1.54 [6294 4.04 [5170 2.86 [2849 6.81 [5132 3.4 [7583 2.33 [2207 2.56 [2586 1.49 [1011 11.9 [7414 0.978 [7731 1.59 [6791 1.66 [1011 8.77 [25 22] [25 80]] [25 61]] [16 50]] [25 69]] [5 27]] [25 100]] [5 40]] [25 94]] [1239 3.4 [18 76] [6 50]]] [18 41]] [26 83]] [6364 2.09 [25 85] [25 100]]] [18 22]] [4 43]] [18 76]] [6364 1.54 [6184 10.8 [25 82] [25 100]] [25 100]]] [7329 4.69 [25 75] [25 100]]] [5561 8.78 [25 100] [25 75]]]]] [5460 0.891 [7383 2.21 [7255 3.72 [7354 0.655 [7132 0.68 [2570 0.719 [4338 1.12 [2483 9.47 [2 23] [4 80]] [4 54]] [4 61]] [4 92]] [8 68]] [2526 3.36 [13 50] [8 44]]] [2 100]] [2 75]]] [1704 1.56 [4934 0.734 [7518 3.13 [4061 20.4 [7340 1.9 [3687 1.22 [4170 3.52 [3012 3.83 [1721 5.98 [6547 7.45 [429 11.9 [7321 6.61 [3111 1.12 [5034 1.87 [2993 13.6 [703 4.76 [7526 1.85 [5384 28.6 [3908 1.19 [7185 6.44 [2759 4.36 [4611 0.983 [14 32] [37 44]] [14 80]] [14 64]] [15 30]] [35 66]] [17 41]] [7 100]] [36 77]] [4154 5.12 [896 1.76 [14 70] [14 83]] [14 57]]] [15 100]] [14 82]] [7251 1.3 [4369 7.38 [6199 20.5 [5812 4.45 [3008 1.48 [721 1.49 [695 5.87 [6883 2.09 [7692 5.36 [6949 4.67 [2846 7.46 [5316 11.1 [5680 1.83 [3884 3.31 [429 26.7 [7381 0.55 [36 16] [17 18]] [17 25]] [7623 1.92 [15 73] [15 100]]] [28 80]] [32 83]] [32 69]] [17 70]] [32 75]] [23 70]] [14 42]] [14 91]] [2591 1.99 [17 36] [17 55]]] [1078 15.3 [17 36] [17 67]]] [17 38]] [32 65]] [695 5.85 [1078 5.23 [19 60] [17 54]] [14 62]]]] [14 100]] [17 55]] [36 100]] [32 57]] [37 93]] [896 8.15 [112 1.1 [7665 3.23 [32 80] [32 97]] [32 100]] [32 54]]] [14 94]] [32 100]] [14 97]] [5692 2.23 [3929 20.4 [17 65] [17 33]] [3929 4 [17 83] [17 93]]]]] [23 0.4 [673 2.13 [2088 2.24 [791 3.54 [2538 0.846 [2912 1.57 [2097 5.82 [4320 7.4 [2986 1.83 [4114 19.9 [5170 5.44 [5662 6.43 [6491 1.15 [2232 17.9 [2540 2.16 [2237 7.22 [1038 1.66 [7523 1.55 [2099 8.95 [4602 3.23 [4159 9.11 [7330 2.16 [2000 5.13 [2987 1.54 [338 28.4 [939 8.33 [1025 1.45 [440 2.53 [435 13.3 [1078 4.91 [4768 10.7 [2902 5.88 [23 17] [28 41]] [8 26]] [2180 12.5 [2110 4.14 [23 12] [22 42]] [4 20]]] [23 57]] [23 81]] [23 42]] [3003 1.23 [23 41] [27 100]]] [25 100]] [2259 34.7 [23 75] [10 100]]] [23 92]] [2 27]] [429 10.9 [2226 12.2 [2199 29.8 [27 15] [10 45]] [23 37]] [27 43]]] [26 93]] [1899 42.9 [23 73] [23 100]]] [7737 9.17 [23 57] [17 33]]] [23 100]] [1 94]] [23 60]] [23 59]] [23 100]] [2 25]] [33 85]] [27 80]] [10 25]] [27 100]] [23 79]] [1104 1.83 [10 88] [10 100]]] [23 82]] [7481 6.17 [2701 2.22 [6178 4.76 [4569 0.701 [1919 5.88 [929 1.25 [3027 11.8 [3794 1.09 [5967 4.34 [2846 18.2 [2752 31.7 [2083 8.7 [1991 3.19 [1022 10.9 [2108 1.68 [852 1.87 [5509 1.45 [3309 7.19 [1769 16.4 [4398 8.3 [4154 67.5 [2841 0.391 [1995 27.4 [957 0.481 [7340 3.31 [1888 10 [2039 4.76 [1955 3.09 [11 16] [4 50]] [29 66]] [14 61]] [32 88]] [27 27]] [28 50]] [14 85]] [26 75]] [30 33]] [11 56]] [11 100]] [23 46]] [11 100]] [7512 4.95 [23 34] [10 30]]] [23 90]] [1991 8.18 [23 83] [23 37]]] [438 6.89 [2 14] [14 32]]] [7354 9.8 [1995 7.99 [968 5.49 [23 36] [28 72]] [23 17]] [14 30]]] [22 80]] [28 57]] [29 61]] [6342 1.58 [23 59] [23 87]]] [6920 1.64 [2526 8.45 [23 100] [23 60]] [23 100]]] [2 38]] [28 92]] [25 100]] [2004 1.11 [29 87] [29 100]]] [15 100]]] [719 1.36 [2931 2.56 [23 69] [23 100]] [2 20]]] [2199 5.84 [25 47] [26 66]]] [2098 0.475 [6333 1.79 [7668 1.19 [3099 2.23 [6177 4.91 [3873 0.858 [5140 3.21 [7449 6.01 [2195 0.112 [4571 1.77 [5170 2.69 [5130 0.542 [3959 1.37 [6380 3.19 [5804 2.2 [2753 19 [906 2.94 [178 6.81 [4754 1.78 [2570 1.18 [2628 9.28 [2227 8.55 [957 9.56 [1221 1.92 [2526 30.3 [6776 4.28 [7665 10.1 [28 12] [14 24]] [32 50]] [18 35]] [30 33]] [37 55]] [13 80]] [14 20]] [4 55]] [11 37]] [25 30]] [29 22]] [7512 5.62 [31 12] [22 42]]] [22 83]] [14 57]] [29 100]] [16 61]] [33 58]] [8 33]] [1 58]] [29 32]] [33 90]] [32 100]] [25 97]] [1 100]] [25 85]] [32 100]] [29 90]]]] [5 87]] [2793 1.34 [12 88] [27 57]]] [4393 4.59 [3698 1.28 [968 0.284 [5170 2.15 [3027 4.24 [7343 10.1 [7259 1.58 [1429 1.42 [4920 21.3 [7516 3.67 [5034 5.88 [1980 1.79 [26 26] [18 21]] [14 86]] [26 95]] [26 100]] [6949 4.26 [2753 9.28 [1888 1.3 [5154 4.55 [7241 0.532 [7149 13.7 [5281 1.63 [5106 5.15 [1980 29.9 [5034 14.3 [1429 56.9 [2178 1.08 [7169 1.95 [28 48] [28 100]] [28 71]] [28 28]] [14 100]] [14 78]] [28 100]] [7 75]] [30 77]] [14 23]] [14 60]] [14 30]] [7 50]] [28 90]]] [14 92]] [19 33]] [8 30]] [4205 13.9 [26 82] [26 53]]] [5851 1.83 [5692 8.61 [28 98] [28 94]] [28 87]]] [28 100]] [26 100]]] [13 100]] [1597 1.18 [2048 1.44 [7101 0.654 [29 69] [29 95]] [29 100]] [5011 5.58 [29 98] [29 60]]]] [1239 14.5 [1783 5.54 [1883 1.25 [1025 3.32 [1906 4 [7623 1.03 [144 4.61 [2259 8.84 [5647 37.7 [682 7.71 [2 40] [2 73]] [2 75]] [36 44]] [6538 4.8 [2 66] [2 100]]] [4 90]] [2 84]] [2902 1.73 [663 13.9 [1078 49.1 [5411 2.07 [5812 6.5 [4332 3.07 [23 11.6 [7512 8.54 [6927 9.63 [2 100] [2 72]] [2 70]] [2 77]] [2 85]] [2570 2.99 [2752 17.6 [2 100] [2 86]] [2 100]]] [2 83]] [6927 8.71 [2 54] [4 50]]] [2 55]] [2 74]]] [2081 0.921 [2526 9.21 [2 100] [2 85]] [2 100]]] [2 48]] [4 43]]] [25 100]] [6525 8.98 [1986 2.04 [4741 1.31 [7413 1.31 [1674 0.81 [5588 0.233 [3836 3.31 [2488 4.35 [6544 4.4 [2841 2.67 [2143 0.876 [7548 1.69 [2081 1.2 [2913 2.21 [32 41] [112 0.736 [32 99] [32 100]]] [32 33]] [32 100]] [32 42]] [32 47]] [32 100]] [13 100]] [32 83]] [32 33]] [32 93]] [33 85]] [14 19]] [32 26]] [33 50]]] [4353 2.3 [6091 0.426 [2232 0.698 [2913 1.09 [32 53] [32 95]] [27 33]] [32 100]] [32 100]]] [145 0.634 [29 99] [29 100]]] [957 2.28 [6266 4.44 [1078 83 [2157 4.49 [24 85] [12 71]] [27 87]] [4154 8.13 [24 93] [24 100]]] [27 92]]] [7530 3.05 [4342 6.44 [6374 0.931 [2525 1.18 [2520 3.16 [7382 5.52 [7026 1.91 [6337 6.02 [5192 2.58 [1429 7.21 [24 79] [24 53]] [24 100]] [19 41]] [24 85]] [24 45]] [24 62]] [5267 6.53 [24 88] [24 100]]] [24 52]] [24 89]] [2453 4.71 [573 2.62 [1980 2.54 [208 5.31 [19 83] [24 52]] [24 83]] [24 66]] [24 88]]]] [1911 15.1 [6375 0.186 [2225 4.29 [6490 6.02 [5766 0.763 [4569 3.5 [7507 11.8 [957 1.01 [5034 5.74 [28 100] [28 80]] [28 100]] [28 83]] [28 88]] [28 100]] [28 70]] [28 62]] [28 100]] [28 75]]] [573 0.888 [5411 0.569 [6184 2.08 [1391 6.34 [23 32.1 [6528 3.5 [5567 0.857 [6768 0.62 [4851 0.542 [1833 0.805 [364 3.86 [4056 2.92 [6080 3.45 [3698 0.184 [7693 4.11 [228 1.33 [1078 12.4 [719 10.9 [6353 0.616 [3905 3.83 [5472 1.85 [5191 1.51 [1069 2.43 [6970 0.555 [731 1.97 [276 2.65 [4897 1.23 [2127 0.514 [3989 5.32 [5891 0.924 [2 14] [3065 6.67 [14 28] [19 60]]] [28 54]] [31 50]] [18 60]] [11 51]] [4 54]] [17 44]] [6074 6.33 [4 100] [4 62]]] [28 90]] [13 57]] [1899 2.73 [17 50] [32 50]]] [25 43]] [2 50]] [5812 7.21 [1078 26.4 [13 17] [29 21]] [4991 8.44 [1429 3.11 [2 64] [13 71]] [2 81]]]] [2 69]] [7512 23.6 [2 91] [2 37]]] [28 78]] [6080 6.72 [15 50] [15 90]]] [32 96]] [14 80]] [13 100]] [7534 6.32 [17 40] [17 100]]] [31 100]] [14 100]] [15 100]] [1265 0.534 [15 61] [32 100]]] [15 78]] [43 1.07 [968 2.99 [2241 2.61 [2 81] [2 31]] [13 30]] [4 100]]] [2 100]] [4991 0.617 [5818 0.355 [6184 5.64 [4 38] [2 87]] [4833 2.32 [6653 0.355 [4414 1.92 [5412 1.34 [2 91] [2 100]] [2 87]] [2 100]] [2 67]]] [999 1.6 [228 5.62 [2 100] [5819 4.67 [791 6.46 [2 90] [2 100]] [2 55]]] [2 80]]]]] [5871 6.65 [2752 39 [3990 1.64 [37 30] [663 2.59 [3687 3.76 [845 7.63 [3464 16.2 [3056 1.57 [37 53] [37 66]] [37 92]] [37 100]] [37 100]] [3360 1.77 [3359 2.28 [37 79] [37 100]] [38 52]]]] [3464 28.8 [37 82] [37 100]]] [1 33]]] [29 95]] [5732 0.627 [2259 0.426 [1429 59.8 [6342 1.43 [6538 0.921 [7340 3.55 [7357 1.36 [4218 4.89 [6871 1.63 [1888 6.03 [4832 0.84 [3041 3.85 [4235 2.86 [7722 8.29 [1899 20.5 [2753 15.9 [35 17] [22 35]] [25 31]] [17 50]] [25 28]] [35 90]] [24 50]] [5 18]] [29 90]] [13 45]] [35 100]] [32 69]] [2 77]] [1239 4.19 [2 23] [429 5.93 [33 50] [29 35]]]] [1648 8.89 [35 46] [35 77]]] [6708 5.66 [3807 1.6 [4614 1.48 [6989 0.238 [3576 2.06 [7354 9.53 [4478 3.6 [5034 1.53 [1831 1.46 [4209 0.378 [6380 2.1 [4768 0.942 [4764 0.393 [7424 1.81 [5989 1.41 [939 3.94 [4789 2.27 [1059 1.69 [5368 4.31 [1051 1.88 [404 8.79 [7241 2.96 [1899 25.6 [5192 3.09 [6184 6.59 [377 5.88 [23 14] [14 62]] [12 33]] [24 40]] [28 50]] [28 25]] [15 83]] [10 70]] [1429 3.84 [32 45] [29 26]]] [2 46]] [5 42]] [35 63]] [29 33]] [25 58]] [25 20]] [5377 3.27 [2 42] [11 66]]] [14 45]] [4 50]] [30 91]] [4154 9.47 [32 47] [32 100]]] [4478 9.81 [15 90] [5 28]]] [36 100]] [15 100]] [2 93]] [29 100]] [10 100]] [28 69]]] [2707 1.12 [17 0.886 [5106 2.94 [896 1.82 [6091 3.48 [4561 3.65 [4200 3.56 [6879 3.47 [6328 3.25 [7449 0.741 [6408 3.87 [1769 12.5 [407 7.69 [4012 1.98 [145 8.96 [663 8.2 [6492 2.26 [6795 1 [5716 0.13 [5007 17.3 [6727 4.98 [6153 0.222 [144 0.426 [2081 19.5 [688 1.66 [695 46.9 [5462 17.1 [2469 4.6 [2023 1.13 [4569 1.06 [394 12.3 [221 1.16 [28 93] [28 100]] [28 80]] [28 100]] [28 100]] [28 90]] [28 85]] [28 80]] [28 100]] [28 66]] [28 100]] [28 100]] [28 83]] [28 77]] [28 100]] [28 75]] [28 66]] [6653 1.46 [7169 4.58 [1239 3.78 [28 100] [28 80]] [16 37]] [28 77]]] [28 57]] [28 84]] [18 55]] [28 70]] [28 66]] [434 0.289 [28 95] [28 100]]] [28 55]] [28 40]] [28 71]] [28 66]] [28 70]] [14 36]] [6134 0.79 [2628 1.42 [1509 1.27 [28 99] [28 100]] [28 100]] [28 100]]] [663 4.99 [28 100] [17 33]]] [18 60]]]] [808 2.36 [5904 0.967 [2629 0.3 [1047 5.07 [1025 21.4 [5716 0.469 [6266 1.17 [1062 1.1 [5267 4.14 [24 85] [19 50]] [7491 17.3 [24 25] [5 25]]] [24 87]] [24 77]] [1239 9.88 [24 100] [23 68]]] [2081 1.31 [24 91] [24 80]]] [24 60]] [19 72]] [17 23]]]] [1451 0.0814 [4889 8.39 [6397 1.79 [299 1.01 [1429 55.6 [7405 1.65 [957 0.535 [5412 1.86 [2023 1.36 [7665 3.6 [381 3.7 [3529 3.76 [927 2.33 [2461 48.2 [2259 5.2 [23 7.39 [2461 10.6 [27 83] [27 97]] [14 28]] [27 17]] [27 33]] [27 100]] [27 100]] [27 100]] [3 27]] [27 82]] [27 50]] [5851 0.373 [1136 1.14 [23 16.4 [27 100] [27 85]] [27 100]] [27 100]]] [6 100]] [27 37]] [6 91]] [27 77]] [6 50]] [1 37]]] [5165 0.73 [673 5.16 [4663 12.5 [5732 5.78 [819 1.81 [1300 0.46 [5034 1.91 [5812 0.545 [4279 10.1 [3557 2.39 [338 1.79 [3219 0.675 [7354 0.623 [4218 5.53 [3905 0.786 [7176 5.16 [6973 0.971 [7661 0.84 [144 1.38 [957 1.32 [2477 6.17 [3903 5.92 [6017 4.15 [4417 0.37 [685 8.93 [639 1.44 [2526 7.64 [6332 5.81 [1391 3.33 [2924 3.55 [826 5.79 [7241 10 [371 9.88 [7662 6.67 [2988 1.6 [2846 4.35 [7255 10.6 [221 1.08 [296 3.55 [2332 5.26 [3406 7.52 [811 2.81 [2752 11.1 [2902 2.09 [1911 4.8 [5110 5.12 [7305 6.92 [6189 4.63 [6294 2.27 [7279 1.83 [701 15.2 [1239 3.53 [1025 2.65 [12 13] [4 29]] [2241 1.64 [21 15] [10 45]]] [1078 7.69 [36 63] [10 100]]] [4 66]] [26 28]] [25 90]] [15 62]] [2752 1.22 [15 36] [15 91]]] [4 57]] [4 40]] [899 4.53 [2939 3.18 [6074 7.27 [7665 7.87 [15 50] [4 43]] [15 100]] [15 26]] [14 62]]] [927 3.6 [5110 1.99 [1995 12.2 [7032 9.43 [1429 8.52 [5439 2.54 [7512 15.6 [10 41] [10 52]] [10 66]] [6401 4.85 [328 4.76 [36 42] [2 20]] [36 100]]] [31 90]] [10 62]] [15 59]] [10 100]]] [10 100]] [36 100]] [10 100]] [12 26]] [12 51]] [14 75]] [15 100]] [12 100]] [21 93]] [36 50]] [2470 3.27 [15 50] [15 100]]] [15 100]] [15 75]] [12 58]] [3008 2.35 [6342 7.64 [4 30] [15 54]] [25 76]]] [4 100]] [26 49]] [15 82]] [21 100]] [10 95]] [15 100]] [4530 2.86 [1888 4.27 [7169 1.38 [5769 1.38 [1161 0.986 [7442 7.14 [5632 5.26 [3616 23.9 [10 52] [10 100]] [30 87]] [27 100]] [10 57]] [10 100]] [27 38]] [32 55]] [15 71]]] [3207 1.01 [896 3.71 [1783 0.724 [6184 0.891 [2081 0.77 [2470 1.62 [32 24] [4 56]] [2 21]] [2 43]] [10 48]] [2 51]] [32 57]]] [12 100]] [10 100]] [5693 2.65 [15 66] [15 89]]] [3067 2.15 [1404 0.843 [939 2.82 [906 1.39 [3909 3.81 [15 38] [15 100]] [15 66]] [32 37]] [15 100]] [36 100]]] [15 82]] [811 0.623 [36 73] [4279 1.25 [1078 18.5 [36 100] [36 50]] [36 100]]]] [3972 4.74 [2752 5.6 [15 100] [15 71]] [15 71]]] [26 73]] [12 100]] [1436 7.93 [4424 1.18 [4851 2.7 [7241 4.07 [1674 4.17 [504 5.58 [2844 2.7 [896 2.89 [5467 4.67 [429 36.2 [1429 32.6 [4221 1.85 [2526 2.25 [3931 19.8 [6393 3.6 [4283 1.53 [15 76] [4170 15.4 [4283 30.9 [2081 5.74 [3338 1.73 [2923 3.11 [15 94] [15 100]] [15 100]] [15 81]] [15 76]] [15 55]]] [15 100]] [10 55]] [2 30]] [15 100]] [15 28]] [15 41]] [12 71]] [2 50]] [15 100]] [15 100]] [12 50]] [32 37]] [36 50]] [15 100]] [15 57]]] [7279 2.37 [1640 0.914 [7255 0.637 [2 31] [6791 1.27 [23 1.11 [12 92] [12 57]] [12 100]]] [2943 3.41 [2 77] [4 77]]] [4 100]]] [2331 1.55 [5776 12.3 [1416 1.46 [126 2.15 [719 5.39 [6294 1.73 [7512 1.98 [3 63] [34 1.49 [7665 15.4 [14 78] [429 32.6 [14 100] [14 92]]] [32 100]]] [14 61]] [14 100]] [32 100]] [14 100]] [14 100]] [4279 3.37 [32 88] [32 100]]]] [10 100]] [27 100]] [5509 0.888 [337 0.537 [1400 7.94 [15 65] [2808 1.6 [5732 9.18 [36 50] [15 84]] [15 100]]] [15 100]] [32 55]]] [7465 2.51 [2752 2.15 [4417 2.16 [5138 6.5 [5412 4.81 [5753 3.41 [2143 13.3 [15 45] [32 50]] [15 80]] [15 37]] [12 100]] [15 60]] [2752 39.6 [695 2.77 [1899 8.59 [15 81] [15 71]] [15 33]] [12 60]]] [15 100]]] [6189 2.89 [7185 2.74 [1906 1.36 [791 8 [26 56] [5480 2.11 [26 69] [26 100]]] [25 42]] [7590 4 [1081 0.888 [26 76] [26 100]] [26 100]]] [25 92]]] [7512 7.01 [14 87] [14 100]]]] [7258 0.805 [3016 1.46 [5218 1.92 [3105 3.39 [5467 0.87 [6970 0.524 [1116 0.437 [4690 0.234 [711 0.3 [305 1.19 [1055 0.96 [978 2.12 [5412 0.186 [2696 2.46 [1025 3.02 [5833 1.8 [7623 5.91 [5776 5.33 [5232 3.55 [5829 0.713 [7472 6.21 [6566 4.93 [809 1.49 [5647 1.1 [4004 0.457 [6524 12.6 [6413 2.62 [1062 9.69 [5484 7.89 [7329 1.59 [756 3.6 [112 1.31 [2770 4.89 [7169 4.53 [5926 3.41 [5227 5.86 [429 1.25 [1913 27.7 [2562 24.4 [5530 8.98 [4154 13.1 [6342 2.02 [2804 6.02 [6155 50.1 [4533 18.6 [6722 5.38 [312 9.43 [221 5.88 [6260 35.8 [4457 3.82 [5235 9.43 [2151 3.51 [30 57] [30 100]] [11 100]] [30 71]] [22 57]] [329 2.67 [2259 8.47 [30 80] [30 100]] [30 100]]] [33 33]] [30 100]] [22 70]] [11 88]] [12 100]] [6342 27.3 [33 16] [5211 38.3 [30 40] [30 70]]]] [22 28]] [28 50]] [23 41]] [13 36]] [1297 3.91 [4611 1.54 [7317 3.94 [5826 4 [7176 14.1 [5684 3.65 [1 2.76 [859 5.56 [7241 1.83 [584 1.06 [2526 11.5 [6732 12.6 [11 29] [22 77]] [23 62]] [23 55]] [22 36]] [22 38]] [11 88]] [30 100]] [22 87]] [11 100]] [30 100]] [4764 1.64 [37 41] [35 100]]] [9 90]]] [887 3.03 [1899 4.22 [37 37] [35 37]] [11 68]]] [20 78]] [6342 1.55 [30 21] [1980 1.85 [429 9.52 [2 19] [9 40]] [23 23]]]] [30 100]] [2241 1.31 [22 31] [22 85]]] [30 100]] [33 100]] [22 86]] [7449 4.67 [2939 1.51 [22 30] [22 28]] [22 45]]] [0 82]] [6525 5.15 [22 100] [22 47]]] [8 95]] [859 4 [11 45] [22 50]]] [22 87]] [6566 25 [11 100] [741 6.49 [11 91] [11 100]]]] [38 69]] [11 100]] [0 100]] [1239 7.94 [30 90] [30 40]]] [2739 1.51 [7664 2.15 [4414 14.5 [5122 1.51 [30 62] [2913 31.4 [4768 2.49 [7695 2.26 [30 96] [30 100]] [30 75]] [38 55]]] [30 78]] [30 55]] [30 100]]] [4451 19 [1 7.63 [5211 50.6 [11 100] [11 87]] [11 77]] [12 77]]] [1753 3.5 [11 59] [22 100]]] [1429 63.7 [5330 16.4 [5435 8.49 [4738 0.741 [30 97] [30 100]] [30 85]] [30 66]] [6199 18.1 [30 100] [30 75]]]] [1391 0.898 [5412 12 [6276 3.31 [30 15] [11 45]] [6048 9.43 [22 37] [0 44]]] [2752 4.79 [0 55] [22 86]]]] [7453 0.654 [1391 0.62 [7176 1.01 [4832 1 [248 4.59 [883 3.26 [7414 0.829 [5804 4.5 [392 1.64 [4288 0.647 [4447 3.65 [5692 1.92 [5865 2.59 [6413 2.26 [328 6.89 [1239 10.8 [2259 34.4 [2004 3.11 [23 47] [23 88]] [0 60]] [23 100]] [0 76]] [0 100]] [0 100]] [23 74]] [23 100]] [23 100]] [23 100]] [4 57]] [2 40]] [0 87]] [25 50]] [2 60]] [0 41]] [2488 0.763 [7255 4.79 [0 60] [0 80]] [0 77]]] [23 93]]] [438 0.96 [6199 5.26 [11 100] [11 87]] [11 100]]] [328 23 [2913 10.9 [30 100] [30 83]] [30 71]]] [712 1.71 [791 19.8 [5227 1.36 [1980 7.41 [22 67] [22 90]] [22 60]] [1429 35.5 [11 59] [22 100]]] [22 100]]] [5416 0.528 [5880 1.55 [2394 0.699 [1239 18 [7179 1.08 [2752 7.35 [5999 0.234 [1534 1.07 [3905 3.65 [6883 2.13 [6415 0.949 [5865 2.96 [0 25] [0 100]] [0 85]] [11 40]] [0 86]] [0 100]] [0 54]] [5267 3.5 [7428 8.97 [4 52] [32 37]] [4 50]]] [8 100]] [4 21]] [2612 0.734 [978 10.2 [0 100] [0 94]] [0 100]]] [4 100]] [5757 0.528 [0 69] [0 100]]]] [4851 20.4 [2343 0.602 [329 1.06 [5326 2.49 [6760 2.42 [2410 12.4 [7322 1.87 [2696 23.7 [2695 2.59 [7623 26.7 [30 95] [30 72]] [30 100]] [30 85]] [30 100]] [30 75]] [30 100]] [30 100]] [30 100]] [30 85]] [5221 12.1 [30 80] [30 100]]]] [5871 1.69 [4568 1.79 [2225 5.21 [1 9] [29 71]] [28 72]] [30 36]]] [672 2.18 [2136 2.42 [7200 1.51 [695 2.56 [10 82] [5110 2.86 [558 1.43 [10 86] [10 100]] [10 100]]] [10 100]] [10 100]] [10 100]]] [1899 2.26 [30 98] [30 62]]] [7680 0.952 [6877 2.72 [3926 1.51 [7354 1.96 [811 1.31 [10 60] [10 100]] [8 100]] [8 100]] [10 83]] [10 100]]] [5833 19.2 [3649 2.44 [7031 36.9 [7080 1.99 [5812 1.72 [24 88] [24 100]] [24 100]] [24 50]] [5833 9.4 [24 66] [24 85]]] [3659 25.9 [24 100] [24 75]]]] [6727 0.994 [7176 6.47 [7354 6.97 [2470 7.64 [11 54] [11 100]] [11 83]] [22 71]] [11 100]]]] [1634 0.971 [1054 1.48 [1078 12.1 [4703 0.162 [248 0.6 [429 8.77 [7620 5.26 [1783 29.6 [5345 3.11 [22 61] [22 100]] [6462 4.13 [13 14] [25 100]]] [22 89]] [29 1.58 [6883 3.7 [2143 3.38 [887 1.01 [1701 0.743 [4870 2.46 [5412 10.9 [6027 7.43 [1783 44.7 [1338 5.15 [5462 8.35 [978 9.28 [6199 6.08 [1429 91.9 [6359 13.6 [22 83] [10 66]] [22 50]] [35 42]] [22 66]] [2 28]] [38 77]] [1876 5.01 [21 44] [26 42]]] [22 100]] [30 54]] [22 100]] [22 100]] [22 100]] [22 37]] [9 72]] [9 57]]] [33 28]] [7007 0.577 [4703 11.7 [1783 71.9 [7210 2.56 [4704 5.83 [25 50] [25 27]] [33 57]] [30 25]] [33 35]] [25 100]]] [2993 6.67 [3095 0.671 [2939 9.2 [221 6.76 [7330 4 [2526 19.3 [7210 3.69 [7491 0.31 [5999 17.6 [7169 11.1 [2029 9.18 [2149 11.4 [7016 2.07 [6033 1.05 [1391 0.921 [6996 3.32 [906 7.38 [22 91] [22 85]] [22 100]] [22 100]] [22 100]] [22 100]] [22 90]] [22 93]] [22 77]] [22 60]] [22 100]] [22 85]] [25 62]] [28 33]] [22 55]] [29 70]] [22 66]] [10 33]]] [7329 10.7 [11 42] [11 80]]] [13 100]]] [2913 1.39 [15 95] [7085 27.8 [15 100] [15 90]]]] [6294 3.98 [6287 3.51 [3130 5.36 [5372 0.45 [2752 38 [2108 8.41 [791 26.4 [5267 13 [7009 8.51 [2081 4.31 [131 0.0973 [4314 0.356 [5509 0.237 [4799 0.852 [701 1.17 [4231 1.87 [7741 0.876 [7428 0.938 [10 98] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [10 100]] [695 0.214 [7741 1.46 [1899 2.8 [10 100] [4154 2.28 [2103 1.12 [10 75] [10 100]] [10 100]]] [10 100]] [10 100]]] [10 75]] [10 94]] [10 87]] [10 83]] [10 91]] [10 100]] [10 75]] [10 77]] [10 42]]] [6342 0.761 [915 13.2 [1592 0.164 [2993 0.901 [1078 1.37 [1017 1.56 [750 3.27 [429 79.6 [3 100] [909 5.38 [766 2.2 [3 97] [3 100]] [3 100]]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [765 4.35 [3 99] [3 100]]] [3 100]]] [4991 3.53 [6732 0.258 [5363 0.389 [2178 0.241 [6621 0.207 [2064 0.127 [5784 1.04 [6007 1.36 [1620 3.58 [1452 0.315 [6713 1.17 [5753 0.443 [7343 1.35 [1876 1.07 [6155 1.69 [6413 0.706 [22 95] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 84]] [22 80]] [22 83]] [22 62]] [22 63]] [22 100]] [22 100]] [22 100]] [22 88]]] [7357 1.39 [6177 2.86 [7590 2.22 [4858 0.189 [5480 3.65 [2566 2.01 [4011 0.339 [6921 0.444 [5647 10.9 [7560 1.54 [2815 0.354 [2081 3.97 [7314 6.67 [3457 7.29 [2812 4.58 [6617 2.94 [385 1.64 [6791 5.5 [4603 1.32 [5366 1.5 [2263 1.58 [248 5.88 [1980 8.1 [887 0.852 [2259 9.93 [1025 4.07 [2488 2.89 [5586 3.07 [7665 0.914 [2849 3.65 [1587 7 [6449 8.68 [23 42] [23 78]] [6 42]] [18 62]] [7 29]] [23 100]] [7169 2.16 [1533 0.518 [2491 4.67 [8 92] [8 100]] [8 100]] [8 66]]] [2 47]] [4673 1.5 [2628 5.51 [2526 14.3 [18 32] [8 68]] [18 50]] [6499 4.35 [6 75] [6 100]]]] [8 100]] [7254 3.83 [1429 63.1 [394 0.677 [5462 4.29 [23 57] [23 50]] [23 84]] [8 83]] [23 80]]] [144 3.79 [4017 1.5 [26 54] [26 100]] [35 55]]] [7 62]] [23 100]] [26 88]] [23 69]] [26 84]] [7 94]] [23 93]] [35 100]] [384 11.5 [26 60] [26 78]]] [380 4.45 [1913 0.561 [2161 3.31 [7471 1.28 [661 1.49 [3222 4.22 [392 1.99 [4279 2.21 [23 62] [23 100]] [23 88]] [8 88]] [23 100]] [23 100]] [35 50]] [377 1.1 [23 97] [23 83]]] [27 42]]] [23 100]] [407 3.93 [5350 8.27 [6 72] [6 100]] [6 100]]] [5693 0.808 [5412 1.1 [23 36] [18 40]] [18 46]]] [1062 8.74 [23 100] [23 75]]] [8 96]] [6 100]] [7722 9.07 [385 1.99 [7324 0.728 [6885 0.486 [1783 28.4 [7354 6.68 [5582 2.15 [4645 7.06 [2259 12.2 [429 21.2 [7693 0.734 [728 4.47 [7255 8.17 [26 39] [18 60]] [18 53]] [16 55]] [4154 2.56 [5130 5.59 [719 2.19 [383 4 [23 74] [18 66]] [18 47]] [18 82]] [23 100]]] [1078 12.1 [18 59] [18 50]]] [18 78]] [23 100]] [5480 19.5 [7512 4.86 [18 51] [685 33.2 [4895 1.66 [731 6.03 [2526 1.08 [18 66] [18 92]] [7354 12.8 [2809 2.12 [16 50] [16 57]] [18 85]]] [18 100]] [16 50]]] [18 90]]] [26 50]] [23 94]] [23 100]] [26 61]] [26 70]]] [1084 1.07 [4338 3.15 [5750 0.545 [5007 3.28 [23 67] [23 100]] [23 100]] [23 100]] [23 100]]] [26 66]] [2913 8.81 [695 2.59 [7309 0.843 [25 73] [25 100]] [7 21]] [25 100]]] [3457 7.4 [3156 2.3 [35 66] [35 100]] [35 75]]]] [7101 0.274 [2734 0.703 [7231 4.36 [2939 121 [2713 1.74 [1585 2.42 [7489 3.94 [2690 2.47 [4017 5.53 [2652 0.745 [2730 5.73 [6732 4.12 [7472 4.12 [5723 0.538 [7260 3.24 [1754 1.84 [5873 0.658 [6880 23.7 [5491 13.3 [2327 0.664 [3582 1.39 [6107 0.928 [2866 1.19 [2526 2.75 [6177 23.1 [2654 1.51 [7419 0.644 [1239 49 [2752 0.638 [5626 3.21 [45 10.7 [5037 0.545 [163 2.04 [4977 2.4 [1957 0.103 [7203 0.398 [4768 13.1 [2722 25.4 [3972 15.6 [85 10.1 [2720 3.4 [4235 11.3 [1943 2.99 [3972 3.14 [6353 3.52 [5716 1.99 [414 0.849 [4414 29.4 [6848 2.7 [2855 9.03 [3994 1.33 [7084 4.37 [187 22.1 [5931 3.72 [38 50] [16 50]] [38 76]] [5 46]] [38 90]] [38 95]] [18 40]] [38 36]] [38 32]] [1 22]] [7 42]] [14 40]] [1944 2.01 [38 76] [38 81]]] [37 36]] [18 33]] [18 87]] [16 33]] [16 66]] [38 73]] [38 72]] [38 90]] [6 70]] [25 28]] [18 22]] [37 35]] [16 39]] [1429 20.6 [16 41] [19 22]]] [2707 21.9 [7 66] [6880 6.06 [17 26] [38 37]]]] [16 42]] [16 39]] [7 73]] [5408 3.87 [2726 0.891 [429 0.832 [187 0.186 [2628 46.6 [16 34] [26 62]] [16 66]] [38 40]] [16 50]] [16 91]]] [37 51]] [7242 7.23 [4538 67.6 [38 100] [38 80]] [38 85]]] [5 71]] [5 67]] [14 91]] [1783 1.25 [5789 10.1 [17 33] [19 62]] [17 87]]] [5873 18.1 [38 78] [38 53]]] [17 86]] [2714 6.51 [2181 3.04 [16 38] [5 55]] [16 66]]] [16 54]] [6208 11.1 [38 80] [17 75]]] [2628 18.2 [18 75] [18 60]]] [7 84]] [2949 6.29 [17 55] [2951 41.2 [17 55] [19 80]]]] [2628 49.7 [5 44] [38 77]]] [2707 46.7 [5894 5.22 [16 63] [16 50]] [13 61]]] [38 91]] [1239 14.7 [4878 5.29 [14 100] [14 85]] [2952 0.849 [1980 2.22 [14 44] [14 75]] [14 100]]]] [6848 11.6 [7421 9.29 [2469 6.17 [7354 0.975 [4731 0.861 [2712 4.98 [7623 2.19 [301 1.32 [6830 9.9 [7153 8.46 [5412 5.86 [2640 13.2 [187 26.8 [6256 2.01 [2650 2.79 [5578 13.2 [414 22.5 [2668 10.9 [1239 58 [6406 42 [1429 22.9 [2029 6.23 [5102 23.5 [5931 13.4 [7224 1.04 [16 55] [16 71]] [16 87]] [6 58]] [6 71]] [6 40]] [6 40]] [7 44]] [7 80]] [6 68]] [16 33]] [13 25]] [18 60]] [6 68]] [2649 15.4 [6 81] [4854 12.2 [6 44] [6 66]]]] [2628 34.8 [28 40] [16 45]]] [6 63]] [18 55]] [30 80]] [30 66]] [16 35]] [2279 5.18 [16 75] [16 66]]] [18 64]] [2649 11.6 [16 100] [16 85]]] [23 13 [6 95] [6 45]]] [18 71]]] [5056 1.57 [1943 1.11 [2949 0.383 [7371 3.64 [2232 3.84 [5579 11.9 [2178 1.19 [1587 6.79 [2672 10.6 [3675 27.4 [2707 81.8 [4071 23 [5067 19.5 [3239 15.4 [2689 5.62 [1660 3.7 [2707 65.8 [38 58] [7348 7.84 [2654 6.33 [3095 2.09 [38 70] [38 90]] [16 80]] [38 100]]] [38 100]] [16 55]] [16 75]] [38 83]] [16 40]] [38 28]] [38 86]] [16 53]] [14 22]] [38 92]] [16 83]] [38 62]] [17 44]] [2721 2.48 [6757 4.76 [38 82] [38 100]] [38 60]]] [38 96]] [17 53]]] [2681 4.59 [2958 2.59 [392 3.85 [16 33] [30 90]] [16 33]] [16 85]]] [7149 18.6 [195 2.88 [2259 6.05 [6701 3.14 [2868 4.52 [4414 17.1 [5724 1.26 [4851 9.74 [2939 111 [16 17] [16 35]] [6 38]] [16 64]] [193 1.96 [16 54] [6 60]]] [16 62]] [7 87]] [16 26]] [6 75]] [26 28]]] [2030 0.463 [2681 10 [302 3.84 [5753 2.23 [663 1.06 [2649 7.21 [6422 1.25 [2679 3.07 [16 36] [16 64]] [16 100]] [6 62]] [6 55]] [28 28]] [30 57]] [30 31]] [6 60]]]] [4154 18.2 [2259 33.9 [4017 0.898 [4876 0.252 [2369 0.22 [28 95] [28 100]] [28 100]] [28 100]] [22 37]] [28 71]]] [7473 0.118 [16 24] [1587 0.304 [2852 0.595 [2466 4.47 [7242 1.77 [95 6.85 [2068 0.118 [4896 3.55 [2853 12.6 [199 0.17 [2748 9.71 [38 68] [38 100]] [2676 4.13 [1395 6.97 [200 3.85 [2241 12.4 [38 96] [16 57]] [2939 15.9 [2951 2.65 [38 66] [12 55]] [7332 4.43 [1783 4.55 [7260 2.24 [7343 3.18 [7500 14.9 [38 88] [38 66]] [38 71]] [5 37]] [38 96]] [38 94]]]] [38 77]] [38 63]]] [12 66]] [38 57]] [38 100]] [38 75]] [5 55]] [5210 4.3 [8 50] [38 43]]] [5 42]] [38 60]]]] [2999 2.45 [2902 8.76 [663 27.6 [3644 2.89 [2490 0.529 [5261 0.693 [4158 1.78 [7385 2.15 [7014 1.66 [5260 2.43 [7512 16.9 [13 71] [36 61]] [13 100]] [13 100]] [13 100]] [13 80]] [13 100]] [13 100]] [36 100]] [13 70]] [13 50]] [36 87]]] [5937 9.8 [5692 0.785 [660 1.98 [6708 3.4 [2178 2.33 [4414 25.6 [1980 12.8 [4223 3.51 [5753 9.43 [4684 0.525 [23 24.8 [4768 2.07 [1023 2.3 [7014 3.72 [6260 4.38 [4718 3.76 [721 4.13 [5412 2.44 [13 66] [13 94]] [13 100]] [13 100]] [13 100]] [13 100]] [13 64]] [13 100]] [13 75]] [13 100]] [13 60]] [13 100]] [11 37]] [13 36]] [11 28]] [13 42]] [13 39]] [4224 1.62 [6260 0.595 [7381 4.95 [13 70] [1 33]] [13 100]] [13 77]]] [21 92]]] [5118 0.325 [6033 0.457 [1413 0.703 [6530 0.505 [4447 1.49 [5122 0.4 [1400 10.8 [5090 2.38 [887 0.808 [384 0.644 [859 0.729 [5769 1.42 [6436 0.147 [7176 0.728 [3033 3.41 [5211 30.7 [660 1.87 [1025 0.382 [3676 1.42 [798 1.02 [23 2.26 [5197 2.24 [1239 5.11 [6445 3.31 [5412 4.6 [30 50] [20 36]] [30 77]] [23 66]] [23 85]] [5345 2.28 [203 0.967 [6909 10.2 [756 1.92 [4279 9.16 [5509 8.24 [30 100] [30 92]] [30 61]] [30 100]] [30 87]] [30 54]] [30 100]]] [23 100]] [8 100]] [23 83]] [791 8.86 [23 71] [23 100]]] [7664 1.78 [4497 5.38 [1919 4.59 [7623 7.04 [7315 5.26 [7322 7.46 [403 5.75 [5589 5.75 [2472 4.07 [2081 7.04 [30 79] [23 45]] [30 100]] [30 100]] [30 100]] [30 100]] [30 100]] [30 100]] [23 100]] [30 100]] [23 62]]] [23 100]] [4414 8.05 [2354 2.33 [5692 15.7 [22 82] [22 97]] [22 100]] [22 75]]] [30 100]] [30 100]] [7491 0.675 [1986 0.736 [30 60] [22 62]] [1025 0.917 [22 94] [22 100]]]] [23 93]] [22 100]] [2199 5.39 [4486 0.732 [22 90] [22 100]] [22 71]]] [10 97]] [7315 8.25 [2143 4.7 [429 0.978 [7155 1.64 [2913 19.6 [5034 1.48 [1429 15.6 [30 75] [6711 2.71 [30 98] [30 100]]] [30 100]] [791 4.37 [30 100] [30 85]]] [30 100]] [5904 18.7 [4984 5.72 [6364 1.23 [5225 2.53 [30 87] [221 12.6 [6711 0.4 [3345 3.23 [30 100] [30 85]] [30 100]] [30 80]]] [30 100]] [30 85]] [30 66]]] [30 66]] [30 77]]] [1980 2.29 [22 53] [23 100]]] [22 100]] [10 100]] [22 100]] [5480 0.325 [6031 1.26 [7338 5.75 [5118 13.5 [22 60] [22 100]] [22 100]] [22 100]] [22 100]]]] [377 0.748 [6584 0.121 [731 1.78 [4309 0.52 [2331 0.741 [4984 0.609 [2826 0.715 [1626 0.442 [6269 0.756 [6189 1.01 [6560 0.82 [1420 0.864 [3008 18.3 [695 2.35 [6604 2.74 [6711 3.48 [1400 0.568 [2628 8.65 [1672 1.03 [7623 7.08 [537 1.22 [1710 0.529 [6106 1.37 [5225 3.54 [5857 1.85 [802 4.39 [2806 9.4 [1679 3.97 [1783 48.5 [4948 4.95 [7512 3.81 [5795 10.3 [6722 3.75 [338 5.13 [3492 1.16 [4342 1.5 [4858 2.38 [663 5.92 [4778 1.65 [2934 1.37 [4893 2.44 [1078 1.89 [6877 3.58 [7615 1.55 [400 6.38 [6413 8.77 [5412 22.3 [2093 6.62 [34 12] [3 55]] [30 60]] [0 75]] [34 100]] [3 50]] [5 30]] [392 2.59 [0 5] [23 33]]] [14 33]] [33 100]] [15 100]] [134 8.05 [32 20] [16 20]]] [18 44]] [24 100]] [0 66]] [26 81]] [5211 11.5 [30 76] [30 100]]] [34 100]] [4479 2.79 [1899 22.5 [4231 1.41 [914 3.02 [2753 7.14 [663 3.44 [2795 1.77 [2793 3.58 [4897 2.02 [4587 1.72 [7722 2 [939 11.4 [7305 11.3 [5198 2.59 [5034 2.94 [5480 4.04 [6557 3.55 [2993 6.27 [2760 5.39 [5154 2.36 [5812 10.3 [688 11.7 [7185 12.8 [328 22.2 [5 16] [788 2.53 [18 38] [18 75]]] [7 57]] [7 87]] [12 75]] [33 37]] [5 100]] [19 37]] [5 87]] [10 25]] [23 2.82 [32 83] [32 57]]] [5 41]] [25 70]] [5 80]] [5316 1.47 [1011 3.15 [14 37] [5 41]] [32 61]]] [32 50]] [19 81]] [24 57]] [24 90]] [7381 1.6 [5 29] [14 57]]] [5 70]] [429 43.6 [32 88] [32 75]]] [10 50]] [22 40]] [32 57]]] [3 81]] [30 57]] [30 74]] [12 90]] [21 49]] [0 100]] [30 90]] [32 100]] [30 100]] [3 100]] [400 6.68 [2259 45.4 [30 52] [34 81]] [34 100]]] [22 100]] [7041 1.49 [2913 3 [6581 5.84 [5801 1.59 [5429 0.971 [6375 1.04 [4 17] [30 50]] [16 53]] [16 70]] [1429 8.48 [17 64] [17 40]]] [2628 24.9 [5 56] [7 50]]] [5 50]]] [5007 5.69 [5277 4.19 [6199 4.1 [5789 0.574 [5267 4.39 [5206 1.51 [1783 4.35 [14 21] [26 41]] [2 25]] [10 61]] [10 66]] [14 56]] [10 100]] [15 40]]] [7241 3.62 [6708 1.18 [3008 2.62 [2466 2.87 [144 3.79 [1980 5.11 [30 56] [21 66]] [30 66]] [30 88]] [328 16.6 [30 87] [30 100]]] [30 100]] [30 50]]] [6184 0.683 [2259 8.83 [30 98] [30 86]] [30 87]]] [7188 8.62 [6714 1.3 [6155 0.182 [3734 2.13 [714 1.13 [4218 0.732 [5226 0.84 [4235 10.2 [1611 1.03 [7548 1.46 [5843 0.901 [7354 2.69 [6077 0.481 [4624 4.32 [14 20] [14 100]] [13 38]] [6243 5.69 [663 8.91 [7 28] [5 46]] [5 100]]] [22 62]] [429 17.7 [14 90] [32 52]]] [14 100]] [26 61]] [22 100]] [14 42]] [22 100]] [17 49]] [10 57]] [22 100]] [12 59]]] [95 1.18 [355 1.79 [2739 2.06 [859 1.52 [5439 3.09 [30 55] [30 100]] [30 100]] [30 100]] [30 96]] [5 38]]] [2199 9.48 [6231 0.864 [673 1.82 [25 63] [25 100]] [25 100]] [25 57]]] [429 8.37 [0 57] [6598 1.96 [0 98] [0 100]]]] [429 12.1 [7309 0.618 [25 96] [25 100]] [25 83]]] [13 100]] [7322 1.27 [5122 0.77 [30 84] [30 100]] [30 100]]] [695 3.66 [899 0.535 [1011 1.05 [791 5.41 [7021 0.27 [673 1.45 [602 8.3 [248 13.1 [2434 0.986 [5054 3.83 [5871 13.7 [2726 0.464 [124 1.08 [6830 0.412 [5439 10.7 [3794 20.1 [7734 1.57 [2268 5.12 [3056 3.34 [3078 11.9 [3519 4.47 [5435 0.502 [1108 5.49 [3204 3.94 [3579 4.65 [2466 8 [7472 1.9 [7600 4.2 [429 24.6 [7215 2.67 [5132 4 [6184 11.5 [1400 13.7 [6724 2.13 [3027 6.37 [4154 13.5 [5 31] [7665 11.1 [4 47] [32 70]]] [5 66]] [14 50]] [4 61]] [4 100]] [18 62]] [7 42]] [6310 9.11 [178 2.96 [7512 15.2 [17 27] [5 75]] [17 50]] [17 80]]] [32 100]] [38 54]] [17 44]] [17 73]] [5 60]] [2 40]] [16 36]] [19 84]] [17 73]] [5 87]] [18 50]] [18 47]] [19 63]] [17 90]] [14 62]] [32 100]] [16 36]] [14 69]] [4 86]] [2381 0.472 [19 50] [18 75]]] [6230 26.6 [2526 4.07 [25 50] [25 81]] [26 91]]] [17 51]] [26 62]] [5 100]] [7692 1.29 [6723 3.46 [485 3.27 [4316 1.1 [4369 1.03 [4154 8.14 [328 5.8 [1732 0.534 [2178 0.795 [7340 3.32 [663 6.34 [6241 3.78 [2968 6.17 [1716 3.23 [1451 1.36 [685 3.94 [2707 1.82 [5345 4.04 [2826 6.54 [17 40] [14 30]] [4 28]] [19 41]] [7 71]] [17 50]] [14 100]] [5 75]] [5 90]] [144 14.8 [6396 3.27 [896 6.35 [14 66] [17 41]] [17 100]] [1078 3.14 [14 60] [14 57]]]] [1400 4.93 [32 92] [32 100]]] [32 45]] [14 100]] [6230 13.5 [14 62] [14 38]]] [32 37]] [32 75]] [32 100]] [2752 20.1 [38 87] [19 50]]] [14 100]] [14 100]]] [4654 1.23 [573 5.95 [5480 0.642 [429 11.5 [26 30] [3520 1.12 [7248 0.659 [5753 3.08 [4184 3.85 [7009 0.59 [7737 0.838 [1190 5.22 [3913 7.18 [2752 19 [906 0.53 [6074 1.46 [1980 1.89 [931 0.662 [17 48] [19 50]] [17 69]] [17 88]] [5 53]] [1429 25 [4 28] [663 5.45 [5 72] [17 55]]]] [19 58]] [5 28]] [5 33]] [2826 5.68 [5 50] [5 78]]] [19 37]] [7677 1.39 [5429 3.85 [5 57] [5 95]] [5 85]]] [7 42]] [19 90]]] [18 61]] [2826 7.41 [17 90] [17 58]]] [5 100]]] [5891 4.75 [2913 1.75 [906 5.76 [14 59] [32 62]] [32 100]] [32 100]]] [3014 6.83 [5730 2.16 [1553 0.994 [7690 4.17 [6401 5.32 [1025 4.41 [7354 1.29 [131 1.06 [6134 0.532 [7542 0.78 [141 3.82 [5009 3.95 [7734 0.52 [628 3.61 [826 1.95 [4369 0.662 [3243 2.65 [134 3.06 [663 14.9 [6544 0.935 [6955 9.5 [5675 0.882 [7600 2.28 [1638 1.11 [112 2.21 [5812 18.3 [1089 3.98 [6332 11.2 [2752 7.67 [17 53] [7255 9.14 [899 0.898 [5732 2.19 [5316 1.9 [4279 11.7 [7343 2.16 [5605 4.65 [5871 4.95 [7548 1.64 [14 57] [14 96]] [7512 20.3 [14 83] [14 100]]] [5 28]] [14 94]] [14 37]] [14 83]] [4154 4.76 [7512 9.38 [14 100] [14 87]] [14 85]]] [14 94]] [12 62]]] [37 50]] [17 28]] [19 27]] [3342 0.426 [14 93] [14 100]]] [14 100]] [32 100]] [14 100]] [32 50]] [7149 0.491 [3917 1.86 [5732 10.1 [7321 0.935 [2452 1 [6076 6.94 [1023 1.3 [3905 0.963 [663 8.13 [6920 3.91 [14 100] [14 80]] [14 90]] [14 100]] [14 100]] [14 83]] [14 100]] [14 100]] [14 75]] [14 100]] [14 100]]] [1888 1.17 [2752 20.7 [5034 4.19 [32 40] [14 100]] [14 70]] [14 80]]] [23 12.2 [7381 6.5 [14 37] [17 40]] [19 62]]] [19 57]] [1429 46.1 [32 50] [32 86]]] [7428 4.66 [12 44] [12 100]]] [27 33]] [17 25]] [7 30]] [5 25]] [32 100]] [14 100]] [32 37]] [2813 2.11 [4851 6.35 [5 32] [32 66]] [18 80]]] [4338 2.73 [2752 29.2 [4 33] [14 81]] [4 92]]] [32 93]] [6199 9.96 [7241 2.3 [14 82] [14 100]] [14 80]]] [32 100]] [32 100]] [19 43]]]] [30 98]] [32 65]] [4418 0.736 [5198 1.18 [7457 1.34 [4369 0.606 [899 1.08 [32 89] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]]] [3204 0.787 [7214 0.452 [248 8.5 [5521 0.65 [1630 1.05 [3929 1.08 [7177 3.42 [1023 0.492 [6043 1.17 [2470 1.18 [3057 0.389 [6076 2.29 [4071 1.35 [7269 1.53 [5480 2.68 [6240 1.41 [1505 2.01 [978 15.9 [2526 6.58 [7325 1.01 [3732 2.59 [6581 0.87 [725 3.82 [1707 2.11 [324 3.9 [3058 2.59 [7413 5.06 [328 2.78 [5429 0.978 [5892 1.12 [1587 7.47 [4533 0.917 [3342 8.33 [791 35 [2752 34 [4369 2.92 [7314 5.18 [6243 2.82 [6077 2.7 [6544 3.04 [7512 6.87 [4267 1.06 [429 30.2 [17 23] [17 55]] [16 42]] [6557 5.62 [6534 1.55 [5 27] [17 40]] [5 87]]] [14 100]] [7 93]] [5 85]] [7 70]] [32 42]] [5 47]] [7 42]] [17 65]] [14 33]] [4897 2.15 [38 61] [5 37]]] [14 56]] [5 92]] [7 47]] [17 76]] [5 100]] [7 70]] [6597 11.4 [17 81] [17 38]]] [17 66]] [2628 8.85 [3317 3.42 [163 1.66 [5 39] [38 57]] [17 70]] [5 41]]] [17 44]] [5 70]] [2811 2.82 [3315 0.907 [3901 2.53 [3220 1.3 [1511 3.3 [1253 0.705 [7009 3.21 [6550 3.2 [1557 1.37 [5412 2.22 [3317 1.17 [1062 10.2 [7188 10.1 [7241 5.05 [4896 0.502 [5673 3.31 [429 8.55 [7 25] [5 34]] [5 50]] [14 93]] [5 47]] [7 66]] [5 90]] [19 45]] [17 36]] [2628 4.44 [7 81] [17 60]]] [5 57]] [2826 12.8 [5 71] [2628 2.62 [19 31] [5 71]]]] [14 30]] [5 100]] [5 100]] [5 100]] [5 100]] [2811 8.42 [5 100] [5 75]]]] [5429 2.34 [3724 2.72 [6534 1.18 [1533 1.63 [7325 3.4 [1580 1.15 [6591 4.41 [5198 2.12 [3561 2.46 [5376 6.32 [429 28.9 [2636 1.04 [2966 6.08 [719 4.29 [144 14.6 [112 1.69 [2753 6.09 [144 1.58 [5 24] [17 36]] [5 57]] [14 72]] [16 25]] [7 54]] [17 37]] [17 66]] [7712 1.82 [7665 13.7 [4154 4.83 [1025 7.03 [6310 6.81 [3342 10.3 [17 42] [5 27]] [19 46]] [4 83]] [16 34]] [17 29]] [5 100]]] [14 46]] [5 100]] [2 42]] [7335 2.61 [17 69] [17 38]]] [733 1.32 [602 0.876 [17 51] [17 60]] [17 85]]] [5 80]] [5 76]] [6535 6.93 [17 76] [17 58]]] [5 80]] [5 93]]] [5 85]] [23 3.11 [6597 15.6 [19 100] [19 66]] [19 100]]] [18 44]] [731 12.3 [5 83] [19 50]]] [6575 1.77 [5693 2.39 [5007 3.16 [731 5.83 [5 35] [5 60]] [5 33]] [5 100]] [5 20]]] [896 10.5 [17 89] [17 50]]] [3548 5.09 [4001 6.57 [3223 1.99 [1507 1.21 [662 2.1 [6230 29.2 [688 0.931 [5 91] [5 87]] [5 70]] [5 75]] [5 41]] [5 63]] [5 69]] [5 66]]] [5480 1.83 [4 81] [4 57]]] [18 83]] [4926 2.41 [4530 0.873 [328 5.08 [724 0.56 [5693 8.65 [4968 0.96 [6732 0.234 [5413 2.42 [17 37] [19 42]] [7 35]] [17 66]] [19 41]] [17 65]] [7 75]] [17 53]] [18 66]]] [7 100]] [1476 0.671 [4000 0.183 [3247 0.583 [999 2.53 [5491 3.5 [602 1.57 [5904 1.19 [6396 0.135 [1463 0.617 [1535 3.79 [3675 0.928 [1911 1.19 [7325 5.58 [735 1.26 [1499 7.39 [5 79] [5 57]] [5 33]] [19 50]] [17 44]] [5 88]] [5 54]] [5 100]] [1062 1.73 [4805 3.95 [17 76] [16 64]] [2636 1.21 [4870 1.48 [6074 1.54 [17 86] [17 83]] [17 91]] [17 63]]]] [19 90]] [6333 1.54 [4105 1.06 [3119 1.66 [4154 4.1 [2081 0.516 [7512 5.33 [17 40] [6395 0.578 [17 55] [1584 3.44 [6074 0.289 [23 1.92 [17 100] [17 83]] [17 100]] [17 50]]]] [17 75]] [5 37]] [17 84]] [5 100]] [19 50]]] [5 36]] [1062 1.61 [17 90] [17 100]]] [5 100]] [5 68]] [1011 2.32 [978 5.29 [5 100] [5 90]] [5 80]]]] [6047 2.1 [4851 0.65 [662 0.582 [6920 3.76 [1919 2.29 [17 36] [19 66]] [1072 3.25 [17 81] [17 100]]] [16 37]] [663 8.16 [1888 1.11 [17 57] [17 90]] [17 90]]] [17 42]]] [5412 1.03 [4806 5.03 [731 4.89 [19 73] [957 6.75 [896 5.29 [17 40] [17 71]] [19 71]]] [19 100]] [726 0.564 [23 3.19 [19 100] [19 95]] [19 100]]]] [1986 2.27 [2466 0.607 [7007 1.08 [6445 1.37 [5480 2.48 [26 51] [26 91]] [25 80]] [25 100]] [685 5.21 [25 100] [25 76]]] [25 100]]] [2939 4.73 [5412 0.991 [469 0.541 [6911 3.78 [6239 0.83 [7244 1.97 [2610 1.83 [2752 23.7 [3562 5.19 [6550 0.849 [6599 3.24 [726 0.327 [17 42] [38 37]] [19 100]] [17 57]] [19 53]] [7665 13.1 [458 0.876 [731 7.65 [7 69] [19 57]] [19 75]] [17 66]]] [19 94]] [6581 0.631 [19 46] [38 70]]] [14 35]] [19 83]] [19 96]] [688 2.72 [3317 1.7 [3734 0.785 [1632 0.577 [19 63] [19 100]] [19 100]] [2628 4.11 [19 69] [19 66]]] [17 42]]] [2760 1.1 [6581 3.37 [17 48] [19 50]] [17 62]]]] [5753 9.29 [663 13.9 [5 92] [5 74]] [5 57]]]] [6588 0.185 [2610 0.55 [4805 0.81 [3558 1.09 [6357 1.41 [1546 1.1 [721 2.24 [3194 3.16 [6401 0.655 [899 0.904 [5675 0.707 [21 3.76 [7535 0.78 [642 0.511 [5969 2.77 [4533 3.06 [649 1.39 [3104 4.5 [6591 0.201 [2526 4 [17 42] [2259 6.03 [7682 4.48 [7586 2.34 [17 73] [17 35]] [17 57]] [16 33]]] [4851 2.5 [17 92] [5732 4.93 [7534 1.13 [896 7.79 [6584 3.3 [17 45] [1239 1.66 [17 80] [17 100]]] [7722 9.66 [16 42] [17 100]]] [17 100]] [17 68]]]] [5 50]] [17 100]] [5 50]] [17 100]] [5 57]] [5 36]] [5 75]] [35 40]] [14 90]] [5 94]] [5 100]] [14 75]] [5 37]] [1883 0.441 [7373 1.58 [1899 1.22 [4895 1.19 [5389 0.699 [17 40] [3732 6.71 [929 0.96 [38 44] [19 50]] [17 55]]] [17 50]] [38 75]] [7512 14.1 [17 80] [38 85]]] [19 42]]] [7526 1.31 [19 39] [17 85]]] [985 2.24 [6544 2.69 [1888 0.433 [17 69] [1703 2.32 [7711 0.274 [5969 0.416 [5316 0.794 [19 45] [5412 0.673 [19 81] [19 75]]] [19 100]] [19 50]] [17 50]]] [17 61]] [134 1.71 [17 40] [17 50]]]] [19 90]] [1570 0.34 [1151 2.53 [7333 0.424 [1078 5.27 [7534 0.589 [7722 18.6 [7590 3.6 [6395 5.43 [6380 8.11 [17 38] [17 66]] [6074 4.74 [17 80] [17 100]]] [5 40]] [5 71]] [7665 15.5 [17 58] [7384 4.55 [17 100] [17 83]]]] [6550 8.23 [429 14.3 [17 50] [7520 1.52 [6970 1.29 [736 1.61 [2570 0.472 [1078 9.48 [17 100] [17 82]] [17 100]] [4588 0.452 [6978 0.879 [17 72] [17 83]] [17 93]]] [17 71]] [17 100]]] [17 50]]] [724 0.9 [17 100] [896 2.7 [17 66] [6977 3.64 [17 60] [17 100]]]]] [19 63]] [17 100]]]] [3345 0.852 [5211 4.29 [7310 1.44 [429 5.94 [14 41] [7067 0.792 [4517 4.29 [6653 0.232 [673 3.33 [6883 3.18 [1239 17.3 [7449 0.911 [2381 4.12 [6547 0.811 [1011 0.649 [719 2.62 [1101 0.496 [1084 2.1 [6231 3.7 [380 4.07 [4533 3.15 [383 1.6 [4205 6.76 [14 86] [14 28]] [14 100]] [14 55]] [14 40]] [30 81]] [26 28]] [14 44]] [328 24.3 [14 100] [14 44]]] [7 46]] [14 100]] [30 40]] [32 33]] [14 51]] [7 62]] [26 62]] [4414 5.44 [14 50] [28 80]]] [28 71]] [7 56]]] [25 100]] [1679 2.48 [30 52] [30 88]]] [6713 1.89 [30 77] [30 100]]]]] [5838 2.79 [5994 1.04 [2469 2.27 [3281 0.539 [23 2.31 [5154 5.05 [2259 0.511 [1876 2.4 [1996 8.59 [312 1.48 [7141 18.4 [4897 0.778 [1764 7.4 [2893 9.9 [6621 9.66 [6935 4.67 [4235 8.95 [5480 4.85 [5412 1.93 [33 94] [33 100]] [33 100]] [33 66]] [33 66]] [33 80]] [33 83]] [33 62]] [33 100]] [33 66]] [33 100]] [33 76]] [33 36]] [221 4.41 [33 62] [33 100]]] [33 100]] [6276 6.07 [5244 6.32 [6068 9.28 [328 29.7 [233 41.7 [335 0.362 [5641 2.5 [2241 1.6 [17 5.55 [5702 8.84 [4611 3.19 [1340 1.71 [6524 5.05 [1263 0.428 [7428 12.1 [6359 0.372 [1359 14.5 [7552 2.61 [7316 1.34 [7413 0.938 [5368 0.795 [7207 12.7 [33 100] [33 93]] [33 100]] [33 100]] [33 88]] [232 3.19 [33 75] [33 100]]] [33 83]] [33 100]] [33 66]] [33 100]] [33 80]] [33 91]] [33 60]] [33 88]] [33 87]] [33 84]] [33 85]] [33 75]] [33 75]] [33 76]] [33 75]] [9 50]] [33 66]]] [33 66]] [13 50]] [10 60]] [33 57]]] [4645 1.07 [3666 1.1 [2709 7.82 [7214 0.838 [2110 0.802 [5681 1.85 [3905 0.829 [2569 4.57 [4739 14.8 [64 0.914 [5962 1.76 [248 3.08 [5007 2.29 [978 5.38 [2260 10.6 [7245 0.185 [5721 12.8 [5574 0.898 [2963 2.16 [6711 10.4 [3208 1.63 [719 12 [2048 11.4 [1820 2.96 [7207 7.17 [2897 11 [2752 4.51 [2117 0.891 [6717 1.29 [673 10.6 [3374 1.62 [6452 10.4 [4457 7.69 [2605 14.3 [5900 9.8 [5377 1.42 [4592 0.84 [4897 8.83 [6757 1.99 [2131 1.72 [3308 1.02 [6471 1.93 [38 50] [2143 0.485 [2993 31.3 [5637 6.2 [4768 10.8 [3008 1.06 [7060 5.23 [4279 10.4 [1646 2.89 [2732 4.5 [5799 2.51 [26 79] [26 100]] [26 50]] [26 90]] [1881 15.4 [26 100] [26 85]]] [25 33]] [26 100]] [26 100]] [26 63]] [26 60]] [7428 1.04 [26 100] [26 88]]]] [26 100]] [26 50]] [33 38]] [26 52]] [26 54]] [26 38]] [25 33]] [26 100]] [26 62]] [26 100]] [26 100]] [26 94]] [26 83]] [38 55]] [2939 10.4 [5412 1.85 [26 50] [26 44]] [1078 5.71 [16 75] [26 90]]]] [16 33]] [14 42]] [6 37]] [24 33]] [26 100]] [16 29]] [26 50]] [16 50]] [26 37]] [16 30]] [19 50]] [18 60]] [2749 2.62 [7354 5.44 [19 29] [18 66]] [2259 4.19 [26 90] [26 88]]]] [1078 9.12 [26 36] [5007 3.75 [28 54] [26 44]]]] [6524 6.63 [1337 0.428 [1078 63.1 [6882 2.14 [4738 5.44 [4923 7.53 [5904 3.73 [7502 3.52 [2965 5.93 [5799 7.8 [23 38.1 [384 3.6 [5940 1.57 [1030 9.97 [407 19.7 [2897 15.6 [232 1.24 [1062 8.26 [423 12.6 [7260 5.54 [733 3.03 [4279 20.1 [1239 30 [6472 8.33 [338 1.48 [6134 0.713 [181 0.792 [6216 6.9 [6474 13.1 [5205 2.1 [5198 9.64 [673 23.9 [673 18.9 [6406 2.22 [2955 3.02 [5851 0.907 [1400 0.861 [2849 13.3 [2081 1.46 [6474 1.22 [4895 1.34 [26 95] [26 100]] [26 100]] [26 100]] [26 85]] [26 100]] [26 100]] [26 87]] [26 100]] [26 71]] [26 100]] [26 77]] [26 90]] [26 87]] [26 88]] [26 100]] [26 80]] [26 100]] [663 9.65 [26 84] [26 100]]] [26 68]] [1881 5.62 [26 78] [26 71]]] [26 76]] [26 50]] [26 72]] [26 62]] [33 50]] [26 42]] [26 59]] [26 63]] [26 61]] [978 1.6 [4602 0.25 [5869 1.18 [26 100] [26 77]] [26 91]] [26 100]]] [26 47]] [26 52]] [26 66]] [6 42]] [19 84]] [35 60]] [2628 4.63 [26 100] [26 90]]] [26 42]] [19 50]] [33 80]] [26 40]]] [26 31]] [19 55]] [16 60]] [16 100]] [19 57]] [5435 1.34 [1895 1.37 [26 55] [16 33]] [16 51]]] [26 32]] [144 1.17 [19 75] [19 100]]] [16 38]] [24 52]] [18 62]]] [811 3.08 [2320 0.217 [4420 0.125 [3481 0.336 [5034 0.81 [3559 3.89 [5402 1.86 [125 1.07 [568 0.232 [6548 3.6 [7665 1.37 [2145 13 [2826 1.96 [1995 5.95 [1253 0.347 [2787 0.373 [663 9.56 [3909 0.379 [1499 1.66 [7354 2.07 [6310 0.832 [2471 2.65 [3219 0.938 [3884 0.77 [5809 2.49 [2476 1.9 [3209 0.713 [1094 0.792 [6732 5.15 [15 81] [15 100]] [0 33]] [15 100]] [7481 19.2 [7449 5.97 [15 96] [15 100]] [15 77]]] [15 100]] [15 100]] [15 100]] [15 100]] [15 54]] [36 50]] [15 71]] [15 100]] [32 57]] [15 100]] [15 100]] [15 46]] [32 75]] [32 66]] [2259 0.351 [4279 4.33 [7449 13.7 [5692 4 [15 75] [32 85]] [15 100]] [15 100]] [4369 3.25 [695 0.978 [32 51] [36 80]] [32 85]]]] [4154 7.73 [36 71] [32 100]]] [32 75]] [32 50]] [13 100]] [32 100]] [4383 0.949 [4170 1.02 [5969 4.52 [1069 0.505 [5316 1.21 [7340 1.17 [32 88] [32 100]] [32 100]] [32 83]] [32 91]] [32 100]] [32 100]]] [6732 9.13 [36 42] [36 90]]] [15 100]] [3368 0.217 [2084 0.392 [1405 4.85 [7526 2.46 [7373 0.335 [3483 0.385 [6094 2.51 [112 0.341 [4398 10.6 [4154 4.49 [827 0.62 [32 73] [32 100]] [3027 2.73 [6717 2.67 [6091 3.31 [2083 0.668 [4279 20.5 [899 8.39 [32 88] [32 100]] [36 38]] [32 100]] [32 100]] [32 100]] [32 83]]] [15 85]] [1980 10.5 [32 100] [32 71]]] [32 62]] [1166 3.2 [6106 0.924 [4163 4.37 [7722 8.96 [5316 0.385 [7449 2.26 [6333 0.376 [4801 2.15 [32 77] [32 100]] [32 100]] [32 97]] [32 100]] [32 100]] [32 100]] [32 100]] [32 81]]] [36 72]] [36 69]] [36 85]] [32 100]] [36 100]]] [5472 1.93 [1783 0.978 [15 84] [15 62]] [7512 12.4 [36 75] [36 100]]]]] [1785 3.65 [328 1.97 [1781 2.4 [7139 3.04 [1919 0.734 [1094 11.9 [3311 2.01 [6163 0.659 [1995 20.6 [4176 7.41 [7737 1.81 [6490 1.34 [4228 6.12 [976 0.294 [5007 2.56 [3791 1.01 [5157 2.56 [429 34.6 [4320 0.508 [5211 0.699 [27 57] [10 56]] [27 91]] [3323 17.5 [4119 6.68 [791 38.4 [7449 1.04 [3404 1.85 [6025 4.55 [2143 21.8 [3095 4.97 [1995 13.6 [2087 1.22 [774 21.4 [499 7.9 [819 0.431 [27 76] [27 100]] [1089 5.77 [1176 1.27 [4153 2.15 [4369 0.768 [927 1.27 [961 9.09 [2752 29.4 [27 96] [27 80]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [500 1.89 [27 90] [27 100]]]] [27 85]] [27 100]] [27 85]] [27 100]] [27 66]] [10 55]] [27 100]] [27 50]] [27 69]] [27 66]] [27 60]]] [5 57]] [27 100]] [29 66]] [27 100]] [27 62]] [23 73]] [10 75]] [27 63]] [27 58]] [27 100]] [23 100]] [978 5.26 [2526 0.922 [27 76] [27 100]] [23 100]]] [23 38]] [27 34]] [23 100]] [2752 0.543 [27 80] [23 34]]] [10 87]]] [3003 0.349 [4207 2.79 [4142 0.643 [4369 1.55 [4288 0.277 [7644 3.23 [2331 4.57 [774 2.07 [1640 2.35 [6199 0.603 [1429 5.3 [168 5.49 [2931 8.77 [2445 3.33 [2267 5.62 [3554 4.33 [6791 6.49 [819 0.224 [2474 3.27 [2091 4.82 [4197 3.88 [1094 11.6 [5660 3.51 [429 45.5 [685 2.24 [392 12.5 [4592 7.31 [5034 3.3 [4353 11.9 [4214 1.48 [145 17.7 [1078 49.5 [2 11] [7241 3.45 [27 43] [10 88]]] [19 45]] [4154 36.1 [24 61] [27 40]]] [15 31]] [1078 16 [32 100] [32 50]]] [15 36]] [25 36]] [26 33]] [27 60]] [2 69]] [15 25]] [15 100]] [2241 1.39 [27 20] [14 39]]] [15 100]] [27 98]] [2 36]] [957 1.23 [3559 4.33 [25 42] [32 100]] [27 83]]] [31 100]] [19 42]] [27 90]] [19 50]] [1079 13 [3325 5.85 [4968 0.398 [1159 1.84 [899 0.75 [4198 9.05 [7453 5.53 [3480 7.87 [5753 5.22 [1078 28.1 [2752 1.35 [30 14] [3424 8.54 [6800 3.03 [6260 6.11 [2763 7.14 [7354 2.02 [6177 1.24 [2770 3.18 [1239 1.11 [1062 5.26 [7449 1.02 [896 1.19 [30 21] [14 37]] [28 55]] [29 54]] [1436 2.56 [14 19] [25 50]]] [30 100]] [25 58]] [18 57]] [4 53]] [4154 19.2 [24 50] [24 70]]] [29 100]] [23 45]]] [5693 2.93 [2199 0.341 [2931 13.3 [4163 4.5 [4353 1.9 [1932 4.1 [976 3.23 [939 6.39 [27 15] [27 35]] [27 100]] [14 45]] [28 40]] [27 83]] [23 33]] [28 50]] [24 50]]] [28 40]] [32 87]] [23 50]] [19 71]] [1078 13.6 [32 75] [32 44]]] [27 100]] [6230 6.99 [30 35] [30 100]]] [29 100]] [19 54]]] [429 13.7 [2260 6.79 [695 6.51 [2923 3.36 [4338 2.73 [19 39] [2 50]] [25 90]] [26 50]] [19 85]] [2752 27.9 [29 13] [32 72]]]] [4159 1.04 [2 87] [2 93]]] [811 5.62 [5025 1.07 [2259 5.27 [3027 12.6 [5647 0.978 [957 0.235 [2461 2.9 [1078 47.4 [23 31] [27 37]] [27 100]] [4154 27.5 [27 98] [27 88]]] [27 37]] [4137 1.93 [1119 9.77 [27 98] [27 96]] [27 100]]] [3159 2.28 [27 29] [27 100]]] [35 83]] [10 82]]] [3728 12.9 [32 76] [32 100]]] [30 100]] [5654 3.1 [5911 2.26 [286 2.07 [32 22] [2 47]] [22 41]] [2 92]]] [1400 13.3 [819 0.466 [2488 6.17 [3905 1.09 [3896 1.78 [4414 9.72 [4329 0.559 [1159 0.644 [27 83] [27 100]] [27 100]] [27 44]] [32 100]] [32 94]] [13 100]] [27 100]] [10 97]]] [2752 5.49 [4120 0.852 [27 88] [27 100]] [27 88]]] [29 98]] [27 100]]] [429 7.25 [5174 0.875 [7642 1.24 [5192 0.444 [2766 1.72 [3635 0.849 [221 2.99 [4657 2.59 [1842 1.32 [285 5.71 [2023 13.2 [1587 6.93 [1379 8.35 [1932 11.9 [4802 19.2 [4682 3.76 [4768 28.9 [3130 1.33 [2559 2.37 [99 2.48 [1 96] [1 100]] [1 71]] [1 85]] [1 66]] [1264 2.39 [1 81] [33 70]]] [1 70]] [1 75]] [7583 4 [1 79] [1 93]]] [1 57]] [1 60]] [33 75]] [36 44]] [6524 19 [1 64] [248 34.4 [1 76] [1 100]]]] [7623 1.65 [1 93] [4658 3.79 [7646 3.11 [23 6.27 [1 90] [33 80]] [33 87]] [1 80]]]] [3100 7.29 [4655 5.68 [248 8.74 [1 100] [1 75]] [4656 12.7 [1 100] [1980 28.8 [1 85] [1 100]]]] [1 75]]] [33 56]] [5561 0.444 [1 70] [33 87]]] [33 54]] [2939 12 [7176 7.26 [33 54] [1 75]] [1 88]]] [1072 8.57 [7664 1.86 [4956 7.21 [1253 1.29 [7623 15 [1003 3.88 [2199 12 [4201 20.1 [7169 3.12 [1379 5.99 [232 6.35 [2892 2.89 [5661 1.9 [1 98] [1 100]] [1 100]] [1 88]] [248 8.09 [1 83] [1 90]]] [1 87]] [1 87]] [1 86]] [1 100]] [1 82]] [1 70]] [1 77]] [1 50]] [1 80]]]] [4218 0.394 [826 0.821 [4149 11.5 [1888 2.46 [499 3.14 [877 0.0855 [4011 0.257 [7381 1.95 [7665 1.97 [6524 11.5 [6998 0.0505 [4158 1.08 [6711 1.01 [5034 0.262 [36 0.584 [2143 0.282 [6230 7.09 [5007 1.59 [22 53] [29 47]] [17 50]] [29 37]] [22 100]] [28 78]] [6711 5.13 [22 71] [22 100]]] [791 10.2 [28 60] [28 100]]] [28 85]] [2831 1.55 [6530 12.6 [80 0.367 [791 32 [6529 26.6 [6427 2.89 [968 1.86 [248 7.58 [1436 3.54 [2091 7.08 [126 8.07 [384 5.49 [155 3.96 [957 3.14 [857 1.4 [6320 1.87 [1980 38.8 [512 2.35 [2826 3.55 [110 2.89 [6613 5.75 [5412 20.7 [36 1.57 [5462 12.5 [7016 3.4 [22 51] [22 97]] [28 57]] [22 100]] [28 76]] [7 40]] [22 100]] [7 88]] [22 66]] [1 16]] [22 92]] [22 100]] [27 42]] [22 100]] [7 75]] [28 69]] [28 64]] [28 50]] [7 40]] [2902 3.72 [28 89] [28 100]]] [22 100]] [5480 5.15 [22 63] [22 100]]] [22 71]] [22 100]] [22 92]] [22 100]]] [5454 2.18 [1995 0.787 [5472 0.659 [6310 1.13 [22 32] [7 53]] [36 80]] [4279 0.359 [2081 2.32 [16 33] [22 80]] [22 53]]] [29 75]]] [4806 1.21 [7 81] [17 100]]] [28 93]] [22 100]] [27 86]] [2913 0.662 [4414 1.02 [3480 2.28 [7 60] [36 100]] [7 30]] [7 93]]] [27 100]] [32 38]] [6080 0.458 [7665 1.23 [28 81] [4414 1.41 [494 0.657 [17 44] [17 89]] [17 83]]] [15 100]]]] [6668 0.469 [5508 0.218 [6654 0.294 [4896 0.381 [6168 0.649 [6413 12.8 [6228 5.59 [2029 1.46 [1112 0.414 [826 0.294 [5371 1.21 [1913 2.44 [4600 2.97 [503 9.45 [4168 11 [3075 0.909 [851 24.1 [32 100] [2233 0.186 [4643 2.77 [32 100] [32 71]] [32 100]]] [32 100]] [2081 4.07 [32 96] [32 100]]] [32 90]] [32 75]] [112 1.28 [32 98] [32 100]]] [32 83]] [32 100]] [32 66]] [32 91]] [32 91]] [32 90]] [32 83]] [2143 4.28 [1429 136 [6653 0.483 [6353 0.297 [7665 0.845 [2181 0.12 [5789 0.536 [32 96] [32 100]] [32 100]] [32 100]] [32 85]] [32 87]] [32 44]] [6382 2.48 [32 37] [32 100]]]] [32 63]] [4576 1.92 [32 80] [32 100]]] [32 63]]] [4795 2.89 [517 1.72 [506 3.36 [7737 2.59 [6375 2.07 [3993 2.22 [2384 2.17 [1333 1.5 [553 1.43 [2259 31 [7088 5.29 [508 1.49 [791 20.5 [585 4.27 [21 88] [21 100]] [5041 30.1 [694 3.18 [5697 1.68 [21 99] [21 100]] [21 100]] [535 30.5 [21 92] [21 98]]]] [21 100]] [21 85]] [21 50]] [21 100]] [10 100]] [10 100]] [21 66]] [21 100]] [10 100]] [21 66]] [4924 1.67 [805 5.15 [569 16.7 [21 100] [21 89]] [21 100]] [21 100]]] [21 100]]] [2703 0.429 [3622 0.589 [7734 0.688 [6213 0.197 [2701 0.313 [1671 1.74 [5911 0.931 [711 0.778 [535 4.5 [1888 1.62 [6524 0.707 [5090 1.86 [1995 6.08 [7623 9.03 [3960 4.2 [867 1.1 [5040 2.66 [2470 2.96 [2259 8.07 [2527 5.52 [1913 9.15 [2951 2.22 [7381 4.27 [6031 1.72 [1025 10.1 [7210 14.3 [429 79.6 [7512 19.7 [5154 4 [7009 1.94 [5007 4.63 [917 1.37 [4768 1.95 [7188 6.01 [7451 3.47 [248 17.9 [560 11.8 [6310 0.709 [18 20] [18 66]] [16 64]] [18 60]] [29 100]] [16 36]] [22 33]] [9 60]] [19 45]] [9 20]] [28 38]] [1011 2.97 [5007 11.2 [1429 27.6 [18 36] [18 86]] [18 100]] [18 85]]] [9 28]] [22 71]] [29 30]] [1980 2.73 [22 94] [22 100]]] [2 100]] [16 55]] [29 71]] [16 85]] [7169 5.58 [4574 2.73 [2846 6.99 [4508 7.47 [429 14.8 [19 39] [18 43]] [19 72]] [18 93]] [29 57]] [8 40]]] [4 55]] [21 61]] [867 4.13 [22 69] [22 97]]] [29 100]] [27 87]] [791 20.3 [28 41] [29 61]]] [22 88]] [145 0.711 [1391 1.29 [6530 0.707 [22 62] [22 80]] [859 0.345 [1078 16.5 [22 66] [22 100]] [22 100]]] [22 100]]] [178 0.167 [6883 1.61 [560 4.72 [7302 1.17 [7169 14.9 [4785 2.85 [560 2.52 [1769 11.4 [134 4.83 [7185 4.19 [1429 24.2 [978 0.387 [19 66] [18 75]] [2707 0.821 [18 74] [18 71]]] [18 66]] [18 40]] [18 88]] [16 33]] [8 40]] [32 50]] [19 80]] [18 75]] [18 83]] [18 80]]] [21 100]] [22 100]] [1186 0.891 [22 62] [22 100]]] [7260 2.02 [31 7 [7665 2.61 [1239 1.19 [18 83] [18 91]] [1073 1.51 [7301 6.57 [6040 15.6 [6230 4.33 [7516 1.13 [7601 2 [2939 0.574 [978 13.2 [18 94] [18 85]] [18 85]] [18 71]] [18 100]] [18 45]] [16 58]] [18 44]] [18 71]]] [16 60]] [19 50]]] [2701 2.93 [15 50] [6068 19.7 [29 100] [29 85]]]] [4184 0.586 [7169 7.85 [29 95] [29 85]] [29 50]]] [4513 1.45 [2385 3.78 [7514 3.38 [1400 8.18 [2831 0.624 [6230 12.5 [673 2.68 [6659 3.62 [6206 0.322 [2656 1.49 [5660 0.515 [2903 2.7 [5680 0.982 [5009 1.82 [1783 0.77 [1911 6.23 [6342 7.58 [7665 10.5 [7733 3.88 [434 2.94 [999 0.356 [5716 2.32 [5157 8.21 [7203 4.31 [383 7.58 [7428 10.4 [7118 4.17 [5485 11.5 [18 84] [18 40]] [18 55]] [18 66]] [5485 5.91 [1078 2.83 [18 77] [18 64]] [18 87]]] [18 55]] [695 3.64 [2752 19.2 [7185 4.42 [18 94] [18 88]] [18 71]] [18 100]]] [18 37]] [18 100]] [18 50]] [18 100]] [18 70]] [24 42]] [18 50]] [1696 0.486 [1783 1.4 [19 54] [532 5.03 [6035 2.55 [7677 0.744 [2671 1.3 [5723 6.76 [7245 2.76 [896 15.7 [1631 1.09 [7736 4.21 [5753 1.64 [4573 0.832 [6791 0.983 [4205 1.55 [2268 3.21 [6732 6.65 [18 95] [18 73]] [18 62]] [18 83]] [18 50]] [19 55]] [16 44]] [18 100]] [18 75]] [18 35]] [18 95]] [18 50]] [18 55]] [19 50]] [14 40]] [7301 0.564 [18 62] [19 70]]]] [7734 8.4 [18 55] [19 66]]]] [248 4.47 [7722 1.06 [7736 2.73 [429 44.8 [4508 1.6 [132 1.29 [695 4.96 [6040 1.58 [19 83] [19 50]] [18 60]] [18 91]] [19 45]] [19 100]] [5130 2.59 [18 52] [14 40]]] [18 71]] [18 100]]] [4645 2.35 [16 54] [18 57]]] [5160 0.898 [16 27] [19 66]]] [4859 0.963 [6732 0.671 [7735 2.52 [18 100] [18 85]] [18 100]] [18 80]]] [19 53]] [1072 0.322 [18 50] [19 46]]] [6830 11.1 [5641 1.83 [788 4.33 [532 9 [18 51] [19 54]] [18 85]] [19 92]] [16 62]]] [6517 3.83 [18 91] [18 55]]] [19 60]] [978 3.3 [6353 1.95 [6715 3.63 [18 100] [18 62]] [18 60]] [377 2.65 [985 4.1 [7354 23.5 [7733 4.02 [2466 0.479 [7723 0.496 [18 97] [18 100]] [18 100]] [18 83]] [18 85]] [18 77]] [18 71]]]] [26 93]] [7546 0.945 [18 45] [19 71]]] [5013 2.02 [2275 0.612 [7332 2.15 [4927 7.09 [7185 2.34 [680 0.945 [791 21.1 [1011 5.88 [6007 1.47 [549 0.688 [788 16.3 [7427 2.52 [4851 2.73 [19 49] [18 50]] [18 76]] [16 55]] [560 3.29 [18 85] [18 62]]] [18 100]] [719 3.48 [7340 9.37 [978 14.3 [19 40] [18 88]] [18 66]] [18 93]]] [18 79]] [18 100]] [6230 2.08 [7693 0.901 [4154 4.12 [3742 0.978 [7735 5.41 [1078 7.31 [7185 5.8 [18 85] [560 3.55 [19 37] [26 36]]] [18 84]] [18 94]] [18 83]] [19 58]] [18 84]] [18 72]]] [6042 11.8 [7590 1.04 [5480 11.3 [19 75] [18 45]] [18 62]] [18 57]]] [144 11.1 [18 38] [19 82]]] [549 1.3 [18 76] [18 63]]] [7665 9.18 [19 73] [16 33]]]] [19 90]]] [1429 43.4 [29 100] [29 81]]] [2232 1.34 [5757 0.608 [29 98] [29 100]] [29 87]]]] [7347 1.04 [2429 0.957 [7734 0.171 [7480 26.9 [2694 1.34 [1239 24.2 [2685 0.884 [5491 9.31 [2890 0.202 [7372 12.6 [5874 0.466 [2667 2.2 [69 0.115 [4431 1.75 [6961 0.102 [2649 0.606 [2727 1.5 [4011 0.589 [5632 1.25 [88 0.508 [7457 1.43 [7231 14.6 [7038 7.18 [4496 5.36 [4104 0.928 [1675 1.35 [6007 4.71 [6380 0.622 [301 1.01 [3120 7.46 [7488 2.14 [2628 50.9 [2853 1.74 [2867 2.79 [7124 0.16 [7150 5.38 [2687 9.58 [4851 6.62 [5564 1.66 [2006 3.08 [1895 10.9 [3742 0.579 [5148 0.761 [6471 1.57 [2178 8.39 [4895 12.9 [2939 49.3 [7472 2.72 [6370 5.36 [6574 1.27 [4673 0.573 [2887 12.2 [6937 6.78 [7279 1 [2983 0.695 [6959 0.25 [192 14.3 [1445 0.471 [38 45] [11 30]] [7 33]] [16 42]] [38 35]] [17 44]] [16 62]] [38 100]] [38 81]] [17 83]] [18 33]] [38 88]] [4414 3.88 [38 70] [38 66]]] [8 38]] [38 100]] [26 80]] [2887 9.13 [38 88] [38 45]]] [10 25]] [5681 3.15 [5 26] [38 58]]] [38 88]] [14 100]] [2951 24.2 [2849 43.3 [6 47] [17 38]] [6 50]]] [4909 22.1 [1896 2.24 [38 93] [38 100]] [38 71]]] [2707 9.55 [16 46] [16 100]]] [18 37]] [16 44]] [2955 6.78 [61 13.7 [38 84] [38 100]] [38 53]]] [187 48.7 [2666 32.4 [2951 36.4 [2868 8.77 [38 63] [6 33]] [187 9.2 [3675 5.02 [38 62] [38 45]] [4768 2.67 [38 87] [38 100]]]] [16 72]] [16 40]]] [38 98]] [5 40]] [16 71]] [17 29]] [16 47]] [6 75]] [5 87]] [5 59]] [16 37]] [16 54]] [5 64]] [2679 11.9 [3056 0.151 [5 37] [6 50]] [4854 5.07 [16 30] [37 66]]]] [1253 0.567 [190 6.12 [16 42] [1078 2.57 [2869 1.08 [1820 5.06 [16 63] [6 66]] [37 33]] [2849 27.8 [16 50] [13 37]]]] [17 28]]] [1429 9.35 [1980 2.46 [2866 0.602 [37 31] [112 1.7 [37 61] [37 86]]] [23 40.5 [37 40] [16 44]]] [5 48]]] [16 34]] [2983 1.74 [4017 0.423 [5438 1.78 [1429 0.206 [23 30.1 [4414 13.4 [1395 6.9 [2656 1.26 [5595 18.2 [2731 8.29 [2978 10.6 [5873 2.35 [1897 11.2 [6 59] [18 44]] [6 71]] [16 85]] [16 71]] [6 85]] [6 36]] [16 32]] [16 47]] [7242 2.05 [5931 2.44 [5673 6.46 [7149 2.84 [37 31] [33 37]] [16 39]] [6 28]] [37 63]]] [2275 2.27 [4154 2.36 [1783 30.1 [2731 9.46 [7150 4.24 [7206 8 [5799 6.16 [6007 3.14 [5894 1.64 [4895 1.73 [7231 6.06 [1701 7.25 [5170 4.66 [6129 0.569 [5632 6.53 [5753 0.423 [6 32] [6 38]] [16 60]] [6 69]] [16 50]] [6 72]] [16 58]] [16 78]] [18 33]] [6 100]] [18 71]] [16 100]] [16 100]] [16 60]] [6 76]] [18 33]] [6 75]]] [4854 1.75 [5673 10.4 [18 40] [19 40]] [7149 4.26 [2656 7.11 [4851 15.4 [16 54] [6 25]] [16 33]] [18 71]]]] [16 70]] [1896 1.76 [7149 3.33 [52 3.02 [2628 23.1 [37 23] [5647 1.65 [5578 7.66 [429 3.86 [6 39] [16 64]] [6 54]] [16 41]]] [37 57]] [2628 29.7 [6 62] [18 42]]] [3435 6.14 [16 40] [5673 2.47 [37 66] [37 81]]]]]] [7039 2.4 [75 5.44 [6942 0.867 [1900 0.915 [2143 1.05 [2275 0.696 [7150 1.41 [2955 8.68 [2868 15.1 [1687 3.5 [2690 0.226 [16 46] [6008 1.11 [16 40] [6 37]]] [16 68]] [6 55]] [165 0.467 [2654 3.71 [7260 3.1 [6 74] [6 57]] [190 10.4 [16 70] [18 84]]] [16 45]]] [6 20]] [6 70]] [16 42]] [4851 5.92 [16 88] [6 35]]] [6 90]] [4528 7.22 [16 85] [16 38]]] [16 54]]] [7619 0.571 [6959 14.7 [5102 3.09 [4431 16.6 [2978 9.3 [6406 0.934 [6422 0.994 [4414 4.18 [16 50] [7665 3.97 [5776 0.824 [5100 2.26 [16 84] [16 68]] [16 100]] [16 25]]] [6 37]] [16 88]] [16 44]] [2640 11.9 [16 62] [16 35]]] [4427 0.443 [190 7.41 [6 66] [6961 5.63 [1429 7.16 [6 35] [16 57]] [16 80]]] [1395 1.57 [16 43] [35 44]]]] [1429 16.3 [6 72] [16 65]]] [26 36]]] [5981 1.22 [2653 0.496 [7304 2.66 [4684 1.28 [2869 1.42 [6449 1.65 [5918 5.14 [6207 16.8 [7370 5.65 [2199 0.444 [2750 2.45 [1754 0.206 [38 97] [38 100]] [2023 2.68 [38 85] [38 50]]] [38 96]] [2750 11.6 [38 49] [38 90]]] [38 68]] [2974 0.161 [4601 6.61 [24 46] [24 75]] [33 33]]] [6 42]] [2707 23.7 [5 25] [38 50]]] [38 45]] [12 85]] [16 62]] [2707 22.8 [17 66] [17 85]]]] [2955 25.3 [5692 1.75 [64 1.01 [2620 3.35 [165 0.283 [190 9.37 [1364 1.28 [7206 0.442 [5102 8.11 [2983 3.35 [190 4.39 [6 35] [5723 6.4 [16 40] [6 58]]] [16 72]] [16 100]] [6406 14.9 [2689 0.221 [16 71] [16 100]] [16 55]]] [16 100]] [1769 1.09 [4851 19.9 [2682 6.17 [2259 5.92 [16 50] [6 46]] [16 50]] [2713 12.7 [18 33] [6 66]]] [6 33]]] [4851 4.83 [16 40] [16 87]]] [6 58]] [18 50]] [26 47]] [2939 67 [6 87] [2667 24.5 [5100 20 [3 21] [6 58]] [6 81]]]]] [7473 0.12 [2939 92.8 [38 94] [38 50]] [38 100]]] [2852 2.87 [16 97] [16 100]]] [4103 11.8 [2890 13 [3836 4.83 [5 85] [5 42]] [5 66]] [37 52]]] [4717 0.484 [2268 1.58 [2849 48.1 [14 94] [14 36]] [14 100]] [14 100]]] [6380 3.1 [3510 1.02 [2584 1.58 [5799 6.4 [5238 0.567 [6251 0.905 [7043 1.93 [5104 2.28 [7031 4.07 [6471 15.1 [6199 11.3 [2717 2.75 [6514 0.582 [7038 9.6 [2955 29.9 [5681 1.02 [6 48] [2978 25.9 [64 4.61 [78 5.56 [2671 1.02 [6409 12.1 [2661 3.92 [37 50] [2707 11.4 [16 50] [5986 19 [7041 1.95 [1769 0.917 [7282 7.36 [5673 10.1 [4939 3.12 [5673 3.64 [6 100] [6 91]] [6 62]] [6 55]] [6 60]] [6 71]] [6 54]] [6 45]]]] [19 44]] [16 85]] [18 46]] [5 42]] [6 85]]] [5099 8.51 [16 63] [4426 7.7 [16 52] [6 90]]]] [18 62]] [16 30]] [16 54]] [18 42]] [16 42]] [16 66]] [16 88]] [6 78]] [16 70]] [16 50]] [18 50]] [6 100]] [37 54]] [16 75]]] [2709 0.0346 [6831 1.15 [6257 5.09 [1369 7.58 [2439 0.943 [1333 2.33 [2655 2.46 [7480 2.28 [89 2.34 [1980 4.12 [2727 0.338 [7419 4.81 [6199 0.139 [4880 2.26 [5801 6.03 [2685 5.61 [4937 16.3 [6701 3.76 [5017 1.22 [2650 0.96 [7038 3.79 [2749 4.85 [2951 16.8 [6 23] [2679 6.65 [1262 0.446 [2259 8.15 [6 38] [38 100]] [38 62]] [38 50]]] [26 66]] [16 47]] [18 29]] [38 62]] [7 40]] [6 76]] [7282 15.7 [1239 40.7 [18 50] [7 42]] [3 21]]] [16 76]] [3422 2.18 [6 59] [5 54]]] [2869 1.37 [2725 2.59 [6133 6.68 [2897 1.68 [2650 2.75 [7370 0.0585 [38 20] [2939 21.5 [5 27] [38 75]]] [16 75]] [16 45]] [16 77]] [23 9.02 [7 94] [7 70]]] [167 0.938 [17 18] [38 57]]]] [7101 1.37 [1429 7.35 [6 26] [16 76]] [7421 1.14 [3 42] [16 100]]]] [16 48]] [7304 4.03 [5799 1.55 [2869 3.14 [23 14.2 [7473 0.269 [6 42] [187 5.68 [38 72] [38 50]]] [2868 0.843 [38 36] [16 50]]] [17 63]] [17 41]] [8 54]]] [38 100]] [7419 0.785 [2861 3.33 [2713 15.2 [6 46] [6 75]] [2656 5.33 [16 33] [16 61]]] [6 77]]] [7421 1.32 [2707 15.7 [6 43] [6 70]] [16 62]]] [7 93]] [6848 31 [38 96] [38 75]]] [7 100]] [5568 6.05 [1899 3.13 [1429 15.7 [2713 1.17 [18 47] [1355 3.08 [192 1.17 [18 83] [18 100]] [18 100]]] [2939 36.5 [18 100] [18 80]]] [18 45]] [18 50]]] [2143 1.77 [6207 3.34 [7132 6 [2526 1.53 [5594 2 [16 36] [18 100]] [16 54]] [18 62]] [7 87]] [18 100]]] [6688 2.21 [1981 1.45 [7231 4.84 [6 40] [16 57]] [1981 3.16 [16 55] [16 80]]] [16 77]]]] [2566 0.265 [2644 0.502 [304 2.73 [5931 4.73 [2713 9.72 [187 5.09 [16 58] [2695 0.711 [16 56] [2649 5.63 [30 100] [30 58]]]] [30 100]] [4738 6.1 [30 60] [30 100]]] [328 1.04 [30 86] [30 100]]] [1262 1 [16 28] [16 58]]] [6 37]]] [190 4.37 [38 47] [38 92]]] [5438 1.26 [1459 0.338 [7260 5.08 [7185 10.6 [5597 1.37 [5969 0.344 [1062 0.801 [6687 2.94 [4154 1 [2939 18.1 [4717 0.988 [18 79] [18 100]] [4895 0.282 [190 7.81 [7255 2.31 [4426 0.763 [18 58] [18 92]] [18 45]] [16 56]] [2466 4.43 [18 88] [18 70]]]] [16 27]] [19 57]] [19 52]] [19 50]] [5130 0.697 [6 41] [5641 3.24 [16 50] [16 70]]]] [18 100]] [16 33]] [16 75]] [19 61]]] [7489 14.4 [38 42] [1897 14.5 [2259 54.9 [673 5.97 [38 100] [38 81]] [7169 0.84 [167 8.41 [7623 1.39 [38 93] [38 100]] [38 85]] [38 100]]] [38 71]]]] [5170 0.587 [1919 0.454 [7619 0.638 [2656 0.284 [2466 3.37 [5412 0.146 [4909 2.01 [7231 9.19 [78 1.27 [1897 0.469 [37 1.06 [2242 1.03 [2850 2.66 [2750 0.344 [6574 0.986 [5801 4.34 [194 12.8 [3867 4.9 [16 33] [16 92]] [18 58]] [26 57]] [17 33]] [38 42]] [18 38]] [38 75]] [17 32]] [6380 2.24 [38 25] [2259 1.51 [1895 16.4 [17 100] [17 85]] [17 100]]]] [5600 1.32 [83 3 [6371 1.73 [17 27] [4851 3.86 [16 84] [18 50]]] [28 30]] [16 76]]] [16 88]] [38 100]] [5368 0.273 [6207 5.13 [7255 1.53 [16 50] [16 40]] [2081 1.25 [26 27] [16 40]]] [16 66]]] [2856 1.7 [16 66] [16 92]]] [45 2.94 [6256 8.63 [5345 4.54 [6134 5.43 [2619 3.84 [7049 4.13 [6659 0.725 [2640 3.06 [7222 1.72 [5797 2.63 [5693 3.25 [1395 1.16 [2980 3.97 [5435 6.4 [5100 15.8 [24 1.02 [6422 0.276 [6940 4.78 [5626 1.63 [1437 0.362 [5578 0.62 [5435 4.38 [7255 10.6 [2678 0.546 [16 36] [16 66]] [16 54]] [2650 2.35 [18 66] [2656 10.6 [5 57] [16 50]]]] [18 42]] [16 26]] [16 77]] [6941 5.36 [4889 0.639 [16 53] [16 100]] [6 54]]] [16 100]] [16 37]] [6 44]] [4746 1.52 [4716 6.12 [5609 1.31 [16 64] [16 73]] [16 41]] [26 52]]] [16 88]] [2654 0.728 [16 75] [16 100]]] [16 94]] [6 44]] [192 0.671 [16 28] [6 50]]] [6 23]] [18 70]] [5435 12.7 [5099 21.7 [16 67] [7048 5.27 [16 71] [6 28]]] [16 90]]] [18 35]] [78 10.4 [7343 6.49 [26 66] [1783 9.35 [16 65] [16 36]]] [26 56]]] [23 40.3 [30 42] [6 57]]] [18 94]] [18 47]]] [28 40]] [30 56]] [1896 0.561 [7255 0.609 [33 37] [2650 5.12 [7232 5.63 [26 64] [26 92]] [16 66]]] [5609 1.15 [16 100] [26 80]]]]]] [3758 0.571 [7354 0.252 [5005 0.432 [5626 0.483 [3008 0.192 [6418 0.651 [194 1.29 [5673 10.5 [5316 1.73 [1844 1.85 [6757 0.281 [731 1.89 [2629 4.35 [929 2.28 [328 2.59 [1391 2.73 [7 99] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 71]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]]] [7371 7.47 [4574 0.172 [6353 0.45 [4851 2.44 [3400 0.888 [3399 0.487 [7476 0.0902 [4017 0.997 [7042 1.35 [7499 0.45 [7323 3.75 [1860 0.0862 [2023 7.36 [7390 0.1 [38 64] [7475 3.33 [6824 0.123 [4895 0.738 [7255 0.654 [2469 1.78 [38 100] [38 77]] [38 100]] [38 81]] [38 69]] [4910 2.43 [7486 3.42 [7255 1.8 [1789 0.835 [2851 4 [2951 16.2 [1587 0.413 [17 40] [1900 0.608 [38 62] [19 44]]] [38 88]] [38 72]] [2259 26.5 [38 57] [38 86]]] [2259 51.6 [38 91] [17 55]]] [38 83]] [38 87]]]] [38 40]] [4537 1.25 [5147 0.759 [7149 5.21 [2885 0.147 [38 71] [38 90]] [38 100]] [38 100]] [187 4.43 [7242 8.77 [6959 2.89 [5545 2.57 [2207 0.532 [6933 0.993 [6108 10.4 [2884 5.11 [2466 3.75 [6385 4.22 [38 54] [38 100]] [1436 5.75 [190 2.72 [7440 1.52 [2849 47.9 [38 88] [38 100]] [38 100]] [38 75]] [4539 6.25 [38 57] [38 92]]]] [2367 2.74 [7472 3.1 [6720 2.2 [1808 1.87 [3819 0.764 [2750 1.26 [38 77] [17 50]] [1587 2.56 [38 100] [38 62]]] [38 100]] [3551 1.17 [61 38.7 [2951 11 [5081 12 [4538 33.8 [17 55] [38 70]] [38 90]] [38 92]] [19 40]] [3121 1.19 [38 84] [38 100]]]] [38 100]] [23 65 [38 100] [38 88]]]] [200 3.8 [38 64] [16 28]]] [38 100]] [38 88]] [17 83]] [38 100]] [4539 2.9 [38 83] [17 53]]] [3983 0.316 [7073 5.91 [6413 0.982 [2631 1.85 [7331 7.46 [5345 1.06 [38 91] [38 100]] [38 78]] [1860 2.49 [38 88] [38 66]]] [17 44]] [38 100]] [6825 2.89 [38 54] [2403 10.9 [38 100] [38 81]]]]]]] [4564 0.495 [1899 3.23 [5381 5.18 [38 90] [17 60]] [38 40]] [8 30]]] [19 63]] [1981 1.49 [97 0.345 [2439 6.14 [2242 0.726 [38 64] [38 93]] [38 100]] [2862 11.7 [6397 2.03 [6342 2.06 [38 83] [38 100]] [2688 12.6 [38 83] [38 100]]] [38 83]]] [38 75]]] [187 6.28 [7390 3.95 [2951 2 [1 22] [2939 20 [38 55] [38 66]]] [5 40]] [38 100]]] [6199 8.22 [7484 0.229 [194 2.54 [6758 1.81 [7486 2.31 [7343 2.33 [6216 0.669 [2862 10.8 [3418 1.29 [2075 0.234 [2389 0.136 [2851 1.25 [7304 2.55 [7475 3 [38 40] [2111 0.668 [38 52] [38 60]]] [18 50]] [8 30]] [38 85]] [6 34]] [5 100]] [1895 5.26 [5209 2.67 [1436 1.27 [2707 10 [5 66] [38 57]] [38 50]] [38 100]] [38 63]]] [1429 33.3 [5 66] [37 63]]] [17 46]] [38 91]] [38 100]] [16 78]] [4685 0.816 [7445 23.7 [7484 4.09 [38 65] [7390 4.95 [7485 1.23 [38 30] [38 60]] [4131 8.42 [7472 8.28 [1899 6.97 [38 100] [38 87]] [38 62]] [38 44]]]] [17 75]] [17 72]]] [7486 6.28 [38 70] [17 40]]]] [5 51]] [5 72]] [7476 0.317 [2951 15 [2081 1.36 [7472 1.23 [17 85] [165 3.43 [14 50] [38 85]]] [6 50]] [38 100]] [1866 4.5 [1429 28.3 [16 50] [4564 4 [187 1.83 [17 54] [5637 7.85 [17 100] [17 75]]] [38 70]]] [1866 7.16 [17 69] [5637 12.4 [17 85] [17 100]]]]]] [6881 0.247 [7476 0.345 [1395 2.71 [38 64] [38 50]] [2854 0.196 [37 43] [17 54]]] [6208 10.1 [14 33] [17 78]]]] [7132 3.28 [38 83] [23 10.8 [38 100] [1748 5.18 [38 100] [16 50]]]]] [6951 0.579 [5891 0.211 [32 29] [17 85]] [17 80]]]] [5976 1.08 [7722 0.868 [5061 0.203 [6521 0.698 [6601 1.04 [5705 1.3 [7255 0.313 [633 2.79 [4612 0.975 [5974 2.26 [2470 4.39 [2826 0.629 [6524 1.07 [7571 1.64 [232 1.23 [2758 3.4 [3929 0.331 [4079 3.3 [826 0.644 [2260 4.97 [5471 1.81 [4338 10.2 [3149 2.65 [7501 1.72 [2259 4.87 [4924 6.46 [719 2.81 [7176 0.682 [5978 2.24 [915 6.54 [4292 1.49 [6949 3.31 [518 3.82 [7661 1.65 [5937 2.24 [2701 4.69 [5047 3.76 [3004 12.8 [1239 11.1 [5381 17.9 [4200 6.55 [361 2.22 [802 13.7 [429 60.4 [2760 26.3 [6544 4.42 [2990 2.2 [731 15.2 [6848 0.538 [5662 4.67 [4956 2.86 [2752 4.56 [20 23] [789 13.6 [4664 10.2 [6541 1.99 [2628 1.56 [4114 1.71 [1391 6.02 [5412 18.9 [4154 15.7 [2526 6.55 [1742 6.17 [4991 9.1 [7491 29.6 [5267 9.18 [435 10 [5480 6.33 [5851 8.63 [328 16.1 [3227 7.94 [3056 4.35 [1888 17 [12 82] [12 65]] [12 100]] [31 50]] [12 55]] [12 64]] [12 100]] [12 71]] [12 42]] [12 100]] [12 81]] [12 100]] [2225 10.4 [2093 3.4 [12 96] [12 100]] [12 87]]] [12 58]] [12 68]] [15 87]] [12 100]] [12 98]] [12 100]] [12 57]] [12 71]]] [38 42]] [12 88]] [12 53]] [31 50]] [12 100]] [36 55]] [12 50]] [12 33]] [5972 28.7 [21 53] [21 88]]] [12 23]] [12 41]] [36 70]] [12 24]] [36 100]] [3 100]] [1888 3.24 [12 50] [12 84]]] [21 89]] [12 100]] [21 88]] [3 100]] [3 46]] [21 41]] [31 100]] [7210 5.37 [5322 2.26 [1400 3.5 [12 88] [12 100]] [12 100]] [12 70]]] [36 64]] [21 95]] [5307 2.33 [2426 6.88 [5468 3.18 [7604 5.88 [2259 21.6 [1980 16.6 [4233 2.49 [3895 6.81 [7449 16.8 [3072 3.03 [731 3.88 [695 2.46 [5812 2.82 [12 45] [12 100]] [36 67]] [31 87]] [12 94]] [12 52]] [31 78]] [3 100]] [2199 3.03 [12 56] [12 70]]] [939 3.55 [7449 15.9 [2411 2.07 [7623 4.37 [1713 9.39 [2657 3.94 [3067 2.59 [4494 2.73 [1429 17.9 [4369 3.4 [3480 7.87 [2939 9.3 [5812 7.46 [5972 17.4 [1 2.89 [36 28] [3 44]] [36 58]] [12 88]] [12 55]] [36 100]] [12 36]] [2939 14.8 [4814 4.13 [5270 7.88 [144 1.13 [7354 1.85 [7419 2.74 [36 57] [36 100]] [36 100]] [36 100]] [36 90]] [36 100]] [12 87]]] [36 100]] [36 100]] [12 100]] [31 100]] [12 50]] [36 100]] [12 40]] [36 73]]] [31 100]] [12 96]] [12 100]] [30 77]]] [12 100]] [36 96]] [2081 3.94 [6173 3.11 [31 68] [31 100]] [31 85]]] [12 100]] [6260 1.47 [36 89] [36 100]]] [79 3.58 [12 94] [12 90]]] [31 100]] [705 0.901 [6873 0.888 [328 0.513 [12 99] [12 100]] [12 100]] [12 100]]] [31 100]] [4414 2.47 [33 100] [33 83]]] [883 13.3 [5322 5.26 [3872 2.42 [896 1.28 [7354 1.57 [2280 1.61 [2701 2.11 [11 3.98 [6727 3.11 [7106 3.82 [2628 4.29 [2260 1.12 [4627 2.86 [978 4.95 [36 81] [31 55]] [12 100]] [36 100]] [12 63]] [36 100]] [12 72]] [31 100]] [12 100]] [36 83]] [36 98]] [811 1.27 [2752 11.2 [36 80] [36 97]] [36 100]]] [12 100]] [12 92]] [12 66]]] [3663 1.31 [5972 8.07 [33 28] [36 74]] [36 100]]] [1418 0.324 [7185 9.26 [5972 8.53 [12 87] [178 3.49 [2826 4.59 [12 97] [12 100]] [12 90]]] [12 85]] [12 100]]] [1001 1.44 [729 2.17 [6074 0.701 [2578 2.62 [2471 3.47 [3243 2.82 [321 1.56 [7654 2.67 [7296 2.44 [1025 12.9 [2143 7.47 [4283 2.42 [7176 4.69 [5978 1.61 [6665 4.85 [6294 5.73 [826 2.93 [6342 3.07 [23 35.9 [7449 26.1 [31 61] [15 88]] [15 71]] [15 86]] [15 81]] [31 100]] [12 100]] [31 100]] [12 82]] [15 81]] [12 53]] [31 75]] [31 100]] [12 78]] [31 100]] [15 100]] [15 93]] [31 100]] [5745 0.701 [15 79] [15 100]]] [31 100]] [31 100]]] [1277 2.26 [523 2.35 [1299 2.88 [2526 7.05 [6015 2.46 [916 8.62 [21 58] [21 86]] [802 2.46 [21 87] [21 100]]] [21 85]] [9 100]] [9 100]] [9 100]]] [203 2.44 [36 96] [36 100]]] [4690 2.59 [21 93] [21 100]]] [7095 1.89 [5831 2.89 [2131 3.12 [6732 6.8 [6276 8.6 [5508 2.45 [5110 16.4 [7259 2.52 [826 0.992 [2990 0.21 [5322 35.6 [915 3.23 [2347 4.44 [2628 41 [4583 1.53 [6124 1.25 [1713 8.55 [4374 1.18 [4895 1.62 [1764 0.491 [791 13 [5972 6.82 [12 77] [2957 8.83 [3243 1.15 [4761 2.3 [12 94] [12 100]] [12 100]] [12 83]]] [12 86]] [5467 2.09 [12 62] [12 100]]] [12 76]] [12 100]] [31 100]] [12 100]] [12 37]] [12 66]] [31 100]] [12 37]] [12 71]] [12 100]] [5110 8.39 [4414 0.632 [434 0.585 [2628 25.1 [12 100] [12 85]] [12 100]] [12 100]] [12 93]]] [12 33]] [12 72]] [31 66]] [31 62]] [12 53]] [31 85]] [15 100]] [15 85]]] [7241 1.72 [4533 5.36 [6260 2.06 [4414 4.67 [899 1.71 [125 1.96 [36 81] [36 100]] [36 93]] [36 87]] [36 100]] [31 50]] [36 100]]] [15 100]] [2058 0.74 [31 75] [31 100]]] [36 100]] [2929 1.65 [1400 0.555 [2849 1.64 [7566 4.47 [3896 1.87 [7185 6.43 [5705 1.33 [6199 0.592 [6865 1.26 [7018 2.17 [978 1.69 [2760 1.62 [2526 7.02 [23 4.76 [36 79] [36 97]] [12 38]] [36 66]] [31 83]] [36 100]] [36 100]] [36 97]] [5198 5.62 [36 100] [36 66]]] [36 50]] [31 100]] [6865 1.12 [2902 1.87 [7520 3.14 [5472 2.04 [36 84] [36 100]] [36 83]] [36 100]] [36 100]]] [12 44]] [5412 7.93 [6727 1.73 [2902 1.1 [144 0.724 [2331 0.808 [7712 3.28 [36 97] [36 83]] [36 100]] [36 100]] [36 100]] [36 100]] [36 85]]] [6230 5.23 [31 83] [31 42]]]] [5838 1.17 [534 0.583 [4279 1.14 [4312 2.46 [3 99] [3 100]] [3 100]] [3 100]] [3 100]]]] [5462 1.95 [5725 5.91 [5151 0.203 [1844 4.07 [2470 11.2 [1884 10.2 [2199 4.4 [3698 0.543 [5447 10.8 [1023 3.86 [1104 0.884 [4171 2.3 [869 0.982 [7241 2.8 [4322 0.371 [4279 0.484 [4851 1.9 [4163 4.76 [32 79] [32 100]] [7354 1.54 [7665 40.5 [32 100] [32 68]] [32 100]]] [4056 0.78 [3483 1.31 [4896 0.471 [4851 0.816 [32 94] [32 100]] [32 100]] [32 100]] [32 100]]] [32 100]] [32 64]] [32 80]] [32 100]] [32 75]] [32 77]] [32 57]] [32 100]] [32 50]] [32 57]] [1888 1.78 [31 97] [31 50]]] [31 100]] [2058 1.36 [4279 6.43 [31 100] [31 83]] [31 100]]] [1429 10 [31 100] [31 81]]] [7512 3.67 [31 92] [32 100]]]] [5402 0.404 [3008 10.5 [407 0.662 [6015 0.394 [896 0.38 [2504 1.33 [328 14.2 [663 1.08 [4895 2.22 [13 95] [13 100]] [13 100]] [25 55]] [13 100]] [13 100]] [13 71]] [25 100]] [14 37]] [13 100]]] [3438 0.154 [5282 0.319 [4154 1.32 [5117 0.318 [2849 0.66 [5089 1.01 [435 0.561 [5969 1.24 [6109 0.327 [663 1.04 [4213 0.994 [1628 4.47 [4114 35.3 [5972 9.38 [1888 1.56 [4523 0.832 [2701 3.29 [2562 0.438 [4555 0.438 [4704 3.51 [5812 4.29 [929 0.431 [996 0.626 [5661 3.71 [9 2.05 [7016 0.84 [3454 0.34 [6490 0.562 [5237 1.66 [760 7.87 [3235 1.68 [5412 7.59 [4781 0.505 [1638 1.5 [6660 1.83 [1405 6.83 [429 41.1 [1184 2.02 [1025 9.5 [6766 11.2 [2184 2.02 [3418 3.31 [6339 7.5 [4799 8.95 [957 1.85 [7354 6.1 [394 4.55 [2749 1.16 [4601 1.17 [3849 0.911 [7729 3.04 [430 2.79 [5110 17.2 [7620 1.38 [6848 0.519 [7737 9.61 [7623 4.61 [3274 2.59 [4775 1.54 [2813 8.54 [1439 1.14 [5211 7.83 [392 5.3 [3851 2.82 [2955 11.7 [7305 8.38 [2234 4.2 [5092 4.26 [1916 51.9 [7139 12.7 [2470 8.27 [6529 9.59 [2165 1.57 [407 3.27 [6230 5.99 [144 7.96 [7600 9.35 [2218 0.262 [5170 1.2 [1659 1.21 [5539 4.56 [248 9.97 [3424 38.3 [2913 10.3 [23 14] [32 50]] [27 100]] [25 26]] [13 100]] [478 0.522 [19 57] [17 50]]] [7512 1.12 [33 62] [33 87]]] [1 75]] [32 66]] [22 51]] [6230 14.8 [14 63] [19 41]]] [23 52]] [15 45]] [28 72]] [4 25]] [14 60]] [23 82]] [22 100]] [2 33]] [25 90]] [38 69]] [35 73]] [28 30]] [22 36]] [23 92]] [22 92]] [2 78]] [11 100]] [4235 1.81 [1 28] [1 40]]] [22 71]] [35 71]] [22 82]] [11 94]] [22 87]] [1 100]] [35 95]] [25 81]] [26 100]] [1239 3.84 [28 36] [28 61]]] [36 40]] [27 62]] [36 68]] [28 100]] [8 100]] [23 73]] [35 100]] [23 42]] [11 94]] [5110 3.05 [2913 7.21 [2897 2.35 [3237 0.49 [1062 16.4 [1913 3.46 [11 27] [2 50]] [23 40]] [11 100]] [28 75]] [22 50]] [11 92]]] [15 100]] [934 1.04 [11 85] [11 100]]] [14 100]] [1997 0.644 [11 65] [11 100]]] [429 8.7 [5120 8.2 [23 23] [22 100]] [6322 4.35 [23 58] [23 100]]]] [11 100]] [23 90]] [11 100]] [4663 2.07 [5412 6.16 [23 67] [23 100]] [23 100]]] [11 100]] [22 100]] [11 100]] [1 65]] [23 98]] [826 2.41 [328 9.45 [7085 3.44 [1389 1.04 [5211 0.924 [4414 1.86 [23 31] [23 60]] [23 100]] [23 66]] [23 100]] [23 58]] [23 100]]] [429 15.9 [2 30] [5 23]]] [7085 8.29 [33 44] [33 62]]] [23 100]] [504 7.23 [7428 0.448 [5227 4.27 [5211 15.8 [2526 28.6 [23 100] [23 70]] [23 100]] [23 80]] [23 88]] [23 80]]] [5480 1.85 [29 91] [29 100]]] [11 100]] [1170 0.581 [2897 4.76 [429 52.3 [2739 9.51 [2905 2.54 [2536 10 [7512 6.96 [7 10] [1062 7.96 [1888 10 [14 14] [429 11 [36 31] [5 33]]] [4 50]]] [2 37]] [4 43]] [4 55]] [27 41]] [6 38]] [2 70]]] [12 65]] [27 71]] [29 100]] [12 100]] [6977 0.296 [695 10.8 [6187 0.894 [4114 0.494 [7016 1.9 [1454 3.97 [5155 0.273 [791 11.4 [1783 4.05 [5883 3.5 [663 16.2 [731 3.15 [2526 13.8 [1429 6.71 [22 46] [18 17]] [0 31]] [5 52]] [28 30]] [5 46]] [7722 1.31 [19 22] [14 44]]] [867 2.31 [429 32.7 [2526 2.32 [22 41] [2 33]] [695 2.71 [29 73] [29 66]]] [36 40]]] [7 26]] [22 83]] [101 1.08 [22 80] [22 100]]] [29 33]] [2 100]] [7491 0.873 [22 63] [22 85]]] [1062 2.93 [17 78] [3905 3.08 [17 60] [17 33]]]]] [22 84]] [815 3.35 [2745 0.888 [2753 1.12 [1995 6.44 [384 0.611 [2845 0.833 [7512 20.8 [663 0.849 [23 68] [29 57]] [23 96]] [23 100]] [23 100]] [11 45]] [26 33]] [23 54]] [26 100]]] [6660 2.37 [685 0.325 [791 13 [4630 1.49 [1025 13 [134 1.76 [7508 1.04 [1084 0.888 [2089 0.546 [2143 5.84 [435 6.85 [23 26] [23 63]] [978 2.11 [27 30] [23 61]]] [23 62]] [23 100]] [23 100]] [2 33]] [6956 0.549 [2081 11.3 [23 87] [23 100]] [23 100]]] [14 40]] [1709 1.33 [6920 2.34 [3237 0.544 [1125 1.63 [1 0.328 [6031 3.5 [4630 0.141 [1980 12.7 [11 20] [4135 3.31 [2763 4.57 [23 42] [23 57]] [27 66]]] [11 50]] [22 100]] [826 0.818 [11 88] [11 100]]] [11 100]] [11 100]] [6920 11.9 [23 85] [23 45]]] [22 100]]] [2526 0.717 [377 0.657 [23 90] [791 15.3 [11 28] [23 66]]] [2151 0.908 [1906 0.266 [386 0.525 [791 8.75 [23 100] [5225 0.519 [1899 1.01 [23 88] [23 100]] [23 100]]] [23 100]] [23 85]] [23 75]]]] [11 100]]] [23 100]] [1600 0.489 [1995 1.69 [2663 0.41 [1218 1.66 [2083 2.86 [5972 3.52 [7583 0.842 [5013 1.77 [5170 4.7 [5100 2.15 [2628 1.2 [248 1.23 [22 24] [26 33]] [2752 6.69 [7255 1.73 [2955 5.96 [16 29] [2862 0.47 [38 100] [38 80]]] [18 50]] [2259 31.7 [2750 1.82 [194 6.91 [7149 2.62 [7449 0.785 [5723 0.338 [16 52] [18 41]] [16 100]] [276 1.06 [6 28] [18 87]]] [6 33]] [5 30]] [38 62]]]] [187 3.65 [7512 4.32 [16 90] [16 71]] [5626 3.95 [16 35] [6 25]]]] [33 63]] [29 100]] [1 82]] [12 90]] [29 60]] [29 86]] [2225 1.62 [7149 6.64 [2709 2.32 [16 48] [1899 2.21 [6 60] [16 50]]] [1675 2.46 [16 88] [16 62]]] [18 66]]] [4851 3.01 [1062 8.76 [1429 37.6 [1094 0.956 [4939 3.03 [2849 14 [11 35] [29 60]] [16 63]] [29 61]] [22 24]] [29 85]] [5 25]]] [7 100]]] [1913 0.318 [436 0.532 [867 0.378 [1094 0.606 [5119 0.752 [2048 0.963 [2485 1.34 [650 1.6 [857 0.432 [11 97] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]]] [1078 6.81 [2081 2.62 [2707 9.43 [906 6.76 [233 0.6 [7729 1.28 [286 10 [3273 1.01 [1704 1.78 [2847 0.453 [4348 3.68 [5034 1.31 [6798 0.952 [3480 1.82 [6899 1.98 [1253 11.3 [1078 2.25 [2793 6.51 [2793 4.59 [560 1.21 [6929 0.615 [1913 13 [2342 0.424 [2745 7.36 [2117 0.618 [4218 1.17 [33 14] [5 35]] [24 33]] [1 71]] [22 45]] [23 54]] [35 41]] [18 100]] [36 55]] [24 54]] [7354 4.77 [5412 4.61 [5 9] [5647 20.1 [22 54] [2 20]]] [5 27]]] [2 57]] [33 76]] [15 50]] [2 100]] [32 52]] [33 100]] [22 66]] [5812 10.3 [17 77] [17 100]]] [1 100]] [5420 0.994 [23 58] [23 100]]] [1 100]] [2005 0.618 [33 100] [33 57]]] [4154 13.9 [33 88] [33 66]]] [38 90]] [6491 0.417 [4365 0.249 [2398 2.01 [2156 2.35 [5211 2.08 [2752 16.3 [2005 2.87 [33 42] [567 2.65 [33 46] [1 100]]] [2526 10.4 [22 11] [1899 8.2 [1 28] [2081 8.16 [4 60] [18 40]]]]] [23 77]] [23 100]] [12 100]] [23 75]] [23 90]]] [2828 0.949 [809 0.107 [5804 0.474 [7620 0.782 [6871 2.37 [6920 0.848 [760 0.15 [7176 2.21 [6446 0.174 [2091 22.8 [4769 1.46 [2011 0.379 [1068 3.76 [7508 0.654 [7340 1.4 [4122 8.4 [2089 0.24 [660 6.07 [685 1.11 [6122 0.654 [6111 3.31 [2531 0.467 [1072 4.22 [1888 0.858 [4761 1.31 [5970 0.808 [4200 2.52 [1567 1.12 [2005 2.98 [6031 2.81 [2178 11.9 [6932 0.33 [1899 0.454 [2764 13.5 [23 23] [22 36]] [7742 0.608 [6342 0.942 [5883 3.84 [5812 4.07 [28 11] [13 63]] [23 88]] [2 25]] [2 33]]] [10 36]] [23 54]] [22 100]] [23 39]] [28 75]] [22 87]] [23 71]] [27 28]] [7413 0.25 [5 19] [2 87]]] [1 69]] [23 100]] [29 70]] [29 61]] [2005 0.736 [5753 1.27 [7665 6.06 [567 1.04 [5647 9.07 [23 69] [22 62]] [23 100]] [14 33]] [28 75]] [1226 1.14 [23 61] [16 45]]]] [2005 1.19 [5412 2.5 [23 52] [23 85]] [23 88]]] [23 76]] [27 88]] [32 68]] [23 100]] [2232 1.97 [23 79] [23 42]]] [221 1.3 [6031 3.53 [23 19] [22 100]] [7101 0.573 [29 34] [29 75]]]] [328 2.56 [29 100] [23 42]]] [4141 8.2 [27 63] [27 100]]] [29 100]] [6524 3 [2178 1.86 [5120 1.22 [1995 2.36 [2259 1.45 [22 45] [33 45]] [2752 14.6 [33 41] [1899 4.91 [22 100] [22 71]]]] [22 100]] [22 100]] [22 100]]] [826 3.68 [23 100] [939 7.03 [23 91] [23 83]]]] [2470 2.16 [5753 10.3 [2768 0.269 [1429 19.7 [5422 0.316 [2766 2.59 [2005 0.239 [2023 0.502 [5110 1.9 [4288 0.5 [934 0.85 [3027 2.86 [23 89] [23 100]] [23 100]] [23 100]] [22 70]] [23 100]] [5651 1.37 [23 100] [23 90]]] [23 85]] [23 100]] [2423 0.139 [1980 14.3 [7512 1.75 [29 38] [24 83]] [23 81]] [23 100]]] [23 45]] [23 50]] [11 61]]] [29 95]] [645 2.75 [2178 3.47 [2823 0.931 [7512 8.43 [4288 13.5 [5799 0.655 [5121 0.914 [1899 4.98 [22 100] [22 91]] [22 100]] [22 100]] [22 90]] [22 53]] [22 100]] [22 71]] [22 85]]] [6110 0.316 [5110 1.46 [10 57] [22 100]] [22 100]]] [22 100]] [28 100]]]] [939 1.32 [2807 0.356 [22 96] [22 100]] [22 87]]] [2470 0.472 [791 8.78 [2849 2.74 [11 26] [16 71]] [3099 0.703 [1436 0.546 [2091 0.671 [3273 17 [11 80] [11 53]] [11 100]] [11 100]] [35 100]]] [3575 1.79 [2763 3.14 [11 100] [2023 0.484 [844 0.708 [11 92] [11 100]] [11 100]]] [11 100]]]]] [7512 4.48 [3008 3.53 [5322 0.456 [630 2.55 [1239 15 [7480 0.981 [4168 0.483 [1411 1.11 [5809 2.87 [828 0.47 [791 10.1 [4420 3.03 [3874 1.86 [3210 0.551 [6155 0.829 [5447 4.74 [4283 1.13 [2707 6.19 [1036 13.5 [3187 2.51 [7627 5.15 [362 3.75 [1391 0.927 [2004 1.06 [685 0.537 [4669 6.67 [5154 15 [1036 3.47 [4764 4.35 [4851 17.8 [221 6.51 [957 2.03 [7424 7.5 [5017 9.79 [23 37.2 [6276 0.911 [6848 5.58 [2180 1.14 [1783 43 [3929 5.82 [4154 9.78 [112 4.83 [35 20] [15 60]] [15 27]] [12 50]] [33 37]] [15 60]] [906 1.01 [6199 11.3 [35 72] [35 50]] [35 100]]] [7 25]] [15 55]] [15 40]] [26 50]] [5 34]] [30 37]] [15 100]] [35 82]] [26 38]] [3 61]] [15 75]] [26 19]] [23 66]] [15 47]] [18 71]] [35 100]] [8 100]] [35 78]] [38 29]] [15 100]] [32 50]] [3458 1.46 [1467 2.89 [5753 2.17 [15 100] [15 50]] [15 100]] [15 100]]] [15 100]] [12 100]] [15 100]] [4398 3.44 [3458 0.33 [6849 1.06 [221 0.544 [6080 0.747 [3045 1.86 [504 1.85 [1888 1.36 [5462 1.19 [7649 0.921 [2081 5.06 [6406 4.29 [2259 19.5 [2752 16.7 [2913 11 [15 55] [15 41]] [7411 4.12 [15 33] [2913 7.77 [7085 13.5 [2476 1.86 [1391 3.18 [2760 1.73 [6155 7.26 [15 71] [15 100]] [15 92]] [15 95]] [15 100]] [15 71]] [15 75]]]] [15 27]] [15 25]] [15 22]] [15 100]] [35 57]] [12 38]] [2081 2.02 [3480 2.35 [1899 1.42 [15 95] [15 90]] [15 100]] [15 88]]] [35 66]] [15 100]] [28 32]] [35 44]] [3929 10 [15 100] [15 85]]] [6155 0.395 [4011 2.36 [3209 0.998 [15 84] [15 100]] [15 100]] [15 100]]]] [15 95]] [4611 6.73 [3357 1.57 [2752 1.95 [15 84] [6342 16.2 [15 100] [15 83]]] [15 100]] [15 92]]] [15 100]] [5809 0.483 [15 94] [15 100]]] [15 97]] [4533 5.41 [1062 9.56 [7424 1.07 [5047 0.938 [4154 3.79 [4854 1.55 [791 21.6 [23 0.891 [6849 1.35 [35 24] [35 100]] [33 17]] [15 46]] [6 44]] [33 38]] [3 100]] [16 25]] [1400 2.86 [15 58] [15 100]]] [791 9.19 [2526 2.79 [35 35] [33 50]] [35 87]]]] [5676 1.69 [23 11.2 [1899 13.3 [1899 1.16 [6379 0.678 [3153 4.74 [6849 8.45 [35 90] [5462 35 [35 50] [35 71]]] [35 100]] [35 97]] [35 100]] [35 85]] [35 50]] [35 93]]] [1412 0.211 [4283 0.285 [5480 10.1 [5322 16.8 [550 0.536 [15 72] [15 93]] [6191 3.66 [7491 2.9 [4416 3.65 [5326 21.8 [15 96] [30 42]] [15 100]] [15 100]] [15 80]]] [15 33]] [15 100]] [15 100]]] [826 1.44 [6310 0.342 [328 10 [4414 4.3 [6675 1.17 [6436 1.75 [5673 1.28 [2849 1.66 [35 35] [30 40]] [30 80]] [30 100]] [30 100]] [15 46]] [35 64]] [630 2.31 [35 77] [35 100]]] [35 40]]] [3886 1.23 [392 8.42 [6155 0.606 [7623 3.5 [495 2.09 [6230 2.22 [2939 20.6 [5034 1.22 [5007 1.17 [560 1.44 [5705 1.22 [3006 0.99 [5110 3.39 [721 1.53 [5809 5.95 [5211 1.21 [1429 44.1 [5267 5.78 [1769 5.51 [36 16] [4 33]] [14 30]] [978 4.93 [32 32] [5 54]]] [7411 10.1 [10 33] [30 94]]] [15 100]] [36 53]] [7657 2.92 [12 66] [12 100]]] [26 100]] [36 100]] [18 50]] [15 53]] [14 53]] [5 60]] [1079 3.43 [3874 3.31 [685 1.04 [1429 28.4 [1899 7.37 [663 5.26 [14 39] [17 75]] [4 50]] [5 59]] [14 40]] [12 100]] [17 25]]] [5 100]] [5122 1.02 [14 27] [30 100]]] [2913 1.45 [2475 0.963 [15 63] [15 100]] [15 100]]] [978 4.37 [26 44] [26 71]]] [15 100]]]] [5364 11.3 [3325 6.68 [6380 2.31 [328 8.49 [2139 0.65 [7491 22.7 [5972 2.84 [1259 1.32 [4239 25.3 [695 1.53 [1062 6.92 [5135 5.13 [1548 0.0985 [1783 0.554 [4241 0.396 [1769 1.17 [5134 16.7 [7664 0.921 [1980 25.8 [20 100] [20 96]] [20 77]] [20 91]] [20 100]] [20 100]] [20 100]] [20 100]] [4437 2.82 [1078 11 [20 100] [20 85]] [20 100]]] [20 97]] [20 66]] [20 93]] [20 82]] [20 85]] [20 75]] [20 57]] [20 66]] [20 60]] [29 75]] [20 72]]] [722 0.227 [3323 7.09 [7665 0.166 [7456 0.473 [6310 0.38 [1930 5.2 [7623 17 [4374 0.606 [7241 0.837 [7434 5.62 [12 100] [5980 5.66 [12 94] [12 100]]] [12 100]] [12 100]] [12 100]] [12 96]] [12 100]] [12 100]] [12 100]] [12 71]] [12 100]]] [3006 0.213 [7007 0.271 [6732 2.16 [5480 0.3 [221 2.46 [232 0.715 [1003 1.17 [6182 0.614 [1341 0.554 [7561 0.73 [2925 0.423 [4369 1.33 [7354 2.28 [4611 0.472 [178 1.93 [5566 1.01 [1980 11.1 [1420 1.65 [1427 3.31 [423 3.57 [7187 2.39 [7512 19.1 [23 24.4 [2628 26.9 [731 1.12 [26 41] [26 79]] [31 45]] [1078 0.607 [33 31] [25 33]]] [25 43]] [26 82]] [26 89]] [25 88]] [25 100]] [2939 6.74 [1993 1.51 [2526 6 [25 32] [25 63]] [25 53]] [1 46]]] [14 100]] [7722 2.95 [6471 4.47 [7552 0.8 [7742 1.42 [182 1.05 [25 48] [25 100]] [25 100]] [5198 3.6 [26 100] [26 50]]] [26 100]] [5693 0.995 [25 85] [25 85]]]] [2748 0.675 [248 21.3 [32 27] [4338 0.709 [2259 0.592 [26 79] [4611 11.4 [26 95] [26 75]]] [26 100]]] [26 60]]] [26 20]] [1899 9.58 [2770 0.855 [1239 21.2 [6189 2.76 [25 44] [25 90]] [33 45]] [25 100]] [1 50]]] [392 9.53 [26 96] [7187 8.17 [26 100] [26 72]]]] [1239 6.72 [1 94] [1 50]]] [38 100]] [25 100]] [25 98]] [23 29.9 [7512 14.9 [6178 2.54 [25 69] [25 100]] [25 63]] [33 91]]] [5393 6.14 [99 1.16 [6320 4.72 [3207 2.86 [7566 3.57 [2521 3.76 [7329 1.13 [7043 0.763 [435 1.95 [248 8.41 [30 46] [2586 2.03 [393 0.268 [144 2.22 [25 80] [25 50]] [25 33]] [25 94]]] [25 100]] [25 100]] [4279 1.31 [25 100] [25 85]]] [25 66]] [25 55]] [16 44]] [1 60]] [1 50]] [1 54]]] [267 2.54 [560 0.503 [2763 2.9 [6152 2.82 [248 14.7 [18 60] [6311 1.84 [4235 13 [6073 1.52 [2755 8.13 [5267 0.248 [26 61] [26 100]] [685 9.15 [26 93] [695 0.81 [26 61] [6581 4.46 [26 100] [26 88]]]]] [26 100]] [26 100]] [19 46]]] [26 60]] [8 28]] [283 0.44 [18 69] [18 100]]] [5482 10.4 [18 96] [18 88]]]] [7576 0.931 [5340 1.11 [6826 2.96 [732 2.37 [5482 3.88 [7187 1.26 [1023 7.73 [26 52] [26 100]] [7712 0.568 [379 0.975 [432 1.14 [26 82] [26 100]] [26 100]] [26 100]]] [18 72]] [719 5.33 [1025 5.97 [4851 1.34 [7185 3.78 [26 92] [26 100]] [26 100]] [26 80]] [26 50]]] [18 100]] [18 90]] [6177 20.6 [25 77] [25 100]]]] [1993 0.569 [6177 0.543 [18 80] [5897 0.277 [180 0.281 [5871 1.66 [25 100] [25 83]] [25 100]] [25 100]]] [25 100]]] [3309 0.978 [2717 3.38 [7231 7.61 [7668 3.9 [269 0.494 [677 1.49 [4604 1.55 [2667 2.08 [7038 2.91 [5198 2.17 [7681 9.27 [1400 25.9 [985 5.71 [134 1.72 [5154 0.329 [4427 0.546 [673 6.5 [2707 15.1 [2530 0.68 [26 94] [26 100]] [26 75]] [254 5.63 [26 100] [26 88]]] [26 75]] [26 87]] [26 100]] [26 85]] [26 87]] [26 72]] [26 100]] [26 50]] [26 57]] [26 75]] [26 80]] [5316 0.569 [3007 0.987 [26 83] [26 38]] [26 88]]] [26 60]] [26 57]] [26 55]] [26 57]]]] [4154 3.06 [514 0.16 [4810 0.746 [6803 0.9 [5048 1.2 [578 0.55 [791 24 [594 0.589 [563 1.49 [5049 0.327 [2752 3.63 [1332 3.48 [5410 15.7 [3008 3.45 [6048 0.571 [5034 1.33 [4218 5.93 [1025 6.37 [5086 2.42 [7211 2.01 [536 7.95 [6306 2.42 [617 0.272 [1338 4.51 [4684 1.61 [7451 4.98 [4279 2.36 [627 15.1 [5969 1.12 [3628 2.12 [6653 10.1 [5154 8.97 [7255 6.85 [2081 0.873 [21 81] [7032 1.91 [21 94] [21 71]]] [21 53]] [21 40]] [9 40]] [21 100]] [21 100]] [3 71]] [3 100]] [21 100]] [3 57]] [21 54]] [9 100]] [3 90]] [3 57]] [9 62]] [9 75]] [21 100]] [3 100]] [3 100]] [21 100]] [3 100]] [3 59]] [9 84]] [1 2.41 [2199 0.234 [12 35] [21 62]] [21 33]]] [5439 10.2 [6892 0.485 [505 0.739 [1025 7.25 [688 0.327 [9 50] [6260 7.01 [688 4.4 [9 94] [9 56]] [9 92]]] [21 85]] [9 70]] [21 100]] [21 100]]] [9 93]] [9 100]] [635 0.487 [3480 0.348 [5047 1.27 [939 0.505 [6268 2.49 [5381 13.5 [1239 73.1 [7176 2.99 [5040 0.546 [524 0.797 [6132 3.76 [1906 2.62 [3843 1.06 [1400 2.16 [7211 1.22 [2023 0.666 [4569 4.76 [29 1.19 [747 1.56 [7465 1.04 [2155 2.89 [526 1.11 [2002 26 [2243 1.14 [699 1.41 [2146 12.1 [6199 2.18 [918 1.27 [688 1.4 [5693 4.76 [21 62] [21 83]] [2083 1.32 [21 82] [21 100]]] [21 90]] [21 91]] [21 80]] [4414 3.98 [21 95] [21 60]]] [3 50]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [3 44]] [21 100]] [21 84]] [21 46]] [15 51]] [15 40]] [6085 1.63 [429 75.8 [21 77] [21 100]] [21 100]]] [9 100]] [6320 4.13 [645 1.3 [815 2.62 [21 96] [21 100]] [21 100]] [21 75]]] [6191 13.6 [5972 0.546 [5329 9.08 [21 100] [21 84]] [21 100]] [21 98]]] [12 46]] [21 56]] [3 60]] [9 100]] [32 55]] [3 100]] [15 66]] [5049 11.5 [21 55] [21 75]]]] [614 1.65 [569 1.53 [5915 12.5 [9 100] [9 87]] [9 100]] [9 100]]] [3 100]] [6131 0.78 [538 9.98 [6713 2.02 [7419 0.753 [5972 0.27 [538 4.02 [21 50] [9 100]] [1322 0.135 [1299 0.504 [9 90] [9 100]] [9 100]]] [9 66]] [9 60]] [21 62]] [9 100]]] [1342 1.82 [6407 8.45 [112 13.4 [6909 0.384 [6886 0.632 [4811 4.49 [1980 15.6 [6048 13 [4794 5.2 [4794 1.89 [6314 0.386 [1239 45.6 [21 100] [21 90]] [21 100]] [7354 0.359 [7428 1.69 [5193 0.852 [21 93] [21 100]] [9 57]] [21 100]]] [21 100]] [21 88]] [4794 15.1 [693 2.68 [21 97] [21 100]] [21 58]]] [21 83]] [916 3.73 [21 100] [21 65]]] [21 77]] [21 66]] [9 50]] [9 77]]] [1987 1.59 [7088 0.457 [659 0.49 [5049 3.13 [9 76] [9 97]] [9 100]] [9 100]] [9 40]]] [5969 0.546 [5208 1.58 [535 1.12 [6260 1.55 [504 1.66 [5454 1.32 [237 0.924 [2178 23.4 [1391 0.898 [2752 8.54 [2418 0.634 [538 1.66 [5509 0.797 [537 0.649 [791 18.9 [7491 7.13 [3 94] [3 83]] [429 67.6 [3 85] [3 39]]] [3 100]] [3 100]] [9 55]] [3 100]] [2752 21.1 [3 45] [15 82]]] [15 100]] [3 50]] [3 100]] [3 57]] [15 70]] [756 0.438 [3 98] [3 100]]] [5851 2.57 [5454 1.36 [21 97] [21 100]] [21 55]]] [5938 0.982 [641 1.14 [2998 1.82 [6871 0.907 [606 2.42 [6673 1.82 [1018 1.48 [4279 10.2 [21 100] [3 50]] [3 100]] [3 100]] [3 85]] [3 100]] [3 100]] [3 100]] [21 100]]] [21 55]]]] [3971 1.87 [7258 0.196 [6290 0.11 [1239 0.456 [5731 0.33 [6653 0.621 [6920 1.35 [7305 10.2 [11 100] [11 60]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]] [11 70]]] [4353 0.464 [4200 0.792 [5019 2.87 [1429 56.6 [6763 1.69 [6955 1.92 [3388 0.654 [3332 5.02 [2978 1.98 [1913 1.59 [2955 3.46 [3308 1.86 [5637 1.05 [7413 3.09 [3140 2.97 [731 3.05 [2259 3.86 [4398 2.4 [5673 1.71 [831 5.03 [23 0.805 [2023 1.95 [35 81] [35 50]] [35 27]] [35 100]] [35 30]] [35 100]] [35 25]] [26 35]] [35 80]] [26 26]] [16 50]] [30 50]] [37 54]] [30 60]] [26 85]] [3849 8.43 [3561 1.59 [4279 0.686 [4070 1.12 [6616 13.3 [5539 6.02 [2755 2.59 [203 9.38 [6230 0.843 [7512 7.92 [23 6.14 [35 64] [35 26]] [7 27]] [5 27]] [13 87]] [26 45]] [13 100]] [16 20]] [35 100]] [3450 0.711 [4622 8.02 [774 6.96 [1776 5.62 [35 60] [35 100]] [35 90]] [35 50]] [35 84]]] [30 100]] [4876 8.56 [2826 4.5 [3710 26.9 [421 2.18 [3457 1.07 [3234 8.34 [2081 14.5 [144 0.238 [2491 4.5 [3444 13.2 [5673 9.4 [673 13.5 [1161 0.971 [6732 1.46 [5462 15.9 [3130 14.4 [1429 14.1 [6199 17 [2259 16.6 [3851 1.31 [837 30.4 [2753 11.9 [831 12.5 [4279 53 [4279 5.38 [35 80] [35 100]] [35 71]] [35 100]] [35 33]] [35 57]] [35 95]] [35 52]] [6199 27.7 [27 36] [35 83]]] [1511 7.82 [35 74] [35 50]]] [35 75]] [35 63]] [25 33]] [35 100]] [26 80]] [35 70]] [1078 19.7 [35 95] [35 100]]] [8 60]] [26 23]] [35 68]] [35 96]] [1031 1.6 [35 90] [35 96]]] [26 71]] [35 36]] [5 38]] [8 30]]]] [7098 0.91 [4181 0.359 [3273 2.55 [5673 0.833 [1961 2.08 [2628 5.04 [3711 8.13 [2232 7.66 [3444 4.53 [4611 5.87 [6115 3.88 [35 95] [35 88]] [35 90]] [35 68]] [35 60]] [35 100]] [35 40]] [35 90]] [3332 24.9 [35 100] [35 87]]] [35 100]] [35 83]] [35 100]]] [3667 1.34 [7169 3.11 [673 10.1 [35 20] [26 100]] [14 60]] [35 100]]] [5171 1.32 [26 66] [26 100]]] [895 1.54 [2488 7.79 [3850 5.26 [23 28.6 [4533 4.44 [4895 5.59 [7322 46 [3849 3.4 [35 74] [1776 9.5 [5676 15.2 [2178 0.441 [3849 8.47 [35 88] [1170 5.62 [3710 9.8 [3633 9.18 [5680 14.3 [978 9.18 [3435 12.8 [740 2.93 [6199 11.8 [35 98] [1429 72.2 [35 100] [35 53]]] [35 100]] [35 90]] [35 84]] [6203 4.85 [35 82] [35 85]]] [35 88]] [35 75]] [35 100]]] [35 100]] [35 55]] [35 80]]] [35 75]] [33 50]] [35 84]] [17 40]] [1031 6.11 [33 41] [35 78]]] [8 86]] [35 100]]] [6616 2.86 [6203 3.91 [2259 1.85 [5262 1.85 [35 39] [13 100]] [22 36]] [13 75]] [7187 2.04 [26 45] [26 90]]]] [978 1.58 [13 26] [2752 35.7 [26 57] [5 72]]]] [1913 9.88 [30 80] [30 100]]]] [1343 1.12 [7571 0.229 [6525 0.756 [7620 0.497 [7529 0.352 [3604 0.942 [5222 0.644 [7535 0.309 [5194 0.331 [5211 2.48 [4494 0.497 [975 0.192 [6178 1.52 [2795 0.445 [2470 3.39 [7205 1.28 [1181 1.73 [3011 0.719 [6668 1.38 [896 0.402 [4395 0.222 [685 0.563 [3652 4.16 [7722 2.2 [4205 0.595 [1 2.53 [209 0.445 [1389 1.82 [7665 2.05 [3573 0.445 [221 2.85 [6859 2.5 [6235 2.62 [2411 6.14 [4364 2.36 [400 4.8 [6857 2.59 [7446 1.36 [178 1.15 [2663 1.73 [868 2.28 [766 0.921 [1895 0.172 [4518 1.29 [1285 0.502 [2139 1.42 [6732 2.89 [131 1.41 [268 2.65 [1239 16.9 [4147 15.6 [2259 34.8 [2199 0.378 [7428 0.42 [24 22] [10 44]] [12 38]] [34 40]] [24 100]] [9 17]] [25 92]] [36 50]] [28 70]] [34 81]] [9 70]] [24 100]] [38 38]] [3 50]] [34 100]] [16 75]] [24 100]] [38 61]] [28 60]] [34 100]] [2488 3.94 [2342 3.7 [34 66] [34 100]] [34 100]]] [24 73]] [34 100]] [7271 2.62 [4147 1.69 [208 1.97 [663 1.33 [2841 0.499 [4611 1.86 [791 5.68 [1913 1.37 [24 51] [4023 0.703 [24 85] [24 100]]] [36 53]] [36 50]] [6920 2.96 [36 81] [36 100]]] [36 51]] [24 84]] [24 95]] [31 100]]] [6998 1.66 [6856 1.85 [28 35] [28 96]] [28 100]]] [10 100]] [3660 1.41 [6853 5.88 [36 34] [3008 13.4 [7595 2.01 [2260 3.42 [4956 12.1 [2832 7.09 [721 3.14 [7233 3.6 [7354 1.46 [6859 6.1 [2516 1.92 [1429 27.5 [24 41] [36 56]] [24 100]] [1899 35.5 [4414 1.62 [1702 1.79 [7106 18.6 [36 55] [24 100]] [36 87]] [31 87]] [24 80]]] [36 80]] [32 100]] [36 83]] [791 11.9 [36 86] [36 66]]] [24 87]] [429 17.9 [36 85] [36 100]]] [36 100]] [25 61]]] [24 100]]] [885 1.61 [24 93] [24 100]]] [24 87]] [1997 2.34 [5462 0.978 [3576 0.986 [1899 19 [4815 2.04 [16 1.29 [6859 1.35 [36 30] [1899 3.61 [36 88] [36 80]]] [36 100]] [36 90]] [10 61]] [36 100]] [36 77]] [36 45]]] [28 83]] [2913 1.37 [4326 0.548 [7583 1.06 [7354 1.2 [1239 5.82 [5198 9.29 [4908 1.65 [2628 3.65 [1078 17.7 [5716 1.39 [7590 4.27 [36 91] [36 100]] [36 100]] [36 73]] [36 75]] [36 66]] [36 77]] [24 66]] [7399 1.54 [6401 0.829 [36 98] [36 100]] [36 100]]] [36 100]] [36 58]] [32 97]]] [1888 14 [7512 6.96 [7382 1.01 [24 96] [24 100]] [5673 2.11 [24 66] [24 83]]] [24 80]]] [2488 4.4 [2763 1.65 [5480 5.62 [6363 0.769 [4369 7.12 [972 9.81 [4533 0.291 [5753 1.29 [28 75] [28 90]] [28 100]] [28 71]] [25 54]] [28 100]] [18 50]] [28 50]] [8 100]]] [28 94]] [5812 1.05 [6230 2.2 [7705 0.766 [394 0.47 [2458 0.766 [5698 1.22 [1239 2.68 [6338 2.44 [1919 5.41 [2341 1.12 [5034 2.87 [1429 1.96 [24 62] [1888 10.6 [3905 1.06 [5693 1.41 [17 2.1 [4908 1.46 [957 10.2 [2311 2.02 [5692 5.77 [631 6.05 [36 73] [36 91]] [36 90]] [36 100]] [36 50]] [36 100]] [36 88]] [2752 22.2 [631 4.02 [24 48] [36 83]] [36 83]]] [36 100]] [36 66]]] [32 57]] [24 100]] [18 66]] [19 80]] [3907 0.519 [24 53] [36 100]]] [24 100]] [24 77]] [18 66]] [36 100]] [2593 2.51 [5413 0.568 [731 1.01 [5692 3.35 [32 44] [32 58]] [18 90]] [7 37]] [19 100]]] [24 100]]] [4006 2.45 [2832 1.4 [28 66] [28 100]] [28 100]]] [36 100]] [4569 4.26 [1429 15.7 [36 87] [36 100]] [36 90]]] [2259 70.8 [36 100] [36 57]]] [23 6.13 [4409 1.02 [7168 1.68 [7187 0.455 [7512 0.506 [31 51] [2259 8.23 [25 55] [31 96]]] [26 100]] [31 100]] [31 100]] [1370 1.47 [15 16] [38 100]]]] [1696 1.71 [5267 3.59 [6732 6.29 [2518 12.3 [4040 17.5 [891 0.835 [2773 0.747 [1389 1.01 [4154 49.6 [3424 1.64 [2466 6.37 [2827 1.95 [2341 0.445 [6336 0.59 [7591 5.6 [4146 5.36 [4279 4.36 [1783 6.3 [24 100] [24 88]] [1020 1.13 [4023 1.74 [4338 15.2 [24 95] [24 100]] [24 100]] [24 100]]] [24 90]] [24 85]] [24 100]] [24 100]] [24 77]] [24 80]] [24 77]] [24 77]] [24 100]] [24 100]] [24 100]] [24 80]] [4545 0.503 [2752 16.7 [24 76] [4338 21.9 [24 80] [24 91]]] [24 100]]] [24 75]] [3642 5.42 [1239 3.97 [24 82] [24 100]] [19 62]]] [19 47]]] [25 100]] [2752 26.8 [1783 2.17 [2199 3 [1206 0.882 [28 93] [28 100]] [28 75]] [429 18.8 [28 70] [28 100]]] [610 13.6 [5968 0.693 [2787 4.04 [4279 0.99 [710 0.459 [4414 0.384 [221 0.911 [28 97] [28 100]] [28 100]] [28 100]] [28 100]] [28 83]] [28 100]] [28 87]]]] [36 100]] [7497 0.208 [5728 0.697 [4799 0.402 [1161 0.508 [1116 0.688 [7176 0.754 [1300 1.17 [1611 0.914 [5467 0.924 [5439 5.59 [6230 12.1 [2259 7.18 [6859 2.53 [30 24] [30 75]] [80 1.08 [4414 7.48 [880 2.51 [2434 2.39 [5345 2.32 [7411 4.67 [7665 4.99 [5647 2.02 [22 47] [22 90]] [22 36]] [30 80]] [30 75]] [30 100]] [22 100]] [30 50]] [22 100]]] [22 70]] [10 80]] [10 100]] [30 100]] [10 100]] [7428 0.949 [7181 2.04 [5283 0.944 [859 2.71 [1753 3.56 [2902 0.463 [22 88] [22 100]] [22 100]] [22 100]] [22 100]] [22 90]] [22 75]]] [1429 20.3 [5034 6.43 [30 100] [30 88]] [30 100]]] [10 100]] [4373 1.25 [221 5.72 [558 0.618 [10 76] [10 100]] [30 75]] [10 100]]] [24 82]] [22 100]]] [7335 0.241 [1 0.421 [5462 4.86 [392 5.83 [4395 6.39 [610 0.35 [3338 0.273 [28 97] [28 100]] [28 100]] [28 87]] [28 80]] [28 83]] [28 66]] [28 75]]] [6338 1.25 [695 6.11 [2760 6.77 [1783 10.8 [1062 6.04 [4357 7.98 [2526 12.6 [2517 0.509 [4154 12.2 [24 72] [6869 0.77 [1628 10.4 [2453 0.734 [7381 0.677 [24 90] [24 100]] [24 100]] [24 80]] [24 100]]] [3659 10.2 [24 100] [24 92]]] [4154 17.3 [4279 0.465 [24 54] [429 8.41 [24 72] [24 100]]] [24 100]]] [24 90]] [978 1.24 [24 60] [24 100]]] [24 53]] [36 55]] [36 73]] [3637 0.942 [24 78] [19 71]]]] [3052 0.605 [6605 1.03 [2899 1.2 [1679 0.644 [30 96] [30 100]] [30 100]] [30 100]] [30 100]]] [6517 1.7 [429 15.7 [30 33] [6802 0.96 [28 94] [28 100]]] [28 100]]] [5654 2.19 [4045 0.959 [4806 1.12 [1888 4.84 [1783 1.83 [7535 3.46 [4299 3.04 [2453 12.9 [24 89] [24 72]] [24 79]] [24 100]] [4169 3.38 [791 10.8 [24 83] [1025 18.8 [19 50] [19 87]]] [19 55]]] [3637 2.63 [24 92] [24 83]]] [19 42]] [24 50]] [19 75]]] [5904 0.183 [5282 0.257 [2904 0.627 [1911 0.231 [22 70] [6524 3.25 [711 0.607 [4154 1.5 [22 100] [22 83]] [22 100]] [22 80]]] [28 85]] [22 100]] [14 35]]] [4235 1.65 [5693 0.3 [2752 16.1 [6853 48.3 [28 88] [28 66]] [5007 3.17 [1078 16 [28 100] [28 88]] [28 90]]] [28 100]] [25 61]]] [5904 3.11 [7305 2.38 [2259 3.41 [36 55] [1986 5.59 [2526 6.37 [7732 0.327 [4185 10.1 [4088 0.4 [2628 8.85 [6724 6.56 [36 100] [36 83]] [36 89]] [36 100]] [36 83]] [36 100]] [36 77]] [36 54]]] [36 60]] [7583 0.782 [36 100] [19 72]]]] [6729 0.855 [6202 2.44 [2025 0.209 [7067 0.214 [2902 3.24 [418 1.27 [1078 19.5 [28 100] [968 3.34 [28 95] [28 80]]] [28 75]] [28 85]] [28 100]] [28 100]] [28 80]] [28 84]]]] [7255 0.415 [3770 0.394 [30 0.157 [802 0.613 [6416 0.162 [6269 4.55 [884 0.162 [5835 1.69 [6935 5.48 [1180 2.11 [7389 1.15 [2752 3.66 [6530 2.95 [2993 0.77 [1 1.53 [5814 1.07 [36 53] [13 100]] [36 100]] [36 86]] [36 100]] [632 0.24 [811 0.0963 [5412 11.2 [5402 1.33 [5472 23 [4851 0.261 [1429 1.84 [13 42] [435 8.15 [5647 5.16 [429 11.4 [36 86] [1783 0.395 [3905 1.65 [4270 0.736 [4908 0.858 [36 98] [36 100]] [36 100]] [4615 2.44 [6261 0.835 [7698 3.18 [36 71] [36 100]] [36 100]] [36 100]]] [36 100]]] [36 75]] [13 50]]] [4042 0.322 [2241 0.662 [6859 0.361 [36 98] [36 100]] [36 66]] [36 100]]] [36 52]] [13 100]] [13 85]] [3916 1.96 [36 100] [36 93]]] [36 100]]] [13 100]] [13 100]] [13 77]] [13 100]] [36 100]] [791 15.9 [13 50] [13 100]]] [13 100]] [13 100]] [13 100]] [13 100]] [3431 0.332 [3008 1.37 [5779 2.99 [2793 0.327 [6970 2.71 [144 24.8 [7259 1.5 [4843 1.51 [7024 18 [7601 4.95 [699 4.31 [1429 0.668 [13 97] [6269 0.34 [1218 1.19 [144 5.25 [13 100] [430 0.227 [13 97] [13 100]]] [13 100]] [13 100]]] [13 90]] [13 86]] [13 85]] [13 85]] [36 60]] [13 84]] [2488 6.92 [13 50] [13 100]]] [36 70]] [36 100]] [7009 1.67 [36 83] [13 87]]] [36 100]]]] [2913 4.1 [695 0.234 [5859 1.2 [4799 4.96 [3055 4.5 [1391 5.69 [2004 2.69 [4938 3.86 [1143 1.4 [5838 9.46 [811 1.22 [6048 8.65 [7363 0.695 [6177 16.5 [6395 16.1 [2752 18.2 [2151 1.71 [3527 27.4 [5920 0.493 [4832 10.6 [6970 6.87 [3494 7.38 [1906 10 [3332 9.9 [7512 24.3 [1068 6.67 [6703 5.89 [3929 7.23 [896 1.82 [5015 4.82 [7241 14.9 [7695 0.158 [6732 8.49 [996 0.124 [3008 21.4 [2334 0.413 [6294 5.38 [2005 12.8 [2993 18.2 [2225 2.84 [929 0.403 [2604 0.126 [4312 12.3 [6848 1.67 [992 0.813 [7176 0.754 [6653 1.31 [1483 0.792 [8 99] [8 100]] [8 100]] [8 100]] [8 100]] [8 83]] [8 77]] [8 100]] [8 100]] [8 88]] [8 88]] [8 85]] [7413 2.7 [8 99] [8 100]]] [8 100]] [8 77]] [8 100]] [8 87]] [8 100]] [8 93]] [8 87]] [8 75]] [5218 0.324 [4852 0.835 [8 90] [8 100]] [8 100]]] [32 37]] [8 97]] [8 83]] [35 66]] [8 95]] [8 77]] [8 55]] [2 50]] [8 70]] [8 72]] [8 55]] [4288 0.248 [4606 0.634 [2596 1.23 [2582 0.775 [8 92] [8 100]] [8 100]] [8 100]] [8 52]]] [8 42]] [25 55]] [8 50]] [35 50]] [2384 1.62 [10 69] [10 100]]] [5699 1.5 [35 83] [35 100]]] [8 50]] [8 50]] [5911 13.2 [826 1.39 [996 5.5 [5969 0.858 [23 71] [23 100]] [8 55]] [23 100]] [8 50]]] [5851 5.13 [22 61] [0 81]]] [0 100]] [3829 4.74 [7009 3.99 [8 55] [8 37]] [8 100]]] [0 93]] [4799 1.15 [6265 0.353 [2589 0.536 [1 1.12 [6791 1.01 [5692 0.792 [8 56] [8 80]] [22 88]] [10 71]] [8 100]] [22 75]] [6350 1.76 [10 66] [10 100]]]] [1980 11.7 [791 4.73 [0 66] [0 100]] [0 70]]]] [4154 8.01 [5891 0.276 [4218 0.512 [916 0.239 [1800 0.739 [284 0.719 [907 0.756 [4430 1.16 [6413 0.392 [2748 0.79 [2818 0.711 [5393 6.49 [5041 2.5 [6133 1.01 [537 0.711 [7185 16.8 [4576 3.2 [538 5.12 [1328 2.37 [7571 0.35 [2764 0.0511 [917 1.82 [3222 3.1 [7203 0.623 [4863 1.43 [3458 0.78 [6383 1.23 [178 2.08 [435 8.3 [7461 7.21 [7512 1.32 [4553 1.58 [31 52] [16 50]] [2302 0.536 [248 17.1 [1400 0.728 [7665 19 [736 7.65 [4079 0.998 [6859 1.28 [685 3.98 [1713 2.04 [6732 1.14 [6653 0.671 [7009 2.47 [2267 1.35 [31 84] [31 100]] [31 72]] [31 100]] [13 41]] [31 100]] [18 66]] [31 100]] [31 100]] [31 69]] [2913 24.3 [721 4.07 [31 96] [31 75]] [31 75]]] [31 100]] [31 66]] [31 100]]] [31 50]] [31 50]] [31 50]] [19 37]] [15 33]] [3 100]] [18 33]] [8 83]] [3 60]] [11 27]] [568 3.35 [7296 0.196 [896 0.35 [2340 0.763 [7428 8.07 [31 100] [31 80]] [31 100]] [31 100]] [31 100]] [31 87]]] [3 100]] [21 83]] [12 44]] [18 26]] [3 100]] [3 42]] [21 100]] [3 57]] [12 100]] [38 55]] [6416 0.81 [7 68] [13 100]]] [15 83]] [3 51]] [18 78]] [38 94]] [4530 0.358 [429 85.9 [3 52] [21 100]] [21 85]]] [7623 1.93 [915 1.23 [3 74] [3 100]] [7 42]]] [4916 0.671 [5941 4.23 [3 58] [3 100]] [3 100]]] [1764 0.197 [2380 1.38 [2969 2.65 [682 1.22 [5047 0.595 [766 2.02 [2064 1.04 [2259 4.35 [896 0.457 [756 5.88 [5405 8.71 [4154 10.2 [3 18] [7449 4.2 [688 12.5 [2526 12.8 [5692 2.67 [916 3.27 [3 94] [3 100]] [3 100]] [3 87]] [3 66]] [3 100]]] [31 100]] [3 100]] [13 50]] [3 53]] [31 50]] [3 100]] [3 100]] [31 100]] [31 100]] [31 100]] [6544 1.46 [31 92] [31 100]]]]] [2611 0.602 [665 0.105 [6537 0.58 [6584 0.0664 [7547 0.121 [6983 0.295 [7516 0.294 [4519 0.154 [6866 0.21 [4889 2.72 [7583 0.126 [4146 0.455 [7327 0.305 [2453 0.371 [6099 0.975 [2752 1.78 [6732 0.169 [1919 3.94 [2541 6.09 [7301 0.543 [5509 7.64 [5964 3.83 [1384 2.02 [1888 3.96 [791 7.48 [6289 3.79 [7404 1.26 [7665 16 [5632 0.183 [2574 11.6 [5090 7.03 [6524 5.32 [5692 11.9 [5851 1.73 [299 0.975 [3008 11.1 [2955 1.4 [7034 1.38 [5409 7.02 [178 2.18 [6 21] [30 33]] [6 91]] [2 100]] [6 44]] [6 35]] [6 100]] [33 50]] [26 92]] [25 96]] [16 64]] [2 84]] [1696 1.38 [7038 0.864 [1834 1.81 [33 23] [30 66]] [6199 0.996 [7446 0.842 [4895 0.583 [6406 0.191 [190 2.95 [16 75] [16 90]] [16 66]] [16 72]] [6 50]] [7 78]]] [26 55]]] [5692 12.2 [5797 10.5 [2551 6.46 [2079 7.05 [7381 9.18 [5099 3.23 [3558 7.94 [4154 2.16 [6199 5.26 [7149 17.3 [5820 8.47 [701 3.7 [6279 29.9 [2849 22.2 [299 2.15 [1364 4.78 [2962 10.7 [6098 3.03 [6399 2.89 [7491 25.9 [5316 9.43 [2616 19.5 [7722 8.75 [6 16] [22 44]] [2597 7.25 [5211 17.9 [4833 7.94 [6361 18.2 [6674 14.3 [6 44] [6 85]] [6 100]] [2 41]] [24 77]] [2 80]]] [7 87]] [2 88]] [6 100]] [6 88]] [31 50]] [6 100]] [6 96]] [16 50]] [2 100]] [31 100]] [4 87]] [6 90]] [7 32]] [2 76]] [7 36]] [6 88]] [1640 14 [2 60] [2 50]]] [6 86]] [6 100]] [6 100]] [25 55]]] [4736 2.85 [7419 0.296 [5962 1.55 [6 95] [6 100]] [6 100]] [6 83]]] [6020 26.1 [2558 7.23 [1429 2.42 [6 86] [978 2.35 [1239 50.3 [6 100] [6 96]] [6 100]]] [6 70]] [6 71]]] [2739 4.76 [429 7.94 [31 46] [24 15]] [4 81]]] [4533 3.56 [4611 0.47 [4 18] [8 45]] [2 50]]] [896 1.03 [6 90] [5093 16 [6138 0.593 [3008 12.7 [6 85] [6 100]] [6 100]] [6 57]]]] [5962 15.2 [2030 2.67 [2558 1.26 [6 90] [6 50]] [6 100]] [6 96]]] [5 62]] [5747 1.77 [2939 22.6 [2613 1.76 [6 91] [6 100]] [4675 1.11 [6 42] [6 80]]] [6 100]]] [24 76]] [4607 0.551 [2526 30 [6098 2.35 [6 66] [16 60]] [2279 1.95 [7237 7.22 [7419 0.358 [6 83] [5723 1.15 [1913 0.507 [6276 2.37 [6100 9.83 [6 100] [6 94]] [6 87]] [6 100]] [6 100]]] [6 63]] [6 95]]] [6 77]]] [4832 1.27 [6735 0.457 [6977 7.82 [3667 5.97 [3027 0.337 [4719 2.26 [5797 9.45 [6342 8.24 [1400 3.79 [906 8.12 [685 0.861 [7512 55.6 [7132 3.8 [5769 12.5 [2592 17.5 [5435 2.9 [2081 16.2 [791 42.4 [7722 7.47 [6077 2.49 [6549 0.169 [791 19.4 [17 16] [4 19]] [19 33]] [2 37]] [7 15]] [24 56]] [2 40]] [18 100]] [4 64]] [2 72]] [4 92]] [5509 7.69 [17 22] [5 78]]] [7734 1.46 [18 40] [6 44]]] [26 29]] [26 32]] [7 41]] [4 94]] [17 68]] [4 76]] [2 83]] [5 43]] [4 41]] [2 55]]] [4832 0.0445 [4805 0.642 [2482 0.639 [3998 1.42 [5480 0.689 [673 1.48 [5005 0.428 [2962 2.68 [6926 0.185 [6578 1.87 [5509 3.72 [7188 1.03 [431 1.39 [3905 0.213 [3008 0.977 [5812 0.611 [7571 2.16 [3660 1.33 [6230 1.5 [1628 2.71 [4717 0.391 [248 15.2 [7133 2.89 [5348 5.21 [6374 2.77 [2259 14.2 [5239 0.821 [6977 3.54 [6103 5.31 [1390 0.525 [5664 3.91 [4253 3.15 [1668 6.11 [791 1.13 [6310 4.84 [6581 6.66 [5692 10 [6791 3.48 [2 13] [7 50]] [24 28]] [5 61]] [17 40]] [3101 0.637 [6544 3.47 [2753 8.27 [7512 15.3 [1059 3.33 [429 16.1 [19 13] [312 0.621 [2536 2.64 [4 32] [5 50]] [4 65]]] [2 84]] [7413 1.57 [5 20] [2 53]]] [24 83]] [14 40]] [4 83]]] [1919 6.74 [18 100] [18 63]]] [2 100]] [2 81]] [24 100]] [31 84]] [896 2.72 [4 13] [5 54]]] [4 100]] [814 0.275 [3644 2.05 [5472 1.37 [5403 2.46 [2270 2.99 [6859 6.03 [5192 3.37 [24 20] [24 55]] [5692 7.17 [24 100] [24 62]]] [24 100]] [31 100]] [36 100]] [24 90]] [36 88]]] [24 93]] [731 12.5 [2628 2.7 [5 41] [5 28]] [5 37]]] [4 100]] [1239 7.5 [6363 2.82 [25 74] [25 100]] [1429 13.1 [1 46] [22 30]]]] [1997 0.794 [7203 2.16 [16 66] [16 100]] [16 50]]] [1628 9.55 [24 80] [24 100]]] [221 4.61 [4571 1.44 [1783 9.35 [5753 2.77 [2753 1.56 [2752 21.4 [1011 5.24 [7736 0.321 [7354 2.71 [5054 1.2 [5 25] [4 85]] [5 90]] [7 71]] [4 42]] [134 1.61 [7413 4.34 [5 60] [4 22]] [5 68]]] [7009 1.62 [5 33] [1062 0.634 [5 78] [5 88]]]] [5 64]] [38 37]] [7665 10.8 [19 75] [14 40]]] [4 44]]] [24 89]] [978 6.03 [31 70] [31 100]]] [2846 8.55 [7354 1.41 [5118 1.07 [4479 0.688 [4960 0.998 [5405 0.914 [3576 0.561 [3196 0.917 [3929 1.36 [731 0.611 [1059 1.97 [4316 5.16 [573 1.48 [739 0.935 [6989 1.71 [2793 0.835 [1980 9.49 [1073 6.95 [1919 6.25 [7512 25.7 [1640 3.74 [5647 13.1 [6184 1.52 [2143 2.36 [4 37] [4 90]] [2 88]] [31 45]] [2 57]] [2 22]] [6077 4.27 [2752 20 [4 57] [2 44]] [4 84]]] [2 100]] [2 48]] [24 66]] [2 89]] [2 76]] [1505 1.18 [4 34] [5 100]]] [2 88]] [5771 1.08 [2570 5.11 [2628 1.51 [2 79] [2 100]] [2 66]] [2 100]]] [5345 4.41 [3554 3.27 [929 3.78 [4324 2.6 [5692 18.1 [6048 2.73 [1899 12.8 [3027 0.402 [7590 1.44 [7718 2.54 [663 5.21 [5647 7.23 [4851 0.32 [23 0.703 [2005 0.37 [4 30] [4 50]] [4 54]] [7 33]] [5 31]] [5 58]] [2 44]] [4 92]] [2 50]] [7461 0.846 [4 55] [2 43]]] [4 100]] [4 90]] [4 93]] [5412 0.77 [19 50] [5 40]]] [5 78]] [17 40]]] [17 44]] [5 57]] [5 95]] [31 100]] [5654 3.34 [5819 0.647 [4 93] [4 100]] [4 85]]] [5662 3.42 [17 57] [17 45]]] [12 100]] [791 6.72 [7665 7.11 [5 71] [4154 2.03 [5 87] [5 100]]] [5 67]]] [2826 2.46 [12 77] [12 100]]]] [2936 1.73 [3196 1.51 [6865 0.734 [3014 1.42 [1007 4.48 [5733 1.73 [1919 8.2 [1980 2.96 [5833 2.44 [6732 0.55 [1059 1.83 [6177 2.65 [4895 1.62 [7 35] [26 30]] [25 100]] [26 66]] [17 36]] [24 100]] [1919 0.742 [6230 3.42 [1078 11.8 [2752 13.9 [25 33] [25 93]] [25 50]] [16 33]] [25 35]]] [7 58]] [24 82]] [19 77]] [17 51]] [36 100]] [17 91]] [25 100]]] [7698 0.521 [7526 6.76 [733 0.124 [7009 3.9 [6588 0.749 [5732 3.57 [3928 1.3 [7106 2.22 [1201 4.38 [1400 3.05 [5673 0.568 [7214 2.28 [1906 2.69 [5692 3.73 [978 19.8 [3715 1.72 [2752 8.62 [14 37] [7 43]] [19 40]] [17 89]] [2571 1.35 [17 51] [6 33]]] [17 70]] [7 63]] [3794 1.32 [19 56] [38 55]]] [36 45]] [35 70]] [36 100]] [695 0.411 [17 81] [17 50]]] [14 66]] [7241 2.12 [5819 0.813 [1151 2.45 [17 40] [17 83]] [17 95]] [17 47]]] [17 28]] [7414 0.335 [7169 1.62 [17 83] [17 66]] [17 72]]] [7 77]] [7106 0.508 [7210 1.41 [36 100] [36 83]] [36 100]]]] [25 84]] [4229 0.717 [5197 2 [4851 1.17 [731 5.37 [7188 5.11 [37 34] [17 52]] [3056 1.1 [2259 0.975 [985 1.9 [5 33] [5 62]] [17 57]] [5 100]]] [647 2.97 [7693 0.934 [5673 10.4 [6591 0.53 [6732 8.21 [7 38] [17 44]] [17 50]] [17 77]] [7 66]] [7 85]]] [5 58]] [19 63]]] [5515 3.41 [695 5.1 [6590 2.22 [328 2.8 [6887 2.37 [896 0.967 [17 22] [6920 0.803 [7354 1.08 [17 29] [5 71]] [17 50]]] [5 66]] [1239 0.637 [7 36] [7 66]]] [19 62]] [978 9.31 [695 14.5 [5 50] [5 45]] [17 47]]] [4279 8.9 [141 11.5 [1429 57.4 [5 93] [38 55]] [5 80]] [5 77]]]] [31 100]] [2907 2.17 [2567 2.22 [4218 1.77 [2753 1.27 [1909 0.43 [1400 7.82 [637 6.27 [929 1.43 [2 38] [2628 2.64 [2616 7.03 [2 87] [4 60]] [2 94]]] [2 85]] [2 94]] [2 57]] [4 63]] [5 58]] [2 86]] [2 96]]] [2628 20.6 [2628 1.17 [31 93] [5509 1.39 [6544 1.39 [6578 1.23 [31 43] [31 100]] [31 100]] [5 50]]] [682 3.07 [4 25] [31 100]]]] [7 100]] [6178 1.14 [2993 0.8 [2903 2.54 [248 20.7 [913 0.885 [6524 3.87 [25 32] [25 92]] [26 40]] [1980 15.8 [5431 0.888 [4092 0.756 [7681 2 [26 47] [26 100]] [26 100]] [7512 3.28 [26 66] [26 100]]] [25 66]]] [1 91]] [2752 21.3 [26 66] [26 100]]] [25 100]]] [6827 0.412 [2470 2.76 [5516 0.0885 [4791 2.68 [6616 1.1 [7681 0.911 [6028 0.317 [7668 0.141 [968 1.75 [5812 0.371 [1059 1.63 [726 2.4 [1079 6.96 [2826 13.8 [145 5.32 [4969 0.867 [5969 0.136 [1400 1.71 [7279 1.45 [7734 0.363 [1919 3.44 [6031 0.609 [7203 1.76 [2813 1.15 [2759 1.09 [2526 28.2 [7693 1.48 [18 31] [18 52]] [18 62]] [26 50]] [6732 22 [7210 4.41 [18 86] [18 100]] [18 64]]] [16 54]] [22 55]] [18 74]] [7724 0.313 [2260 15.2 [7566 2.9 [2671 0.429 [5011 3.54 [5192 6.34 [1012 1.55 [5386 1.13 [731 3.99 [7188 1.06 [23 3.04 [18 87] [18 100]] [18 100]] [18 77]] [18 66]] [18 70]] [16 50]] [18 50]] [18 57]] [7737 1.68 [429 22.3 [7693 2.95 [18 60] [18 100]] [328 5.47 [18 100] [18 91]]] [18 100]]] [19 57]] [18 57]]] [19 60]] [26 42]] [7712 6.86 [7038 0.643 [4184 9.32 [4159 3.06 [1888 3.95 [4927 0.0791 [1783 6.57 [6740 0.14 [1899 7.36 [384 2.04 [7241 0.552 [2752 19.3 [18 100] [18 87]] [18 100]] [18 88]] [18 77]] [18 100]] [18 28]] [18 100]] [394 0.855 [7722 2.14 [18 53] [18 84]] [18 50]]] [16 37]] [18 64]] [18 50]] [17 33]]] [19 54]] [19 38]] [7 31]] [19 50]] [7737 1.43 [429 19.5 [26 44] [16 37]] [19 72]]] [5871 0.167 [16 37] [2760 0.501 [6 50] [2 42]]]] [4 27]] [8 45]] [7512 17.9 [1429 2.21 [26 100] [26 71]] [26 66]]] [1668 0.952 [38 62] [38 69]]] [26 100]] [2755 2.64 [2259 0.413 [26 85] [685 1.78 [19 71] [19 45]]] [26 73]]] [16 94]] [5597 2.89 [5480 14.4 [6363 2.87 [7409 0.623 [7343 4.32 [2552 0.481 [7332 0.709 [7057 0.152 [4740 0.262 [2732 1.03 [2667 0.495 [5345 0.25 [18 70] [18 40]] [16 75]] [16 100]] [16 100]] [19 57]] [16 90]] [16 63]] [4332 0.273 [2616 4.39 [2689 0.516 [26 50] [18 50]] [18 61]] [18 90]]] [6 66]] [23 1.79 [155 3.51 [26 71] [26 92]] [18 60]]] [18 76]] [2644 0.861 [896 4.59 [16 50] [16 90]] [16 100]]]] [2752 18 [26 86] [4 33]]] [18 100]]] [978 15.2 [1986 0.711 [208 0.797 [5 70] [5 100]] [5 66]] [38 33]]] [2143 0.849 [429 8.75 [5406 1.2 [31 78] [31 100]] [731 3.3 [31 95] [31 100]]] [31 100]]] [6544 0.325 [3517 0.75 [1535 0.469 [7009 2.11 [6924 0.618 [5297 1.43 [23 23.7 [2951 1.28 [6203 0.332 [3381 0.773 [7566 6.27 [573 1.92 [6848 1.35 [248 2.55 [4479 3.7 [725 1.93 [5157 0.334 [7185 6.42 [7588 0.229 [2811 5.68 [2753 1.1 [429 19 [1899 2.13 [5 81] [5 42]] [5851 2.06 [6230 7.97 [17 48] [2526 6.84 [14 27] [5 43]]] [17 44]]] [5 61]] [5 78]] [17 50]] [5 66]] [1703 0.321 [5692 3.2 [5 33] [5 71]] [5521 0.228 [17 57] [19 50]]]] [17 81]] [17 88]] [26 66]] [16 77]] [1888 3.49 [19 41] [4 40]]] [5 100]] [7722 6.28 [19 73] [18 55]]] [18 41]] [16 50]] [25 77]] [1703 3.86 [1899 1.02 [19 50] [19 100]] [19 50]]] [19 66]] [931 2.75 [6732 9.76 [6732 3.52 [2526 8.84 [5 81] [5 100]] [5 100]] [5 53]] [5 80]]] [5 85]] [6015 0.214 [5316 1.47 [19 100] [19 83]] [19 100]]] [5641 0.676 [7214 2.85 [3516 0.312 [31 0.507 [7534 0.662 [17 43] [7665 13.1 [17 83] [17 100]]] [791 10.7 [7251 2.87 [17 100] [17 71]] [17 50]]] [19 100]] [19 70]] [19 36]]]] [2259 2.78 [1913 2.56 [6089 0.117 [7689 2.46 [6310 0.45 [896 1.53 [6159 1.02 [2 74] [2 71]] [7009 2.89 [3532 0.707 [939 1.17 [1723 0.412 [2526 9.83 [7665 9.85 [2 61] [25 33]] [7544 4.17 [906 1.1 [4601 3.04 [5843 0.357 [4253 0.268 [2 66] [2 100]] [17 60]] [2 100]] [913 2.45 [4154 2.46 [2 80] [2 100]] [2 88]]] [896 15 [2 93] [2 87]]]] [4 91]] [4 54]] [22 100]] [4 62]]] [5 25]] [19 90]] [5660 5.63 [7265 3.12 [7491 1.43 [2675 0.358 [7718 0.855 [6732 14.5 [2 98] [2 77]] [2 100]] [2 100]] [2 83]] [2 88]] [2 83]]] [4929 0.366 [2 63] [4 69]]] [6989 0.161 [695 0.748 [7293 0.383 [2902 7.34 [17 0.564 [1173 0.212 [1883 0.722 [7722 1.59 [8 22] [4 30]] [2 44]] [2 50]] [5267 0.739 [2 60] [2 33]]] [2 92]] [4 80]] [2752 12.4 [4 70] [5412 2.13 [4 57] [31 85]]]] [2 95]]]]] [7343 0.978 [7679 0.139 [4712 3.88 [5102 2.95 [299 23.5 [5093 2.74 [1268 0.75 [1783 1.06 [5409 21.7 [4414 2.16 [6123 1.39 [7667 2.86 [6 100] [6 87]] [6 100]] [6 100]] [6 77]] [6 100]] [6 75]] [2412 1.39 [6 88] [6 77]]] [6 83]] [6 54]] [6 96]] [5594 1.38 [6 37] [6 90]]] [6 33]]] [1668 2.48 [4344 6.25 [5575 7.1 [2456 1.35 [5605 2.3 [7149 0.822 [5647 20.2 [7712 4.57 [3649 36.3 [929 1.33 [4031 6.46 [3424 1.67 [7751 4.1 [2275 3.18 [5753 0.493 [7512 28.4 [24 100] [24 92]] [24 100]] [24 94]] [24 71]] [24 90]] [24 83]] [24 88]] [24 78]] [24 65]] [24 66]] [7590 0.945 [1239 3.18 [24 88] [24 100]] [24 100]]] [24 70]] [1078 22.7 [7712 1.6 [2453 11.9 [7169 4.84 [24 83] [24 100]] [24 100]] [5220 0.942 [23 6.36 [24 95] [24 62]] [24 100]]] [24 44]]] [24 70]] [24 100]] [24 57]]] [1087 0.333 [3527 1.1 [144 7.44 [2752 13.5 [4 100] [1011 0.498 [7327 7.98 [4218 0.677 [5660 0.518 [4 98] [4 100]] [4 100]] [2616 9.8 [4 71] [4 100]]] [4 100]]] [4 50]] [4 80]] [4 87]]] [7428 2.09 [1240 2.13 [1390 0.756 [24 83] [24 100]] [7419 0.635 [24 97] [24 100]]] [24 55]]] [1600 0.519 [3333 0.858 [2826 1.33 [4742 0.0434 [7043 0.421 [3008 2.35 [2936 0.673 [3100 0.717 [7384 0.754 [234 0.642 [25 40] [25 100]] [7 100]] [5693 3.67 [1 76] [1 100]]] [25 100]] [5412 0.293 [896 8.15 [25 91] [25 73]] [25 100]]] [25 100]] [2 30]] [5154 1.11 [248 20.1 [5692 2.62 [7 100] [7 83]] [25 91]] [7 100]]] [1 100]] [7 100]]] [194 0.698 [2905 0.429 [5962 14.3 [728 1.24 [2763 2.23 [4889 32.5 [7123 0.862 [187 1.12 [982 0.391 [5632 9.31 [5778 1.94 [7381 1.1 [929 2.32 [2301 13.9 [6749 2.16 [5983 16.5 [4154 1.14 [4851 1.19 [2466 0.838 [2579 8.21 [4674 8.41 [2260 4.49 [6934 3.56 [6 87] [2551 7.37 [16 44] [6 83]]] [6 52]] [5716 4.07 [6 92] [6 100]]] [6 100]] [6 46]] [6 30]] [5598 0.487 [6 59] [6 60]]] [6 100]] [5983 0.768 [6099 5.92 [5797 0.453 [7149 6.53 [1311 0.729 [6 86] [6 100]] [6 50]] [6 88]] [6 100]] [6 100]]] [6 60]] [6 47]] [2 30]] [6 69]] [6 33]] [4732 1.77 [6 100] [6 87]]] [2599 3.85 [4414 7.63 [299 3.11 [4713 1.55 [1364 0.132 [6 59] [16 45]] [7 57]] [6 90]] [6 100]] [6 100]]] [6 16]] [6 93]] [7419 0.454 [7 31] [4 41]]] [4 33]] [6 50]] [5 36]] [16 35]]] [6866 23.8 [3884 0.938 [3593 0.279 [3207 2.42 [7241 11.3 [7009 11 [2993 2.03 [4154 0.861 [3547 1.31 [5007 1.72 [6310 2.47 [6310 0.401 [1025 0.767 [5 97] [5 91]] [5 100]] [5 83]] [5 83]] [5 87]] [5 100]] [5 85]] [5 86]] [5 68]] [5 63]] [5 62]] [5 100]] [5 57]]] [3630 3.98 [308 0.765 [2453 23.1 [5904 0.143 [6337 7.87 [5427 0.655 [2451 2.86 [3630 2.93 [4349 0.542 [2093 0.74 [695 1.82 [6336 6.49 [896 9.56 [4046 3.27 [4735 2.39 [5053 4.41 [1034 0.242 [4518 17.9 [24 100] [24 91]] [24 100]] [24 80]] [2793 1.5 [5792 1.2 [24 100] [24 85]] [24 100]]] [24 55]] [2795 9.39 [24 100] [24 50]]] [24 84]] [24 83]] [24 57]] [5206 0.215 [7591 0.191 [4601 2.78 [4340 1.84 [7080 2.61 [5673 6.12 [24 100] [24 95]] [24 96]] [24 90]] [24 83]] [24 100]] [24 71]]] [24 85]] [24 74]] [3653 0.259 [24 58] [24 100]]] [19 69]] [3640 1.03 [19 87] [24 66]]] [24 46]] [4034 2.24 [3208 1.32 [4816 0.241 [1239 0.501 [308 5.34 [2259 29.9 [3643 1.07 [24 100] [24 85]] [24 69]] [791 6.64 [24 55] [24 71]]] [208 0.737 [1602 0.333 [141 0.891 [24 97] [24 100]] [24 70]] [23 5.87 [5792 1.82 [4518 4.75 [24 100] [24 83]] [24 100]] [19 50]]]] [24 50]] [3548 0.351 [19 42] [19 100]]] [6721 0.396 [4957 1.12 [24 65] [19 75]] [24 88]]]] [2517 7.32 [24 82] [24 66]]]] [6575 0.368 [2605 0.125 [7609 2.64 [2846 0.227 [826 1.53 [6826 1.99 [2586 0.252 [1429 43.3 [7576 0.59 [5480 0.156 [5432 1.17 [5692 20.3 [6068 8.15 [7428 3.17 [260 6.67 [2259 14.1 [6189 4.83 [673 0.129 [26 46] [7321 5.87 [7677 0.258 [985 0.516 [1888 0.418 [7668 0.46 [2983 0.782 [2005 1.95 [2748 0.861 [1432 1.66 [1783 1.89 [394 2.62 [7722 4.37 [26 55] [26 82]] [26 100]] [26 71]] [26 100]] [26 100]] [26 50]] [26 80]] [5007 5.56 [5412 2.52 [6230 0.41 [26 96] [26 70]] [19 37]] [6 50]]] [4604 0.627 [663 1.51 [896 0.623 [26 92] [26 100]] [26 66]] [26 100]]] [5368 0.617 [26 90] [26 100]]] [26 100]] [26 62]]] [25 80]] [6 38]] [25 75]] [25 87]] [25 100]] [25 78]] [25 100]] [5693 3.36 [7677 4.14 [2755 4.09 [1221 0.877 [407 0.685 [2951 7.58 [5509 3.21 [2470 8.02 [736 0.319 [7722 2.66 [178 7.88 [7665 5.73 [26 88] [26 98]] [26 80]] [26 100]] [26 100]] [26 55]] [19 55]] [16 25]] [26 100]] [26 60]] [4221 0.182 [5680 5.79 [5368 0.434 [407 4.36 [26 100] [26 93]] [26 100]] [26 66]] [26 100]]] [26 66]] [2748 0.794 [26 85] [1011 0.762 [26 53] [26 75]]]]] [25 100]] [18 63]] [3008 1.15 [25 62] [25 100]]] [532 0.507 [18 96] [18 100]]] [6342 0.276 [1429 3.47 [6177 8.54 [25 55] [25 100]] [25 60]] [25 100]]] [896 4.38 [19 50] [18 93]]] [4601 2.96 [5695 1.29 [25 100] [2763 0.462 [25 66] [25 100]]] [25 50]]] [1884 0.63 [7397 0.144 [4611 1.64 [6189 0.258 [25 70] [25 100]] [26 75]] [25 100]] [26 100]]] [26 100]]] [5726 0.994 [6983 8.11 [4929 0.181 [5662 1.41 [7365 0.38 [7343 1.2 [2987 1.57 [5240 0.448 [7592 2.22 [2483 0.492 [7512 11.6 [4 71] [2605 0.452 [6173 1.32 [7697 1.25 [4 47] [31 100]] [31 100]] [31 100]]] [4 100]] [791 9.76 [4 87] [4 44]]] [4 75]] [4 81]] [1011 0.352 [31 86] [31 100]]] [4 81]] [4184 1.14 [4 73] [4 83]]] [5405 0.381 [739 0.803 [1173 0.969 [4832 1.85 [429 29.1 [4 100] [4 83]] [4 85]] [4 80]] [4 62]] [31 100]]] [7449 14.2 [2487 0.724 [7512 18.1 [2091 2.08 [4832 9.54 [1101 1.11 [929 1.49 [228 0.65 [7677 2.54 [4 97] [4 87]] [4 100]] [2673 1.41 [4 100] [4 80]]] [4 80]] [4 88]] [4 83]] [2483 0.754 [7085 4.67 [1011 8.87 [4 83] [4 55]] [4 75]] [4 100]]] [31 100]] [4 100]]] [31 100]]] [1640 5.38 [5812 18.5 [2023 3.58 [1899 0.627 [7009 0.417 [2616 14.8 [2943 0.509 [4 86] [4 100]] [4 100]] [4 100]] [4 100]] [4 92]] [4 94]] [4 75]]] [1690 1.08 [429 10.7 [3732 0.63 [2946 0.888 [2829 3.57 [1027 3.76 [6936 3.76 [7563 0.649 [7601 1.71 [7185 0.54 [19 31] [4218 0.809 [17 46] [17 100]]] [5 61]] [3061 3.04 [6581 49.5 [7598 2.64 [5673 1.38 [5 81] [19 63]] [5515 9.3 [5514 19.2 [5 80] [5 90]] [5 100]]] [5 63]] [5 38]]] [17 57]] [429 7.23 [19 83] [19 85]]] [17 60]] [5 100]] [17 64]] [469 0.0891 [6866 0.918 [5514 0.302 [3905 0.0664 [7566 3.46 [1648 0.455 [4304 2.18 [4071 2.19 [4718 0.606 [6885 0.826 [5821 1.31 [7682 0.564 [573 9.3 [4478 1.92 [2526 42.7 [5515 1.58 [5753 0.872 [6791 1.94 [668 1.72 [1062 2.24 [3879 3.4 [1888 12.8 [3057 1.98 [1078 5.26 [3078 5.31 [6199 1 [17 44] [17 42]] [17 50]] [7253 0.921 [5812 7.55 [17 28] [17 41]] [5 90]]] [5 85]] [17 81]] [17 100]] [5 46]] [17 57]] [12 50]] [6230 4.75 [38 55] [663 0.768 [5 90] [5 60]]]] [2826 3.34 [7722 18.6 [5 91] [5 42]] [5 92]]] [7512 28.2 [17 66] [17 84]]] [2526 21.9 [17 100] [17 66]]] [6550 0.671 [17 50] [17 75]]] [1239 3.25 [663 2.27 [17 52] [17 38]] [17 100]]] [17 80]] [17 100]] [5 50]] [5 91]] [736 0.603 [5 62] [5 63]]] [4741 1.91 [2905 0.664 [7241 4.21 [4083 0.632 [17 73] [1630 0.507 [3078 1.19 [6353 0.796 [1580 0.455 [1429 54.9 [17 50] [17 50]] [17 37]] [38 55]] [19 88]] [19 55]]] [38 88]] [17 50]] [17 72]]] [2842 1.9 [7241 5.69 [1078 10.8 [5 71] [5 50]] [19 33]] [5 85]]] [7009 3.04 [6002 0.929 [1587 0.466 [3108 1.8 [6581 36.6 [1656 1.59 [4588 0.111 [3798 10.6 [3905 3.23 [1072 0.224 [896 3.04 [17 100] [1630 1.52 [5390 1.45 [3008 3.65 [7566 0.554 [726 0.215 [17 78] [17 83]] [14 41]] [7665 15.7 [7185 3.36 [17 75] [17 100]] [17 100]]] [1025 1.03 [17 50] [38 55]]] [19 42]]] [2601 0.157 [17 66] [38 63]]] [7067 0.92 [5019 4.37 [5819 0.446 [3964 2.59 [3675 1.09 [568 0.218 [5384 9.24 [6436 0.195 [7203 3 [2764 0.276 [6554 1.98 [2902 6.06 [978 4.9 [17 54] [6313 1.36 [7381 2.29 [17 91] [17 72]] [1078 6.95 [17 78] [19 40]]]] [17 50]] [6977 0.705 [6315 2.01 [17 58] [19 57]] [19 42]]] [17 62]] [19 53]] [19 84]] [32 30]] [35 50]] [17 90]] [5673 11 [17 84] [17 62]]] [7693 0.137 [17 83] [17 100]]] [35 90]] [7722 2.81 [4414 0.329 [3558 1.45 [573 1.29 [5019 1.91 [17 42] [35 100]] [19 100]] [38 50]] [17 43]] [3562 1.67 [6436 0.586 [7595 3.82 [17 53] [17 86]] [19 54]] [19 87]]]]] [1648 6.35 [17 42] [38 72]]] [6591 1.3 [725 0.231 [5412 4.35 [17 100] [17 87]] [17 100]] [1668 0.652 [5154 0.466 [17 92] [17 100]] [17 57]]]] [5729 1.79 [1239 0.566 [1745 0.797 [17 80] [17 100]] [17 87]] [17 72]]] [19 51]] [7689 1.54 [19 100] [19 62]]] [134 0.986 [6230 6.05 [19 43] [19 92]] [4083 2.73 [1621 0.627 [17 61] [19 60]] [17 83]]]] [5662 0.262 [6729 2.63 [19 100] [17 44]] [19 90]]] [731 2.64 [5 50] [5 47]]]] [2962 1.03 [2526 18.1 [7708 0.635 [5 45] [5 57]] [3676 17.4 [731 3.84 [647 4.17 [1899 2.58 [5 62] [5 88]] [5 100]] [791 8.58 [5 100] [5 88]]] [19 88]]] [5 82]]] [7188 3.35 [5819 0.323 [7722 4.85 [5 100] [5 75]] [5 71]] [5 100]]] [4939 0.897 [4776 0.342 [4802 0.26 [5650 0.818 [3381 2.45 [1072 1.54 [624 0.949 [6347 0.228 [4218 0.782 [7737 0.172 [2541 1.05 [19 100] [19 85]] [19 100]] [929 1.26 [19 100] [19 87]]] [19 66]] [19 66]] [19 85]] [19 76]] [19 69]] [19 71]] [19 62]] [19 64]]]] [7253 0.697 [134 15.1 [7693 0.186 [2784 0.369 [7665 23.9 [2588 1.33 [6557 0.476 [7215 0.345 [3554 2.03 [1919 6.98 [791 10.9 [17 100] [17 83]] [17 88]] [17 83]] [17 100]] [17 100]] [4218 1.55 [17 84] [17 100]]] [2826 2.73 [3929 10.1 [17 100] [17 80]] [17 50]]] [17 40]] [17 100]] [19 55]] [5389 0.367 [5660 0.407 [6380 0.597 [21 1.58 [7413 0.349 [7690 1.14 [7534 2.8 [17 94] [17 75]] [17 57]] [4719 0.349 [1239 2.11 [17 100] [17 92]] [17 85]]] [17 40]] [14 37]] [1062 1.6 [38 33] [17 85]]] [19 71]]]]] [7576 0.253 [7243 0.452 [6216 0.182 [5695 0.626 [6364 0.946 [1445 1.89 [3099 0.357 [7253 0.283 [7544 0.479 [2628 3.15 [7623 0.121 [1051 0.218 [978 8.07 [6077 4.44 [2764 0.731 [6186 0.497 [5812 1.48 [33 26] [6187 1.26 [2 100] [2 47]]] [2 82]] [1 33]] [2 100]] [2081 0.297 [2470 1.08 [17 5.59 [19 0.562 [2905 2.27 [7712 0.773 [7169 0.78 [2 86] [2 100]] [2 100]] [2 70]] [2 100]] [2 76]] [4 77]] [23 4.93 [2 94] [2 68]]]] [1980 3.53 [2 90] [2 100]]] [4742 0.362 [2 63] [2 45]]] [7461 6.09 [978 31.8 [6187 12 [2767 2.15 [221 2.72 [2526 21.9 [7693 1.25 [7722 3.54 [2081 1.02 [2752 12.1 [2 85] [2 40]] [2 83]] [4 44]] [2 77]] [1429 0.649 [2576 0.754 [5412 6.87 [2 100] [2 83]] [2 100]] [7707 0.333 [978 6.14 [2 83] [2 100]] [2 66]]]] [2083 2.2 [3327 4.47 [7700 3.58 [5576 2.01 [1429 4.36 [2 100] [4 45]] [6798 3.3 [7712 3.86 [1190 0.226 [1429 24.1 [7665 11.9 [2 100] [2 97]] [2 87]] [2 100]] [2 81]] [1640 11.3 [2 60] [2 100]]]] [2 58]] [2 75]] [2 63]]] [2 66]] [2 54]] [2 42]] [2 62]]] [6735 0.253 [2 88] [2 100]]] [4 50]] [1 100]] [2 53]] [2 61]] [7516 0.524 [25 62] [25 66]]] [5771 8.8 [4 100] [4 87]]] [4 77]] [25 100]]] [520 0.221 [3734 0.452 [5661 6.42 [5812 1.16 [5192 1.52 [4991 3.86 [2 39] [144 10.3 [1 41] [2 100]]] [1078 14.9 [2 86] [2 38]]] [978 33.3 [134 2.13 [651 1.77 [1007 1.8 [2064 1.55 [5652 3.52 [6982 0.534 [2745 3.57 [567 11.2 [147 10.9 [4343 0.112 [2939 2.28 [7512 23.5 [7382 0.389 [1925 0.412 [5574 2.26 [2 100] [2 83]] [2 66]] [2 75]] [2 62]] [5818 7.14 [4184 3.74 [4991 17.4 [2091 1.32 [4184 2.69 [6989 7.31 [2 100] [1919 11.4 [2 100] [2 77]]] [2 87]] [2 90]] [2 69]] [2 100]] [2 70]]] [2 100]] [2 71]] [2 50]] [2 68]] [4338 0.856 [4 100] [4 75]]] [2 60]] [2 50]] [4929 0.562 [2 93] [2 100]]] [2 42]] [145 4.1 [5820 8.13 [2907 0.133 [3130 4.3 [6310 0.526 [7584 0.468 [1033 3.43 [7324 0.0837 [1436 3.21 [4350 2.56 [7566 2.18 [2 98] [2 94]] [2 83]] [2 90]] [2 57]] [2 50]] [2 100]] [2 81]] [4 50]] [2 100]] [2 76]] [2 76]]] [2 44]]] [2 57]] [17 63]] [724 0.509 [2 100] [2 66]]]] [6133 0.363 [2733 0.322 [7734 4.05 [4675 0.437 [5724 3.09 [7491 0.223 [2029 18.2 [4514 17 [985 0.811 [7255 2.6 [3239 0.372 [2470 8.93 [6004 4.91 [4422 4.01 [2611 11.5 [7260 1.63 [5723 10.9 [1783 22.8 [1078 35.3 [1338 0.162 [4986 4.86 [4762 9.57 [7419 9.96 [407 0.292 [2526 86.4 [1316 6.72 [4822 1.21 [300 6.18 [6633 9.7 [1913 2.86 [7675 16.7 [6 100] [6 85]] [6 97]] [6 88]] [6 71]] [2566 5.98 [7224 8.03 [1374 2.56 [4937 1.5 [6933 1.66 [6 94] [6 83]] [6 85]] [6 100]] [6 62]] [1383 3.08 [6 71] [6 62]]]] [6 78]] [6 71]] [6 100]] [6099 17.9 [4449 8.36 [6 100] [6 88]] [6 85]]] [6 84]] [6 45]] [6 60]] [5090 0.623 [6 33] [6 100]]] [6 44]] [6 71]] [6 62]] [4732 1.89 [7665 12.3 [16 57] [6 79]] [6 86]]] [7149 3.26 [6 100] [6 57]]] [6 40]] [6 58]] [16 44]] [2461 1.29 [4889 12.4 [7519 1.11 [2037 0.316 [4820 3.96 [2551 1.78 [23 3.16 [6 100] [6 71]] [7419 13.4 [6 60] [16 50]]] [6 60]] [2279 1.34 [16 50] [6 80]]] [6 83]] [16 50]] [16 50]]] [16 50]] [16 57]] [6422 1.52 [6 65] [6 75]]] [2939 3.93 [2282 0.905 [18 36] [6 100]] [16 70]]] [16 80]] [6977 1.61 [6199 1.07 [1268 3.92 [5964 7.77 [5381 0.769 [7665 20.6 [5594 1.81 [2029 25.2 [4882 0.912 [5167 5.6 [5007 0.732 [2661 1.91 [5090 0.0932 [6100 5.98 [4674 0.556 [1429 14.2 [6 100] [1078 12.4 [6 96] [6 80]]] [6 100]] [1899 10.8 [6 100] [6 50]]] [5988 2.89 [7406 0.205 [1899 7.09 [4434 0.489 [6098 0.424 [6 93] [6 100]] [6 100]] [6 100]] [6 100]] [2396 1.57 [6 83] [6 100]]]] [6 87]] [6 83]] [6 72]] [6 66]] [6 66]] [6 71]] [1320 0.916 [7564 0.454 [7419 4.02 [6 100] [6 70]] [6 100]] [7667 8.62 [6 50] [6 83]]]] [1316 0.318 [6 85] [16 60]]] [6514 4.1 [6 94] [16 56]]] [5964 6.75 [6 100] [6 83]]] [6 45]] [6 50]]] [18 50]] [6 43]] [7038 1.91 [6 91] [1899 2.57 [2717 0.971 [16 66] [16 100]] [4725 0.454 [6 69] [2370 0.152 [6 57] [16 66]]]]]]]] [5011 0.0355 [4218 0.252 [1919 0.161 [126 0.0285 [4369 1.66 [2143 1.56 [5211 2.78 [6269 0.492 [3045 1.06 [6017 0.344 [7453 0.529 [7188 0.485 [5472 1.79 [939 0.593 [2701 2.48 [1069 1.28 [6732 0.549 [4716 0.271 [5509 0.292 [1171 0.211 [5753 6.78 [29 20] [29 66]] [35 29]] [1078 0.994 [17 44] [3 16]]] [16 100]] [5 27]] [4 80]] [1980 15.1 [144 1.47 [2705 1.49 [29 92] [29 100]] [29 100]] [29 92]]] [939 20.8 [2766 1.29 [6230 1.14 [155 7.44 [5482 4.16 [29 88] [29 77]] [29 75]] [3 25]] [29 100]] [27 62]]] [13 78]] [17 26]] [1995 1.63 [2628 0.529 [112 0.537 [29 62] [29 100]] [29 38]] [1980 18.6 [29 100] [29 80]]]] [5413 0.546 [23 1.75 [29 77] [29 100]] [29 100]]] [4663 3.63 [35 70] [35 100]]] [13 100]] [4991 1.6 [23 33] [11 33]]] [1069 0.28 [2149 0.49 [1911 2.21 [5225 2.33 [3027 2.64 [29 51] [29 26]] [23 71]] [29 100]] [2029 2.49 [2011 1.43 [2200 2.78 [440 6.59 [2819 0.243 [1239 0.165 [2225 2.83 [29 78] [29 100]] [29 93]] [29 100]] [29 75]] [29 77]] [29 100]] [29 77]]] [4 53]]] [4799 2.81 [2488 4.09 [4768 8.51 [12 63] [6230 1.19 [32 50] [32 80]]] [13 87]] [32 100]]] [794 0.454 [7035 0.0285 [29 90] [29 100]] [29 100]]] [1429 28.5 [6186 0.763 [3989 0.843 [23 9.17 [5647 21.1 [6184 2.12 [2 37] [2 94]] [6074 0.434 [4 63] [2 83]]] [4 50]] [23 50]] [2259 1.12 [2 88] [2 100]]] [5953 0.141 [6342 0.246 [5521 3.3 [978 12.3 [4768 16.4 [16 30] [17 40]] [4 60]] [19 100]] [19 81]] [19 100]]]] [1696 0.37 [3516 0.142 [1783 2.56 [6920 0.196 [682 0.843 [725 0.938 [1648 2.01 [7354 1.47 [5192 1.81 [6230 3.4 [35 28] [17 72]] [12 37]] [13 62]] [19 42]] [5 66]] [13 100]] [36 44]] [5039 0.635 [13 54] [13 100]]] [7381 3.16 [19 100] [19 81]]] [19 100]]] [1888 0.53 [688 2.48 [3008 3.99 [2151 1.2 [567 0.327 [2077 0.108 [6017 0.115 [2802 9.21 [5007 17.7 [29 100] [29 92]] [29 100]] [29 100]] [29 100]] [29 100]] [2091 4 [29 100] [29 71]]] [29 85]] [29 66]] [19 40]]]] [5058 0.214 [4107 0.45 [7324 19.9 [5785 0.329 [3554 2.42 [6185 1.2 [2521 3.42 [6677 6.17 [477 2.59 [3715 0.479 [407 6.47 [7038 1.09 [7297 3.49 [5797 14.2 [2658 11.7 [1594 4.1 [1648 2.03 [3527 1.88 [5847 0.0927 [939 2.06 [3105 17.9 [7742 26.5 [1452 0.568 [7298 1.01 [4478 0.245 [221 73.7 [2673 3.85 [1075 5.43 [7520 10.6 [7032 0.847 [5819 0.359 [2943 7.41 [7491 14.9 [429 1.58 [5238 2.49 [695 3.31 [2939 3.11 [4 96] [4 100]] [4 100]] [4 100]] [7512 10.1 [7324 0.548 [4 99] [4 100]] [4 100]]] [4 93]] [4 97]] [4 100]] [4 100]] [4 84]] [4 83]] [4 95]] [4 83]] [4 100]] [4 85]] [4 75]] [2628 7.46 [4 93] [4 100]]] [7588 13.4 [4 75] [4 100]]] [4 97]] [5886 1.92 [4 100] [4 80]]] [4 71]] [4 85]] [2939 2.07 [4 100] [4 76]]] [4 80]] [4 77]] [4 77]] [4 75]] [4 75]] [4 75]] [4 85]] [5 50]] [4 75]] [4 61]] [4 50]] [32 100]] [4 55]] [4 50]] [32 81]]] [3041 0.626 [6326 1.76 [7499 4.54 [3687 2.27 [77 0.534 [3332 5.72 [221 1.36 [819 2.04 [3027 26 [3089 2.09 [5099 5.66 [602 0.388 [3999 0.662 [5588 1 [3905 2.94 [7009 4.31 [4326 0.988 [4851 4.87 [4154 4.98 [4414 12.9 [726 11 [695 3.61 [841 0.244 [3294 0.866 [112 5.81 [843 0.392 [2752 7.71 [37 75] [3027 6.42 [5753 1.91 [3080 1.2 [3771 0.74 [3126 0.327 [3675 0.693 [6761 0.193 [37 93] [37 100]] [37 100]] [37 85]] [37 100]] [37 100]] [37 85]] [37 57]]] [37 100]] [37 83]] [37 100]] [37 100]] [2488 16.6 [2746 3.72 [3781 3.66 [4071 16.3 [3780 0.249 [960 1.33 [3171 0.353 [4107 0.649 [3308 2.05 [1899 0.517 [791 1.81 [37 88] [3879 4.37 [3867 2.86 [3314 0.904 [3204 4.95 [707 6.3 [37 100] [37 84]] [37 85]] [37 100]] [37 100]] [37 100]]] [37 100]] [37 85]] [37 100]] [37 100]] [37 88]] [37 100]] [37 90]] [37 97]] [37 90]] [19 36]]] [37 57]] [37 58]] [37 24]] [19 55]] [37 37]] [37 56]] [4898 1.97 [5377 0.377 [5129 3.31 [1475 6.03 [3338 6.53 [3772 10.5 [103 0.342 [2179 1.26 [722 7.36 [6999 2.22 [365 7.53 [3905 25.8 [1078 18.7 [957 22.4 [707 7.8 [3691 0.517 [3883 1.04 [3079 16 [3905 14.9 [3610 6.23 [3992 0.978 [3991 1.93 [4533 1.08 [37 95] [37 100]] [37 85]] [37 100]] [37 88]] [37 75]] [3182 0.503 [800 0.96 [5158 2.11 [3928 11.1 [37 100] [37 90]] [37 100]] [37 100]] [37 100]]] [37 100]] [37 100]] [37 71]] [37 75]] [1533 0.498 [3831 9.81 [3079 11.2 [37 86] [37 96]] [37 75]] [37 100]]] [695 1.58 [37 99] [37 100]]] [37 87]] [37 88]] [37 80]] [37 83]] [37 66]] [37 66]] [37 85]] [37 85]] [37 55]] [37 78]] [37 75]]] [37 57]] [37 100]] [32 28]] [16 42]] [3127 15.8 [4071 0.187 [4107 0.321 [3921 20.2 [37 100] [3692 5.68 [37 100] [37 83]]] [37 100]] [37 100]] [1122 16.5 [37 80] [37 100]]]] [27 83]] [27 100]] [3990 0.29 [37 23] [37 100]]] [35 82]] [4071 0.766 [37 50] [16 78]]] [3781 16.1 [1783 8.66 [3318 2.89 [2618 5.46 [3905 48.6 [7401 3.17 [4130 3.18 [2628 6.59 [7354 0.752 [4969 2.15 [4065 42.4 [3507 8.92 [3975 12.2 [1260 0.305 [5642 1.12 [3250 1.56 [1546 11.2 [552 3.38 [3424 13.2 [3748 20.6 [3394 21.6 [3045 3.68 [3136 12.7 [3262 13.1 [3220 7.46 [5130 2.72 [1436 0.226 [2849 7.68 [3560 3.33 [1754 0.403 [2752 7.46 [3928 7.3 [37 100] [3294 6.35 [37 100] [37 87]]] [3929 0.184 [3080 0.275 [3611 0.397 [1473 0.394 [1078 13.4 [3775 25.7 [37 100] [37 87]] [3374 0.99 [2780 0.537 [3079 7.04 [37 85] [37 100]] [37 100]] [37 100]]] [37 100]] [37 100]] [37 100]] [37 100]]] [37 83]] [37 78]] [37 83]] [37 100]] [37 88]] [3691 1.55 [37 83] [37 100]]] [1541 6.67 [1078 38.7 [6597 0.752 [3777 4.6 [6657 10.1 [826 0.357 [7428 2.17 [707 19.1 [3907 14 [7472 5.1 [4109 2.73 [2259 4.65 [49 0.557 [1507 8.16 [3716 0.299 [3088 12.2 [1518 1.23 [3725 7.47 [37 100] [37 92]] [37 100]] [707 0.821 [3374 4.12 [37 100] [37 90]] [37 100]]] [37 100]] [37 85]] [37 100]] [328 3.66 [37 100] [37 88]]] [37 98]] [37 88]] [37 80]] [37 80]] [37 90]] [37 100]] [37 87]] [37 94]] [37 85]] [37 89]] [37 71]]] [37 80]] [37 85]] [37 77]] [37 80]] [37 75]] [37 70]] [37 90]] [2753 3.53 [37 81] [37 100]]] [2466 2.88 [37 83] [37 75]]] [37 76]] [37 85]] [37 90]] [37 55]] [37 77]] [37 80]] [832 1.42 [3782 1.15 [328 3.58 [37 100] [37 91]] [37 100]] [37 84]]] [38 57]] [37 73]] [37 81]] [37 75]] [3299 3.11 [37 57] [37 100]]] [3253 3.69 [6865 0.34 [832 0.432 [7210 0.808 [1980 3.72 [37 82] [37 100]] [37 71]] [37 57]] [37 100]] [19 50]]] [37 66]]] [35 57]] [35 80]] [312 4.71 [3905 0.549 [35 65] [3929 0.274 [37 50] [37 100]]] [37 94]]]] [3921 0.536 [2849 5.96 [5170 1.73 [802 5.93 [5472 0.707 [228 0.0445 [537 0.493 [3222 1.57 [2755 0.386 [6537 1.35 [3003 0.185 [2818 0.622 [6230 0.877 [4519 0.154 [2562 1.03 [499 1.33 [5482 0.243 [1240 1.94 [5566 0.0796 [2079 0.199 [1283 0.416 [534 1.15 [2752 2.32 [7615 0.247 [5110 0.749 [6983 1.66 [5539 8.46 [7540 0.278 [4699 0.384 [4865 0.225 [2611 0.244 [7675 1.27 [7742 3.76 [3619 0.428 [6457 0.135 [2939 84 [7419 1.34 [2698 1.15 [5528 0.173 [819 0.0905 [1628 0.0379 [491 0.364 [4308 0.0313 [5403 2.83 [3022 5.64 [4851 0.169 [7737 0.636 [5940 0.108 [5500 0.186 [2106 1.05 [5409 5.5 [7032 0.874 [2470 2.55 [248 4.52 [371 6.07 [4005 0.0623 [7405 2.37 [1843 0.635 [1521 0.512 [4690 2 [6768 1.31 [5937 2.01 [7578 0.15 [3332 1.14 [3019 1.2 [4323 1.04 [6581 4.72 [3292 7.18 [287 3.25 [3944 0.17 [4154 0.283 [5218 3.14 [2616 0.33 [7665 0.0825 [429 0.276 [4702 4.67 [7623 87.3 [6647 6.43 [5732 1.58 [7210 0.333 [6606 0.699 [1617 1.88 [397 3.98 [1943 1.27 [1888 1.45 [5067 2.63 [2408 11.9 [3667 14.1 [2268 7.51 [2048 1.17 [2199 3.14 [6484 3.15 [1980 30.5 [6063 8.3 [232 0.446 [1772 8.79 [2052 7.09 [6566 34.8 [1340 1.12 [6899 3.79 [1 16] [33 78]] [11 31]] [11 86]] [1078 166 [1 45] [1 85]]] [2081 12.6 [7329 4.88 [2939 11.1 [7623 51.1 [33 44] [1 60]] [33 32]] [2 28]] [33 40]]] [33 87]] [22 100]] [6074 17.2 [6058 4 [1961 13.3 [7369 10.6 [4663 14.9 [1915 17.8 [7139 47.1 [1 21] [22 50]] [1 93]] [29 25]] [2081 14.8 [1429 100 [33 37] [7 57]] [15 77]]] [35 63]] [33 100]] [11 62]]] [25 78]] [1761 3.46 [4338 6.17 [5989 2.6 [2081 5 [6445 6.47 [1742 8.8 [6471 2.44 [2180 3.05 [7330 12.9 [1 27] [13 44]] [1 56]] [26 91]] [33 77]] [30 88]] [3379 0.864 [1939 11.7 [1239 100 [1995 8.78 [2184 17.9 [29 22] [1 16]] [2093 4.95 [1 27] [1 46]]] [1 19]] [23 50]] [1 56]]] [25 24]] [23 95]] [28 88]]] [2161 0.796 [2095 13.4 [2153 6.2 [1062 4.62 [7343 1.37 [2294 6.68 [3027 2.52 [2050 49.2 [5374 1.69 [3207 10.5 [1 30] [4 33]] [1 100]] [1 91]] [2072 8.46 [2151 1.2 [29 36] [1 62]] [1 33]]] [33 40]] [29 65]] [7 28]] [2241 9.43 [29 76] [37 33]]] [35 78]] [3227 5.22 [2219 0.627 [1253 3.54 [3435 5.89 [2225 17.5 [1913 16 [2294 0.639 [1783 110 [1997 0.652 [25 15] [1 50]] [35 50]] [35 33]] [4 27]] [1 68]] [29 54]] [29 54]] [2164 1.2 [29 71] [1 27]]] [29 100]]]] [34 25]] [35 82]] [6899 6.06 [5308 6.49 [5412 7.04 [33 53] [33 66]] [7 75]] [1279 6.06 [33 93] [25 85]]]] [7 46]] [5812 6.49 [7009 15.6 [3239 3.5 [112 29.3 [2081 29.3 [2178 14.1 [12 9] [36 53]] [4 17]] [14 55]] [16 60]] [13 40]] [4 30]]] [7390 1.27 [1960 0.611 [2119 36.7 [2286 0.308 [1954 4.45 [2155 2.44 [1935 36.1 [3435 20 [1260 0.55 [23 9.23 [6625 23.7 [1066 3.03 [2939 24.9 [3809 4.35 [2117 34.6 [3435 3.18 [1 26] [35 29]] [29 51]] [1 100]] [33 30]] [11 40]] [33 73]] [23 67.9 [1 22] [30 44]]] [11 21]] [35 61]] [22 35]] [29 66]] [1956 5.55 [35 38] [35 70]]] [2072 3.92 [29 58] [29 71]]] [35 40]] [29 51]] [16 71]]] [4926 8.2 [397 26.3 [397 23.4 [18 81] [18 100]] [18 76]] [18 100]]] [10 98]] [5410 8.2 [1453 0.699 [4397 4.71 [28 65] [28 100]] [28 100]] [28 40]]] [1622 7.63 [5312 12 [7285 6.8 [5808 0.387 [3576 7.99 [5312 5.17 [4558 4.68 [2149 2.21 [6830 17.6 [6900 2.01 [301 3.7 [4682 3.27 [2199 22.4 [1429 74.2 [1895 4.57 [6027 19.6 [6155 3.18 [6332 1.95 [221 19.3 [5108 3.62 [33 6] [12 46]] [30 35]] [4 70]] [1429 24.8 [18 50] [15 85]]] [30 36]] [38 60]] [5 21]] [4 28]] [33 100]] [30 100]] [33 87]] [33 81]] [1 40]] [14 93]] [15 83]] [15 70]] [1783 3.69 [15 100] [15 80]]] [11 41]] [12 84]] [11 100]]] [1708 4.67 [407 6.86 [28 26] [7 73]] [28 95]]] [5753 2.15 [30 83] [30 100]]] [5799 2.54 [7197 0.677 [7101 1.99 [5017 2.09 [4444 18.4 [23 14.6 [1437 3.39 [2939 16.6 [2020 13.9 [2120 7.46 [1999 1.71 [7491 2.54 [2122 12.4 [35 32] [35 66]] [24 28]] [35 71]] [35 100]] [35 58]] [24 35]] [1 58]] [33 19]] [9 75]] [35 86]] [35 86]] [35 80]] [23 28]]] [30 100]] [1078 48.1 [583 0.363 [915 0.869 [4628 2.91 [5202 4.57 [719 1.02 [585 2.16 [2925 1.04 [5759 1.62 [5629 1.12 [5480 4.23 [429 88.3 [1638 1.43 [4630 7.86 [4326 6.42 [2488 7.82 [2463 1.19 [2914 2.89 [3450 4.14 [2259 0.43 [7318 5.75 [811 16.7 [6848 4.26 [635 1.83 [5731 7.94 [21 7] [11 100]] [328 20.2 [9 67] [9 100]]] [35 70]] [1239 7.94 [10 40] [10 90]]] [3 96]] [7255 7.58 [1684 13.2 [3320 1.39 [3310 4.63 [6471 0.824 [10 6] [26 80]] [29 84]] [27 100]] [11 73]] [5588 6.4 [2048 4.08 [4364 7.11 [12 11] [32 100]] [12 81]] [12 87]]]] [3155 1.37 [35 73] [35 83]]] [1078 23.9 [30 66] [0 54]]] [27 100]] [1534 0.786 [1180 2.54 [5692 13.8 [7198 5.15 [8 44] [13 100]] [8 100]] [13 100]] [0 100]]] [27 61]] [7285 2.79 [1151 0.544 [2093 11.2 [6227 0.46 [5412 5.81 [5491 4.7 [4553 0.47 [851 4.72 [2179 6.05 [7324 0.813 [3317 1.9 [11 21] [12 54]] [23 50]] [11 100]] [3929 6.09 [6074 1.07 [17 24] [17 84]] [5 54]]] [1783 39.3 [18 75] [18 100]]] [11 87]] [11 67]] [17 67]] [11 90]] [5 48]] [18 90]]] [14 100]] [2208 11.1 [6086 11.2 [2099 12 [599 26.5 [5206 20.4 [1987 4.22 [1899 42.3 [27 21] [29 28]] [21 65]] [21 75]] [11 50]] [21 88]] [27 100]] [35 66]]] [7186 11.7 [1194 2.18 [756 2.22 [6859 4.42 [1788 5.75 [859 2.49 [560 3.45 [3474 2.16 [22 32] [11 36]] [18 61]] [1078 4.13 [22 94] [22 100]]] [10 100]] [22 100]] [10 57]] [10 100]] [18 80]]] [15 95]] [30 91]] [26 89]] [2039 4.27 [2081 2.2 [21 55] [21 81]] [21 100]]] [663 17.2 [18 56] [4859 15.3 [18 66] [18 85]]]] [429 8.99 [9 53] [7210 2.46 [9 85] [9 100]]]] [7 100]] [4914 2.35 [906 12.6 [2023 6.4 [21 35] [21 72]] [21 71]] [9 70]]] [1239 29.9 [21 80] [24 0.953 [126 3.51 [21 55] [9 66]] [9 100]]]] [4120 3.9 [7634 2.02 [1216 5.27 [7764 1.12 [7353 0.756 [7733 5.71 [3449 4.38 [791 0.0413 [7449 25.6 [957 0.664 [7428 0.428 [2151 10.4 [1087 14.9 [3269 24.4 [2108 0.904 [3555 2.62 [2091 10.6 [2939 2.99 [27 16] [27 50]] [2086 5.18 [27 17] [32 50]]] [32 80]] [9 33]] [27 100]] [17 22]] [4 42]] [29 33]] [448 1.06 [5322 4.76 [4663 24.8 [1899 16.2 [2199 5.44 [978 9.88 [4326 1.57 [27 94] [27 100]] [27 60]] [27 100]] [27 75]] [27 100]] [27 100]] [27 100]]] [23 27]] [286 1.27 [2149 8.69 [1991 2.94 [1451 5.27 [3575 0.96 [2211 1.15 [2931 17.9 [685 12.7 [2280 14.7 [4478 14.4 [4769 2.59 [3972 2.58 [1051 0.77 [6192 3.03 [3309 6.98 [5264 8.47 [35 12] [13 100]] [11 100]] [1078 86.1 [11 80] [11 62]]] [10 56]] [37 50]] [29 100]] [27 57]] [25 50]] [23 81]] [23 90]] [10 75]] [11 100]] [11 50]] [11 87]] [29 33]] [939 3.7 [791 14.4 [27 71] [11 28]] [27 86]]]] [35 82]] [10 100]] [35 95]] [10 100]] [27 100]] [27 96]] [27 93]]]] [6260 2.35 [83 5.82 [6471 9.62 [7382 9.72 [429 9.46 [170 4.17 [1600 4.76 [177 3.83 [7267 9.8 [7734 6.26 [3099 4.33 [7233 6.85 [4655 4.2 [5931 4.2 [5926 3.55 [176 5.33 [4675 1.17 [7609 6.06 [364 0.644 [7755 1.55 [5254 2.09 [4682 1.68 [1059 12.4 [7142 3.26 [1611 8.72 [6247 2.18 [14 11] [20 100]] [14 100]] [20 100]] [6 66]] [33 86]] [10 100]] [20 81]] [39 2.39 [1742 2.84 [4535 0.644 [1997 1.93 [14 37] [14 93]] [14 75]] [19 55]] [17 50]]] [8 87]] [6 50]] [19 54]] [20 82]] [20 59]] [1 100]] [32 82]] [1 76]] [2268 2.15 [18 46] [18 85]]] [4 100]] [3675 2.45 [2251 0.355 [19 75] [19 85]] [12 30]]] [7 100]] [19 82]] [5420 3.94 [6831 9.99 [1011 1.08 [3896 15.6 [7554 2.38 [6866 4.07 [2320 3.7 [7259 9.62 [939 21.7 [7734 1.51 [1164 11.4 [663 6.62 [247 6.67 [7255 38.5 [4205 3.94 [5757 1.05 [6103 4.54 [2701 9.4 [1025 2.7 [3117 12.2 [2939 34.8 [14 16] [5 48]] [31 100]] [2 35]] [32 44]] [32 54]] [29 79]] [14 61]] [13 100]] [3 52]] [2259 14.3 [145 1.37 [32 16] [19 27]] [36 32]]] [13 75]] [4997 5.05 [18 45] [7 100]]] [31 67]] [14 79]] [32 87]] [5 87]] [5267 17.3 [10 70] [10 100]]] [32 77]] [5412 16.7 [1429 13.9 [1993 12.7 [4 25] [1 38]] [5 25]] [17 36]]] [18 88]] [2493 3.94 [13 62] [13 100]]]] [24 75]] [26 87]] [7314 6.42 [1995 2.11 [19 67] [19 95]] [19 50]]] [6859 4.59 [6184 2.2 [7512 31.9 [13 83] [13 39]] [13 100]] [36 60]]]] [17 1.36 [573 1.29 [4513 1.66 [6701 5.49 [7693 2.59 [6287 10.6 [6736 1.65 [6524 12.6 [4742 5.62 [2554 2.96 [1047 8.8 [3931 9.8 [5397 26.3 [7413 6.85 [5348 1.67 [1974 4.56 [4832 1.67 [6977 6.2 [2628 1.59 [1080 21.5 [2275 15.4 [4713 15.6 [7009 1.09 [1429 10.2 [6 47] [6422 10.7 [5963 22.5 [6 62] [6 92]] [6 90]]] [17 36]] [6 92]] [6 90]] [6 100]] [5 17]] [4 55]] [2 47]] [6 96]] [18 47]] [2 41]] [6 100]] [4 64]] [24 100]] [6 100]] [2 23]] [25 58]] [2 68]] [6 81]] [1429 4.95 [4 33] [18 33]]] [6 100]] [6 87]] [2 49]] [4 46]]] [878 2.89 [10 90] [10 100]]] [6065 1.23 [1389 1.48 [1410 3.47 [5046 1.65 [2461 0.379 [4290 31.1 [4198 0.592 [150 1.07 [220 0.611 [6306 2.12 [1696 2.15 [917 2.69 [4614 0.935 [5629 0.416 [429 36.3 [4342 11.3 [5785 1.36 [5271 14.7 [2143 2.28 [4338 3.79 [663 8.41 [4280 11.8 [1078 63.2 [6413 2.07 [4682 5.12 [1564 0.384 [1684 1.7 [1661 4.75 [2323 3.69 [24 6] [32 90]] [18 72]] [7085 0.742 [404 1.41 [11 37] [2 53]] [11 57]]] [17 48]] [1812 2.7 [33 82] [33 100]]] [4997 4.73 [7 28] [7 100]]] [27 18]] [29 80]] [4587 11.1 [29 21] [32 80]]] [24 36]] [23 47.9 [5969 0.546 [1764 11.9 [4769 1.02 [4293 2.65 [6349 1.9 [2996 2.13 [6390 1.92 [1980 30 [957 0.877 [28 6] [27 52]] [2251 0.82 [29 19] [29 47]]] [29 62]] [27 100]] [10 85]] [29 100]] [29 100]] [15 86]] [1980 18.8 [12 44] [29 78]]] [29 64]]] [2259 30.5 [32 100] [32 96]]] [2048 3.07 [1980 3.37 [32 73] [2178 1.09 [32 95] [32 100]]] [10 57]]] [429 14.4 [24 85] [24 100]]] [7011 4.14 [907 6.06 [3622 3.82 [1395 3.84 [3480 2.24 [5976 2.24 [976 1.39 [4071 7.52 [1400 11.9 [7512 0.298 [5040 6.82 [1429 27.2 [3159 4.95 [4321 7.94 [3 38] [10 100]] [27 100]] [2178 0.634 [28 17] [3 21]]] [21 66]] [4279 22.3 [6524 4.59 [5413 0.298 [2259 2.73 [2 30] [32 22]] [29 66]] [7 54]] [29 36]]] [10 57]] [12 57]] [27 100]] [3 100]] [32 83]] [27 100]] [29 100]] [3 69]] [26 87]]] [6417 0.416 [15 98] [15 100]]] [29 97]] [3 85]] [26 78]] [3 95]] [10 100]] [7385 3.77 [10 82] [10 100]]] [6990 2.54 [7512 39.5 [19 53] [10 51]] [10 100]]] [26 90]] [4414 4.31 [4320 0.336 [27 88] [27 100]] [27 100]]] [3 100]] [978 1.83 [1645 2.26 [4154 23.3 [10 53] [10 77]] [15 100]] [10 100]]] [3653 4.07 [885 3.83 [24 98] [24 100]] [24 100]]] [22 100]]] [3045 1.14 [4070 1.73 [3152 13.2 [3634 15.6 [3449 0.155 [6294 13.2 [1161 30.1 [5816 3.94 [3708 0.174 [35 64] [35 100]] [35 44]] [35 84]] [35 62]] [35 92]] [35 84]] [35 96]] [3944 9.77 [3633 1.73 [35 95] [35 100]] [3155 12.1 [35 50] [3744 15.2 [35 78] [35 62]]]]] [35 56]]] [6199 0.978 [32 88] [32 100]]] [2939 15.8 [3095 1.86 [3125 3.55 [5851 2.69 [3901 2.06 [3701 5.26 [5267 1.33 [978 3.7 [37 83] [8 80]] [5368 13.1 [21 27] [11 83]]] [37 100]] [1 40]] [37 28]] [37 94]] [11 33]] [37 100]]] [4292 3.55 [328 23.3 [7722 22.9 [1783 9.59 [3056 6.06 [3734 2.39 [929 11.7 [6583 7.33 [1899 16.7 [1899 3.45 [3424 8.47 [6883 16.6 [6591 2.37 [4654 7.46 [5692 2.54 [6653 7.46 [7526 5.26 [2913 4.27 [5 29] [5 95]] [17 60]] [8 62]] [2526 10.2 [5 54] [7248 2.79 [17 61] [17 87]]]] [5 81]] [134 11.5 [17 42] [17 60]]] [2616 47.5 [5 70] [5 92]]] [5 50]] [17 44]] [5 70]] [17 64]] [17 66]] [17 70]] [5 76]] [112 4.85 [26 18] [19 59]]] [5 72]] [26 43]] [5 85]]] [27 100]] [24 88]] [1429 9.85 [1907 2.54 [5851 0.963 [850 29.4 [791 67 [5412 7.45 [2526 43.2 [2143 1.88 [7101 17.7 [663 9.22 [1959 1.59 [2048 1.86 [3711 6.49 [1078 21.3 [35 82] [35 90]] [35 96]] [35 75]] [35 100]] [30 41]] [35 73]] [35 100]] [35 69]] [37 45]] [35 56]] [35 66]] [35 70]] [35 85]] [4774 7.67 [831 0.377 [1943 0.994 [3462 0.999 [35 63] [35 66]] [1 37]] [3711 0.795 [35 81] [35 100]]] [35 100]]]] [10 100]] [6726 0.921 [1325 4.77 [2002 12.1 [2241 1.03 [1318 2.88 [4416 3.18 [4716 0.327 [739 2.89 [6091 11.2 [5312 9.34 [21 63] [21 100]] [21 63]] [21 100]] [21 100]] [21 100]] [9 66]] [21 45]] [21 66]] [9 55]] [9 50]]] [31 100]] [1391 1.81 [1436 3.48 [527 1.83 [513 5.15 [2628 23.8 [7101 2.99 [3988 3.5 [485 3.32 [5219 1.02 [8 55] [2555 1.79 [3740 1.99 [3424 1.01 [3057 8.09 [939 2.59 [999 1.02 [5219 13.9 [2321 11.4 [6727 3.82 [8 94] [8 71]] [8 83]] [1888 6.85 [429 7.69 [8 93] [8 100]] [8 100]]] [8 100]] [8 100]] [8 85]] [8 100]] [8 100]] [8 100]]] [8 71]] [0 100]] [35 55]] [8 23]] [21 73]] [8 100]] [0 25]] [0 91]]] [13 100]] [23 8.81 [2199 1.18 [22 80] [22 100]] [22 85]]] [4737 24.3 [7549 12.7 [2005 11.5 [6940 3.17 [2549 0.709 [1913 25.1 [7224 1.14 [2223 2.16 [2207 1.86 [6 91] [6 100]] [6 100]] [6 100]] [6 66]] [6 100]] [6 66]] [6 77]] [6 60]] [6 73]]] [3308 4.76 [6918 0.249 [5588 2.1 [631 0.351 [1078 0.543 [28 55] [4565 0.527 [1078 12.5 [28 92] [28 99]] [28 75]]] [28 66]] [2939 6.35 [28 77] [28 100]]] [28 100]] [28 30]]] [5412 1.47 [615 1.07 [4279 5.39 [5280 4.07 [5619 14.9 [634 3.01 [328 19.9 [6883 5.05 [1325 8.2 [2039 4.76 [21 78] [21 90]] [21 54]] [21 40]] [21 55]] [21 100]] [9 87]] [9 100]] [3 72]] [9 42]] [9 53]]] [1696 1.38 [6484 2.73 [7397 2.06 [851 4.37 [7516 3.9 [7413 5.32 [5429 4.34 [685 9.01 [5629 2.65 [3323 2.32 [7254 7.2 [273 2.61 [3100 2.11 [3336 1.57 [1429 23.3 [1078 4.61 [791 11.6 [5373 11 [978 11.7 [7449 7.52 [429 11.9 [4683 12.6 [2900 6.27 [2936 1.44 [4256 4.07 [4200 5.75 [6899 5.68 [5530 5.26 [1899 38.5 [6058 8.56 [5386 11.8 [7512 18.5 [234 0.673 [7729 1.25 [362 2.73 [673 17 [1841 8.85 [2029 5.96 [2251 15.5 [2975 1.58 [5753 7.69 [5211 9.84 [178 8.31 [233 2.01 [2081 40 [2272 2.3 [33 33] [7 100]] [1 47]] [33 92]] [25 78]] [13 57]] [2259 22.6 [13 16] [11 27]]] [31 36]] [29 57]] [1 33]] [11 57]] [25 50]] [15 50]] [7640 6.59 [1 85] [1 76]]] [33 100]] [1 36]] [1239 62.5 [33 75] [33 100]]] [33 88]] [1 60]] [33 69]] [33 81]] [26 66]] [33 100]] [25 93]] [33 100]] [33 75]] [791 3.28 [4154 6.67 [4414 10 [26 15] [29 57]] [29 81]] [29 62]]] [33 66]] [25 40]] [33 85]] [7729 2.06 [896 7.87 [2081 13.9 [29 30] [248 20.8 [8 37] [33 58]]] [392 8.2 [26 43] [26 100]]] [1 91]]] [6732 11.4 [5073 3.91 [6197 3.7 [2913 15.4 [939 2.62 [4657 2.26 [29 16] [1 75]] [29 34]] [26 50]] [25 55]] [29 100]] [26 66]]] [6660 27.6 [232 0.852 [5254 2.7 [4682 4.76 [6772 4.91 [5333 2.62 [7369 16.6 [6782 1.47 [6810 2.46 [6063 3.4 [3635 1.14 [7449 8.6 [2232 9.42 [1577 2.03 [6328 5.81 [4655 1.54 [1870 1.66 [7619 17.7 [5073 2.92 [4948 6.86 [5496 4.79 [7401 0.858 [5965 2.61 [429 2.51 [400 0.0757 [6199 17.2 [1 6.28 [4997 7.76 [1436 7.47 [33 24] [15 27]] [7 100]] [15 61]] [1 40]] [14 71]] [1259 6.9 [3095 8.7 [939 5.53 [2048 8.24 [2039 3.23 [1980 30.5 [6333 1.46 [29 10] [19 27]] [29 53]] [11 20]] [31 70]] [29 58]] [29 100]] [15 40]]] [3 100]] [7 52]] [0 57]] [3 91]] [29 92]] [13 100]] [13 100]] [1 95]] [1279 1.07 [1783 1.75 [11 54] [4 40]] [4 57]]] [7 100]] [1 29]] [29 20]] [1 100]] [22 100]] [32 100]] [31 100]] [2119 2.86 [31 36] [31 81]]] [11 100]] [30 100]] [33 63]] [10 100]] [33 96]] [15 88]]] [35 100]] [1 100]] [1980 11.1 [32 94] [32 80]]] [1 56]] [7640 8.61 [2091 2.44 [23 6.6 [4655 1.33 [12 35] [1 91]] [221 6.15 [7729 7.3 [1 78] [1 100]] [1 85]]] [1 85]] [1 61]]] [3474 5.45 [15 87] [15 100]]] [6581 3.13 [2143 1.44 [26 42] [26 50]] [384 3.13 [26 90] [26 100]]]] [6177 2.79 [7583 5.62 [4154 13.2 [26 74] [33 33]] [25 100]] [25 100]]] [5491 5.26 [25 65] [25 83]]] [7343 5.05 [7734 4.02 [1783 2.02 [1888 8.47 [2939 1.95 [26 53] [25 50]] [6 25]] [18 50]] [5632 2.01 [18 48] [18 100]]] [26 45]]] [2284 0.532 [429 20 [4630 20 [32 33] [12 87]] [5891 21.9 [32 60] [17 69]]] [32 42]]] [25 100]] [25 84]] [1888 10.4 [26 83] [26 62]]]] [2605 1.05 [4179 6.97 [1 13.8 [820 1.42 [6647 1.59 [3703 5.95 [4888 1.4 [429 19.4 [6471 1.69 [5447 1.45 [6960 2.13 [392 12.1 [5211 7.54 [7233 1.72 [6485 1.51 [2270 2.41 [2350 2.62 [5288 5.46 [4283 2.13 [5629 3.82 [377 7.27 [2053 3.68 [2048 0.111 [5693 6.01 [6342 14.7 [4929 2.56 [695 46.5 [1078 29.4 [4721 8.73 [5322 15 [4704 4.9 [7411 7.17 [4767 0.554 [1700 1.23 [7077 4.35 [7623 25.1 [2526 4.05 [3474 7.39 [2939 26.8 [791 26.2 [1899 0.33 [1429 13.7 [15 28] [2939 5.79 [25 21] [30 27]]] [221 1.76 [695 8.49 [1078 4.65 [15 12] [21 30]] [4 41]] [2939 2.11 [6 27] [30 71]]]] [31 58]] [15 55]] [4 80]] [978 2.59 [25 30] [4 47]]] [31 35]] [4 85]] [25 100]] [31 62]] [15 94]] [25 100]] [15 94]] [4 100]] [1239 5.45 [15 31] [10 27]]] [4 72]] [4 71]] [2259 3.82 [4 42] [21 58]]] [4 47]] [24 33]] [30 36]] [26 42]] [15 100]] [15 100]] [30 75]] [31 100]] [21 85]] [25 100]] [31 100]] [11 58]] [1400 2.39 [1078 18.5 [26 90] [25 30]] [26 96]]] [5151 0.797 [2081 1.1 [31 83] [31 100]] [31 100]]] [31 45]] [26 93]] [1168 3.45 [1909 1.92 [7566 0.459 [6663 6.13 [4602 9.52 [4929 4.65 [4664 16.2 [5629 3.06 [828 4.27 [7052 2.99 [4279 25 [6068 49 [4530 3.82 [719 2.35 [3243 11.1 [3452 2.24 [2471 3.5 [6566 6.56 [6505 7.3 [5824 4.42 [6155 3.82 [429 30.1 [25 21] [4 38]] [30 35]] [11 88]] [11 100]] [11 100]] [15 52]] [11 100]] [4 66]] [4 82]] [4 40]] [15 100]] [15 85]] [11 100]] [15 65]] [15 100]] [15 93]] [4 84]] [26 81]] [11 100]] [722 0.459 [1400 14.6 [4 100] [4 85]] [4 100]]] [4 100]] [11 100]]] [31 100]] [15 96]] [968 1.06 [30 100] [30 90]]] [2913 9.43 [3455 14 [11 93] [11 87]] [11 66]]] [11 79]] [15 90]] [7512 3.11 [25 91] [25 100]]]] [7512 44 [5812 1.57 [1025 5.14 [2332 2.64 [6131 2.38 [4408 1.79 [2488 3.4 [2536 1.11 [4224 1.85 [5007 11.1 [2641 5.38 [3115 4.67 [5206 2.02 [7022 3.39 [7034 3.53 [2259 20.3 [643 14.6 [7266 1.74 [21 25] [4154 1.74 [2 100] [2 75]]] [2 50]] [31 71]] [13 82]] [13 100]] [21 88]] [31 100]] [31 100]] [31 85]] [13 100]] [2 33]] [13 100]] [31 100]] [13 46]] [31 100]] [2 51]] [2 53]] [13 64]]] [1327 2.88 [6099 6.89 [2029 1.93 [5931 3.4 [6 91] [6 100]] [6 88]] [6 70]] [9 83]]] [2072 0.481 [35 66] [1959 1.44 [35 84] [35 100]]]] [6772 16.8 [7428 0.183 [2127 0.226 [1822 0.383 [2470 4.14 [1783 134 [4630 2.43 [30 100] [30 57]] [30 57]] [30 92]] [30 100]] [30 90]] [30 100]] [4154 1.89 [1459 5.75 [30 100] [30 88]] [30 75]]]] [4535 1.11 [4572 0.355 [4059 0.308 [6307 0.0948 [6811 0.165 [274 1.61 [5552 3.59 [2402 6.67 [535 0.887 [6681 0.1 [1624 0.513 [23 1.03 [1241 0.0984 [4804 13.7 [7210 9.28 [4154 21.3 [5905 0.32 [5632 0.0863 [1980 24.5 [1673 2.89 [1951 1.57 [6353 2.51 [429 51.4 [1429 64.5 [2466 12.5 [3 20] [31 66]] [2143 1.96 [1899 2.13 [17 36] [1429 98.5 [17 45] [17 100]]] [32 59]]] [21 100]] [14 87]] [10 42]] [17 83]] [3 66]] [7 47]] [19 100]] [32 79]] [5753 4.67 [3 34] [3 92]]] [17 100]] [5753 17.4 [14 83] [14 100]]] [4896 2.83 [7009 7.62 [1997 1.01 [17 41] [6383 0.739 [17 60] [17 85]]] [3 71]] [4630 12.3 [32 50] [17 53]]]] [17 90]] [2227 0.0806 [5892 7.75 [7139 2.86 [4630 23.3 [3446 0.502 [17 31] [17 57]] [17 76]] [17 100]] [5940 2.24 [32 62] [3682 2.31 [14 62] [17 57]]]] [17 45]]] [21 100]] [7210 7.63 [6382 9.18 [14 42] [3 42]] [32 38]]] [14 100]] [32 100]] [32 100]] [32 100]] [4559 19.1 [1980 0.52 [2259 27.5 [429 29.6 [1773 1.26 [17 84] [17 100]] [17 54]] [14 57]] [1783 2.56 [5753 3.1 [5891 21.9 [1899 0.143 [17 44] [17 71]] [3 36]] [17 66]] [17 77]]] [17 100]]] [1980 1.29 [17 90] [17 50]]] [1251 7.46 [3599 3.93 [7058 0.595 [1943 15.5 [4635 5.64 [1769 0.451 [6682 0.981 [5839 0.168 [4635 1.59 [17 50] [19 94]] [19 100]] [968 14.9 [19 70] [17 42]]] [19 36]] [19 36]] [19 82]] [35 100]] [478 3.35 [17 60] [17 83]]] [4639 2.49 [19 100] [19 75]]]]] [1078 42.8 [7256 3.99 [100 0.41 [384 6.81 [2929 0.632 [4859 5.03 [4198 0.672 [7724 1.85 [957 0.311 [168 15.9 [1995 3.23 [17 2.49 [788 4.13 [6406 0.358 [2241 0.394 [144 35.9 [7739 13.9 [738 9.09 [6375 3.92 [1769 9.21 [23 17.8 [7314 3.12 [2268 5.08 [939 10.6 [685 12.4 [5484 5.18 [10 16] [18 55]] [14 37]] [13 57]] [18 25]] [18 57]] [19 33]] [31 50]] [20 46]] [18 100]] [10 35]] [19 52]] [10 45]] [33 33]] [7734 5.73 [6 45] [19 50]]] [13 72]] [25 25]] [19 62]] [383 3.4 [10 51] [429 25.7 [18 70] [16 50]]]] [5480 1.9 [5345 5.41 [19 54] [19 80]] [18 100]]] [168 0.444 [19 40] [19 66]]] [18 100]] [2929 7.83 [25 87] [25 54]]] [18 48]] [2259 10.6 [23 181 [19 70] [22 33]] [1961 5.06 [94 2.85 [1079 6.83 [2225 1.01 [176 3.47 [19 35] [19 54]] [19 60]] [19 73]] [13 40]] [18 55]]]] [6822 3.59 [2023 0.931 [19 76] [19 100]] [19 100]]] [1094 0.57 [6877 0.328 [5791 0.691 [5674 2.97 [2275 2.85 [6973 1.43 [4228 1.27 [218 1.64 [1161 6.06 [5345 11.4 [10 42] [18 45]] [10 100]] [104 0.634 [10 96] [10 100]]] [10 83]] [10 100]] [19 60]] [19 83]] [10 100]] [10 100]] [7449 3.94 [1094 13.2 [6000 3.57 [10 96] [10 100]] [10 57]] [10 100]]]]] [4552 0.314 [791 2.11 [3463 3.57 [4602 1.39 [2394 1.89 [1116 2.3 [377 7.26 [3558 1.72 [7548 3.14 [968 22.6 [7314 8.67 [1754 0.809 [4702 2.58 [269 1.56 [719 0.321 [5099 1.12 [6380 1.46 [3368 5.54 [6584 0.879 [5294 8.46 [2336 2.7 [6859 8.74 [4430 12.2 [4414 55.8 [3051 3.55 [1656 5.26 [7132 0.782 [4896 4.75 [647 5.62 [4326 9.14 [5514 3.94 [7068 2.82 [2259 52.2 [5994 8.42 [5816 0.785 [4718 22.9 [3251 59.7 [4154 27.8 [6552 1.54 [6711 2.59 [5637 3.88 [6276 5.8 [6581 0.546 [1429 56.9 [4690 3.48 [2127 0.934 [6134 8.18 [4852 4.76 [7354 6.02 [5151 2.26 [355 4.07 [5753 1.83 [7381 33.4 [4431 1.92 [30 16] [26 37]] [7 77]] [1429 9.13 [1888 20.2 [32 30] [14 27]] [38 24]]] [30 77]] [24 58]] [26 50]] [29 50]] [25 50]] [1 50]] [8 100]] [14 29]] [4 27]] [29 69]] [14 50]] [30 83]] [4 100]] [32 38]] [14 80]] [7 90]] [4 91]] [7 91]] [36 30]] [7 90]] [5 64]] [32 54]] [7 100]] [14 43]] [4 60]] [3 100]] [30 100]] [15 84]] [15 100]] [30 72]] [36 100]] [8 86]] [5 41]] [3368 18.9 [36 100] [36 45]]] [6382 23.7 [4896 0.878 [7210 3.16 [17 48] [14 42]] [14 50]] [14 50]]] [6 34]] [5 25]] [26 88]] [30 96]] [1396 1.83 [4896 0.457 [6380 3.19 [17 50] [17 100]] [17 80]] [17 71]]] [30 82]] [28 82]] [1980 3.14 [14 75] [14 100]]] [2628 25.5 [19 38] [17 34]]] [7 65]] [7695 2.3 [30 98] [30 100]]] [30 96]] [26 92]] [5 69]] [221 3.89 [3905 14.4 [7133 0.978 [2526 0.271 [847 16.7 [6812 0.634 [7073 1.05 [811 5.41 [5564 2.71 [6682 1.35 [3051 0.695 [286 1.99 [2470 11 [3480 4.35 [4876 1.67 [3929 9.75 [4558 0.324 [2628 18.5 [5290 1.11 [5225 5.05 [4154 11.5 [5632 3.12 [7381 1.11 [7334 2.82 [1400 3.13 [4565 0.137 [7068 1.71 [6328 7.92 [6857 6.83 [5851 15.8 [1664 7.53 [6581 32.5 [7255 6.4 [2913 2.48 [5753 6 [2939 9.97 [14 22] [7 20]] [30 20]] [32 43]] [15 50]] [5 65]] [3 63]] [14 70]] [28 90]] [24 90]] [36 52]] [19 55]] [26 58]] [17 54]] [14 23]] [7 45]] [32 49]] [30 100]] [2939 0.692 [8 20] [24 71]]] [5 54]] [17 55]] [17 38]] [24 37]] [32 91]] [11 32]] [5211 1.87 [16 28] [11 100]]] [30 100]] [1654 0.51 [32 46] [7210 0.618 [17 71] [17 100]]]] [14 100]] [2470 24 [15 60] [15 100]]] [5940 1.71 [17 81] [17 44]]] [32 95]] [29 100]] [4478 4.15 [6591 2.69 [7066 0.412 [5001 2.89 [7381 9.81 [7665 7.36 [851 4.29 [7305 1.55 [32 27] [3 25]] [19 75]] [6732 3.48 [6887 4.67 [7 45] [5 54]] [17 24]]] [5 47]] [7 100]] [17 100]] [17 74]] [26 76]]] [4 100]] [5316 23.8 [32 44] [32 96]]] [2939 1.43 [2628 1.96 [28 14] [5034 2.76 [30 93] [30 100]]] [24 28]]]] [7189 0.383 [6809 10.1 [32 66] [2136 0.141 [1674 0.709 [32 100] [32 80]] [32 100]]] [5839 1.72 [17 62] [32 100]]]]] [5576 8.21 [24 91] [24 85]]] [590 6.09 [569 2.04 [5941 3.76 [2752 0.512 [1783 20 [1239 8.55 [4587 4.76 [7233 1.27 [5404 4.35 [5480 7.54 [4611 9.22 [1220 2.09 [2259 2.92 [791 36.3 [5403 26.3 [31 79] [7585 8.2 [5725 5.88 [31 96] [31 100]] [31 100]]] [31 42]] [1400 1.67 [896 1.61 [7169 3.4 [31 82] [31 75]] [31 100]] [31 100]]] [31 100]] [31 100]] [31 42]] [3 100]] [31 100]] [31 44]] [3 50]] [5403 4.33 [31 46] [1844 0.178 [4997 14.2 [3 56] [7 100]] [31 77]]]] [7 60]] [3 91]] [3 100]] [3 100]]] [1899 12.5 [177 14.1 [7737 1.87 [3027 19.5 [7583 3.65 [2913 2.87 [4279 19.9 [19 55] [2342 2.54 [32 26] [31 38]]] [19 27]] [1 75]] [32 90]] [7517 2.52 [2199 3.99 [6830 1.88 [6131 0.63 [2137 0.288 [5288 5.3 [2091 3.26 [4571 0.901 [5346 5.91 [7010 4.86 [1079 29.1 [3027 2.19 [5410 7.56 [6342 1.16 [5918 18.8 [7665 37 [7665 9.89 [39 1.97 [168 68 [144 27 [19 76] [4279 3.38 [19 85] [18 38]]] [19 86]] [19 66]] [6320 1.01 [19 85] [19 100]]] [19 58]] [19 70]] [19 100]] [19 63]] [19 70]] [19 58]] [19 66]] [28 40]] [19 87]] [19 34]] [19 55]] [19 92]] [13 30]] [14 92]] [19 40]] [25 88]]] [19 89]] [1980 12.5 [19 48] [4159 0.592 [1995 3.5 [12 21] [19 25]] [1 42]]]]] [4324 1.48 [2589 1.13 [3952 1.25 [2491 2.31 [2334 0.364 [8 66] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]]] [2257 0.0468 [2001 0.942 [5994 0.112 [1769 0.218 [4770 0.0494 [29 89] [29 100]] [29 90]] [29 100]] [29 100]] [29 100]]] [3844 0.384 [7441 0.242 [1997 0.235 [7623 1.05 [1253 2.02 [4568 2.09 [2526 1.36 [392 2.28 [3097 14.3 [455 1.51 [1911 1.09 [6294 2.04 [27 99] [27 100]] [27 100]] [27 100]] [451 3.5 [27 83] [27 100]]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]]] [5602 7.39 [5528 1.27 [15 93] [15 100]] [15 87]]] [4418 15.5 [5727 1.48 [811 1.15 [2225 1.22 [5308 10.5 [4398 2.51 [6173 2.04 [31 69] [31 100]] [31 100]] [31 64]] [31 100]] [7169 1.97 [31 94] [31 100]]] [31 100]] [31 100]]] [7421 0.887 [1769 5.03 [7739 0.999 [7123 4.97 [906 0.956 [7301 0.0878 [4308 1.11 [7009 1.01 [1723 7.3 [5484 3.65 [7734 4.62 [1888 10.1 [2029 8.46 [2081 11.6 [2955 2.02 [16 13] [16 33]] [29 57]] [6 62]] [18 44]] [18 92]] [18 84]] [24 44]] [9 42]] [19 75]] [19 58]] [9 72]] [16 83]] [19 83]] [4 41]] [6749 25.4 [132 0.904 [5637 2.73 [4533 2 [2558 12.8 [6199 9.06 [685 13 [4712 6.07 [2939 33.2 [300 0.673 [6169 0.478 [1454 0.938 [1239 7.27 [6 60] [1356 10.4 [4673 4.65 [7580 3.03 [5598 22.1 [4939 3.76 [7666 18.8 [2419 3.7 [6166 1.73 [2569 9.9 [6 86] [6 70]] [6 100]] [6 75]] [6 50]] [16 40]] [6 100]] [6 100]] [4891 0.907 [6920 6.16 [6 100] [6 78]] [6 100]]] [6 72]]] [6 90]] [6 100]] [6 100]] [16 46]] [6 100]] [6 50]] [19 42]] [6 50]] [6 97]] [6 40]] [18 71]] [16 58]]]] [1585 1.11 [7104 0.191 [2665 5 [5607 0.241 [6409 7.78 [7281 2.49 [1429 26.2 [7759 5.88 [5577 10.2 [2006 0.277 [6113 0.816 [7123 9.17 [4279 2.49 [2672 15.3 [200 0.204 [2199 22.3 [2117 5.32 [4601 1.71 [2689 13.2 [2654 8.91 [2949 13.9 [7206 1.91 [2710 4.35 [2081 18.6 [5985 17.5 [3027 6.32 [7009 10.6 [190 0.652 [6279 14.1 [3679 0.205 [2951 16.4 [2649 13.5 [1 27] [6 35]] [4496 3.17 [6839 23.2 [5393 5.11 [7169 6.98 [4564 6.45 [38 61] [7 66]] [1 42]] [38 57]] [16 50]] [38 100]]] [38 84]] [38 93]] [38 93]] [16 18]] [38 91]] [16 37]] [21 18]] [38 33]] [38 75]] [30 26]] [2682 5.38 [16 31] [13 25]]] [16 81]] [36 50]] [12 42]] [15 41]] [38 95]] [2727 31.5 [16 57] [6 50]]] [29 45]] [16 53]] [14 50]] [7476 1.36 [38 82] [38 72]]] [2712 14.1 [7 23] [16 70]]] [13 41]] [2949 9.03 [7369 3.37 [38 43] [6950 2.33 [7065 0.399 [2102 3.8 [1446 1.61 [1458 0.406 [4895 2.39 [2652 12 [17 34] [17 53]] [4609 23.8 [17 90] [2951 49.9 [17 55] [19 60]]]] [17 88]] [32 77]] [32 63]] [19 62]] [17 76]]] [19 52]]] [6 37]] [16 42]] [17 100]] [2948 0.0442 [38 79] [38 100]]] [2232 0.797 [7121 0.898 [1899 4.01 [190 1.23 [2712 3.36 [2733 19.2 [16 55] [16 42]] [38 50]] [2 50]] [38 66]] [2728 7.11 [1239 0.98 [16 55] [16 87]] [16 92]]] [16 33]]] [14 66]]] [4630 1.46 [7330 31.1 [6363 1.62 [7397 2.11 [5561 5.02 [2235 0.319 [2246 0.0449 [5574 1.22 [5851 20 [3754 3.57 [1698 39.8 [663 19.9 [4414 1.32 [1913 1.94 [2202 0.289 [6524 16.6 [1698 13.9 [1293 3.65 [6082 0.266 [7665 3.23 [25 97] [25 100]] [25 100]] [25 100]] [1698 16.5 [25 85] [25 100]]] [25 93]] [25 100]] [1783 34.5 [25 100] [25 77]]] [25 75]] [25 85]] [25 81]] [25 83]] [25 70]] [25 83]] [25 100]] [25 66]] [25 50]] [25 100]] [25 100]] [25 75]] [25 100]]] [3030 0.86 [475 52.1 [1783 3.54 [4533 4.39 [1068 10.7 [4382 0.276 [5969 6.34 [1429 19.7 [2461 0.535 [3269 1.6 [2939 1.07 [27 43] [27 85]] [27 83]] [27 100]] [27 50]] [27 60]] [27 100]] [27 60]] [8 37]] [5218 1.4 [27 44] [10 100]]] [11 44]] [27 100]]] [2597 4.78 [7397 0.483 [2913 3.55 [5845 2.2 [4369 4.6 [4799 1.37 [7491 45.5 [4768 23 [4338 25.2 [673 3.88 [1239 1.83 [2740 6.17 [3357 31.6 [282 6.02 [5238 7.87 [854 1.98 [978 21.7 [435 4.62 [2591 0.942 [6853 6.29 [7742 51.1 [4279 2.37 [6552 1.98 [7744 1.85 [7722 6.8 [2241 2.89 [2628 14.1 [1980 13.2 [4611 1.93 [3027 18.2 [5812 4.5 [4 39] [4 51]] [4 89]] [4 50]] [2259 9.8 [2 50] [2 33]]] [7742 37.2 [7742 11 [4 81] [1078 53.2 [4 97] [4 66]]] [4 66]]] [4 50]] [4 33]] [4 96]] [4 100]] [19 44]] [4 50]] [31 87]] [2628 9.65 [4 100] [4 75]]] [22 58]] [6550 1.71 [4 72] [4 100]]] [4 100]] [4 84]] [18 100]] [2259 29.2 [4 100] [4 88]]] [4 100]] [4 17]] [38 25]] [7032 12.5 [4 60] [2 78]]] [2 80]] [9 42]] [10 55]] [10 87]] [10 100]] [2913 27.5 [2628 3.41 [31 43] [31 80]] [25 61]]] [25 100]] [2 86]]] [4939 11.6 [2029 4.75 [5090 11.4 [1783 22.1 [2210 1.67 [7404 4.35 [2225 4.7 [2535 0.879 [2616 4.95 [2143 3.24 [6 63] [6 57]] [6801 1.13 [6515 21.1 [4675 2.01 [6 97] [6 100]] [6 87]] [16 57]]] [6 57]] [6 50]] [1311 3.37 [6098 1.17 [6 96] [6 100]] [6 87]]] [6 100]] [6 77]] [6 78]] [6 100]] [6 100]]] [6934 2.48 [6933 12.2 [2125 23.4 [2396 8.14 [2063 6.56 [4547 1.08 [6100 22.9 [6 87] [6 50]] [6 100]] [6 100]] [6 100]] [16 57]] [6 70]] [6 100]]] [1658 20.9 [3 100] [3 88]]] [4876 4.86 [3993 26.3 [5136 20.8 [4690 7.76 [2108 1.12 [289 1.67 [20 100] [20 55]] [20 80]] [7596 1.54 [5211 20.3 [4690 13.7 [20 100] [5931 2.46 [5772 0.873 [20 98] [20 100]] [20 100]]] [5410 11.4 [7570 13.7 [1769 7.69 [20 94] [20 100]] [20 100]] [20 88]]] [20 100]]] [20 56]] [20 75]] [20 64]]] [7203 3.69 [6424 14.7 [6499 9.07 [5397 9.85 [2611 15.3 [5756 3.96 [6439 0.859 [2554 5.45 [4663 0.732 [2628 3.26 [5988 3.72 [6289 0.657 [5408 0.971 [2199 2.04 [6004 1.36 [5716 15.9 [6398 2.1 [2549 20.1 [6167 0.826 [7512 13.5 [6 89] [1374 1.69 [6515 1.44 [1429 2.99 [6 87] [6 100]] [6 100]] [6 100]]] [6 100]] [6 92]] [6 100]] [6 93]] [6 100]] [6 100]] [6 100]] [6 100]] [6 83]] [6 80]] [6 66]] [2558 1.62 [5597 4.02 [1429 7.83 [6 91] [6 100]] [6 63]] [6 100]]] [6 66]] [6 80]] [221 12.4 [6 66] [6 100]]] [6 60]] [2549 5.12 [6 85] [6 76]]] [6 62]] [6 55]]] [4114 2.29 [6078 0.251 [1587 1.05 [939 2.37 [906 7.59 [7032 12.5 [4421 1.11 [5294 12.5 [1634 2.13 [4790 2.73 [13 63] [13 85]] [1851 3.82 [13 97] [13 100]]] [13 55]] [13 57]] [13 63]] [27 45]] [27 50]] [5509 0.348 [1783 25.8 [13 62] [4703 8.72 [791 0.147 [1634 3.07 [13 95] [13 100]] [13 100]] [13 92]]] [13 100]]] [13 100]] [13 66]]] [6581 2.04 [5405 0.265 [5412 1.09 [2266 3.03 [682 4.77 [5306 1.89 [2072 0.354 [2350 1.24 [4806 1.46 [2048 0.692 [1706 1.96 [7271 3.79 [7308 2.67 [4 88] [31 100]] [31 100]] [4 100]] [4 37]] [4 100]] [31 100]] [31 76]] [31 100]] [31 52]] [31 100]] [5267 5.07 [4 54] [1713 3.94 [31 70] [31 100]]]] [31 100]] [4 100]]] [7665 15.6 [3220 3.17 [5932 0.886 [232 1.45 [394 0.838 [4282 1.77 [2259 27.2 [1929 1.11 [429 7.17 [4593 0.932 [2259 7.57 [4214 2.97 [695 7.13 [5034 3.6 [5067 2.75 [5985 2.39 [1996 6.72 [1611 1.59 [6528 1.34 [7413 2.42 [2913 1.94 [7623 36.4 [5086 0.652 [276 14.6 [2939 65.4 [5759 3.36 [2178 9.53 [5692 37.2 [5647 7.77 [30 24] [5110 31.3 [33 64] [12 57]]] [22 50]] [15 53]] [33 100]] [38 50]] [33 94]] [33 90]] [30 70]] [30 66]] [221 5.38 [33 76] [33 91]]] [7729 13.4 [33 82] [1 100]]] [2695 1.59 [30 88] [30 96]]] [33 100]] [30 100]] [30 76]] [30 85]] [22 28]] [5140 6.23 [33 80] [5753 7.67 [33 100] [33 90]]]] [2954 1.78 [328 84 [6082 3.03 [6569 0.394 [30 56] [36 55]] [12 87]] [30 86]] [30 100]]] [15 100]] [7493 0.911 [1078 20.3 [6529 14.6 [429 39.2 [6993 1.01 [7624 1.27 [5219 2.11 [5225 1.1 [560 7.94 [6159 0.924 [4601 5.49 [1429 16.5 [4768 3.53 [6732 4.2 [21 10] [2 41]] [20 25]] [30 26]] [0 50]] [16 36]] [18 100]] [30 78]] [8 100]] [30 100]] [15 100]] [756 0.438 [3 21] [3 75]]] [22 77]] [7335 4.83 [957 3.78 [1888 3.34 [5765 1.51 [1980 25 [1400 20.3 [8 16] [10 76]] [22 43]] [22 100]] [8 55]] [4369 1.29 [27 50] [27 100]]] [6524 2.42 [22 89] [22 100]]]] [15 56]]] [8 91]] [5629 2.22 [5299 1.88 [5330 1.36 [2550 1.81 [7018 1.43 [2019 3.5 [6409 4.35 [5122 0.542 [112 19.6 [1400 4.49 [6155 7.85 [248 0.789 [5789 3.11 [1888 3.7 [30 73] [8 28]] [10 80]] [33 28]] [30 77]] [10 62]] [22 46]] [5326 2.46 [30 96] [30 100]]] [30 100]] [34 100]] [30 100]] [8 100]] [30 98]] [11 57]] [15 100]]] [3 100]] [30 92]] [66 2.54 [791 5.27 [33 85] [33 71]] [33 100]]] [30 100]] [8 96]] [5368 20.9 [5122 1.49 [1239 15.9 [2260 0.516 [7169 4.31 [957 3.74 [5851 12.9 [5211 13.5 [248 21 [7719 4.35 [5693 4 [33 8] [4 26]] [2 43]] [25 50]] [791 1.95 [30 64] [30 90]]] [32 36]] [30 75]] [7169 8.03 [19 50] [17 23]]] [30 100]] [33 66]] [30 100]] [25 77]]]] [24 0.517 [6947 2.23 [7245 1.35 [7616 1.41 [2695 1.06 [5965 0.196 [5067 0.713 [4851 2.66 [2628 6.79 [5269 1.57 [5007 1.74 [7721 0.14 [1116 0.459 [6134 1.21 [221 17.3 [144 12.8 [4200 1.06 [216 20.8 [3 95] [3 83]] [3 100]] [3 61]] [30 66]] [3 55]] [3 68]] [3 100]] [3 100]] [10 71]] [3 28]] [3 54]] [3 100]] [3 100]] [30 95]] [3 100]] [30 76]] [30 60]] [3 100]]] [5231 0.126 [4092 0.795 [7381 0.461 [6529 0.0906 [3088 0.0998 [6189 0.74 [1628 0.0734 [3458 1.15 [877 0.129 [3803 0.164 [5705 0.254 [5117 0.247 [384 0.189 [2808 0.125 [1708 0.283 [5310 0.184 [6853 1.08 [4398 6.91 [7255 3.55 [3559 0.53 [968 0.988 [5225 0.333 [4369 0.886 [7571 1.72 [6982 1.34 [1980 15.1 [2780 0.392 [4501 0.952 [7734 3.24 [5462 2.98 [2701 0.64 [558 2.41 [5211 1.12 [6665 3.79 [4934 1.33 [2846 2.99 [7516 1.8 [695 3.6 [1400 4.35 [2580 0.649 [6182 1.66 [3292 0.197 [6177 6.41 [3708 0.13 [3480 1.43 [5972 1.47 [4154 9.19 [4832 0.441 [328 6.02 [2331 0.949 [6714 1.68 [6325 0.289 [3262 5.24 [1899 93.7 [1704 0.609 [731 1.75 [5254 1.32 [980 4.87 [4365 0.802 [7665 0.0792 [5827 0.519 [673 2.97 [1148 4.35 [1429 24.3 [3273 0.941 [976 1.31 [1038 1.66 [3743 1.1 [5751 2.79 [819 0.963 [7512 0.156 [4331 5.11 [5065 3.7 [435 4.42 [1783 13.7 [3310 6.85 [3652 3.82 [23 11] [24 86]] [6068 5.38 [23 73] [23 66]]] [232 0.362 [1340 5.17 [33 9] [33 71]] [33 71]]] [438 13.9 [23 48] [6 60]]] [15 100]] [27 88]] [2023 2.65 [7764 3.76 [2178 2.32 [1429 22.5 [10 17] [2 42]] [22 40]] [10 87]] [10 45]]] [27 100]] [23 95]] [35 83]] [23 100]] [27 100]] [3860 0.49 [2752 41.7 [11 73] [1 35]] [11 100]]] [4769 0.581 [1830 1.11 [1533 7.39 [6300 1.22 [978 1.4 [1680 2.65 [5891 1.29 [3873 1.17 [6092 2.24 [1753 4.56 [3514 1.27 [1684 1.55 [2847 10.4 [28 7] [22 100]] [6074 10.6 [11 54] [11 86]]] [35 78]] [22 63]] [32 79]] [2752 9.13 [32 100] [32 77]]] [1714 3.93 [5742 8.11 [112 1.29 [4865 1.95 [5368 1.25 [2246 0.172 [17 26] [38 42]] [6566 2.33 [17 88] [32 70]]] [3 100]] [3 42]] [14 44]] [17 50]]] [22 100]] [5390 7.36 [6134 3.36 [2752 65.8 [1630 4.48 [6891 5.76 [430 7.45 [978 42.8 [2207 1.42 [5 26] [16 57]] [19 32]] [22 55]] [19 50]] [7 37]] [23 63]] [7 50]] [38 45]]] [1911 0.608 [28 94] [28 100]]] [2753 4.39 [37 50] [37 83]]] [11 100]] [29 92]]] [15 100]] [26 56]] [11 100]] [6888 2.7 [6584 0.645 [4673 0.412 [6031 4.16 [1533 1.35 [896 2.47 [6106 0.738 [7609 27.4 [2488 4.18 [2526 0.361 [4897 0.119 [4883 3.31 [7680 0.855 [7301 5.37 [5480 1.6 [4505 1.72 [4200 1.6 [32 22] [14 56]] [7512 24.6 [32 100] [32 75]]] [18 46]] [1783 3.88 [14 64] [18 50]]] [791 0.323 [10 71] [10 100]]] [14 92]] [7665 11.6 [145 6.96 [4895 2.93 [19 27] [18 50]] [19 100]] [32 46]]] [100 1.02 [4929 4.76 [2591 8.59 [7737 0.817 [573 0.664 [1207 0.745 [7335 17.6 [18 10] [32 77]] [2 88]] [1062 7.87 [5412 16.2 [4 18] [17 33]] [2 41]]] [24 39]] [17 78]] [4 42]] [19 62]]] [13 82]] [8 87]] [32 100]] [7133 1.13 [1141 0.816 [1745 4.2 [7600 4.84 [967 0.64 [6310 1.66 [6367 1.61 [4851 3.65 [5197 8.27 [1059 6.53 [7354 2.48 [5 18] [18 35]] [2 70]] [18 64]] [14 22]] [4 94]] [663 16.2 [2763 7.49 [23 8.18 [791 13.7 [5 47] [6581 7.36 [5 22] [5 70]]] [1062 4.1 [23 14.7 [19 63] [5 50]] [5 41]]] [31 37]] [5 57]]] [4 90]] [32 77]] [14 100]] [4 50]] [4 100]]] [5 86]] [22 60]] [6 79]] [5383 18.7 [7712 0.645 [7722 6.72 [17 57] [5 35]] [5 60]] [19 61]]] [5 83]]] [660 0.565 [2199 2.55 [4364 28.3 [1239 15.7 [23 100] [23 83]] [23 60]] [23 75]] [807 0.229 [23 94] [23 100]]]] [26 72]] [1980 1.14 [10 96] [10 100]]] [6471 1.2 [7253 6.95 [5523 3.2 [1429 10.2 [4 26] [1009 0.826 [1136 0.407 [5519 3.55 [132 5.63 [207 3.1 [653 3.15 [3248 7.94 [7682 1.33 [3057 1.55 [5880 4.9 [1899 7.94 [5677 0.956 [4719 1.66 [3931 10.9 [7248 1.13 [7354 1.38 [4001 4.13 [17 33] [5 88]] [1239 0.728 [5 47] [18 45]]] [5 72]] [5 77]] [429 18.3 [17 100] [17 63]]] [38 47]] [17 25]] [17 76]] [5 100]] [17 91]] [5 81]] [5 77]] [5 92]] [16 38]] [19 100]] [19 87]] [5 38]]] [19 88]] [17 64]] [1888 3.36 [26 57] [26 100]]]] [2610 0.555 [2902 2.72 [1690 1.87 [13 25] [999 0.359 [17 70] [17 63]]] [17 94]] [17 88]]] [7491 0.861 [1980 5.27 [23 68] [23 86]] [23 100]]] [5605 4.27 [37 90] [37 62]]] [28 100]] [22 87]] [32 61]] [3262 1.57 [4997 1.48 [2925 1.89 [3008 23.2 [3747 0.406 [6544 1.05 [3045 1.42 [673 7.58 [3308 7.59 [432 4.98 [3332 2.05 [6604 6.19 [286 6.02 [248 2.2 [6457 0.418 [6042 4.62 [906 0.206 [7287 1.55 [6621 5.25 [2616 4.93 [7231 2.57 [5579 3.77 [5969 20.9 [1888 5.16 [5106 5.63 [3163 0.931 [2802 2.56 [929 4.95 [28 19] [23 77]] [29 87]] [25 38]] [28 100]] [18 17]] [26 66]] [14 100]] [16 47]] [5 30]] [28 48]] [11 100]] [2251 0.432 [28 37] [28 50]]] [18 83]] [25 85]] [26 21]] [7491 0.642 [939 8.55 [23 35] [27 40]] [23 92]]] [30 100]] [35 82]] [26 53]] [23 43]] [5695 4 [408 2.29 [26 75] [26 95]] [1 71]]] [35 73]] [14 80]] [11 100]] [3332 2.04 [35 42] [35 100]]] [939 3.36 [26 94] [26 100]]] [7 100]] [37 90]]] [477 5.96 [4279 5.43 [7009 5.81 [3905 1.25 [1995 3.15 [328 4.92 [7169 4.63 [5753 8.07 [6732 5.56 [324 1.27 [1089 9.78 [2820 3.14 [1207 5.57 [2 50] [4 63]] [2 92]] [22 70]] [2 83]] [6732 14.4 [7544 1.44 [2 81] [2 83]] [2 64]]] [24 33]] [2 60]] [2 27]] [4 47]] [17 87]] [4 32]] [2 100]] [2 100]]] [7542 5.57 [6374 1.78 [5412 1.2 [3636 1.46 [3916 1.9 [1025 5.18 [7009 3.6 [7634 0.271 [2517 5.26 [3875 4.76 [7313 2.39 [4665 26.8 [5989 5.25 [7512 2.04 [6300 2.59 [5777 1.66 [2793 3.11 [5738 5.38 [6809 3.17 [1133 2.26 [5034 3.19 [4170 6.49 [6926 6.85 [7453 11.4 [7457 4.67 [2384 6.04 [5360 2.67 [310 6.87 [6899 6.74 [5267 1.33 [23 11] [13 34]] [33 100]] [16 46]] [33 100]] [10 100]] [15 85]] [23 72]] [2 55]] [32 77]] [2752 25.4 [32 50] [14 79]]] [26 52]] [32 95]] [15 100]] [4324 1.18 [4117 3.94 [23 25] [27 100]] [23 66]]] [1576 1.93 [26 57] [26 100]]] [28 92]] [2260 4.33 [4851 12.2 [4799 1.63 [2793 1.19 [573 2.99 [826 11.7 [5 17] [32 100]] [5 55]] [14 23]] [32 76]] [14 54]] [18 68]]] [31 72]] [27 84]] [20 94]] [32 100]] [24 95]] [27 96]] [2993 3.29 [2753 12.5 [7346 6.17 [642 1.19 [5 30] [19 46]] [5 90]] [19 37]] [5 72]]] [1049 3.07 [663 1.65 [144 22.2 [957 1.9 [2259 6.27 [24 33] [24 78]] [27 80]] [19 50]] [2 57]] [2 100]]] [6382 2.3 [32 78] [32 83]]] [6260 7.48 [24 84] [24 74]]] [6524 0.846 [2548 0.935 [5668 0.597 [5420 2.16 [5914 0.249 [7354 3.51 [5660 0.624 [2628 2.32 [4169 1.83 [2518 3.59 [24 17] [24 94]] [24 100]] [2 34]] [4187 6.07 [2793 1.89 [5659 1.5 [4428 6.68 [978 8.54 [4833 0.924 [5664 14.3 [5819 2.87 [2 42] [4 38]] [2 16]] [2 70]] [6926 6.86 [4748 1.2 [2 42] [2 44]] [2 90]]] [2 90]] [2 83]] [24 69]] [1072 12.9 [17 60] [2 93]]]] [18 52]] [1025 9.94 [4 48] [2 72]]] [13 95]] [28 40]] [24 83]] [6525 1.13 [155 3.5 [4611 1.38 [3100 0.846 [28 61] [1 100]] [28 100]] [1 100]] [1 77]]]] [6337 0.949 [2616 2.44 [791 4.73 [24 65] [19 42]] [24 100]] [19 66]]] [32 100]]] [6173 0.763 [5423 1.11 [6768 4.29 [3067 3.45 [7295 5.05 [4430 14.7 [2470 4.85 [556 3.5 [3928 1.25 [3664 1.19 [7449 11.6 [2259 2.51 [3874 2.01 [4213 2.99 [2202 4.07 [826 3.5 [2753 5.62 [7512 6.93 [12 68] [12 44]] [36 27]] [12 100]] [12 100]] [12 100]] [12 100]] [6091 3.7 [818 4.24 [6621 1.49 [5716 3.48 [5268 1.39 [2398 1.49 [957 2.35 [5412 9.08 [4279 6.55 [2143 12.3 [36 60] [12 40]] [36 71]] [12 48]] [36 100]] [12 84]] [36 100]] [36 100]] [12 30]] [12 100]] [12 85]]] [12 69]] [36 68]] [12 100]] [36 100]] [23 9.8 [31 75] [15 55]]] [12 90]] [31 100]] [36 100]] [31 100]] [31 86]] [1769 2.75 [31 97] [31 100]]]] [1078 30.1 [2752 32 [5410 0.855 [32 72] [32 71]] [2331 1.86 [15 55] [32 61]]] [1078 34 [15 71] [15 57]]]] [23 8.24 [1031 16.1 [5647 2.37 [3251 2.35 [2039 0.651 [35 86] [35 70]] [35 100]] [35 100]] [35 66]] [35 60]]] [685 3.6 [182 3.18 [112 13.8 [7396 1.62 [6620 1.95 [673 2.96 [25 50] [25 97]] [25 100]] [25 100]] [3 37]] [25 100]] [7 30]]] [3990 2.03 [312 39.2 [37 45] [37 100]] [820 1.67 [5753 0.668 [3297 0.0986 [8 50] [2178 3.21 [1511 0.986 [3506 9.71 [2746 12.4 [2787 0.688 [3838 1.53 [3469 8.2 [1078 11.4 [3262 14.8 [37 96] [37 76]] [37 85]] [37 75]] [37 100]] [37 100]] [37 80]] [37 84]] [37 100]] [37 84]]] [663 4.47 [37 75] [37 43]]] [11 100]]]] [25 99]] [25 100]] [3304 0.795 [7657 1.46 [4425 2.99 [5160 2.5 [4218 0.934 [6089 1.09 [3668 2.78 [1410 2.61 [7737 3.25 [1421 2.42 [4326 0.344 [6177 3.09 [5488 1.99 [3484 1.89 [1568 1.33 [896 0.637 [1141 5.22 [980 4.23 [976 2.11 [7434 1.4 [7449 15.3 [4420 4.45 [5730 1.06 [2259 5.6 [7411 0.917 [2628 5.68 [248 28.4 [429 2.52 [1888 4.95 [15 67] [26 42]] [889 2.16 [5509 4.27 [6196 6.99 [6974 2.99 [15 38] [8 38]] [15 76]] [4 45]] [32 90]]] [26 52]] [4 34]] [791 11.1 [23 6.62 [15 90] [15 100]] [15 81]]] [10 29]] [32 94]] [4665 2.89 [826 12.2 [15 96] [15 73]] [15 100]]] [3322 4.27 [2470 5.99 [15 61] [2844 3.14 [550 15.4 [15 100] [15 66]] [15 100]]] [15 63]]] [12 100]] [27 100]] [2526 3.36 [7185 2.99 [26 92] [26 87]] [26 85]]] [2 84]] [2616 4.05 [4 37] [2 61]]] [32 100]] [15 99]] [12 100]] [221 1.96 [6178 1.72 [25 33] [25 100]] [25 100]]] [7665 1.03 [27 48] [10 24]]] [2 84]] [10 80]] [1410 29.4 [826 1.38 [1980 12.2 [15 100] [15 80]] [15 100]] [15 95]]] [791 24.4 [2 100] [2 60]]] [2 83]] [2474 1.73 [4312 1.9 [2760 2.35 [758 1.33 [2444 19.2 [15 92] [15 70]] [15 100]] [15 100]] [15 100]] [15 100]]] [7169 4.38 [4279 9.3 [14 100] [14 77]] [14 50]]] [15 100]] [12 100]] [15 100]]] [730 0.245 [3610 1.55 [836 0.816 [5480 3.55 [573 0.515 [5403 0.81 [3086 1.2 [731 1.13 [6373 1.08 [3085 2.02 [1528 1.6 [7548 0.675 [6732 3.85 [3928 3.56 [7569 3.35 [4851 0.946 [15 2.13 [3990 0.843 [6711 3.26 [6363 1.33 [3093 8.77 [16 0.292 [6325 1.1 [377 1.17 [5160 5.65 [3687 3.27 [5400 1.83 [6914 0.778 [124 1.47 [7512 4.29 [874 0.904 [3442 2.02 [3823 2.76 [1475 8.81 [6541 3.4 [1621 1.68 [4494 2.65 [6809 3.7 [3779 2.51 [28 20] [37 100]] [32 100]] [36 100]] [14 53]] [12 100]] [37 100]] [37 90]] [11 100]] [4154 3.93 [36 86] [36 71]]] [978 10.9 [7680 1.67 [5426 3.18 [1429 8.5 [7737 3.36 [5192 5.62 [32 19] [4 27]] [10 100]] [5198 2.4 [726 6.64 [2225 0.881 [1646 2.76 [2763 2.62 [14 33] [36 40]] [32 62]] [14 76]] [14 66]] [36 55]]] [36 100]] [10 100]] [5412 2.35 [2 40] [31 57]]]] [32 100]] [4154 6.45 [14 40] [13 100]]] [13 100]] [791 2.49 [37 70] [37 92]]] [14 100]] [6449 0.489 [5693 2.99 [4895 5.79 [28 58] [28 81]] [14 58]] [28 100]]] [28 90]] [36 100]] [12 100]] [286 1.68 [28 55] [28 91]]] [22 100]] [37 77]] [36 100]] [7703 2.2 [5410 1.68 [7340 2.51 [5693 2.28 [14 22] [14 66]] [32 61]] [14 50]] [36 100]]] [14 100]] [5972 4.52 [5753 3.03 [37 53] [37 66]] [12 100]]] [1025 1.82 [7512 2.09 [28 38] [2842 7.24 [7563 2.41 [5812 4.2 [6740 6.22 [7512 30.4 [2752 9.8 [14 90] [5694 1.04 [14 25] [14 100]]] [4851 2.65 [14 38] [17 59]]] [4 33]] [7185 8 [4 54] [17 77]]] [5 70]] [5 100]]] [2259 4.56 [2 44] [13 45]]]] [14 70]] [3262 5.59 [37 88] [37 100]]] [37 93]] [36 89]] [6413 4.2 [3758 3.76 [1690 8.02 [6134 6.36 [5192 3.09 [6395 5.74 [5879 8.94 [1073 3.32 [5972 8.4 [6443 3.45 [286 2.01 [7677 0.724 [5 21] [14 77]] [2 50]] [5 75]] [31 72]] [4 60]] [31 90]] [38 50]] [17 60]] [17 100]] [17 91]] [7 100]] [7 83]]] [706 5.13 [37 100] [37 85]]] [1783 3.85 [2259 30 [719 2.7 [31 90] [31 100]] [31 75]] [31 90]]] [4 32]] [328 2.35 [18 58] [1239 6.09 [7210 3.31 [7722 2.73 [18 58] [18 81]] [18 28]] [38 50]]]] [3262 3.27 [37 70] [37 100]]] [37 95]] [5999 0.327 [28 85] [28 100]]]] [7731 3.71 [4946 1.87 [5206 3.98 [4205 0.99 [5079 4.28 [392 6.94 [7043 1.26 [7310 0.928 [3008 7.22 [4533 1.93 [26 66] [26 83]] [2530 2.35 [25 55] [25 100]]] [25 100]] [25 100]] [26 89]] [25 95]] [26 84]] [26 88]] [18 100]] [18 80]]] [7665 12.7 [328 104 [826 1.51 [5192 1.89 [6350 1.99 [4895 8.76 [6244 2.04 [7514 0.953 [4200 6.17 [7601 1.99 [5680 3.84 [6524 0.945 [6732 7.58 [2628 3.39 [5346 4.2 [1078 28.7 [2763 3.47 [2764 3.66 [1079 1.95 [23 25.8 [18 16] [22 46]] [28 36]] [38 36]] [24 76]] [1239 32.6 [2149 2.42 [1911 8.4 [4 25] [22 36]] [1899 10.4 [2 28] [4 62]]] [25 37]]] [18 87]] [791 4 [429 12.2 [4 45] [4 50]] [2526 6.73 [19 36] [17 62]]]] [36 31]] [28 43]] [22 70]] [18 75]] [22 84]] [22 17]] [22 100]] [30 46]] [10 100]] [32 92]] [7665 10.5 [32 100] [32 91]]] [25 97]] [5034 1.83 [7590 3.94 [685 13.8 [404 20.9 [4851 1.64 [2753 8.76 [2260 3.55 [22 26] [13 23]] [7419 3.03 [22 74] [22 100]]] [14 75]] [28 72]] [2752 22.1 [14 80] [14 57]]] [14 25]] [4876 14.9 [6333 0.768 [705 3.31 [3004 2.49 [3483 2.42 [2993 7.89 [5165 2.3 [4056 3.27 [7535 2.92 [7542 5.72 [2259 6.08 [1429 34.3 [14 89] [6732 6.44 [14 80] [14 71]]] [905 2.99 [144 4.59 [32 48] [7548 2.2 [14 83] [14 90]]] [32 100]]] [32 100]] [14 100]] [32 100]] [14 100]] [14 100]] [32 100]] [14 100]] [32 100]] [2259 2.3 [14 75] [32 98]]] [32 42]]]]] [899 1.97 [3492 2.2 [2526 22.1 [1899 0.632 [14 83] [14 40]] [14 58]] [14 100]] [14 100]]] [1025 15.2 [1402 1.84 [5812 14.3 [3028 2.42 [5926 9.35 [12 92] [12 100]] [12 100]] [12 90]] [12 100]] [12 66]]] [1980 1.77 [5480 0.569 [6946 1.2 [5934 0.305 [5412 6.04 [2804 3.4 [4212 1.82 [811 0.512 [5219 1.39 [5163 0.813 [4699 0.752 [1191 2.18 [4279 10.6 [1574 5.26 [6031 1.89 [5844 1.62 [3356 10.7 [939 2.4 [17 0.956 [1400 9.34 [5222 5.47 [7315 13.3 [1062 3.25 [1184 1.02 [3345 1.51 [4517 8.15 [2746 3.03 [5692 21.9 [5776 6.04 [5753 3.15 [4154 3.61 [6661 2.15 [6184 4.85 [1640 1.99 [6342 11.8 [5067 1.15 [3811 0.978 [7623 0.813 [5824 5.15 [2916 12.7 [978 16.7 [30 41] [23 92]] [30 100]] [11 100]] [5692 1.4 [30 93] [30 90]]] [30 100]] [30 85]] [12 17]] [24 54]] [11 62]] [11 100]] [30 25]] [2752 15.2 [12 36] [6 14]]] [30 100]] [22 25]] [37 37]] [5110 6.67 [30 100] [30 85]]] [30 83]] [11 100]] [11 16]] [30 100]] [30 100]] [10 86]] [4 39]] [6184 15 [10 39] [11 90]]] [8 100]] [22 100]] [22 94]] [4 92]] [791 25 [30 82] [30 71]]] [11 100]] [4359 0.459 [20 90] [20 100]]] [30 100]] [8 90]] [10 100]] [30 96]] [8 100]] [5753 4.93 [4 36] [791 11.9 [22 60] [22 96]]]] [5365 6.95 [20 100] [20 84]]] [10 100]] [934 1.01 [7249 2.15 [7520 0.772 [7176 16.5 [4870 7.04 [2804 7.82 [5755 2.77 [1079 1.28 [1025 4.21 [7199 3.45 [5647 3.85 [1062 9.04 [5824 2.2 [5871 1.57 [1078 59 [1239 14.9 [2033 3.55 [22 78] [22 42]] [23 58]] [23 63]] [22 100]] [11 81]] [22 38]] [22 55]] [22 100]] [11 37]] [22 100]] [11 100]] [8 100]] [22 100]] [11 50]] [19 33]] [22 100]] [23 83]]] [5830 1.17 [7618 1.1 [7512 26.2 [7101 1.23 [6033 0.747 [1184 0.141 [2378 4.02 [4319 0.935 [756 2.12 [695 1.6 [5110 0.747 [4517 0.522 [2550 2.51 [5412 0.514 [2767 0.715 [6287 1.54 [2752 20.7 [2939 2.26 [328 6.67 [4235 12.1 [30 19] [20 100]] [11 30]] [10 22]] [4154 1.03 [826 2.13 [22 26] [23 85]] [23 57]]] [11 100]] [11 87]] [2616 1.22 [5999 2.15 [286 0.502 [567 7.98 [2259 1.9 [23 26] [23 97]] [23 100]] [2143 0.998 [23 96] [23 100]]] [23 38]] [4 63]]] [8 100]] [23 85]] [5118 0.747 [4332 7.41 [7413 0.675 [906 0.509 [2015 2.36 [5824 0.414 [11 40] [11 100]] [8 71]] [2764 0.577 [11 33] [11 100]]] [22 55]] [22 85]] [8 46]]] [6970 1.99 [1913 6.21 [22 60] [22 100]] [28 77]]] [30 93]] [10 87]] [23 100]] [11 100]] [22 100]] [22 82]] [4414 0.554 [4294 1.19 [20 70] [20 100]] [20 100]]] [20 97]] [11 100]]]] [6945 1.4 [4768 2.82 [1426 1.39 [6317 2.51 [705 0.775 [978 2.79 [5467 7.03 [12 71] [3072 2.42 [1062 0.673 [5467 11.6 [2939 13.5 [12 91] [12 62]] [12 93]] [12 100]] [12 100]]] [23 44]] [12 100]] [10 57]] [2526 1.81 [12 72] [12 54]]] [12 100]] [10 100]]] [3896 0.671 [1410 0.967 [1400 0.443 [5413 6.9 [2062 0.424 [1888 6.33 [5647 32.5 [6734 13.4 [7512 12.9 [4154 23.1 [4769 0.629 [2786 1.12 [2004 1.14 [2470 6.47 [1764 1.77 [4206 2.56 [6883 4 [6304 0.938 [5814 1.67 [6080 6.66 [2161 1.25 [29 77] [29 58]] [15 80]] [12 60]] [29 100]] [12 75]] [15 60]] [12 60]] [15 77]] [2081 5.08 [29 100] [29 80]]] [29 100]] [429 43.3 [29 100] [2091 1.75 [29 97] [29 100]]]] [15 64]] [663 0.673 [32 72] [32 76]]] [15 85]] [12 50]] [2701 12.7 [12 38] [12 77]]] [29 100]] [5412 9.62 [29 52] [32 83]]] [15 55]] [15 92]] [32 75]]] [221 0.597 [145 1.24 [5106 1.57 [6849 0.4 [5962 1.85 [2616 0.761 [2259 3.77 [6114 2.84 [3286 1.36 [5023 4.64 [144 5.82 [2903 3.5 [3849 7 [4011 6.96 [1630 1.66 [7512 0.978 [3008 18.8 [4956 1.42 [630 2.54 [2701 10.6 [434 8.33 [3273 1.86 [7451 3.07 [1783 18.2 [3687 3.41 [5673 14.3 [4235 1.95 [1906 2.9 [2913 7.44 [663 1.37 [2199 4.45 [5412 7.16 [5812 4.35 [850 2.42 [429 15.3 [7210 6.34 [35 41] [23 30]] [28 27]] [35 69]] [2 55]] [28 58]] [14 25]] [28 48]] [5 45]] [23 33]] [28 35]] [35 64]] [37 100]] [791 14.5 [28 60] [28 50]]] [23 33]] [35 92]] [26 44]] [29 100]] [35 95]] [6848 13.9 [35 76] [35 100]]] [3867 2.44 [35 58] [35 100]]] [5799 2.24 [5509 1.38 [2846 3.83 [7512 17.7 [642 2.54 [7413 1.62 [3008 2.11 [14 19] [14 50]] [26 44]] [2 33]] [14 46]] [22 41]] [32 30]] [13 57]]] [28 69]] [28 100]] [35 88]] [5 81]] [29 20]] [35 85]] [37 100]] [35 72]] [1429 32.2 [2902 27.6 [7737 1.62 [6131 1.08 [5007 6.14 [5290 1.67 [3008 12.8 [685 0.761 [286 10.8 [5673 2.04 [32 10] [35 43]] [23 60]] [28 46]] [35 57]] [10 100]] [5972 1.34 [24 33] [36 75]]] [22 33]] [10 61]] [2 60]] [2521 0.174 [685 15.5 [4895 2.26 [5462 11.6 [28 30] [14 32]] [14 55]] [28 100]] [3 71]]]] [736 1.08 [4 22] [5 41]]] [6310 0.963 [6353 1.47 [14 20] [5462 8.77 [35 88] [35 100]]] [35 55]]] [5462 15.4 [35 45] [35 89]]] [28 100]] [5637 6.07 [28 40] [14 28]]] [4583 2.59 [5368 6.95 [6074 1.42 [144 5.96 [5753 12.6 [4497 1.03 [4684 1.44 [286 2.33 [6524 2.07 [1036 1.66 [7411 0.537 [6375 3.83 [4614 0.299 [1899 8.4 [28 36] [28 82]] [29 100]] [20 28]] [35 44]] [35 100]] [1239 1.29 [4414 2.96 [28 62] [28 90]] [28 90]]] [28 88]] [28 36]] [28 100]] [15 33]] [29 50]] [24 35]] [29 38]] [21 60]]]] [7186 1.68 [2161 0.726 [6074 4.83 [5154 8.48 [1669 11 [5716 8.36 [3675 11.3 [736 1.12 [6727 2.54 [5132 10.9 [2616 2.83 [4540 1.83 [5480 4.31 [7149 5.05 [7734 5.22 [6 50] [7188 8.26 [791 2.92 [1078 23 [18 22] [18 62]] [23 23]] [18 85]]] [16 37]] [2268 11 [6040 6.94 [5346 2.86 [383 10.3 [4859 4.95 [1888 2.24 [1429 52.6 [18 55] [18 83]] [2752 19.4 [18 88] [18 100]]] [18 52]] [18 61]] [18 77]] [18 89]] [18 45]]] [18 94]] [18 66]] [16 46]] [4 37]] [18 92]] [7 44]] [16 33]] [7 100]] [7 71]] [7 60]] [24 33]] [5099 1.47 [281 1.71 [23 13.5 [18 61] [18 83]] [18 80]] [16 64]]]] [7175 8.46 [29 100] [29 80]]] [695 6.99 [5021 6.29 [1511 1.59 [3971 1.73 [3130 4.88 [37 90] [37 50]] [37 83]] [37 100]] [37 66]] [3587 1.18 [1908 1.2 [3837 1.64 [37 97] [37 100]] [37 100]] [37 100]]]] [1055 0.192 [2101 0.249 [5812 1.85 [5413 0.519 [5972 3.73 [4556 1.28 [1993 0.273 [2802 0.712 [3452 1.06 [3262 2.04 [2002 3.61 [6184 22.9 [7507 2.81 [1439 5.41 [5732 1.47 [5731 0.418 [3959 0.594 [3237 1.33 [1623 3.03 [4602 2.09 [6031 4.68 [2320 4.76 [248 2.42 [2753 4.08 [978 0.47 [5237 0.982 [3273 3.74 [760 5.03 [5083 0.211 [1586 3.88 [2531 0.647 [5236 0.725 [6660 1.04 [1429 14.9 [957 0.224 [4338 1.74 [567 18.2 [826 2.5 [2180 4.63 [2703 2.39 [1 2.4 [7620 20.1 [7742 14.1 [2000 17.9 [6393 3.23 [429 32.8 [5110 1.36 [5211 8.77 [1410 3.45 [4149 20 [3033 3.07 [23 11] [23 42]] [27 60]] [15 100]] [2763 2.95 [23 44] [22 37]]] [11 29]] [5223 0.901 [2004 8.46 [2766 9.77 [2763 14.9 [7766 3.55 [23 22] [29 90]] [2 72]] [13 33]] [23 76]] [11 100]]] [15 91]] [23 90]] [2 31]] [22 100]] [2752 26.5 [11 31] [11 69]]] [29 100]] [2767 5.41 [27 14] [27 35]]] [7481 5.71 [7623 5.75 [5883 1.82 [23 40] [11 66]] [15 66]] [15 100]]] [23 74]] [23 60]] [27 50]] [394 3.5 [5871 5.68 [6711 2.33 [1558 1.99 [4846 1.41 [756 9.65 [7340 1.37 [6301 1.42 [429 5.05 [5110 19.4 [3008 0.0523 [4338 7.07 [5462 11.8 [1450 0.0374 [2526 5.83 [3095 6.82 [2029 0.629 [22 10] [1 43]] [23 58]] [16 10]] [1 33]] [35 56]] [2091 5.35 [23 57] [23 54]]] [30 22]] [22 87]] [4764 3.04 [4135 11.2 [3085 2.65 [6042 2.25 [4768 1.82 [5412 3.92 [2526 3.64 [23 4.47 [29 15] [30 21]] [2526 11.5 [23 44] [23 30]]] [23 45]] [29 56]] [18 62]] [37 100]] [27 69]] [35 52]]] [28 90]] [32 75]] [30 73]] [1 100]] [22 100]] [22 72]] [2178 15.3 [2081 3.89 [12 44] [14 44]] [14 83]]] [28 60]]] [1239 4.13 [11 83] [11 100]]] [7449 3.94 [20 100] [20 62]]] [23 100]] [32 100]] [11 100]] [2526 5.62 [23 87] [23 100]]] [3099 5.05 [11 48] [35 66]]] [11 100]] [4929 4.76 [1078 96 [1919 17.8 [896 2.51 [978 62.6 [2091 7.95 [2029 0.971 [4279 19.8 [1454 16.7 [4338 2.96 [826 12.5 [2846 2.26 [4768 10.3 [6791 2.93 [5328 1.54 [23 76] [23 100]] [23 64]] [23 50]] [23 33]] [23 100]] [1429 18.1 [2001 1 [2764 1.52 [23 96] [23 100]] [23 100]] [23 63]]] [23 50]] [29 41]] [1068 1.33 [23 96] [23 100]]] [25 36]] [23 50]] [2 45]] [23 60]] [23 43]] [8 62]]] [906 4.95 [1913 12.5 [2226 2.4 [14 12] [37 42]] [31 78]] [32 62]]] [6457 1.42 [429 3.01 [4326 1.31 [26 3.82 [3794 2.73 [25 28] [26 72]] [1 75]] [25 83]] [978 4 [1986 10.2 [29 27] [15 78]] [25 42]]] [25 100]]] [3485 1.77 [32 77] [32 96]]] [7461 1.68 [204 3.36 [791 8.07 [22 90] [1391 4.26 [1078 45.4 [22 100] [22 90]] [22 100]]] [22 100]] [22 100]]] [26 82]] [11 100]] [11 97]] [6015 0.444 [2199 5.1 [29 88] [29 100]] [29 100]]] [11 100]] [429 20.1 [7512 3.11 [6910 1.22 [28 82] [15 50]] [28 53]] [28 50]]] [23 92]] [2225 2.37 [2752 20.7 [23 80] [23 95]] [23 100]]] [6394 2.65 [6196 1.45 [23 24] [1986 5.38 [15 32] [1239 6.83 [15 57] [15 88]]]] [15 100]]] [23 65]] [37 99]] [11 100]] [1986 1.62 [29 84] [29 68]]] [4669 7.11 [6178 6.85 [906 7.94 [7449 5.92 [2280 4.66 [5412 0.654 [1062 15.8 [673 5.38 [2199 20.7 [23 70] [4 33]] [26 71]] [23 40]] [4154 1.04 [23 92] [23 100]]] [23 100]] [7453 1.09 [1899 2.26 [23 92] [23 100]] [23 100]]] [23 60]] [25 100]] [4 28]]] [2752 17.7 [23 90] [5851 2.54 [2225 26.5 [23 100] [23 87]] [23 100]]]] [3072 2.07 [6791 3.65 [811 8.05 [2843 8.2 [1106 3.03 [4338 6.56 [12 69] [31 66]] [15 29]] [31 100]] [12 50]] [12 56]] [12 100]]] [340 1.25 [29 38] [1 100]]] [6015 1.5 [1783 7.8 [2536 8.33 [1429 1.53 [1239 18.1 [2906 4.6 [2 31] [4 62]] [1253 19.5 [2 28] [4 72]]] [2398 2.65 [1925 0.967 [1089 8.01 [2199 3.94 [4 24] [5 30]] [978 4.95 [13 60] [4 57]]] [2 30]] [12 90]]] [1899 6.53 [2 77] [2 50]]] [23 25]] [12 81]]] [2547 10.8 [4517 1.06 [791 20.5 [248 1.55 [2526 20.6 [7453 0.705 [5812 2.46 [435 1.53 [23 61] [23 93]] [2 33]] [23 100]] [2760 6.46 [4122 13.3 [23 35] [12 88]] [24 33]]] [25 61]] [23 71]] [23 85]] [27 100]]] [11 92]]] [739 1.17 [5307 1.36 [6974 0.649 [7621 2.11 [6122 2.28 [7470 1.04 [5496 4.16 [4959 0.41 [6077 1.95 [1445 0.873 [2259 7.45 [2178 3.8 [733 0.967 [7512 1.44 [4 81] [4 90]] [4 57]] [4 62]] [5574 1.26 [429 11.4 [2259 9.59 [2 44] [2628 1.1 [11 37] [31 54]]] [5812 4.48 [312 2.36 [4 65] [4 90]] [4 100]]] [4 100]]] [4 30]] [31 60]] [4 92]] [2 64]] [22 30]] [23 62]] [31 100]] [4 62]] [31 100]] [6982 27 [4 100] [4 87]]]] [6546 1.05 [4324 6.72 [4851 3.29 [2701 3.11 [906 7.66 [1001 1.1 [7251 1.72 [203 1.25 [883 1.83 [11 1.31 [814 5.92 [6732 4.46 [2091 5.95 [429 21.3 [7731 1.23 [2962 1.19 [1657 1.89 [31 88] [31 100]] [31 100]] [31 77]] [660 6.11 [1899 7.75 [6077 2.39 [31 73] [31 100]] [896 3.23 [36 75] [31 55]]] [31 100]]] [31 100]] [5978 1.46 [728 6.67 [1078 6.42 [12 84] [31 54]] [31 50]] [31 100]]] [36 100]] [31 100]] [12 85]] [36 100]] [2628 1.46 [36 57] [31 77]]] [4414 1.12 [7742 1.4 [31 96] [31 100]] [31 100]]] [12 50]] [12 100]] [36 88]] [31 65]] [31 100]]] [2470 1.68 [5972 1.71 [2913 0.763 [17 2.4 [7548 0.945 [4851 2.38 [5258 1.39 [819 0.511 [6178 1.47 [4231 1.25 [5218 1.63 [4380 0.349 [899 0.243 [5845 1.65 [3371 1.47 [6544 2.11 [6177 1.64 [3990 0.516 [1133 1.53 [7737 5.14 [2776 3.79 [857 3.08 [978 10.2 [6145 6.44 [1429 7.07 [2259 6.62 [377 2.09 [253 9.44 [3701 3.55 [27 27] [15 100]] [25 66]] [27 33]] [10 45]] [4374 3.14 [2488 3.67 [460 1.17 [3292 1.85 [4154 14.3 [4011 6.94 [6199 8.59 [1769 4.99 [1253 3.09 [939 3.76 [3929 1.39 [4414 0.104 [6949 3.83 [2199 3.05 [7354 8.37 [32 36] [36 60]] [32 66]] [32 88]] [32 18]] [12 72]] [939 11.1 [10 37] [10 40]]] [27 63]] [18 35]] [32 83]] [37 100]] [1980 14.8 [32 76] [28 57]]] [37 95]] [37 100]] [13 68]] [12 85]]] [10 100]] [7354 8.49 [25 56] [18 77]]] [22 100]] [32 95]] [10 70]] [27 100]] [3171 0.703 [37 72] [37 100]]] [2770 1.64 [25 90] [25 100]]] [32 100]] [37 98]] [10 100]] [2753 1.28 [503 1.01 [32 51] [32 94]] [32 83]]] [27 90]] [10 100]] [10 100]] [25 100]] [27 100]] [10 100]] [3905 0.96 [32 74] [32 100]]] [4154 4.89 [32 91] [32 100]]] [7169 3.02 [6260 1.44 [25 33] [13 100]] [13 66]]] [503 3.92 [893 3.86 [6178 3.45 [328 13.4 [429 5.27 [1429 1.31 [32 86] [32 55]] [3130 1.33 [2178 6.22 [867 2.6 [5904 0.471 [4370 5.38 [504 7.26 [1674 0.864 [32 94] [32 100]] [32 80]] [32 46]] [32 100]] [32 71]] [32 62]] [32 80]]] [25 42]] [25 100]] [15 100]] [6091 1.85 [32 91] [32 100]]]] [3488 1.13 [7742 1.97 [6173 0.682 [5692 7.35 [1164 7.83 [5879 3.28 [5753 7.23 [4279 7.32 [7638 0.357 [248 7.94 [5267 2.26 [7340 6.17 [1400 1.38 [12 45] [29 2.46 [6342 1.44 [12 93] [12 100]] [12 100]]] [12 100]] [31 60]] [15 88]] [12 100]] [12 53]] [15 38]] [7623 17.2 [31 69] [31 58]]] [12 96]] [12 62]] [31 100]] [31 100]] [12 100]]] [5732 0.761 [7722 1.76 [7638 1.02 [7340 1.89 [2471 1.1 [6182 1.23 [3696 2.49 [2486 1.27 [4283 0.579 [429 10 [31 44] [896 2.01 [15 67] [31 91]]] [1410 0.29 [15 92] [15 100]]] [31 100]] [15 88]] [25 100]] [4221 1.47 [15 97] [15 100]]] [32 63]] [4279 1.33 [12 100] [12 70]]] [6545 0.818 [695 0.998 [25 52] [31 100]] [31 100]]] [7340 2.23 [4799 0.532 [15 100] [15 76]] [32 72]]]]] [6675 0.949 [5673 1.51 [2903 0.202 [5090 1.25 [2259 1.31 [3345 0.846 [4663 3.43 [5776 3.62 [2745 10.8 [1769 17.6 [1980 8.83 [7512 1.02 [1068 0.852 [5692 4.34 [30 40] [5412 0.75 [221 3.5 [22 50] [30 90]] [7101 2.73 [22 92] [22 100]]]] [22 75]] [22 58]] [2225 0.884 [7103 1.4 [6093 0.803 [112 0.967 [7199 1.53 [7176 1.74 [685 1.87 [30 52] [23 57]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 62]]] [23 53]] [22 100]] [2752 30.6 [30 100] [30 86]]] [22 76]] [30 94]] [2081 4.64 [2902 0.347 [1497 0.347 [5648 1.07 [5468 1.41 [5844 1.26 [1918 1.07 [5160 2.8 [998 0.8 [2770 3.65 [2759 8.61 [5662 0.463 [1089 1.78 [6350 2.6 [7497 2.22 [3993 0.522 [7589 8.5 [5205 2.76 [6604 3.75 [30 62] [30 100]] [30 100]] [30 66]] [30 62]] [23 54]] [10 100]] [10 40]] [996 0.898 [5420 6.93 [23 57] [791 16.5 [23 93] [23 75]]] [23 100]]] [8 90]] [30 100]] [23 100]] [7623 8.01 [30 87] [30 100]]] [23 100]] [22 100]] [10 100]] [23 100]] [8 100]] [286 3.63 [859 0.347 [7449 0.945 [22 50] [22 75]] [5420 1.06 [1062 5.09 [22 50] [22 100]] [22 100]]] [23 58]]] [4954 1.51 [23 88] [23 71]]]] [791 10.4 [22 37] [867 0.741 [22 95] [22 100]]]] [7502 1.98 [6488 0.401 [2023 3.52 [1219 0.84 [1755 1.07 [6530 1.31 [22 90] [22 100]] [22 100]] [22 100]] [22 85]] [22 100]] [22 66]]] [5387 0.805 [5692 6.26 [6696 1.64 [6441 1.65 [30 86] [30 100]] [30 100]] [30 54]] [5904 11.2 [30 100] [30 83]]]] [30 100]]] [2902 0.17 [7512 1.68 [2048 0.232 [1261 0.816 [6347 5.83 [4369 11.7 [1445 6.98 [4221 0.528 [5480 1.59 [6154 2.06 [4639 0.0858 [429 11.2 [5412 2.6 [5034 8.72 [1078 6.92 [11 22] [12 31]] [32 88]] [28 83]] [5327 11.1 [438 2.3 [1106 6.19 [2488 1.11 [2913 4.08 [5972 3.1 [5034 18.3 [4288 11.7 [2004 1.96 [791 41.8 [2081 9.55 [101 2.02 [2847 6.19 [2470 1.51 [5753 7.28 [2526 1.46 [4630 2.53 [2259 13.4 [7428 2.4 [6114 1.3 [1062 6.42 [7612 1.16 [6732 10.5 [1077 7.31 [5013 0.437 [5918 0.778 [728 3.56 [685 0.666 [695 0.321 [7169 9.01 [28 89] [28 80]] [28 98]] [28 100]] [28 83]] [28 87]] [28 100]] [28 88]] [28 81]] [28 100]] [2023 0.473 [5766 1.16 [28 75] [28 80]] [28 100]]] [23 37]] [4414 1.2 [28 100] [28 60]]] [6199 1.36 [5192 5.68 [5851 5.73 [28 72] [4 28]] [28 60]] [28 75]]] [28 40]] [23 35]] [23 23.3 [688 1.28 [7449 0.978 [28 92] [28 100]] [28 100]] [28 83]]] [15 22]] [19 37]] [35 44]] [1068 1.65 [906 1.13 [28 62] [28 100]] [28 66]]] [15 33]] [23 40]] [32 61]] [28 60]] [12 100]] [32 68]] [8 80]] [28 42]] [2259 9.09 [1980 17.3 [28 87] [23 44]] [23 37]]] [32 62]]] [19 46]] [28 100]] [8 41]] [15 100]] [29 50]] [32 32]] [11 55]] [2939 0.975 [11 45] [29 66]]] [4639 0.372 [29 20] [16 40]]] [7542 0.522 [2739 1.56 [6863 1.85 [899 3.04 [7665 1.15 [28 35] [6791 1.47 [1899 2.14 [7548 0.697 [1400 0.84 [32 71] [32 100]] [32 100]] [7169 1.04 [32 50] [20 25]]] [5692 0.775 [32 77] [18 33]]]] [791 19.7 [32 100] [1429 3.6 [32 96] [32 100]]]] [31 71]] [4 50]] [7722 5.49 [6333 3.8 [1429 38.7 [3480 0.522 [4851 1.11 [32 95] [32 100]] [32 100]] [32 85]] [32 71]] [899 6.37 [4279 3.35 [32 50] [32 100]] [32 100]]]]] [4351 0.692 [7623 4.78 [2814 0.949 [7665 4.83 [5897 4.47 [2752 8.68 [4279 0.389 [28 60] [10 33]] [1253 8.12 [791 29.4 [1888 4.25 [2145 0.579 [5766 0.325 [2526 1.34 [2764 2.37 [168 0.426 [7298 1.06 [906 0.232 [2793 0.852 [144 0.634 [4279 5.87 [1911 1.26 [28 95] [28 88]] [28 88]] [28 100]] [28 77]] [28 100]] [28 80]] [28 100]] [28 75]] [28 53]] [28 100]] [28 73]] [28 33]] [15 50]] [23 30]]] [28 66]] [32 80]] [32 60]] [15 95]] [4533 2.69 [28 100] [28 85]]]]] [2091 14 [1429 8.33 [2939 1.39 [32 95] [32 79]] [2902 0.627 [3031 0.712 [6729 1.27 [32 97] [32 100]] [32 66]] [32 100]]] [32 90]]] [5467 1.49 [7449 14 [5447 2.42 [7019 0.748 [241 0.73 [4522 0.728 [7704 1.21 [2804 2.18 [2848 1.05 [6979 2.54 [3480 1.05 [5234 0.894 [2426 4.12 [1783 0.752 [1410 1.25 [2824 1.71 [1078 0.596 [6363 3.36 [6813 3.45 [5322 16.2 [7258 3.27 [7149 1.92 [896 1.08 [4422 12.7 [4158 8.02 [7085 47.9 [7173 10.9 [5692 5.06 [5480 2.01 [7132 6.9 [5267 8.99 [168 3.55 [221 20.3 [4929 12.3 [4716 3.6 [4309 1.89 [6124 3.45 [5809 11.7 [12 42] [15 100]] [12 100]] [32 100]] [32 50]] [13 70]] [1 28]] [12 26]] [31 27]] [4 66]] [8 22]] [17 21]] [31 75]] [13 50]] [31 55]] [12 100]] [392 8.48 [328 10.2 [18 28] [7259 6.1 [26 42] [14 100]]] [14 62]]] [6 21]] [28 50]] [15 58]] [32 100]] [3334 5.26 [12 95] [12 100]]] [5824 3.09 [6982 1.82 [3622 0.597 [2846 0.739 [6524 10.2 [3304 1.43 [978 1.14 [4851 2.33 [2802 2.33 [4373 5.62 [1400 5.91 [4614 1.92 [4611 4.89 [1239 0.519 [5154 3.46 [827 3.45 [3262 2.26 [6184 3.8 [788 4.27 [6126 3.65 [7257 0.644 [4369 3.66 [5972 5.69 [32 16] [12 83]] [32 80]] [12 68]] [12 100]] [18 40]] [29 62]] [37 100]] [22 80]] [32 50]] [939 2.04 [22 13] [28 37]]] [35 43]] [29 100]] [15 33]] [15 41]] [29 77]] [32 52]] [23 12]] [15 100]] [5753 1.98 [28 85] [28 100]]] [32 34]] [29 100]] [4 86]] [11 71]]] [12 100]] [4279 9.7 [15 100] [15 80]]] [2913 9.85 [5838 1.47 [435 3.85 [5007 1.68 [668 5.06 [2726 0.838 [673 10.6 [6960 16 [4991 5.76 [6959 6.83 [3243 9.66 [4235 3.82 [1786 2.76 [6406 3.09 [4114 0.634 [429 12.3 [2846 10 [286 0.384 [4530 1.05 [6034 2.71 [14 16] [30 30]] [17 33]] [25 30]] [22 71]] [5412 1.32 [12 19] [2 12]]] [19 44]] [27 42]] [2 37]] [16 25]] [12 100]] [7 46]] [14 66]] [31 80]] [26 82]] [18 60]] [12 37]] [221 3.44 [19 31] [29 36]]] [11 77]] [14 85]] [30 53]]] [12 97]] [11 100]] [2259 7.36 [2760 13.4 [4533 1.9 [23 2.13 [1400 8.15 [15 73] [15 100]] [15 100]] [15 100]] [15 66]] [32 80]]] [12 100]] [3227 1.89 [2178 2.16 [3698 0.903 [12 99] [12 100]] [12 100]] [12 100]]] [705 3.23 [4690 2.44 [5211 26.2 [8 87] [8 50]] [2526 32.9 [8 87] [8 100]]] [12 100]]] [32 100]] [11 95]] [15 100]] [12 91]] [2259 8.2 [12 33] [5267 1.62 [32 56] [32 93]]]] [5812 1.21 [12 57] [12 100]]] [5267 1.39 [7456 10.5 [7453 0.885 [12 98] [12 88]] [12 87]] [12 83]]]] [826 1.66 [345 1.19 [5419 2.15 [4401 9.46 [7411 2.92 [4306 2.09 [7261 1.28 [1844 4 [5605 1.29 [4420 1.6 [3233 0.581 [2934 7.25 [7449 14.3 [7329 0.515 [7009 3.36 [5405 0.439 [6297 0.904 [2143 3.52 [6982 1.07 [4478 2.16 [3424 0.552 [6791 9.11 [15 21] [4 22]] [11 50]] [15 50]] [31 75]] [30 39]] [31 88]] [31 100]] [13 51]] [25 61]] [7654 1.41 [7481 4.85 [15 60] [15 100]] [15 84]]] [33 48]] [35 88]] [15 100]] [2259 0.952 [12 50] [5588 1.47 [31 84] [31 66]]]] [31 91]] [6342 6.55 [31 86] [5267 3.45 [15 100] [31 100]]]] [33 100]] [1980 21.8 [15 74] [15 100]]] [35 76]] [328 4.05 [15 83] [15 100]]] [15 100]] [7623 1.14 [7095 2.15 [429 42.9 [6342 1.83 [15 79] [15 88]] [15 30]] [15 100]] [15 91]]]] [5978 0.51 [972 0.0933 [1047 0.559 [7601 0.507 [5403 0.709 [7354 1.23 [1391 0.2 [3179 0.275 [6859 0.606 [861 1.42 [1426 0.645 [6852 4.08 [248 14.7 [7497 3.16 [4011 0.782 [6335 1.49 [968 2.87 [642 0.78 [4356 1.71 [6 0.821 [3101 1.99 [5316 2.18 [5218 1.79 [7529 6.86 [1400 9.44 [1174 2.62 [7156 1.25 [7241 4.77 [24 30] [36 64]] [24 50]] [36 100]] [10 70]] [24 100]] [10 100]] [32 93]] [24 100]] [10 100]] [24 80]] [36 88]] [968 11.9 [28 76] [28 90]]] [24 85]] [28 100]] [22 88]] [25 82]] [2341 1.08 [4338 12.5 [36 66] [24 96]] [24 100]]] [10 100]] [32 100]] [968 0.384 [4495 2.15 [4349 0.468 [7314 1.04 [1559 0.73 [1626 1.16 [4851 0.734 [5282 0.888 [4790 1.66 [6388 0.649 [2616 1.42 [3004 0.84 [4214 8.13 [4342 0.87 [4338 2.15 [2434 1.12 [2259 6.73 [7512 6.31 [7149 14.3 [377 3.37 [221 2.53 [978 10.4 [7106 7.94 [28 28] [36 85]] [24 80]] [28 65]] [28 72]] [36 42]] [6853 28.3 [36 66] [24 66]]] [4088 1.12 [1746 6.45 [36 49] [36 75]] [36 100]]] [4457 2.07 [7243 2.42 [36 82] [36 100]] [36 100]]] [5693 3.84 [7665 1.65 [4027 2.49 [24 96] [24 100]] [24 72]] [24 72]]] [24 87]] [6859 12.9 [24 57] [24 100]]] [36 100]] [24 88]] [28 100]] [31 91]] [22 95]] [23 4.53 [5225 0.734 [36 38] [2752 17 [5110 2.28 [30 100] [30 90]] [30 75]]] [30 86]]] [30 94]] [36 97]] [4210 1.02 [30 68] [30 94]]] [4956 3.73 [24 100] [24 81]]] [24 100]] [867 5.06 [1813 0.318 [377 18.1 [7491 10.2 [6363 2.75 [1436 2.19 [1980 9.77 [1625 8.49 [855 8.58 [3027 8.61 [5034 1.02 [28 40] [112 0.697 [4569 5.51 [5809 1.99 [4395 9.92 [7251 2.07 [1980 0.366 [6856 17.3 [28 100] [28 87]] [28 100]] [28 90]] [28 94]] [28 100]] [28 83]] [28 100]]] [28 87]] [28 87]] [28 66]] [28 76]] [28 57]] [28 83]] [28 66]] [28 75]] [28 100]] [28 66]]]] [6853 12.7 [28 96] [28 100]]] [5605 2.11 [144 0.924 [4369 1.79 [22 71] [22 100]] [22 100]] [22 100]]] [1719 1.59 [7301 7.42 [23 0.986 [1746 1.5 [7169 2.7 [36 96] [36 80]] [36 100]] [36 100]] [36 85]] [36 88]]] [734 1.21 [3931 1.02 [5692 1.26 [31 100] [7559 0.736 [7722 6.14 [31 87] [31 100]] [31 100]]] [31 100]] [31 100]]] [728 0.507 [5692 7.11 [429 1.64 [36 66] [36 90]] [36 73]] [36 100]]] [3642 1.06 [429 8.92 [24 87] [24 88]] [24 50]]] [6152 4.33 [2199 4.39 [5904 3.38 [695 9.03 [6997 2.06 [3424 0.149 [1025 3.23 [791 1.09 [4396 3.72 [28 60] [28 100]] [7169 0.0933 [435 0.696 [5192 1.76 [973 0.907 [23 10.9 [855 0.664 [3698 0.84 [28 97] [28 100]] [28 100]] [28 85]] [28 100]] [28 77]] [28 100]] [28 100]]] [28 92]] [28 100]] [28 94]] [28 100]] [28 50]] [28 56]] [28 78]]] [31 100]]] [10 100]] [685 0.651 [3008 2.73 [6160 2.99 [4533 2.54 [5156 0.605 [6606 27.8 [4064 11.1 [7275 1.25 [7210 6.77 [6727 2.74 [5618 0.857 [1842 9.09 [5692 0.121 [939 0.176 [1899 14 [4395 0.628 [6276 4.38 [1869 2.67 [4948 0.349 [1239 2.56 [5462 4.76 [28 77] [28 100]] [28 100]] [28 100]] [28 100]] [28 85]] [28 100]] [28 83]] [28 100]] [28 100]] [28 83]] [5999 7.71 [28 50] [28 88]]] [28 81]] [28 50]] [28 50]] [28 42]] [28 50]] [13 42]] [28 37]] [28 98]] [28 58]] [596 1.11 [1692 0.283 [221 0.414 [906 1.06 [28 100] [28 85]] [28 100]] [28 100]] [1980 0.894 [28 100] [28 87]]]]] [362 5.39 [1783 14.4 [6199 28.7 [6524 0.474 [4154 5.24 [6074 0.251 [6541 2.59 [2752 20.9 [1980 4.1 [4664 1.21 [6091 0.684 [15 97] [15 100]] [15 100]] [15 92]] [6977 7.94 [15 94] [12 100]]] [12 100]] [15 100]] [429 33.8 [15 100] [15 95]]] [5368 0.474 [15 100] [15 85]]] [15 70]] [15 72]] [15 72]]] [673 3.65 [560 0.647 [2616 0.214 [5420 0.16 [1429 30.5 [3633 1.31 [2764 0.418 [5574 1.21 [5316 3.08 [389 0.81 [435 1.54 [5616 0.354 [1226 0.61 [5750 0.606 [551 0.994 [1980 3.37 [685 28.8 [906 2.22 [4690 2.16 [7169 9.38 [6715 4.83 [23 49] [18 80]] [4288 3.12 [23 66] [23 100]]] [8 100]] [23 57]] [26 41]] [695 0.274 [2521 1.73 [2232 5.37 [4279 18 [4338 7.91 [2081 12.7 [2081 8.93 [23 92] [23 83]] [23 87]] [23 77]] [8 42]] [26 37]] [23 100]] [16 37]]] [23 100]] [23 100]] [2064 1.47 [5284 1.75 [4776 1.77 [4154 6.26 [2939 0.967 [23 95] [23 100]] [23 94]] [23 100]] [23 100]] [23 100]]] [23 100]] [978 1.28 [328 8.76 [23 100] [23 64]] [1253 0.686 [7414 0.805 [386 0.444 [5362 7.29 [939 0.414 [23 96] [23 100]] [23 85]] [23 100]] [23 85]] [23 100]]]] [2526 10.7 [18 43] [25 44]]] [7185 5.03 [26 66] [26 100]]] [1226 0.747 [23 93] [23 100]]] [2835 0.431 [791 19.4 [7491 0.253 [2005 1.02 [2765 0.168 [377 0.24 [5911 1.51 [1913 1.32 [6342 0.534 [5412 0.826 [5647 4.95 [23 80] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 90]] [23 100]] [23 100]] [23 78]] [23 100]]] [35 72]] [4927 1.85 [5132 0.688 [5154 2.97 [333 8.11 [3870 0.339 [7737 0.583 [23 45] [18 90]] [8 100]] [8 77]] [7 63]] [1429 61 [18 39] [16 65]]] [2752 8.57 [18 37] [1899 1.57 [18 93] [18 80]]]]] [6320 4.77 [328 2.59 [23 100] [5838 0.824 [7565 0.488 [23 90] [23 100]] [23 100]]] [23 66]]] [383 1.35 [2809 0.377 [5693 3.07 [26 45] [18 40]] [16 48]] [18 93]]] [1064 2.93 [389 5.95 [1078 4.45 [1012 3.83 [1239 18 [18 83] [18 100]] [18 71]] [7186 10.6 [282 0.326 [16 48] [18 70]] [16 71]]] [18 82]] [16 53]]] [4981 1.95 [5693 0.931 [4611 3.91 [4205 4.77 [221 2.51 [394 1.42 [1239 20.3 [7512 13.7 [6294 1.53 [26 55] [26 60]] [18 48]] [26 76]] [26 88]] [25 100]] [384 6.67 [26 84] [26 100]]] [26 100]] [7169 0.652 [7665 17.4 [26 75] [26 100]] [26 90]]] [26 92]]]] [1742 9.14 [5223 0.494 [6395 3.03 [4601 0.143 [2025 1.53 [5693 0.254 [5884 0.418 [7258 1.02 [1095 1.49 [791 6.01 [11 54] [5647 15.8 [11 86] [11 100]]] [11 100]] [11 100]] [11 100]] [11 100]] [11 71]] [11 100]] [11 86]] [11 100]] [11 63]]] [731 1.39 [434 2.98 [1409 0.31 [721 6.06 [4851 0.569 [3480 0.508 [957 1.08 [6269 0.296 [2752 13 [7665 18.5 [31 100] [663 3.94 [31 81] [36 100]]] [4611 1.27 [663 7.68 [36 84] [36 100]] [2309 14.9 [36 100] [36 83]]]] [36 100]] [36 100]] [36 100]] [36 100]] [36 62]] [36 100]] [31 60]] [31 95]]] [1980 11 [5412 3.2 [906 0.328 [11 98] [11 100]] [11 62]] [11 100]]] [22 100]] [3687 1.57 [5732 0.463 [978 1.25 [2701 3.36 [688 3.58 [7411 1.24 [5480 2.38 [3074 0.502 [15 48] [12 100]] [15 100]] [15 100]] [15 84]] [23 4.39 [1429 11.8 [1986 3.94 [15 100] [15 75]] [15 95]] [15 100]]] [5 42]] [5851 0.456 [3243 0.537 [3460 5.2 [6184 2.4 [1069 1.28 [3210 1.22 [2752 7.23 [15 60] [15 100]] [15 100]] [15 100]] [15 100]] [15 70]] [15 100]] [15 100]]] [37 100]]] [631 0.424 [6261 1.26 [2175 0.434 [5160 5.3 [6260 1.29 [5454 16.3 [4028 0.684 [4770 1.03 [4024 1.95 [2526 1.45 [5972 0.0652 [6859 1.89 [3227 2.89 [4326 0.705 [927 0.754 [2187 2.53 [2786 0.956 [1456 0.222 [6753 0.821 [5011 0.739 [29 83] [29 100]] [29 100]] [29 100]] [29 100]] [29 87]] [4611 1.35 [2225 0.911 [29 100] [29 70]] [29 100]]] [29 100]] [29 91]] [36 55]] [36 84]] [1089 1.45 [24 91] [24 62]]] [36 100]] [7505 0.971 [3325 0.263 [4663 0.849 [6213 0.115 [1062 0.849 [435 0.657 [1911 2.94 [2703 4.5 [29 100] [29 66]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 95]]] [24 100]] [1899 24 [2593 4.29 [2773 4.03 [5597 6.5 [29 42] [36 87]] [24 84]] [24 100]] [36 66]]] [1997 1.04 [24 69] [36 87]]] [29 100]] [29 100]] [36 100]] [1783 2.47 [791 13 [7419 8.78 [1239 2.11 [1899 4.48 [24 42] [24 100]] [24 90]] [36 54]] [36 87]] [36 85]]]] [7309 0.295 [4716 0.395 [1775 0.792 [6457 0.469 [1068 6.55 [2987 2.37 [1913 1.02 [1253 0.526 [5491 3.65 [2740 2.85 [7668 1.31 [1779 1.85 [7343 9.2 [2586 0.829 [6178 0.938 [25 72] [4414 1.68 [134 0.852 [2769 2.65 [6177 21.1 [25 100] [25 97]] [25 100]] [25 100]] [25 100]]] [25 100]] [25 100]] [25 70]] [25 72]] [4 93]] [25 100]] [25 63]] [2 36]] [4 84]] [17 36]] [25 100]] [26 57]] [673 4.05 [16 40] [26 93]]] [25 100]]] [1475 0.25 [2753 10.8 [5632 2.13 [4105 5.07 [4414 10.1 [3742 1.87 [160 2.8 [3555 1.69 [832 3.59 [4557 0.0744 [7349 12.5 [429 3.43 [37 88] [3929 3.28 [3374 6.33 [2753 4.85 [2466 0.986 [906 13.1 [1992 7.88 [2782 4.03 [3297 0.329 [4369 10.2 [705 1.69 [2752 18.2 [7169 2.24 [37 82] [37 100]] [37 98]] [37 100]] [37 90]] [37 100]] [37 87]] [37 85]] [37 75]] [37 83]] [37 100]] [144 2.92 [37 100] [37 78]]] [37 100]]] [7343 32.4 [37 66] [37 100]]] [37 50]] [3286 1.27 [3781 6.86 [1077 1.08 [37 83] [37 100]] [37 100]] [37 100]]] [663 2.21 [37 91] [37 86]]] [37 60]] [37 40]] [37 62]] [37 71]] [37 60]] [37 98]] [37 100]]] [899 0.618 [5225 0.254 [7620 0.107 [5526 1.18 [6310 4.69 [4769 0.824 [1077 0.266 [5753 0.935 [7623 0.784 [5289 1.74 [567 12.2 [5480 1.73 [968 3.18 [7354 1.63 [1003 1.68 [221 15.7 [36 2.51 [2752 5.96 [29 46] [6148 2.9 [4991 18.8 [6524 11.3 [6342 7.3 [6653 4.24 [2260 3.14 [22 33] [36 100]] [22 76]] [7 25]] [6342 1.08 [22 64] [15 57]]] [22 40]] [22 66]]] [22 93]] [28 34]] [25 46]] [7 54]] [28 94]] [4312 1.75 [1062 9.44 [22 93] [22 85]] [22 100]]] [22 95]] [28 100]] [15 60]] [14 1.57 [4184 12 [7706 1.03 [1400 4.88 [4615 0.952 [1206 0.181 [5776 2.43 [7338 1.34 [685 0.257 [4424 5.68 [28 54] [28 41]] [28 79]] [22 95]] [28 33]] [28 100]] [36 83]] [36 69]] [22 50]] [29 55]] [36 100]]] [2416 0.266 [688 0.179 [1062 3.04 [28 55] [28 100]] [7 50]] [28 100]]] [896 0.824 [2802 6.77 [29 100] [29 62]] [29 100]]] [7 69]] [29 100]] [2817 1.11 [7103 0.231 [4663 0.902 [5412 0.729 [22 95] [28 48]] [22 100]] [22 100]] [22 100]]] [957 0.714 [2903 0.133 [5282 0.505 [5844 0.914 [22 98] [22 100]] [22 100]] [22 100]] [22 57]]] [2802 1.04 [36 64] [29 100]]]] [6260 1.16 [2588 0.27 [7588 0.199 [6184 0.707 [5812 1.25 [1047 1.31 [1089 1.18 [6865 0.385 [1600 0.894 [6367 0.126 [312 2.59 [6396 1.28 [7735 1.36 [3576 0.693 [6088 0.835 [3525 3.23 [4832 6.49 [2421 2.1 [4214 1.76 [2470 0.472 [6732 8.07 [3014 0.367 [721 1.25 [1025 0.364 [1429 27.4 [2259 1.41 [6077 7.91 [5693 6.03 [14 20] [2 21]] [7 54]] [7354 2.82 [5034 3.64 [1429 12.8 [5 32] [7 59]] [14 85]] [7722 1.41 [7 87] [7 62]]]] [6804 4.57 [610 1.04 [685 0.84 [7512 28.3 [6074 2.22 [4718 1.53 [6524 4.31 [4189 2.44 [2628 2.07 [2760 5.56 [7533 5.63 [5 30] [17 66]] [17 72]] [1078 15.5 [5 60] [5 45]]] [24 100]] [7 57]] [5 100]] [7381 13 [14 33] [7 92]]] [5 52]] [7 74]] [5 90]] [38 45]]] [6395 3.84 [6859 0.364 [731 14.6 [1023 1.74 [4338 8.96 [4279 8.42 [4 27] [2 54]] [24 84]] [2 47]] [4 80]] [1429 53 [24 80] [24 100]]] [4 62]]] [719 1.57 [14 100] [14 87]]] [7689 3.9 [4851 10.9 [17 60] [14 35]] [19 50]]] [7711 1.22 [14 14] [19 55]]] [7449 1.91 [1025 14.1 [4 82] [4 100]] [4 57]]] [24 91]] [24 100]] [2 65]] [35 100]] [2 91]] [5 87]] [7 87]] [141 6.21 [7253 0.978 [7722 1.19 [17 100] [17 52]] [3 33]] [17 100]]] [4154 3 [4 74] [1888 2.49 [4 63] [2 50]]]] [4 100]] [7 100]] [3026 0.898 [5 83] [5 60]]] [429 18.3 [2 43] [3240 0.405 [1444 1.54 [1078 22 [4 75] [4 21]] [4 90]] [4 100]]]] [1389 0.766 [2 42] [4279 18.3 [4035 1.66 [791 6 [24 73] [2517 2.2 [7673 1.25 [24 98] [24 100]] [24 100]]] [24 100]] [24 76]]]] [2742 0.477 [6927 4.19 [4110 3.53 [6591 0.82 [6865 1.11 [4851 0.487 [2478 1.12 [2259 3.32 [7677 2.22 [7382 0.904 [7127 6.37 [6347 1.29 [6396 1.01 [731 4.36 [1059 10 [663 7.71 [286 4.68 [573 1.35 [7185 0.675 [2143 6.51 [2567 1.18 [682 2.35 [5660 3.29 [6406 5.15 [2760 5.54 [695 16.1 [2 56] [7 57]] [2 46]] [2 100]] [2 57]] [4 46]] [2 100]] [2 33]] [2 40]] [7718 3.5 [5815 8.41 [2576 2.06 [2470 6.51 [1062 14.9 [6732 1.81 [5692 8.72 [2 29] [2 70]] [17 44]] [4 84]] [4 100]] [4 84]] [2 63]] [2 80]]] [17 66]] [5 33]] [1059 12 [2 83] [2 87]]] [4 48]] [17 91]] [2 76]] [5819 5.2 [2 60] [2 100]]] [2081 0.713 [2 48] [2 100]]] [4 70]] [24 36]] [4 100]] [6341 2.15 [4154 5.94 [791 5.88 [6581 0.487 [4 69] [4 50]] [7413 1.42 [7241 3.42 [4 36] [14 44]] [4 66]]] [4 66]] [7 100]]] [2760 1.61 [1078 6.22 [5 60] [5 100]] [5 100]]] [2764 4.15 [5692 10.6 [5413 1.11 [7722 1.44 [17 30] [17 55]] [17 79]] [17 100]] [5 50]]] [896 4.93 [5 100] [5 81]]] [1190 1.31 [1888 4.5 [2 91] [2 72]] [2 100]]] [4 95]]] [695 0.644 [4218 5.02 [4235 0.234 [1779 1.17 [4833 3.1 [4414 0.514 [4154 9.3 [6199 2.28 [7665 18.6 [2902 0.855 [5413 2.96 [4 36] [4 88]] [2 66]] [24 28]] [4 40]] [6184 15.2 [7665 9.84 [2 33] [2 33]] [2 54]]] [2752 17.7 [2 80] [2 54]]] [2 85]] [2 42]] [6987 0.282 [2 54] [2 100]]] [14 50]] [4338 2.13 [202 3.1 [1072 0.716 [7449 0.581 [4 54] [4 57]] [4 60]] [4 100]] [2 42]]]] [2470 1.28 [6548 0.199 [6442 1.82 [5896 0.216 [3905 0.785 [2417 1 [5 36] [4 100]] [5812 1.02 [6310 2.85 [17 52] [17 71]] [6395 1.02 [17 43] [17 80]]]] [17 87]] [5 91]] [2143 1.22 [17 82] [17 85]]] [7520 3.63 [7381 18.1 [4 97] [4 87]] [4 83]]]] [5969 2.19 [2841 0.824 [6395 0.782 [7682 7.92 [3734 3.56 [4719 3.14 [2616 30.6 [1429 8.85 [5 33] [7682 1.73 [6413 3.51 [6591 0.37 [7512 22.7 [5 75] [5 60]] [2601 1.82 [3917 0.956 [2591 6.33 [6554 2.29 [17 84] [17 50]] [17 90]] [17 100]] [17 68]]] [19 60]] [6732 3.9 [17 100] [17 85]]]] [19 57]] [17 90]] [19 61]] [38 50]] [17 93]] [5 37]] [17 90]]] [6260 3.65 [4154 11.7 [24 50] [24 87]] [5692 9.78 [24 95] [24 66]]]]] [3905 0.732 [145 0.238 [3687 3.58 [3561 1.35 [3724 2.54 [2999 0.882 [6260 3.89 [3006 1.36 [2259 2.34 [369 3.64 [5969 0.686 [429 12.7 [4047 0.21 [3670 3.97 [3008 3.56 [5480 1.17 [5462 12.3 [3710 10.8 [2766 0.389 [3388 0.904 [2764 15.9 [2628 7.23 [328 56.3 [4533 2.6 [6199 19.5 [3463 1.28 [3667 8.28 [3710 0.963 [3675 11.7 [4421 5.62 [35 87] [35 100]] [13 33]] [35 100]] [35 79]] [35 100]] [35 54]] [35 60]] [35 73]] [35 71]] [35 61]] [328 24.9 [2526 3.15 [35 92] [35 80]] [35 100]]] [35 100]] [23 13.5 [35 73] [35 42]]] [35 58]] [35 54]] [1078 37.8 [35 84] [35 45]]] [35 66]] [35 100]] [3634 14.8 [2470 4.17 [4401 16.8 [6761 7.81 [3705 0.625 [3852 2.13 [2068 2.47 [3387 3.04 [6883 1.4 [5034 0.516 [1980 0.441 [663 4.95 [685 8 [791 39.8 [2763 8.29 [3851 17 [1899 7 [3849 11.1 [35 99] [7096 2.79 [4421 12.2 [377 23.9 [3447 10.5 [35 96] [35 87]] [35 87]] [35 80]] [35 90]]] [23 2.11 [35 89] [35 100]]] [37 50]] [35 77]] [35 57]] [35 77]] [26 33]] [7665 1.87 [1025 14.3 [3444 2.85 [4181 6.66 [1991 0.416 [2091 3.96 [6406 6.93 [35 95] [35 94]] [35 77]] [35 100]] [35 75]] [35 100]] [35 71]] [35 72]]] [35 50]] [35 80]] [35 80]] [35 80]] [35 100]] [35 60]] [35 80]] [35 77]] [35 57]] [35 71]]] [29 30]] [35 55]] [6310 0.0546 [695 0.455 [3153 1.68 [2764 0.841 [35 60] [1899 2.96 [3041 2.8 [30 50] [38 37]] [26 42]]] [2752 9.67 [35 62] [35 92]]] [35 70]] [25 30]]] [26 75]] [13 66]] [24 27]] [328 7.72 [35 50] [8 91]]] [30 97]] [695 1.58 [37 72] [2780 5.71 [37 100] [37 88]]]] [30 58]] [178 2.94 [37 52] [17 71]]]] [11 100]]] [5693 4.7 [751 2.04 [2913 1.31 [4768 5.88 [114 1.09 [5410 26.9 [5413 2.73 [919 0.713 [756 1.36 [7210 9.06 [6181 2.49 [5673 2.37 [5034 65.6 [6732 4.2 [1997 2.46 [7343 9.43 [6015 2.11 [3 95] [3 100]] [3 55]] [3 100]] [14 88]] [14 70]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [14 100]] [3 75]] [3 100]] [3 100]] [3 100]] [3 100]] [14 60]]] [2730 0.649 [3905 1.46 [4891 1.03 [2752 1.14 [2038 2.13 [2280 0.27 [2526 23.2 [6 23] [7149 1.29 [5963 3.56 [7222 1.04 [6 88] [6 100]] [16 66]] [6 100]]] [6 77]] [6 62]] [18 44]] [5692 1.81 [6674 21.7 [4513 4.25 [1079 0.666 [4712 16.1 [5103 0.451 [5851 1.64 [6399 8.51 [4725 0.395 [1383 2.12 [4653 15.6 [7404 21.6 [1363 9.39 [7224 12.6 [2466 7.16 [1336 4.13 [4822 3.61 [2526 13.7 [939 1.96 [6 89] [6 100]] [4713 8.18 [7667 11.1 [4154 2.02 [2038 6.87 [6099 13.1 [7222 0.593 [2526 81.9 [1311 1.06 [5963 1.58 [2939 6.99 [6 97] [6 100]] [6 100]] [6 87]] [6 87]] [6 100]] [6 80]] [6 71]] [6 87]] [6 100]] [6 87]]] [6 80]] [6 81]] [6 63]] [6 82]] [6 75]] [6 66]] [6 66]] [6 100]] [6515 0.302 [4712 0.466 [4726 29.9 [2939 17.5 [1274 6.14 [2282 4.87 [6 98] [6 76]] [6 85]] [6 72]] [6 62]] [6 100]] [5963 5.91 [6 100] [6 96]]]] [6 75]] [6 60]] [6 61]] [6 70]] [16 66]] [2224 6.77 [7038 1.07 [7603 4.9 [6 73] [6 100]] [6 56]] [6 50]]] [6 50]] [5 25]]] [14 33]] [7 100]]] [6199 1.86 [6732 0.337 [7122 0.0937 [2716 0.345 [791 5.67 [2569 0.645 [1457 1.04 [1974 7.72 [2707 12.8 [4524 0.0696 [7203 0.157 [1456 2.44 [2611 13.7 [4513 3.53 [7224 4.64 [7580 4.46 [2579 13.2 [7564 1.91 [7255 2.29 [2602 1.52 [5012 0.444 [6167 0.391 [6020 0.22 [2262 11.4 [2526 29.1 [2079 24.8 [4732 0.463 [6 94] [6 88]] [6 62]] [6 100]] [6 89]] [6 100]] [6 100]] [6 75]] [6 71]] [6 81]] [6 85]] [6 81]] [1283 2.72 [6 87] [16 42]]] [6 100]] [6100 0.437 [1311 1.85 [4891 1.56 [6 66] [6 100]] [6 100]] [7407 1.23 [2396 1.95 [18 44] [6 83]] [6 90]]]] [16 70]] [6 83]] [6 66]] [6 50]] [26 50]] [1335 0.677 [429 1.38 [6 63] [6 63]] [6747 9.79 [6 100] [6 85]]]] [6 50]] [1364 8.71 [5595 0.167 [2412 11.5 [6934 10.8 [2259 90.2 [4891 9.07 [1457 0.0871 [7255 2.59 [6399 3.81 [2368 3.74 [6 100] [1383 0.419 [6 100] [6 85]]] [6 91]] [6 85]] [6 85]] [2554 3.18 [4822 0.752 [6 71] [6 80]] [6 100]]] [6 83]] [4673 3.93 [6 100] [6 41]]] [6 80]] [6 100]] [6 66]]] [2526 37.8 [4725 2.27 [6 68] [6 96]] [2259 65.8 [16 66] [6 100]]]] [6 44]] [6690 0.187 [6 64] [6 57]]] [6 33]] [18 44]]] [7449 3.39 [7085 1.29 [1621 0.808 [7413 0.358 [7402 2.11 [2402 5.45 [14 100] [14 94]] [1239 4.52 [14 100] [14 83]]] [14 81]] [2207 0.251 [14 100] [14 90]]] [14 54]] [14 83]]] [1043 3.56 [934 3.41 [4369 11.1 [1913 16.6 [906 1.23 [2607 2.01 [6114 1.9 [2517 23.6 [4356 4.2 [5142 1.9 [1192 3.6 [429 43.3 [7381 5.05 [5641 1.78 [2844 1.79 [7411 2.09 [3429 0.474 [5420 1.22 [1918 1.08 [1253 4.73 [7512 1.01 [24 36] [791 0.986 [24 77] [7210 5.76 [7751 2.68 [1007 4.17 [134 7.29 [134 0.73 [1062 6.5 [4414 4.18 [3642 17.3 [3646 0.732 [7590 4.81 [24 93] [24 90]] [24 100]] [24 83]] [24 80]] [1899 2.07 [24 53] [24 75]]] [24 100]] [24 80]] [24 66]] [24 88]] [3101 1.18 [24 63] [24 85]]]]] [20 25]] [24 50]] [22 100]] [6260 6.2 [24 100] [24 89]]] [24 45]] [22 62]] [1587 2.66 [19 53] [24 100]]] [4557 5.79 [3663 4.27 [5867 8.29 [7169 20 [4533 5.08 [47 7.81 [4346 7.47 [144 0.586 [7682 0.532 [3008 1.37 [2458 7.46 [4332 3.59 [6134 6.75 [7665 34.2 [1927 0.818 [7535 20.8 [1980 1.31 [3659 23 [5281 14.6 [7373 1.19 [3660 1.68 [2516 1.29 [434 2.54 [1050 2.92 [1240 20.8 [429 10.1 [24 95] [24 100]] [24 91]] [24 100]] [24 77]] [24 100]] [24 100]] [24 100]] [24 80]] [24 90]] [24 100]] [24 94]] [24 100]] [24 90]] [24 80]] [24 87]] [24 92]] [24 100]] [24 100]] [24 100]] [24 83]] [5211 11.9 [24 75] [24 100]]] [24 80]] [24 50]] [24 85]] [3016 2 [7665 11.2 [24 78] [24 100]] [24 91]]] [1738 3.36 [24 100] [24 75]]]] [5753 2.16 [435 1.81 [7665 14.1 [24 67] [4146 7.46 [1078 7.94 [429 45.6 [24 50] [2526 3.17 [24 95] [24 100]]] [24 100]] [24 100]]] [23 38]] [11 55]]] [23 33]] [24 33]] [2902 0.734 [4189 0.888 [24 97] [24 100]] [24 100]]] [24 61]] [17 50]] [18 75]] [663 0.911 [808 0.898 [4338 2.13 [24 25] [3659 2.43 [24 88] [24 100]]] [1253 0.626 [35 36] [28 50]]] [22 43]]] [23 33]] [15 50]] [791 23 [23 50] [23 33]]] [23 91]]] [6524 0.66 [5483 0.0961 [7259 0.96 [6734 0.137 [429 39.8 [112 0.364 [5970 0.805 [2802 1.34 [3959 1.17 [7451 0.313 [7302 0.881 [4993 4.63 [864 1.67 [5812 6.22 [5225 0.797 [7742 5.49 [547 3.21 [7494 4.09 [3310 1.31 [4968 3.28 [2705 1.02 [1400 12 [6042 2.42 [6031 4.7 [1687 1.97 [2809 0.478 [4564 0.415 [1391 2.61 [2004 5.25 [328 18.6 [5314 6.16 [6354 2.47 [883 8.74 [7048 8.08 [6353 3.91 [5013 3.51 [4486 1.08 [1077 9.18 [284 8.73 [4690 2.68 [7537 1.21 [1995 3.11 [726 4.11 [23 52.4 [1888 25.9 [362 1.76 [647 0.945 [429 39.1 [328 7.11 [145 15 [1084 0.761 [7739 3.18 [280 0.613 [1075 3.4 [324 7.6 [738 5.27 [2178 2.44 [1668 3.81 [719 4.46 [4158 0.501 [7186 0.444 [132 15.2 [2259 39 [18 66] [18 40]] [6 55]] [276 13.6 [18 100] [18 57]]] [18 94]] [1429 16 [1239 5.75 [18 63] [18 77]] [18 95]]] [18 91]] [29 44]] [18 66]] [18 50]] [18 40]] [18 100]] [19 50]] [16 42]] [7 50]] [5187 0.303 [964 0.891 [18 78] [18 93]] [18 100]]] [18 45]] [5011 0.273 [18 48] [19 75]]] [19 50]] [18 35]] [10 25]] [18 18]] [18 35]] [18 44]] [8 77]] [18 49]] [3 30]] [16 60]] [19 50]] [2385 1.29 [18 91] [18 90]]] [18 36]] [22 87]] [6732 3.8 [18 83] [18 71]]] [19 59]] [277 0.223 [18 54] [16 61]]] [7 44]] [22 76]] [18 84]] [6310 0.709 [5753 0.359 [1783 1.75 [18 85] [16 57]] [16 57]] [16 70]]] [19 80]] [1980 0.284 [22 93] [22 100]]] [2526 2.65 [18 70] [731 6.9 [7723 4.39 [18 100] [18 75]] [18 66]]]] [26 88]] [29 97]] [26 36]] [29 100]] [29 58]] [560 9.9 [4927 1.01 [5692 5.29 [18 77] [18 90]] [18 100]] [18 83]]] [2628 6.69 [397 1.59 [2759 1.62 [18 83] [18 44]] [18 100]] [18 54]]] [22 100]] [7512 23.9 [2 35] [4 50]]] [22 55]] [29 47]] [2268 21 [5192 1.53 [5969 3.58 [2448 1.46 [532 3.16 [19 46] [731 6.26 [18 49] [18 81]]] [19 72]] [18 85]] [18 80]] [19 88]]] [221 0.625 [29 42] [29 100]]] [29 95]] [23 2.09 [29 91] [29 63]]] [29 100]] [3622 0.589 [2911 1.13 [809 0.157 [152 1.47 [5225 1.15 [685 0.465 [2785 0.761 [719 0.719 [939 1.86 [2846 0.644 [5692 3.33 [663 25 [6342 1.91 [29 77] [29 66]] [18 46]] [18 29]] [22 50]] [29 100]] [18 60]] [29 100]] [18 54]] [22 100]] [4992 0.364 [429 18.1 [18 37] [6353 0.711 [18 80] [18 75]]] [19 50]]] [22 100]] [18 100]] [29 100]]] [7449 0.698 [6826 2.51 [435 0.559 [1630 0.52 [5482 10.9 [5110 1.39 [731 0.99 [29 52] [18 90]] [22 36]] [7737 2.62 [2846 9.04 [6707 4.35 [282 8.41 [6031 3.33 [4927 6.41 [7186 3.11 [18 44] [18 100]] [5160 2.73 [18 72] [19 88]]] [22 100]] [18 55]] [18 78]] [22 71]] [18 72]]] [547 0.52 [18 94] [18 100]]] [4663 3.05 [29 78] [29 66]]] [18 100]] [3622 0.337 [906 0.907 [2526 2.53 [29 83] [18 41]] [144 0.406 [3667 1.54 [4154 1.51 [29 97] [29 100]] [29 100]] [29 100]]] [29 100]]]] [5776 4.3 [392 1.37 [7185 2.2 [5154 5.79 [978 0.644 [5322 16.1 [2178 6.87 [4769 2.33 [560 5.81 [5853 7.86 [5073 1.27 [3326 0.881 [29 100] [29 85]] [29 100]] [29 71]] [29 75]] [29 100]] [29 85]] [29 55]] [29 66]] [29 83]] [6734 3.52 [18 77] [18 83]]] [29 82]] [18 50]]] [4991 0.488 [939 0.928 [3515 4.65 [2294 0.273 [7731 6.5 [6657 0.645 [1646 1.02 [6959 1.69 [5346 5.47 [1078 19.1 [2849 1.14 [1078 11.2 [280 1.45 [5969 2.09 [7736 1.25 [4859 1.72 [7742 0.8 [4504 14.7 [4504 4.82 [2752 6.45 [19 100] [15 33]] [19 31]] [18 66]] [19 61]] [18 63]] [1239 1.53 [18 58] [18 40]]] [18 78]] [26 62]] [18 64]] [18 73]] [429 18.5 [18 62] [7302 3.77 [19 78] [19 58]]]] [18 35]] [18 92]] [18 100]] [19 66]] [16 50]] [19 53]] [4509 1.66 [1078 27.5 [19 85] [19 100]] [19 66]]] [19 87]] [788 6.75 [19 71] [18 66]]]] [4946 4.2 [18 90] [18 98]]] [4611 1.07 [3959 0.434 [6227 1.78 [6896 1.01 [1186 0.0917 [1025 5.93 [6031 0.637 [7497 1.09 [328 6.86 [7512 3.23 [2705 1.05 [22 60] [29 100]] [29 68]] [28 37]] [29 100]] [22 100]] [29 81]] [809 1.1 [22 81] [22 100]]] [22 100]] [22 100]] [29 100]] [29 86]]]] [6026 0.668 [1400 9.95 [1980 4.31 [1137 0.413 [1454 1.47 [3308 2.44 [7634 0.81 [2767 0.829 [1429 24.6 [2752 20.8 [2461 0.523 [2902 6.38 [2752 12.5 [5462 1.51 [4993 4.82 [4139 1.5 [1233 0.579 [4136 13.4 [4135 13.4 [7442 2.7 [1157 0.898 [27 80] [27 100]] [27 100]] [27 97]] [27 58]] [27 100]] [27 100]] [27 85]] [27 85]] [27 60]] [27 75]] [27 100]] [2259 2.01 [660 1.54 [27 53] [23 42]] [23 54]]] [27 72]] [11 55]] [27 100]] [29 52]] [23 40]] [27 100]] [6640 1.2 [2806 0.785 [577 0.886 [5366 0.609 [2088 1.02 [1429 16.1 [2083 0.7 [5662 0.888 [7665 1.01 [4279 3.11 [978 9.81 [3617 0.945 [4137 0.431 [1429 7.58 [976 0.134 [3934 0.645 [819 0.555 [3273 3.69 [906 0.898 [2939 2.62 [1239 2.54 [27 74] [23 25]] [27 75]] [29 26]] [11 75]] [27 100]] [27 100]] [27 100]] [27 91]] [27 100]] [27 100]] [23 93]] [2259 8.61 [4312 0.84 [2091 1.06 [27 47] [27 66]] [27 50]] [23 45]]] [1 17]] [23 80]] [29 33]] [967 1.11 [2241 7.55 [939 6.97 [23 26] [791 6.15 [27 94] [27 88]]] [23 71]] [11 88]]] [23 100]] [23 92]] [23 85]] [23 50]] [23 100]]] [2461 3.6 [2259 13.7 [5345 2.75 [1429 5.39 [10 73] [1429 24 [10 100] [10 77]]] [10 80]] [10 75]] [27 100]]] [10 100]]] [2088 0.557 [6920 0.461 [968 0.202 [7354 0.238 [5851 3.96 [1068 1.92 [5421 1.48 [2199 0.457 [5749 0.634 [435 3.44 [144 0.707 [2143 5.66 [2542 1.79 [23 2.16 [7352 1.01 [7497 1.42 [6320 1.68 [2764 1.95 [6560 0.805 [1226 2.61 [6571 5.22 [1025 13.1 [2760 2.42 [3182 3.31 [7183 2.67 [392 16.5 [2470 10.6 [6444 3.77 [7441 5.38 [7176 29.4 [731 2.35 [4338 23.5 [328 20.8 [3114 0.629 [2536 1.58 [286 4.08 [7241 13.7 [4332 5.62 [2571 0.661 [8 85] [4696 0.81 [8 68] [8 77]]] [8 100]] [8 62]] [23 50]] [8 100]] [8 100]] [8 69]] [8 50]] [8 55]] [22 58]] [8 100]] [8 100]] [30 100]] [23 50]] [22 100]] [30 57]] [8 61]] [23 57]] [23 96]] [23 68]] [1078 11.2 [3958 1.39 [3830 1.08 [8 99] [8 100]] [8 100]] [4533 4.8 [2575 1.65 [2804 1.52 [8 94] [8 100]] [8 100]] [8 77]]]] [1899 3.7 [23 76] [23 65]]] [35 44]] [23 90]] [35 60]] [5412 0.677 [8 34] [22 83]]] [35 66]] [23 66]] [7512 0.84 [22 100] [22 85]]] [6342 0.728 [4690 0.234 [978 18.4 [23 97] [23 84]] [35 40]] [23 83]]] [23 100]] [1429 32.4 [688 0.913 [7413 0.561 [7453 0.734 [685 4.38 [2081 1.76 [23 52] [23 100]] [8 60]] [23 85]] [23 100]] [23 100]] [112 0.647 [8 69] [22 100]]]] [23 75]] [663 0.428 [6732 10.3 [23 78] [22 80]] [22 84]]] [5803 1.33 [5114 1.92 [6670 5.49 [1192 2.15 [0 70] [23 75]] [0 98]] [8 100]] [35 66]]] [504 4.41 [407 10.1 [1998 5.99 [7428 9.26 [2763 6.12 [4332 0.395 [377 4.55 [3056 0.502 [6375 0.222 [2321 0.303 [1239 0.268 [4690 0.924 [8 85] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 87]] [8 100]] [8 94]] [8 71]] [8 66]] [8 88]] [8 71]]] [286 3.96 [6562 0.116 [2143 2.9 [2526 15.2 [22 40] [2570 3.11 [1089 13 [5211 3.05 [8 87] [8 100]] [8 77]] [8 70]]] [8 62]] [8 66]] [22 55]]] [791 10.8 [1888 1.8 [2845 0.46 [2562 5.79 [4414 5.55 [5647 0.75 [5412 0.662 [23 90] [23 100]] [23 100]] [23 80]] [23 70]] [23 100]] [8 100]] [7210 0.236 [2902 4.81 [576 0.347 [1986 6.25 [23 88] [23 70]] [23 100]] [23 44]] [23 100]]]] [5728 0.219 [286 0.69 [2845 0.293 [7176 0.605 [2902 0.855 [685 8.48 [5851 1.06 [23 72] [0 75]] [8 57]] [23 100]] [2628 0.367 [8 68] [8 60]]] [23 100]] [23 100]] [8 100]]]] [3660 1.13 [6046 0.805 [4025 21.3 [1083 2.61 [3640 0.316 [3281 3.22 [4573 3.13 [7413 4.45 [5637 5.92 [3663 6.44 [3661 13 [6734 2.38 [3879 2.47 [203 13.9 [4353 3.69 [6724 1.44 [4338 10.4 [209 5.69 [2548 1.66 [1072 0.154 [3016 7.04 [2265 1.29 [4183 0.571 [1011 5.23 [2793 8.08 [7566 4.33 [144 0.56 [5693 0.492 [1047 0.713 [2793 1.94 [24 96] [24 100]] [24 100]] [24 100]] [24 100]] [24 90]] [24 91]] [24 75]] [24 85]] [19 50]] [24 75]] [24 100]] [24 100]] [24 71]] [4886 13.4 [2199 14.2 [2993 0.415 [7736 0.602 [2457 11.5 [5814 6.42 [5067 3.03 [4173 12.2 [7665 9.37 [6068 5.71 [4492 0.188 [3631 3.79 [149 14 [5052 12.4 [1746 0.161 [985 4.99 [4356 11.7 [4545 0.754 [4299 25 [6853 17.9 [4214 26.3 [24 100] [24 93]] [24 99]] [24 92]] [24 100]] [24 96]] [24 90]] [24 100]] [24 96]] [24 87]] [5692 2.82 [24 96] [24 80]]] [24 100]] [24 80]] [5753 11.8 [3654 4.19 [25 6.2 [4340 0.181 [4147 0.264 [7512 15.9 [24 100] [5413 0.766 [4546 1.66 [2902 1.06 [24 99] [24 100]] [24 100]] [24 100]]] [24 100]] [24 100]] [24 90]] [1389 5.65 [24 100] [24 85]]] [24 85]]] [24 84]] [24 90]] [24 83]] [24 83]] [24 71]] [655 0.741 [24 71] [24 100]]] [24 75]] [24 90]]] [7535 2.42 [24 90] [24 85]]] [24 75]] [24 71]] [4339 0.144 [24 100] [24 75]]] [24 69]] [24 66]] [4279 6.75 [24 50] [24 87]]] [7445 3.78 [24 84] [24 75]]] [24 76]] [24 66]] [19 42]] [1640 1.96 [6374 0.316 [4518 7.2 [24 95] [24 86]] [24 52]] [24 50]]] [24 57]] [24 42]] [7529 4.41 [19 52] [24 55]]] [4818 2 [5641 0.394 [3644 2.09 [6861 2.65 [2593 4.18 [1034 0.721 [1899 7.5 [2518 8.48 [2436 2.29 [5007 1.71 [3638 0.971 [4789 1.96 [6962 8.01 [885 2.32 [6338 12.1 [978 15.8 [2232 0.346 [3652 13.5 [5052 0.195 [5693 7.71 [4519 14.3 [6724 2.6 [5647 0.34 [4022 3.74 [1899 0.327 [1025 34.1 [3641 1.74 [24 98] [24 100]] [24 83]] [24 100]] [24 83]] [24 100]] [24 83]] [24 92]] [24 83]] [24 100]] [24 88]] [24 80]] [24 87]] [19 57]] [24 90]] [24 83]] [24 83]] [24 78]] [3643 0.428 [24 94] [24 69]]] [24 57]] [24 66]] [4300 0.438 [1436 1.4 [772 1.8 [24 82] [19 30]] [24 60]] [24 100]]] [3636 2.21 [7376 2.24 [24 79] [19 60]] [24 100]]] [24 50]] [24 62]] [3652 11.3 [2548 0.4 [3643 0.48 [24 66] [19 63]] [24 100]] [19 69]]] [3659 13.1 [5819 1.1 [4145 2.03 [4035 2.96 [791 9.35 [6739 0.296 [6708 12.6 [1025 25.9 [2265 1.97 [5052 0.711 [19 54] [24 81]] [24 100]] [19 71]] [19 72]] [19 87]] [19 80]] [24 66]] [24 100]] [24 83]] [7381 1.9 [1587 3.1 [19 62] [24 93]] [24 87]]]] [4518 4.17 [429 6.29 [24 83] [24 100]] [24 100]]]]] [4110 0.22 [5482 0.418 [7340 0.998 [6593 0.119 [2580 0.589 [7009 1.57 [6980 0.062 [3518 0.288 [5211 4.47 [7305 2.43 [6173 0.629 [3056 0.925 [5521 0.824 [6239 0.571 [5001 0.235 [6591 0.27 [2482 1.14 [2363 0.23 [2453 2.19 [7384 0.43 [5566 1.11 [731 0.179 [3262 2.32 [6403 1.13 [1690 2.47 [5972 6.58 [1716 0.425 [573 2.72 [7734 2.35 [5160 3.18 [7512 5.69 [4602 2.92 [5034 2.6 [6711 2.34 [4342 2.91 [4633 3.03 [1557 1.36 [5448 3.73 [6235 2.55 [2636 0.616 [5054 6.4 [4210 20.5 [5454 0.382 [2968 3.19 [7244 3.89 [2913 2.96 [1887 3 [2826 1.29 [585 2.28 [5860 4.61 [5965 5.41 [6604 2.24 [6647 0.529 [384 0.381 [6231 2.1 [3959 1.64 [6178 3.13 [4279 2.71 [2983 0.942 [6638 0.942 [1783 50.4 [5632 6.63 [1227 0.876 [4228 1.02 [6031 2.76 [5807 0.192 [3566 2.66 [2259 54.3 [957 26.7 [752 12.4 [769 2.24 [6235 0.585 [5467 11.8 [695 18 [5999 11.7 [5531 0.843 [2136 0.445 [3616 0.588 [5753 20.3 [978 3.91 [398 1.98 [1434 0.952 [849 0.734 [2707 4.85 [3079 5.77 [660 0.467 [5462 17.6 [30 7] [35 63]] [29 44]] [37 62]] [38 33]] [27 71]] [20 61]] [28 43]] [4 15]] [14 33]] [27 63]] [26 45]] [33 50]] [1 52]] [14 43]] [12 100]] [11 40]] [21 57]] [30 100]] [17 61]] [34 43]] [20 58]] [15 60]] [22 70]] [10 66]] [11 100]] [16 62]] [6910 0.787 [30 15] [30 100]]] [30 100]] [16 50]] [6091 0.202 [3989 0.42 [34 15] [3989 1.48 [30 33] [15 57]]] [15 71]]] [25 100]] [29 78]] [957 1.51 [10 29] [10 52]]] [23 43]] [30 72]] [30 77]] [3 100]] [0 73]] [21 100]] [2739 16.1 [248 18.1 [663 30.1 [6045 1.18 [4109 5.38 [695 2.53 [178 10.6 [1997 5.03 [5677 1.93 [6310 6.92 [1567 7.25 [3905 9.96 [6724 11.9 [662 0.739 [6242 4.88 [957 12.2 [738 1.98 [3197 5.45 [5 21] [17 54]] [17 85]] [17 50]] [5 100]] [17 50]] [17 85]] [17 51]] [7 100]] [5 50]] [38 70]] [16 44]] [17 43]] [695 8.87 [7241 2.05 [17 26] [12 62]] [14 38]]] [5 72]] [14 87]] [19 33]] [26 75]] [4 91]]] [30 100]] [663 10.5 [6074 0.956 [1783 19.3 [30 28] [30 80]] [30 55]] [25 33]]] [724 1.36 [144 3.11 [26 25] [17 100]] [16 83]]] [5 53]] [29 51]] [30 94]] [4 77]] [17 49]] [2270 2.54 [34 40] [34 100]]] [32 100]] [4479 21.7 [17 29] [17 70]]] [34 100]] [24 100]] [30 53]] [883 1.23 [1400 1.31 [975 1.55 [2902 0.632 [6134 3.61 [14 79] [32 75]] [14 66]] [28 71]] [14 100]] [28 54]]] [26 84]] [4624 4.2 [7032 3.41 [4288 2.29 [673 1.71 [7563 2.51 [828 0.87 [7680 1.36 [7133 0.546 [914 2.51 [5698 1.2 [7325 3.04 [929 2.84 [610 1.08 [3931 7.86 [2588 3.01 [4574 8.95 [4799 3.34 [4519 2.16 [5034 1.06 [1161 1.31 [4929 4.06 [6907 6.67 [2739 24.4 [723 5.79 [6241 0.575 [384 1.9 [6581 5.1 [145 14.7 [1011 8.61 [6124 10.4 [100 1.09 [6031 3.57 [7311 3.65 [6178 2.2 [5028 1.46 [906 11.6 [7742 0.418 [5429 2.3 [1180 1.15 [2616 5.42 [2846 6.58 [7712 2.82 [939 16.8 [728 13.2 [7419 0.99 [5680 1.75 [5693 13.9 [3554 1.11 [6544 4.87 [4154 13.4 [7525 3.31 [7601 0.956 [7583 2.89 [3317 2.06 [17 8.36 [2968 0.756 [14 20] [5 33]] [13 71]] [14 85]] [1 63]] [18 50]] [30 83]] [24 24]] [14 100]] [14 39]] [4 30]] [5 48]] [18 29]] [14 77]] [10 71]] [14 100]] [328 2.96 [14 57] [7665 19.7 [14 57] [14 100]]]] [4338 5.08 [1429 3.91 [4 55] [6 17]] [23 40]]] [13 100]] [5 63]] [6732 1.91 [5 37] [19 62]]] [32 37]] [14 66]] [25 100]] [20 100]] [22 81]] [19 41]] [12 100]] [6732 5.9 [7512 23.7 [5 35] [7512 29.7 [7 57] [7 70]]] [7 57]]] [19 62]] [6413 3.46 [7722 3.05 [19 30] [17 43]] [38 44]]] [7 40]] [5 38]] [17 84]] [4 90]] [25 90]] [7512 14.1 [4 68] [4 50]]] [10 88]] [2826 0.713 [14 73] [1400 2.06 [5155 0.494 [7595 6.67 [7301 6.28 [728 6.84 [7620 6.36 [6413 6.37 [7241 14.2 [99 9.8 [494 0.69 [1429 21.4 [1239 1.87 [14 84] [14 60]] [702 1.17 [14 97] [14 100]]] [14 100]] [14 81]] [14 85]] [32 62]] [14 63]] [14 100]] [14 66]] [14 66]] [14 76]] [896 4.41 [14 100] [14 97]]]]] [24 80]] [32 67]] [32 90]] [2616 6.33 [2526 23.1 [19 62] [17 50]] [17 90]]] [663 3.45 [32 47] [32 57]]] [5 76]] [7253 1.67 [17 25] [17 66]]] [1078 27.5 [5 79] [5 100]]] [24 93]] [4851 2.09 [14 60] [32 94]]] [4 100]] [10 83]] [7241 1.78 [957 6.7 [7 55] [32 75]] [7 42]]] [5 83]] [26 59]] [4349 2.33 [2752 21.1 [4288 3.44 [4 44] [32 89]] [1899 1.41 [32 57] [32 21]]] [7 55]]] [31 76]] [4154 7.27 [14 94] [14 90]]]] [5632 5.61 [896 1.2 [1888 1.12 [14 57] [14 81]] [7692 1.2 [14 96] [14 100]]] [14 71]]] [5894 1.29 [738 3.79 [5812 9.48 [3908 10.3 [7583 1.41 [1995 8.29 [5132 1.3 [1669 1.99 [7177 2.01 [6883 2.61 [4927 0.613 [957 5.53 [1023 11.1 [2628 5.59 [7512 3.65 [392 8.57 [18 58] [19 50]] [978 16.4 [328 13.2 [3251 2.04 [5 39] [18 87]] [19 61]] [7 58]]] [2636 1.47 [5 73] [7 75]]] [7 85]] [5 50]] [18 100]] [18 50]] [7 100]] [7 100]] [16 57]] [25 45]] [7 100]] [18 80]] [7 58]] [18 56]] [18 70]]] [7590 3.02 [3554 2.83 [1072 10.6 [2910 0.555 [1025 3.98 [5814 9.26 [17 27] [5 83]] [1011 2.64 [2752 31.3 [4 67] [4 74]] [4 82]]] [19 54]] [4 63]] [5 36]] [17 39]]] [978 4.71 [1587 4.76 [7314 3.9 [14 77] [14 65]] [30 63]] [17 77]]] [7413 2.91 [5345 0.612 [4564 2.62 [7677 2.56 [7657 0.644 [3130 2.81 [2251 4.01 [4218 4.13 [12 88] [12 100]] [12 71]] [12 70]] [12 100]] [36 57]] [12 100]] [429 22.8 [12 70] [12 50]]] [12 57]]] [7512 1.39 [17 61] [141 3.39 [17 77] [17 66]]]] [32 100]] [4533 0.982 [37 97] [37 100]]] [6544 0.701 [4478 2.6 [3929 1.59 [7324 4.22 [3010 0.78 [5480 0.782 [494 0.282 [5904 0.869 [4218 1.55 [6233 4.27 [2739 0.682 [6866 0.334 [328 2.55 [1025 0.989 [663 14 [1630 0.669 [6358 0.678 [7177 1.74 [5413 0.393 [7214 0.509 [6776 7.41 [6848 1.89 [1584 0.615 [6524 1.42 [2521 1.5 [728 4.7 [3972 4.59 [6711 2.4 [7526 0.726 [3995 10.6 [4568 8.76 [3905 4.9 [7343 0.707 [3884 1.47 [1062 22.4 [5891 5.67 [4304 2.73 [6719 8.26 [1703 1.36 [4968 7.35 [5341 1.87 [7708 2.57 [7244 1.45 [2968 3.61 [5021 2.02 [6732 5.08 [5799 0.634 [6584 20.2 [5316 2.71 [6022 3.36 [896 9.11 [1429 23 [685 3.07 [26 20] [14 44]] [3424 3.37 [1078 26.4 [5692 4.85 [5 43] [7 62]] [17 38]] [5 85]]] [4851 1.28 [7722 9.92 [5 44] [5 93]] [5 87]]] [7 100]] [14 36]] [17 91]] [17 50]] [3008 3.14 [5 61] [17 57]]] [5 63]] [5 65]] [7241 10 [663 0.96 [7 33] [17 40]] [17 78]]] [17 41]] [14 33]] [19 69]] [17 71]] [17 66]] [19 57]] [978 6.67 [17 90] [17 88]]] [38 57]] [5 100]] [6550 1.12 [5 51] [5 87]]] [5641 0.846 [7185 10.5 [17 37] [7 50]] [26 57]]] [7 87]] [978 10.9 [5 80] [5 100]]] [17 48]] [18 62]] [5 85]] [6251 1.21 [7188 2.7 [17 43] [17 72]] [17 50]]] [5 100]] [7 74]] [6310 5.63 [17 51] [17 41]]] [5 75]] [7 92]] [7251 2.01 [17 31] [17 50]]] [6732 0.285 [1899 14.3 [4338 4.49 [2526 11.7 [17 32] [7 33]] [17 42]] [7 45]] [17 76]]] [7 100]] [4719 0.678 [2541 0.623 [16 63] [17 58]] [38 63]]] [5953 0.513 [5673 1.34 [5413 1.28 [2752 31.1 [17 36] [19 53]] [17 62]] [17 75]] [19 59]]] [4851 1.78 [7169 4.5 [2081 4.45 [6599 2.51 [5637 6.61 [6732 9.02 [17 32] [17 80]] [5 38]] [134 4.64 [19 46] [6597 14.2 [19 88] [19 50]]]] [19 50]] [17 77]] [17 60]]] [5155 0.321 [1630 0.359 [3905 0.551 [2570 3.87 [6924 1.18 [4154 0.309 [663 9.92 [7169 5.48 [695 3.46 [1911 1.84 [1429 26 [4 88] [4 50]] [4 57]] [695 19.8 [4 66] [4 92]]] [4 100]] [4 33]] [1980 1.86 [1899 6.89 [4 63] [4 40]] [7 50]]] [4 80]] [6230 4.83 [4 55] [4 50]]] [17 28]] [24 30]] [17 66]]] [6708 3.87 [5005 1.28 [2983 2.7 [338 2.48 [1913 4.68 [418 1.72 [2470 2.72 [788 3.97 [5155 3.76 [673 2.06 [6977 4.7 [7 39] [7 62]] [26 72]] [7 83]] [6 50]] [4 54]] [7 54]] [7 50]] [26 63]] [16 50]] [7 100]] [7 100]]] [5 88]] [906 0.559 [2752 28 [4851 0.508 [5662 0.711 [4 78] [4 100]] [4 100]] [5 50]] [4 57]]] [2526 4.35 [7665 16.3 [25 100] [31 62]] [25 83]]] [3794 0.516 [17 43] [17 66]]] [728 5.21 [978 3.27 [6230 7.21 [7 62] [19 46]] [7214 2.82 [1062 3.61 [19 60] [19 84]] [19 100]]] [23 7.35 [19 90] [19 100]]]] [6534 0.569 [6920 1.15 [728 3.23 [7192 0.423 [685 1.13 [2526 12.9 [6230 4.08 [7 60] [19 28]] [6732 1.47 [17 55] [17 76]]] [7 84]] [17 50]] [17 51]] [38 55]] [1740 2.99 [3381 0.355 [19 66] [19 100]] [19 66]]]] [6227 0.456 [7354 0.86 [4205 2.2 [1429 30.5 [26 72] [18 46]] [26 100]] [5480 7.01 [1601 0.143 [7679 0.504 [2726 1.32 [2745 1.48 [5637 2.28 [1696 0.73 [7712 0.902 [5516 0.404 [18 53] [16 57]] [19 45]] [18 71]] [19 35]] [18 100]] [18 88]] [16 50]] [4485 0.286 [19 28] [38 100]]] [731 6.24 [18 41] [7601 7.94 [685 14.3 [18 76] [3 30]] [18 53]]]]] [38 73]]] [7 100]] [5 77]] [328 2.8 [7520 0.755 [6587 0.136 [6557 0.976 [7512 23.7 [695 5.38 [791 10.9 [7326 0.805 [4766 0.09 [5 51] [5 70]] [5 77]] [17 38]] [17 25]] [5 83]] [5 92]] [5692 0.136 [5 57] [5 100]]] [5 80]] [5 35]]] [3077 1.34 [5296 0.652 [3558 4.24 [1009 0.661 [1686 2.7 [7244 2.02 [5034 2.46 [4479 7.21 [2752 36.7 [602 3.95 [791 2.99 [144 2.48 [16 34] [17 66]] [2826 13.3 [7 36] [19 60]]] [7210 2.2 [929 1.81 [17 33] [17 100]] [17 62]]] [38 75]] [731 6.75 [17 75] [1630 1.28 [7 67] [16 57]]]] [14 100]] [17 81]] [7 100]] [1888 1.43 [7 76] [7 50]]] [2526 2.76 [7 55] [2628 11.7 [7 100] [7 83]]]] [17 50]] [5641 0.688 [17 48] [19 54]]]] [1648 0.629 [6395 0.471 [14 68] [5297 0.491 [6313 3.93 [5251 3.08 [1704 9.75 [5692 4.98 [5413 7.71 [6549 2.03 [7689 1.38 [6977 0.472 [1557 1.75 [3928 2.8 [14 44] [3929 6.1 [17 80] [17 60]]] [17 100]] [17 85]] [5904 1.6 [19 28] [19 100]]] [5660 0.339 [4870 0.551 [7665 7.41 [1888 1.88 [17 84] [17 77]] [17 68]] [17 75]] [16 25]]] [17 100]] [5348 0.355 [1567 1.34 [17 94] [17 88]] [17 66]]] [5157 1.42 [1899 0.843 [17 90] [17 100]] [17 100]]] [19 53]] [19 46]] [5297 2.73 [19 62] [19 91]]]] [19 57]]]] [4877 3.02 [4895 0.621 [6230 11.8 [14 100] [5034 19.4 [14 100] [14 92]]] [14 100]] [7722 0.446 [14 100] [14 87]]]] [4478 10.3 [4158 2.43 [7601 0.609 [5410 2.24 [5692 6.93 [5632 0.873 [7735 0.808 [7 95] [7 100]] [7 100]] [7 80]] [7 80]] [7 100]] [7 83]] [7 71]]] [1047 2.02 [1390 0.917 [24 42] [24 83]] [4814 10.2 [3102 2.57 [1239 8.49 [24 100] [24 90]] [24 83]] [24 66]]]] [7 100]] [3905 1.42 [3342 7.42 [2259 7.3 [736 1.87 [899 2.7 [31 86] [31 100]] [31 100]] [2143 0.426 [31 100] [31 89]]] [31 77]] [31 100]]] [3732 0.448 [4478 0.227 [1704 1.01 [3463 6.27 [4896 0.191 [2573 1.44 [7325 1.01 [1077 6.85 [1128 0.891 [3798 9.28 [7723 0.382 [6380 5.37 [7665 8.6 [178 0.792 [17 33] [5 62]] [4154 1.69 [2259 2.96 [6936 1.83 [6238 0.741 [1011 7.26 [429 31.8 [5154 5.07 [6554 2.73 [134 3.18 [17 1.36 [724 4.01 [1078 13.4 [2591 0.921 [17 37] [5 53]] [17 35]] [17 81]] [17 40]] [17 60]] [17 75]] [3317 3.12 [17 76] [17 41]]] [2826 3.38 [17 57] [17 96]]] [17 42]] [19 66]] [5 87]] [6581 9.5 [17 50] [5 72]]] [573 3.13 [2752 12.7 [5 100] [5 35]] [17 83]]]] [14 70]] [2939 0.305 [17 65] [17 100]]] [38 70]] [5 100]] [5 100]] [5 100]] [1429 55.7 [17 92] [17 63]]] [2541 0.308 [17 60] [17 77]]] [5 88]] [5692 0.402 [1690 9.86 [5413 1.34 [7188 0.782 [17 73] [17 50]] [17 66]] [17 40]] [736 0.557 [17 64] [17 100]]]] [2760 2.12 [978 1.38 [14 46] [7085 1.03 [2616 10.9 [3554 0.759 [6524 1.17 [5742 1.35 [5413 2.92 [4533 0.182 [5345 2.19 [6584 0.137 [2752 11.1 [17 87] [17 93]] [17 100]] [17 60]] [17 100]] [17 84]] [17 86]] [17 75]] [7381 5.31 [17 100] [17 44]]] [17 45]] [14 50]]] [7689 0.526 [14 33] [17 50]]]] [7085 1.37 [3822 0.232 [4130 0.164 [1587 0.737 [2753 8.86 [648 0.294 [5829 1.52 [7067 1.05 [5692 11.3 [6555 2.34 [6439 0.405 [5632 1.55 [663 16.3 [726 4.5 [3027 0.555 [6599 2.64 [1911 0.743 [738 1.35 [791 26.8 [7734 6.02 [7417 1.56 [17 77] [17 50]] [17 46]] [19 50]] [17 95]] [695 6.74 [17 100] [17 85]]] [19 33]] [17 40]] [19 38]] [19 63]] [16 80]] [3734 1.02 [17 80] [3983 2.72 [7381 5.35 [17 46] [19 57]] [19 85]]]] [719 1.46 [17 88] [17 100]]] [1011 0.849 [38 62] [17 50]]] [6591 5.02 [7253 1.66 [2966 0.212 [3732 2.39 [2178 0.279 [19 36] [38 69]] [4762 0.679 [1884 0.826 [1089 0.605 [4414 0.183 [896 9.14 [17 37] [17 77]] [17 87]] [38 57]] [38 83]] [17 100]]] [17 64]] [6576 1.4 [19 45] [23 40]]] [7598 0.506 [2826 3.42 [7373 1.8 [7723 3.39 [3734 6.46 [38 33] [17 70]] [17 100]] [38 55]] [4218 1.42 [663 3.91 [17 84] [17 69]] [17 57]]] [19 71]]]] [7588 0.565 [1648 1.01 [17 46] [5345 0.264 [19 35] [38 71]]] [35 44]]] [19 50]] [3858 3.33 [35 55] [35 100]]] [5693 0.876 [5812 0.405 [17 46] [17 66]] [5384 0.359 [19 81] [19 62]]]] [38 100]] [7566 1.5 [957 0.695 [3823 1.35 [19 87] [19 100]] [19 100]] [17 80]]] [3563 3.81 [17 41] [19 100]]]]] [7 100]] [6591 0.973 [710 0.486 [112 3.15 [6529 1.44 [1008 0.306 [6581 1.42 [7177 0.37 [144 1.59 [1072 1.31 [14 59] [1704 1.35 [17 66] [17 100]]] [5155 3.24 [929 2.05 [6310 1.02 [17 38] [17 57]] [17 100]] [19 42]]] [7 100]] [17 54]] [38 44]] [1429 26.3 [7 83] [7 100]]] [1650 2.84 [2753 1.24 [899 0.734 [1742 1.92 [2259 1.9 [14 96] [14 80]] [14 85]] [14 100]] [14 75]] [14 100]]] [14 100]] [4870 5.21 [17 64] [22 33]]]] [1632 0.0891 [3743 0.267 [6557 0.473 [7711 1.3 [440 0.233 [3915 2.01 [1633 4.99 [2526 10.4 [19 50] [7 39]] [5523 6.86 [3516 3.8 [5693 1.14 [17 46] [19 37]] [19 100]] [19 89]]] [17 55]] [35 45]] [3798 2.45 [17 38] [17 66]]] [35 65]] [35 86]] [7682 0.525 [2752 24.2 [19 91] [19 100]] [1899 1.5 [19 50] [19 87]]]]] [6333 0.271 [3874 0.86 [6230 5.21 [1429 41.9 [3558 0.577 [7665 2.64 [5110 1.93 [12 26] [30 54]] [5 33]] [5 62]] [144 0.613 [5 42] [5 30]]] [3220 3.33 [2829 1.11 [738 1.23 [731 0.429 [7711 1.5 [653 1.45 [7512 10 [2753 7.03 [12 39] [5 75]] [5 72]] [5 100]] [5 90]] [3732 0.632 [7689 3.02 [5462 4.43 [4001 6.57 [2784 0.317 [5 87] [5 100]] [5 55]] [5 58]] [5 55]] [17 60]]] [17 42]] [7665 2.93 [5 71] [5 33]]] [5 92]]] [12 100]] [4184 10.4 [7598 0.127 [3675 6.22 [7566 2.44 [1544 0.994 [5155 5.85 [1128 0.942 [1980 1.55 [6333 8.15 [429 21.9 [5 85] [5 100]] [5 80]] [5 88]] [5 100]] [5 88]] [5 100]] [5 91]] [5 71]] [5 100]] [5 86]]]] [31 100]] [1420 1.12 [4235 16.2 [7295 0.606 [6457 0.876 [682 0.736 [1652 1.1 [1253 3.52 [6983 1.25 [896 7.45 [2801 1.86 [7352 0.699 [726 0.79 [112 6.55 [2530 2.65 [384 2.94 [31 16] [18 50]] [25 62]] [12 77]] [31 50]] [12 33]] [12 100]] [7548 1.87 [14 45] [14 100]]] [31 100]] [12 66]] [31 100]] [5320 0.555 [5999 1.31 [5978 0.719 [312 8.21 [31 97] [31 88]] [31 100]] [31 100]] [31 100]]] [25 100]] [31 100]] [7722 2.19 [26 88] [26 62]]] [25 100]]] [5851 6.46 [978 0.57 [811 0.57 [2832 2.8 [6910 0.815 [6230 2.1 [2354 0.349 [859 2.04 [1078 9.04 [22 69] [30 84]] [22 91]] [22 100]] [5972 12.6 [6530 0.855 [7315 1.51 [2011 5.92 [2201 3.44 [5420 0.347 [5226 0.6 [1089 1.28 [1239 26.2 [119 6.25 [2831 1.2 [1116 0.655 [30 76] [7665 9.04 [756 18.7 [6230 2.84 [3008 2.5 [30 100] [30 83]] [418 1.43 [1679 12 [30 100] [791 11.7 [30 92] [30 100]]] [30 100]]] [30 83]] [30 77]]] [22 100]] [10 27]] [18 28]] [11 43]] [23 2.62 [2847 0.501 [11 33] [22 100]] [22 100]]] [22 73]] [22 85]] [22 75]] [30 100]] [22 100]] [12 100]]] [6349 0.435 [5225 7.61 [6036 0.599 [30 83] [30 100]] [30 100]] [30 100]]] [6853 17.7 [22 61] [22 96]]] [10 78]] [4158 0.318 [328 7.24 [5211 9.42 [1783 1.05 [4 18] [23 41]] [996 4.9 [23 39] [22 82]]] [35 27]] [8 50]]] [7449 0.835 [7169 7.59 [2588 0.446 [3353 0.677 [0 85] [0 100]] [0 100]] [30 36]] [23 57]]]] [4991 3.13 [7534 1.1 [155 4.27 [4768 9.45 [469 0.672 [3822 1.08 [7711 0.141 [19 100] [791 8.46 [19 100] [17 40]]] [19 55]] [4496 0.837 [7301 1.92 [7526 1.19 [19 100] [1239 1.16 [19 100] [6311 0.515 [19 100] [19 88]]]] [7334 1.98 [19 100] [19 87]]] [19 92]]] [19 57]] [19 61]] [19 45]] [7253 2.27 [19 76] [19 100]]]] [1476 1.25 [7722 21.1 [4851 0.109 [1557 0.664 [6199 4.37 [736 3.45 [1995 1.51 [1783 0.808 [1072 2.99 [6230 4.52 [7722 2.55 [17 100] [17 77]] [1011 0.987 [17 38] [6076 0.427 [6980 7.77 [5 35] [17 64]] [3929 4.31 [17 100] [17 75]]]]] [5 72]] [17 90]] [5 76]] [1703 4.12 [5368 2.67 [4222 1.01 [17 44] [17 86]] [17 100]] [17 71]]] [5 30]] [731 9.52 [17 100] [17 80]]] [5677 1.55 [736 0.062 [377 0.6 [3989 7.89 [6980 3.5 [6597 0.661 [1888 10.1 [722 2.38 [2259 9.71 [791 16.4 [5892 0.379 [5819 0.759 [17 75] [1072 2.62 [17 100] [17 81]]] [1911 2.84 [17 100] [17 87]]] [17 60]] [17 71]] [17 50]] [896 1.95 [5 57] [17 81]]] [17 60]] [17 61]] [5 50]] [663 0.787 [14 58] [14 85]]] [1101 1.2 [7255 0.567 [7742 3.87 [1400 1.19 [5383 10.5 [3732 5.6 [3069 3.58 [4939 3.31 [6068 2.16 [6529 2.17 [6959 0.16 [4344 0.062 [647 1.65 [1065 1.44 [3554 2.96 [2573 0.311 [4222 0.135 [17 0.225 [5692 2.63 [17 69] [17 60]] [17 80]] [6076 3.2 [17 100] [4851 12.6 [5892 0.797 [17 95] [17 100]] [17 83]]]] [1239 3.28 [17 100] [1888 6.3 [17 100] [17 80]]]] [17 57]] [17 80]] [7711 4.3 [17 42] [17 100]]] [17 50]] [38 50]] [17 42]] [17 66]] [17 72]] [5 50]] [17 50]] [19 50]] [17 50]] [17 46]] [17 36]] [6 50]]] [19 90]]] [4588 2.7 [5 87] [14 100]]] [5 72]]] [4960 0.732 [1679 1.42 [6240 0.161 [6074 0.157 [2426 0.632 [3733 0.22 [6365 1.75 [4414 1.52 [6453 0.781 [6552 1.11 [2467 0.904 [6725 0.655 [1025 2.9 [3732 1.49 [1078 1.22 [4098 2.18 [2241 0.894 [726 6.26 [5154 7.61 [6550 4.24 [2752 3.67 [5 30] [1007 11.4 [663 21 [7514 8.96 [2616 32.5 [5345 1.13 [5693 7.35 [2143 1.13 [3884 0.901 [2521 2.26 [3676 1.06 [2526 12.7 [2967 4.97 [735 6.41 [2526 11.5 [1475 1.55 [5462 1.5 [978 10.9 [4279 1.04 [731 16.5 [7009 10.2 [5 81] [5 52]] [5 42]] [5 22]] [5 42]] [5 85]] [5 100]] [14 36]] [19 54]] [12 83]] [5662 2.9 [3558 1.33 [5 69] [2939 18.5 [5 50] [5 90]]] [5 100]]] [5 90]] [5 80]] [5 100]] [5 87]] [7 30]] [5 100]] [5 100]] [19 62]] [134 3.55 [5 27] [19 41]]] [19 91]]] [5 88]] [5 63]] [12 44]] [31 33]] [19 50]] [7449 0.491 [7734 2.15 [6550 0.292 [3929 19.1 [6333 4.98 [6588 1.9 [1533 4.66 [4101 2.99 [1079 3.49 [6997 4.58 [7009 1.87 [7 28] [791 22.3 [2592 3.98 [602 4.47 [5605 5.06 [5149 2.51 [3928 12 [362 1.48 [3820 8.08 [6395 0.574 [4530 0.736 [6589 2.98 [7742 7.54 [7700 2.19 [4875 0.583 [2023 1.6 [5904 0.59 [1198 1.49 [3558 13.9 [429 10.4 [695 1.28 [5 83] [5 83]] [2752 7.95 [5 62] [5 96]]] [5 57]] [5 87]] [5 60]] [5 30]] [5 66]] [5 75]] [5 64]] [2628 6.33 [19 60] [5 90]]] [5 33]] [5 53]] [5 54]] [16 33]] [12 37]] [19 50]] [5 50]] [5 45]] [19 75]] [5 35]]] [7 33]] [791 10.4 [1783 1.81 [5 60] [19 62]] [12 28]]] [19 75]] [5 100]] [5812 12 [1079 0.838 [5 86] [5 100]] [5 80]]] [3057 1.42 [2628 1.43 [5 62] [16 40]] [5 84]]] [19 87]] [6313 3.52 [6557 0.292 [1062 4.05 [5 86] [5 54]] [6732 0.248 [5 88] [5 100]]] [5 50]]] [7566 1.67 [5 50] [5 66]]] [663 8.36 [3252 0.491 [662 1.58 [7009 7.84 [5 81] [5 100]] [5 57]] [5 90]] [5 50]]]] [6550 1.23 [16 55] [17 50]]] [3972 0.846 [6199 7.97 [2616 6.18 [7185 0.264 [2470 2.92 [23 3.41 [5 33] [5 53]] [4 87]] [2 37]] [4 71]] [4 85]] [5 80]]] [19 52]] [19 92]] [4 85]] [5 25]] [6199 6.39 [6015 0.99 [3517 0.611 [978 1.86 [7020 1.44 [1253 0.816 [5 13] [5 25]] [5 57]] [31 1.78 [1059 3.27 [5819 1.45 [144 9.73 [6353 1.05 [4414 2.79 [4 30] [2753 5.09 [3905 3.07 [5155 0.666 [642 0.763 [5 54] [5 82]] [5 100]] [17 37]] [19 60]]] [5 75]] [5 25]] [5 42]] [17 55]] [5 91]]] [19 100]] [7210 1.33 [5 73] [5 87]]] [14 33]]] [12 100]] [1429 41.2 [19 100] [4414 0.44 [17 66] [17 87]]]] [1078 13 [12 62] [19 31]]] [2482 1.01 [144 2.16 [17 58] [19 19]] [31 100]]] [733 0.161 [6333 0.861 [19 82] [19 100]] [19 100]]] [30 68]] [4 100]]] [6733 0.562 [184 0.975 [4871 1.04 [673 1.12 [178 0.952 [25 100] [25 96]] [25 100]] [25 100]] [25 100]] [25 100]]] [2939 1.91 [7699 1.23 [701 1.11 [7308 1.88 [5666 0.108 [602 0.204 [1888 0.483 [5851 1.98 [5693 1.13 [2526 7.11 [31 68] [18 40]] [30 40]] [30 60]] [31 57]] [17 23]] [16 55]] [31 100]] [31 100]] [38 85]] [724 1.19 [695 2.75 [4079 2.15 [17 42] [31 100]] [6592 2.83 [2698 1.05 [17 50] [31 100]] [7664 1.44 [5725 1.06 [31 95] [31 100]] [31 85]]]] [31 100]]]] [3075 0.163 [1072 0.606 [2804 0.561 [6401 0.41 [5480 2.04 [6581 1.55 [2990 2.39 [1705 0.645 [2526 5.75 [429 17.8 [3896 3.08 [429 17.1 [145 18.2 [7413 2.02 [5021 1.81 [3357 24.2 [5110 2.15 [5403 4.05 [1025 7.72 [2993 3.99 [32 97] [32 80]] [32 60]] [31 100]] [32 60]] [32 62]] [32 50]] [12 42]] [32 66]] [32 50]] [31 42]] [2526 2.77 [4381 1.56 [5326 3.89 [811 1.56 [957 3.82 [6103 6.21 [6909 1.48 [3929 0.734 [4968 6.73 [34 13.7 [5972 0.736 [2913 18.7 [2259 17.2 [1913 0.654 [896 14.9 [6342 0.455 [939 4.76 [791 2.13 [32 85] [4312 0.931 [2913 1.78 [889 4.83 [32 100] [32 97]] [32 100]] [32 100]]] [32 96]] [32 100]] [32 66]] [32 100]] [1429 27.2 [32 100] [4279 0.326 [7665 1.39 [32 100] [32 83]] [32 100]]]] [32 90]] [12 37]] [32 80]] [32 66]] [32 88]] [32 100]] [32 81]] [2752 31.6 [32 100] [32 87]]] [31 55]] [32 71]] [32 83]] [32 72]]] [5412 2.52 [1429 34.6 [2081 1.85 [12 22] [12 71]] [32 52]] [31 71]]] [31 80]] [12 100]] [3928 1.27 [4 31] [17 62]]] [18 58]] [889 0.335 [5732 0.385 [2753 1.38 [7717 5.96 [32 93] [32 81]] [32 100]] [32 100]] [32 100]]] [12 100]] [7 30]] [4558 0.588 [7512 5.08 [32 86] [1078 7.5 [1068 1.79 [4170 2.48 [32 100] [6544 4.99 [32 87] [32 100]]] [32 80]] [32 100]]] [32 100]]]] [714 0.904 [2562 1.65 [221 9.84 [5437 1.2 [867 0.296 [1598 0.574 [880 0.569 [6597 0.399 [4769 0.122 [3515 6.28 [2593 2.81 [144 1.48 [1783 1.5 [3905 2.21 [384 1.56 [2826 1.08 [18 50] [7520 5.02 [6981 2.05 [896 13 [4338 0.109 [5484 0.568 [1011 1.26 [7737 4.81 [2763 2.04 [18 63] [13 33]] [16 40]] [18 80]] [18 81]] [16 50]] [18 93]] [16 66]] [18 100]]] [6040 4.77 [18 82] [18 92]]] [32 42]] [6040 0.996 [6711 0.29 [7419 2.01 [7259 3.12 [2809 3.41 [5131 0.488 [5693 3.23 [3251 1.12 [18 46] [19 50]] [28 30]] [19 40]] [18 83]] [19 87]] [16 62]] [18 72]] [134 0.671 [7169 0.514 [18 70] [18 93]] [16 63]]]] [6514 3.72 [6353 1.55 [1838 0.253 [2939 3.76 [1906 0.861 [5692 0.722 [7169 2.41 [3742 0.448 [7185 8.78 [5345 3.42 [5482 6.86 [1239 1.13 [19 53] [18 90]] [18 39]] [18 85]] [19 70]] [18 62]] [22 43]] [5722 0.201 [1888 5.06 [18 76] [2526 7.46 [18 42] [18 75]]] [16 60]]] [19 33]] [19 36]] [4573 1.32 [19 100] [19 66]]] [3251 1.18 [5007 1.87 [896 2.39 [18 50] [18 100]] [18 60]] [18 100]]] [19 88]]] [19 75]] [19 78]] [29 66]] [15 26]] [22 70]] [19 92]] [93 0.348 [22 62] [22 100]]] [19 87]] [29 91]] [22 87]] [22 100]]] [5879 1.3 [1783 7.94 [5838 1.93 [7512 5.87 [3928 3.82 [5 54] [12 66]] [2607 2.46 [3095 0.551 [1545 5.34 [1995 3.21 [1210 6.93 [7588 10.5 [7325 6.25 [7722 4.26 [1888 0.879 [3576 0.421 [5192 1.09 [5 77] [5 100]] [5 80]] [458 1.51 [3194 0.326 [6375 0.552 [2753 3.86 [2829 0.457 [3995 0.881 [978 11.2 [5 100] [5 72]] [5 100]] [5 100]] [5 81]] [5 100]] [5 85]] [5 83]]] [3928 15.8 [3253 1.29 [5285 0.873 [2536 0.26 [5 99] [5 100]] [5 100]] [5 90]] [5 87]]] [5 55]] [5 44]] [5 81]] [5 50]] [5 75]] [5 66]] [5 55]]] [12 54]] [1429 46 [5 75] [37 30]]] [12 100]]]] [3916 0.483 [1410 1.22 [4326 8.83 [4789 3.5 [2793 11.7 [2259 2.97 [328 9.2 [1429 15.3 [2752 57 [6665 0.225 [4398 0.673 [7411 1.45 [5979 3.5 [12 63] [12 100]] [15 100]] [15 100]] [12 100]] [2081 10.2 [705 4.85 [12 91] [12 100]] [12 75]]] [7203 1.67 [3243 3.25 [2793 0.693 [3928 0.898 [7169 8.59 [12 100] [12 90]] [12 100]] [12 100]] [12 81]] [12 85]]] [350 1.3 [4220 3.18 [15 60] [12 100]] [12 62]]] [5911 9.31 [1062 0.237 [7176 0.555 [5926 8.28 [3874 0.885 [4418 5.2 [7428 0.747 [6091 8.18 [2939 0.821 [6541 1.57 [4920 1.09 [2398 2.22 [1997 1.68 [6216 0.728 [6365 2.02 [7491 9.56 [2259 5.47 [12 81] [4154 7.29 [12 100] [12 50]]] [12 88]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [15 66]] [12 100]] [12 57]] [12 100]] [12 62]] [12 100]] [12 100]] [12 89]]] [12 60]] [12 62]] [12 55]] [4425 1.16 [1068 0.661 [2821 0.376 [15 59] [15 100]] [15 83]] [15 100]]] [15 100]]] [6320 0.134 [4279 0.923 [1166 1.09 [1769 1.99 [961 0.917 [1159 0.801 [5322 3.31 [2199 0.186 [1096 2.16 [1433 3.12 [4414 1.79 [286 2.2 [685 2.13 [2526 2.95 [4373 3.07 [3799 3.4 [1124 3.5 [27 99] [27 100]] [27 100]] [27 100]] [27 100]] [1429 22 [27 100] [27 55]]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [1114 0.849 [1062 0.574 [5851 3.51 [27 100] [27 91]] [27 82]] [27 100]]] [27 77]]] [1919 0.846 [3100 0.642 [896 3.29 [663 3.31 [4629 1.14 [5979 0.648 [870 1.1 [1239 15.2 [1657 0.395 [3874 2.16 [147 0.732 [3928 0.756 [4995 13.5 [7638 6.51 [5942 1.81 [5211 0.764 [4682 3.96 [6792 3.62 [7176 3.16 [5140 0.858 [6540 0.971 [144 2.38 [4279 11.8 [5753 3.15 [12 35] [2 22]] [1 62]] [2178 1.47 [7665 6.02 [7396 0.666 [3667 1.18 [2 61] [15 44]] [25 100]] [4768 3.88 [1078 11.3 [2 69] [2 100]] [2 92]]] [2 45]]] [4235 0.971 [2 63] [2 100]]] [1 45]] [12 55]] [12 50]] [33 100]] [24 23]] [15 57]] [12 100]] [2 86]] [12 53]] [2 88]] [12 100]] [12 91]] [7085 15.1 [978 10.1 [2764 0.755 [107 2.59 [6791 4.56 [33 53] [1 60]] [33 90]] [1 71]] [2 55]] [1 77]]] [15 100]] [12 100]] [12 100]] [5871 1.29 [6230 0.722 [6074 19.3 [719 19 [6926 4.77 [1993 3.68 [1429 7.26 [1004 13.2 [4235 14.6 [2 86] [2 77]] [2 100]] [2752 5.26 [978 14.5 [2 59] [2 100]] [2 44]]] [23 41]] [2 94]] [2 37]] [2 55]] [2 35]] [2 41]]] [1072 5.3 [6791 10.5 [1207 1.46 [665 0.571 [7623 4.04 [1078 4.65 [2 50] [6439 2.54 [6736 1.05 [7413 2.77 [7512 15.2 [1079 1.98 [2 82] [2 100]] [2 67]] [2 100]] [2 75]] [2 66]]] [2 37]] [1883 0.538 [5651 0.952 [2 93] [2 71]] [2 100]]] [2 100]] [2264 0.797 [2 69] [2 71]]] [1 100]]] [1 100]] [2470 0.759 [5576 1.11 [4704 1.94 [1690 1.66 [3273 0.545 [4960 0.956 [1 5.93 [665 0.252 [324 4.58 [442 0.703 [147 0.362 [5376 1.47 [6015 2.46 [4288 1.15 [655 14.9 [5461 0.599 [2764 5.04 [5211 2.51 [7381 1.18 [7169 2.81 [4262 1.65 [2628 0.96 [1888 1.36 [429 11.7 [2 64] [2 92]] [1919 5.32 [2 100] [2 83]]] [2 88]] [2 75]] [2752 19.4 [2 72] [4 40]]] [1072 0.968 [2 100] [2 94]]] [2 54]] [1 28]] [2 100]] [1 77]] [1059 1.86 [520 0.367 [1986 2.65 [2 100] [2 83]] [2 100]] [2 94]]] [2 57]] [2 50]] [2 100]] [2 42]] [2 36]] [1069 7.89 [5821 5.72 [1011 11.1 [4414 12.2 [6076 0.252 [2005 9.5 [4414 0.266 [2205 0.632 [2752 5.5 [2 86] [929 0.521 [5753 2.19 [4253 0.891 [2 98] [2 100]] [2 81]] [2 100]]] [2 100]] [2 100]] [2 85]] [2 100]] [2 82]] [2 72]] [2 85]] [2 85]]] [2 37]] [4 100]] [1 70]] [17 90]] [25 28]] [24 61]] [3667 0.892 [4 87] [4 50]]]]] [4703 0.445 [7305 2.16 [269 1.58 [3635 0.477 [1420 0.452 [695 1.25 [2938 0.554 [423 0.193 [7665 10.1 [996 0.323 [6131 5.68 [1754 4.41 [7354 0.445 [202 0.347 [7623 0.154 [6802 1.12 [4221 0.516 [7461 3.03 [6581 1.05 [2529 0.557 [4613 0.322 [1239 23.8 [1094 4.08 [3008 2.23 [906 0.119 [418 0.617 [4369 15.9 [6471 0.732 [5753 8.59 [3332 2.24 [2259 25.2 [732 1.11 [1400 1.81 [4991 7.4 [1089 1.37 [1239 5.43 [791 10.2 [1078 11.8 [25 32] [26 50]] [5692 1.27 [18 30] [26 50]]] [25 57]] [26 50]] [25 100]] [7665 6.94 [2580 2.82 [385 3.88 [2526 3.81 [2826 3.55 [26 53] [26 88]] [25 55]] [26 50]] [25 100]] [25 70]]] [134 2.32 [26 91] [26 63]]] [8 42]] [35 47]] [35 33]] [2755 6.77 [26 68] [208 4.42 [26 91] [26 100]]]] [25 85]] [26 86]] [26 83]] [107 1.56 [2526 5.08 [25 66] [25 92]] [25 85]]] [26 93]] [25 36]] [26 90]] [221 12.7 [25 87] [25 50]]] [26 90]] [25 77]] [26 100]] [26 96]] [1783 3.93 [16 30] [25 56]]] [201 7.7 [25 92] [25 100]]] [5007 2.92 [7169 1.29 [2488 5.49 [18 50] [8 94]] [18 50]] [18 93]]] [38 83]] [248 33.5 [26 87] [26 95]]] [8 100]] [7241 1.11 [4279 4.3 [732 2.43 [2913 0.241 [7354 6.72 [23 17.3 [1888 2.93 [3099 1.08 [2610 0.276 [7731 0.462 [7054 5.14 [1980 0.562 [7665 10.9 [38 50] [1223 8.98 [25 77] [25 57]]] [2764 9.09 [3008 0.489 [6177 2.7 [25 75] [25 100]] [25 100]] [25 50]]] [25 50]] [25 100]] [25 100]] [1 100]] [26 58]] [25 42]] [18 78]] [7700 0.502 [7512 13.1 [26 71] [5429 1.67 [6732 2.49 [25 82] [25 100]] [25 50]]] [25 57]]] [26 72]] [567 1.45 [26 44] [1 100]]] [7734 1.68 [26 88] [18 100]]]] [4764 0.739 [5296 1.61 [6517 1.18 [1081 13 [5007 8.31 [2902 0.472 [5353 0.393 [423 17.9 [5918 4.91 [4221 1.82 [791 11.4 [5692 0.933 [26 95] [26 100]] [26 71]] [26 100]] [26 85]] [2526 5.56 [26 79] [26 57]]] [26 83]] [26 100]] [26 80]] [26 75]] [26 55]] [26 70]] [26 71]]] [7576 0.83 [253 0.422 [25 100] [25 90]] [25 100]]] [6040 0.673 [826 2.33 [7725 0.461 [278 4.58 [1759 0.645 [6827 1.86 [383 0.0573 [7722 9.8 [432 2.31 [5870 0.354 [7665 7.73 [328 14 [1025 0.399 [4533 1.12 [26 35] [26 57]] [26 42]] [38 43]] [6592 1.2 [1980 0.808 [1432 0.349 [26 46] [26 100]] [25 54]] [25 100]]] [26 80]] [26 91]] [31 42]] [16 27]] [18 100]] [18 90]] [18 90]] [18 100]] [431 2.27 [25 83] [25 100]]] [7665 8.05 [18 100] [18 45]]]] [5267 1.08 [6525 0.452 [7693 0.821 [144 1.79 [7576 0.487 [25 98] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]]] [1 100]] [248 10.4 [18 70] [4456 3.86 [3711 0.55 [264 9.5 [7665 5.13 [7101 0.319 [6230 0.307 [26 81] [26 100]] [26 70]] [6027 11.2 [4969 0.57 [826 3.57 [719 8.33 [5680 6.72 [6310 6.97 [6585 21.6 [719 3.95 [262 0.821 [429 14.3 [5753 2.48 [1400 66.6 [2752 6.89 [26 80] [26 100]] [26 66]] [26 95]] [906 1.46 [5192 0.556 [26 100] [26 71]] [26 60]]] [26 100]] [26 89]] [26 60]] [26 84]] [26 57]] [26 100]] [26 70]] [26 100]] [26 88]]] [26 77]] [26 55]] [26 80]]]] [2749 0.243 [397 1.05 [4369 0.336 [7187 1.57 [338 6.34 [6189 0.503 [6034 0.655 [6732 6.22 [1769 5.53 [2580 1.29 [6528 1.16 [221 2.22 [7305 11.8 [25 87] [25 66]] [25 94]] [25 100]] [25 100]] [25 50]] [25 57]] [25 62]] [1587 2.68 [25 100] [25 85]]] [25 66]] [1078 10.9 [26 100] [26 66]]] [25 100]] [18 91]] [26 100]]] [3273 1.59 [4978 5.24 [5605 2.99 [2764 6.99 [1888 2.82 [5322 6.26 [7706 0.434 [6776 1.11 [1906 1.37 [1301 0.943 [7085 0.822 [25 100] [5920 0.591 [144 0.425 [25 100] [25 92]] [25 100]]] [25 83]] [7210 0.635 [25 92] [25 83]]] [25 57]] [25 100]] [1 55]] [26 66]] [1 66]] [25 42]] [25 72]] [1 83]]]] [2550 0.31 [2753 0.225 [2453 0.864 [3088 1.05 [663 0.434 [1081 0.429 [3956 0.803 [731 0.272 [7169 2.15 [20 2.39 [2966 0.899 [3045 1.6 [2752 12.4 [4739 2.11 [5999 2.67 [6406 2.32 [2707 3.25 [3370 1.04 [1062 5.92 [3054 2.64 [3929 4.2 [5368 1.77 [5833 4.46 [2466 3.58 [3057 3.08 [6260 1.29 [6572 2.46 [3222 9.25 [1239 8.42 [8 53] [35 25]] [2804 1.17 [7210 2.51 [857 4.85 [8 76] [8 66]] [8 90]] [8 100]]] [8 100]] [8 100]] [8 100]] [5 28]] [0 28]] [8 30]] [12 33]] [0 100]] [8 100]] [8 100]] [30 50]] [8 37]] [5 41]] [30 100]] [5812 3.24 [1517 0.894 [3262 6.55 [2526 36.2 [6853 7.53 [7176 11.5 [2531 0.654 [4870 0.924 [4288 1.34 [5693 1.35 [12 40] [5 35]] [12 22]] [11 50]] [23 100]] [8 55]] [24 44]] [7255 1.41 [8 96] [8 100]]] [37 100]] [37 50]] [12 61]]] [35 76]] [12 56]] [13 70]] [981 0.695 [6103 0.324 [4338 11.4 [407 4.47 [5160 1.36 [5693 0.605 [1089 4.05 [7297 0.644 [5345 4.42 [248 5.85 [8 23] [15 33]] [36 50]] [8 57]] [22 23]] [2616 0.668 [4 43] [4 30]]] [2259 4.2 [28 71] [19 50]]] [8 88]] [24 95]] [12 69]] [23 100]]] [5480 1.77 [6920 0.646 [5114 0.68 [736 2.99 [7169 3.2 [5 38] [24 17]] [1483 1.5 [7381 5.48 [5 50] [5 57]] [5 76]]] [8 100]] [4 85]] [16 23]]] [8 100]] [26 48]] [5226 1.63 [547 1.78 [978 0.832 [5211 3.35 [876 0.975 [3905 3.23 [5412 0.524 [1899 1.84 [3687 3.49 [5 22] [37 100]] [791 9.34 [12 50] [12 66]]] [5732 0.282 [1078 13.8 [2628 0.963 [32 44] [14 55]] [29 58]] [28 80]]] [36 41]] [29 100]] [22 94]] [5155 1.09 [1899 5.44 [5 40] [2763 4.92 [1995 0.688 [2 31] [2 33]] [4 46]]] [1078 5.61 [14 31] [19 60]]]] [13 100]] [22 100]]] [37 100]] [2518 0.398 [631 0.404 [655 0.324 [4519 1.18 [24 50] [24 85]] [24 100]] [24 100]] [24 100]]] [7512 0.617 [2787 1.48 [178 2.36 [6333 0.775 [3360 0.581 [221 3.46 [37 60] [2259 3.95 [28 81] [29 42]]] [37 100]] [22 30]] [5 66]] [37 100]] [5972 2.68 [1899 9.56 [7176 0.225 [7248 0.449 [6471 0.274 [7601 2.23 [929 3.6 [1888 14.5 [4304 1.46 [5680 0.805 [7566 0.295 [3317 0.861 [5007 3.4 [7454 0.617 [7009 0.855 [5 37] [4766 0.846 [5 85] [5 57]]] [38 40]] [22 33]] [5 84]] [5 23]] [5 50]] [5 83]] [14 30]] [19 56]] [5 100]] [26 50]] [5345 0.449 [5 100] [5 71]]] [22 75]] [25 50]] [12 50]]]] [4929 0.253 [4456 0.897 [5706 7.48 [567 4.55 [3956 0.364 [1980 10.5 [7255 4.83 [2491 0.362 [1463 0.615 [2259 22.1 [8 100] [2607 0.46 [6560 14 [1429 24.9 [8 96] [8 100]] [8 85]] [8 100]]] [8 100]] [8 100]] [8 96]] [4159 2.22 [7354 2.42 [0 50] [8 100]] [8 100]]] [8 100]] [8 91]] [8 81]] [8 72]] [8 100]]]] [2275 7.06 [1783 39.9 [23 0.583 [4282 3.03 [3 99] [3 100]] [3 100]] [791 2.7 [3 94] [3 100]]] [3 81]]] [5769 10.5 [6187 0.129 [2417 0.191 [5240 0.181 [7588 0.269 [7248 0.0961 [286 0.947 [2658 0.167 [4964 0.202 [4235 0.153 [639 1.42 [7568 0.089 [2826 0.441 [649 0.469 [7324 2.42 [1193 1.54 [7584 0.279 [5198 0.421 [23 10 [1587 2.24 [4288 1.47 [7712 0.792 [1429 25 [4748 0.318 [2149 0.543 [7677 0.585 [6989 1.17 [7265 0.53 [1072 0.938 [4 41] [2 85]] [2 76]] [2 100]] [4 55]] [2 33]] [2 100]] [248 0.227 [4 34] [30 33]]] [2 94]] [1068 0.0835 [7722 0.366 [2 83] [2 100]] [2 100]]] [13 83]] [1078 23.6 [791 4.65 [5820 1.75 [2470 5.05 [5769 7.81 [2 25] [8 71]] [4 87]] [2 75]] [4 63]] [228 6.81 [2 42] [23 40]]]] [5770 1.2 [2 77] [2 66]]] [2763 5.69 [2 100] [2 81]]] [11 62]] [4 70]] [4 90]] [4 92]] [17 1.32 [1106 0.581 [2571 0.722 [2752 30.7 [4586 2.57 [23 4.27 [6927 5.94 [4184 11.8 [5819 5.06 [7665 4.96 [2 88] [2 100]] [2 88]] [2 83]] [2 87]] [4 58]] [2 50]] [2 62]] [6539 0.298 [2 85] [2 100]]] [2 100]] [6926 1 [722 0.978 [2 96] [2 100]] [2 100]]]] [4 78]] [2628 2.49 [4991 0.781 [2 42] [2 100]] [5820 0.792 [2752 1.07 [13 37] [7700 0.66 [7085 1.5 [2597 0.331 [223 1 [6988 0.605 [2 66] [2 91]] [2 100]] [2 100]] [2 75]] [2 60]]] [2013 0.657 [5659 0.4 [906 0.536 [1899 3.59 [2 92] [2 100]] [2 100]] [2 100]] [2 83]]]]] [1783 2.76 [4 100] [4 83]]] [312 0.333 [5817 0.764 [429 1.55 [4 62] [7512 8.83 [4 84] [719 0.566 [4 90] [4 100]]]] [4 62]] [4 100]]] [7363 0.295 [736 2.44 [7383 2.44 [178 1.72 [1007 0.304 [2812 0.254 [978 6.19 [140 0.313 [6791 0.615 [2616 2.52 [573 0.13 [2 30] [4 57]] [4154 2.51 [2 88] [2 100]]] [2 100]] [2 100]] [147 0.325 [23 4.56 [5883 2.44 [1899 12.6 [6186 0.805 [1068 2.36 [2 93] [2 80]] [2 100]] [2 71]] [2 100]] [2 63]] [2 100]]] [221 3.16 [2 100] [2 90]]] [2 100]] [4 66]] [2 57]] [2 100]] [4 75]]] [2961 0.951 [6353 0.25 [6537 0.806 [7185 0.0961 [2902 1.99 [4 100] [4 72]] [4 100]] [2 71]] [2 50]] [4 42]]] [4680 2.22 [7605 2.29 [4 100] [4 50]] [4 100]]] [1445 1.21 [4502 0.304 [4771 2.75 [5192 4.81 [17 3.14 [4 100] [7722 1.93 [4 100] [2739 9.42 [4 100] [4 88]]]] [1919 1.63 [4 75] [4 100]]] [4 83]] [4 87]] [4 71]]] [5413 2.44 [4 100] [4 77]]] [2675 0.384 [1783 2.57 [1175 0.449 [6982 0.226 [695 9.26 [3667 1.65 [5771 0.182 [2 76] [1429 12.2 [2674 0.177 [2 66] [7451 1.58 [6047 3.56 [1925 0.244 [1025 14.8 [2574 7.46 [6987 1.71 [2 100] [2 66]] [4995 6.9 [2 100] [2 75]]] [2 92]] [2 100]] [134 1.44 [2 90] [2 100]]] [2 83]]] [6732 6.14 [7665 7.21 [2 100] [5819 0.437 [2 100] [2 71]]] [2 66]]]] [2764 0.996 [7584 3.26 [25 0.124 [2 100] [2 85]] [2 84]] [2 50]]] [2 62]] [695 2.67 [435 0.154 [2616 3.55 [4 33] [2 50]] [2 71]] [4 88]]] [4930 2.55 [4 44] [2 100]]] [2005 2.62 [2905 0.467 [5693 2.18 [731 0.545 [2 94] [4 56]] [1980 2.09 [2 100] [2 75]]] [6074 0.906 [4 63] [2 72]]] [6186 0.263 [2 87] [2 100]]]] [7241 1.07 [7722 0.22 [4533 0.293 [6798 2.57 [2592 2 [2960 0.454 [5460 1.35 [2 100] [2 84]] [2 100]] [2 80]] [1173 2.52 [2 100] [2 62]]] [2 100]] [7381 0.206 [4533 1.06 [2 100] [2 87]] [2 100]]] [2 71]]]] [6575 1.27 [2484 0.684 [5647 35.5 [7515 2.14 [1640 10.3 [5412 2.92 [5770 20.7 [5491 0.96 [7189 0.84 [7210 2.82 [1919 0.545 [4154 8.32 [224 0.688 [4851 13.3 [663 7.72 [1239 3.83 [1980 13.3 [134 1.29 [639 2.73 [178 13.9 [2742 1.03 [6077 0.659 [5770 2.15 [4 91] [4 100]] [4 100]] [4 100]] [4 90]] [4 100]] [4 100]] [4 75]] [4 76]] [5576 2.92 [134 12.9 [4 100] [4 87]] [2 40]]] [4 73]] [6550 2.2 [4 96] [4 100]]] [4 100]] [2742 0.534 [7324 4.81 [4 91] [4 100]] [4 100]]] [7327 1.55 [4 80] [4 100]]] [4 100]] [4 44]] [4 66]] [4 100]] [5625 1.38 [6230 1.91 [286 0.288 [2617 1.95 [2478 1.41 [5847 1.3 [1980 2.39 [4851 2.35 [643 0.664 [7512 38.2 [6926 1.25 [2628 9.24 [7512 17.1 [4 42] [228 25 [7590 12.9 [5820 17.9 [4 94] [4 57]] [4 50]] [2 66]]] [2616 26.5 [4154 1.44 [1190 4.64 [144 2.37 [2 69] [4995 1.85 [2 86] [1899 11.9 [2 100] [2 75]]]] [2 56]] [4279 2.33 [2 94] [2 100]]] [2 54]]] [2 91]] [4 100]] [2 100]] [6552 1.18 [6581 3.03 [4 90] [4 100]] [4 100]]] [2033 1.05 [7461 1.22 [665 3.98 [7271 3.11 [4414 5.69 [2 82] [2 60]] [2 60]] [2 100]] [4 33]] [2 100]]] [1429 20 [4 86] [719 1.98 [7324 1.69 [4 86] [4 100]] [4 100]]]] [4 100]] [7766 1.22 [4 68] [4 100]]] [5753 0.488 [5769 27.3 [5412 3.91 [7009 3.16 [312 0.734 [1919 15.5 [1919 3.58 [144 7.15 [2 60] [978 19.1 [2 100] [2 70]]] [5820 7.41 [2 100] [2 90]]] [2 58]] [2 100]] [2 100]] [2 76]] [3 25]] [2 100]]] [6230 9.08 [719 5.27 [4 33] [4 64]] [4 95]]] [4 100]]] [2 47]] [2 91]] [4 100]] [4 100]]]] [2331 0.132 [5972 0.254 [74 0.235 [3480 2.14 [791 12.1 [6401 1.48 [14 0.55 [6865 2.15 [1400 1.58 [430 0.324 [153 2.51 [5403 1.27 [4851 0.509 [2420 8.96 [6853 1.42 [7381 1.56 [4594 1.78 [6359 1.16 [719 0.38 [5812 0.513 [6744 1.24 [1634 1.37 [2081 2.37 [5753 20 [7665 2.77 [13 20] [6084 1.82 [1025 0.832 [2509 3.03 [13 56] [13 100]] [867 0.956 [13 98] [13 100]]] [13 100]]] [13 30]] [7491 0.372 [5473 1.82 [22 25] [28 44]] [23 33]]] [13 100]] [13 100]] [1062 11.2 [144 4.34 [1062 1.1 [978 7.92 [7255 1.78 [13 96] [13 100]] [4 50]] [13 100]] [13 80]] [13 77]]] [228 2.06 [7034 0.539 [7354 15 [5402 0.928 [1071 3.65 [13 83] [13 100]] [2509 3.53 [13 100] [13 83]]] [13 80]] [13 100]] [13 57]]] [13 44]] [24 36]] [1640 5.68 [2570 1.74 [4 51] [2 42]] [2 100]]] [36 84]] [28 61]] [312 2.86 [6732 0.509 [36 72] [4 31]] [4 100]]] [3 47]] [1086 1.29 [28 100] [28 88]]] [13 100]] [6074 2.2 [5693 0.761 [6853 14.6 [36 83] [36 70]] [1078 8.61 [4 33] [36 50]]] [13 45]]] [36 98]] [36 100]] [2526 10.3 [36 100] [36 91]]] [7106 1.73 [5735 0.237 [1400 1.38 [2421 1.47 [5640 0.487 [6404 0.852 [5402 0.574 [896 9.2 [4765 0.661 [3067 1.01 [4493 1.19 [7590 0.785 [968 0.389 [5824 0.505 [6524 2.7 [632 2.92 [3142 1.68 [7149 1.51 [2488 1.51 [2470 7.02 [7168 0.449 [3342 0.578 [5480 9 [6413 1.62 [23 36.2 [899 3.15 [5692 5.01 [13 51] [36 40]] [36 64]] [13 88]] [13 100]] [22 51]] [13 100]] [22 40]] [11 90]] [519 5.45 [13 100] [13 96]]] [36 61]] [36 100]] [36 100]] [6732 8.93 [6342 1.65 [36 46] [11 37]] [22 87]]] [6566 0.912 [11 80] [11 100]]] [328 0.389 [968 19.1 [28 76] [12 35]] [2259 8.31 [28 100] [28 66]]]] [7716 1.29 [1980 9.98 [6406 10.3 [6231 1.4 [883 0.213 [2259 7.45 [17 1.72 [719 0.637 [7712 2.33 [13 96] [13 100]] [13 77]] [13 100]] [13 92]] [13 100]] [13 100]] [13 83]] [5812 10.1 [13 90] [13 63]]] [13 100]]] [36 100]] [36 100]] [13 100]] [7374 4.95 [721 7.2 [5264 2.39 [719 5.47 [6643 1.75 [3012 2.18 [3429 4.65 [6524 2.46 [7343 6.17 [515 5.62 [13 54] [13 100]] [13 41]] [36 100]] [36 100]] [36 100]] [13 100]] [2939 3.14 [896 13.2 [13 66] [13 71]] [2 50]]] [13 100]] [36 81]] [36 100]]] [1078 1.07 [791 16.3 [2488 3.15 [13 77] [13 100]] [13 99]] [13 100]]] [36 100]] [13 100]] [36 97]] [7255 7.28 [3008 0.975 [23 14.6 [7160 3.36 [1906 1.1 [6857 1.22 [939 4.23 [36 88] [36 66]] [31 36]] [36 100]] [36 100]] [15 50]] [36 100]] [36 33]]] [6791 0.229 [6260 21.3 [13 100] [13 85]] [13 100]]] [36 100]]] [814 7.14 [2225 1.17 [430 1.21 [6853 1.08 [4414 27.7 [23 6.42 [36 93] [36 80]] [36 53]] [36 100]] [13 100]] [36 42]] [32 62]]] [13 100]] [5047 1.16 [7107 0.327 [6124 2.65 [7737 6.54 [2843 0.403 [7271 1.14 [1407 14.4 [312 13.2 [6997 4.32 [6653 1.54 [6177 4.55 [2818 0.53 [3069 0.464 [7665 0.367 [2760 0.99 [36 63] [15 100]] [5950 14.6 [4373 0.528 [17 5.02 [4851 0.0847 [3931 11.1 [3642 7.55 [957 8.03 [2309 0.398 [5007 7.2 [807 6.17 [718 0.545 [4545 0.513 [1747 0.504 [850 0.425 [1429 20.5 [36 96] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 77]] [899 2.64 [36 93] [36 100]]] [36 100]] [36 81]] [36 90]] [36 72]] [36 100]] [6859 1.17 [36 88] [36 100]]] [36 66]] [36 66]]] [36 66]] [12 66]] [36 60]] [36 62]] [12 36]] [36 63]] [36 61]] [36 78]] [31 100]] [36 77]] [12 80]] [16 2.36 [5972 15.1 [36 100] [4956 1.63 [36 100] [36 88]]] [1078 7.72 [7512 12.7 [36 87] [36 100]] [36 100]]]] [3 100]]] [5322 4.5 [6764 1.9 [2108 1.42 [1429 5.55 [36 91] [1429 68.8 [6320 1.23 [36 100] [7512 13.9 [36 87] [36 100]]] [36 88]]] [36 85]] [3482 0.96 [36 100] [36 69]]] [32 62]]]] [537 0.457 [6314 0.383 [2470 1.86 [1592 1.3 [535 1.47 [594 0.115 [495 0.431 [2818 0.505 [7615 1.75 [1312 1.22 [4317 0.629 [538 0.115 [2993 1.43 [5268 3.03 [5034 4.54 [1429 5.15 [688 0.635 [4154 8.93 [2154 2.89 [7481 3.31 [2624 6.23 [573 3.7 [4210 5.38 [6017 1.98 [5972 7.89 [6564 1.51 [5535 7.94 [373 0.59 [5812 15.4 [1101 10.5 [580 16.7 [6148 5.38 [4414 34.8 [1095 16.6 [5937 1.6 [6897 3.76 [550 6.42 [6893 9.05 [2099 4.76 [6085 9.53 [2259 22.1 [6184 13.8 [7449 10.6 [429 146 [1239 90.5 [1980 29.3 [21 27] [21 45]] [9 63]] [21 95]] [15 42]] [15 46]] [3 41]] [21 100]] [21 74]] [21 100]] [15 52]] [9 62]] [539 3.4 [9 51] [21 83]]] [28 50]] [21 54]] [9 68]] [21 94]] [32 30]] [13 62]] [21 90]] [328 27.6 [9 100] [9 80]]] [21 57]] [12 56]] [21 100]] [3 100]] [31 30]] [9 72]] [15 90]] [21 100]] [372 11.9 [7481 4.85 [1062 4.85 [6643 3.82 [791 51.4 [5404 2.82 [907 3.36 [5110 4.76 [583 2.67 [1899 15.4 [1980 14.7 [3 60] [2 30]] [3 100]] [3 95]] [3 90]] [3 90]] [3 100]] [15 50]] [3 100]] [15 36]] [15 100]] [3 71]]] [4414 66.6 [127 0.362 [23 8.97 [4982 3.77 [747 4.22 [4768 8.49 [524 2.07 [6052 10.8 [4154 2.54 [5693 7.11 [236 0.635 [803 6.5 [2199 30.1 [6181 2.28 [21 80] [21 55]] [21 63]] [21 96]] [21 100]] [9 55]] [3 71]] [21 55]] [21 66]] [21 84]] [21 100]] [21 66]] [583 11.8 [9 56] [21 72]]] [9 50]] [15 40]]] [4516 2.33 [4480 3.29 [1239 8.42 [6306 1.33 [896 2.3 [5972 1.31 [2225 17.6 [1078 6.59 [21 20] [663 4.57 [2628 0.313 [7491 6.59 [23 23.1 [15 20] [3 33]] [12 55]] [32 33]] [32 66]]] [21 71]] [2826 0.994 [6979 3.53 [12 84] [12 100]] [12 100]]] [13 66]] [3 100]] [6897 6.15 [2093 7.53 [1913 17.7 [7185 8.64 [2007 1.49 [1391 4.02 [1304 5.2 [21 25] [21 69]] [26 23]] [10 100]] [3 75]] [31 41]] [21 34]] [9 84]]] [9 86]] [9 85]]] [438 3.36 [3 77] [30 50]]] [13 100]] [4214 0.575 [7169 6.54 [5154 6.65 [4407 3.18 [21 42] [3 100]] [3 93]] [21 85]] [3 100]]] [5915 0.325 [328 1.04 [586 0.284 [915 12.1 [5050 1.49 [1277 3.19 [744 0.368 [429 89.8 [5972 5.47 [23 15.6 [806 8.34 [5969 2.9 [21 72] [21 100]] [906 8.02 [9 66] [21 66]]] [9 73]] [2259 4.27 [9 83] [9 100]]] [6320 6.71 [21 86] [21 80]]] [688 5.46 [21 100] [21 94]]] [9 97]] [9 82]] [695 0.818 [749 3.27 [6015 31.2 [21 83] [21 100]] [21 100]] [21 61]]] [634 0.8 [21 98] [21 100]]] [5293 0.504 [5805 0.626 [627 0.364 [1239 46.3 [915 11.8 [4918 0.424 [21 85] [21 100]] [21 100]] [1362 1.34 [635 0.79 [4914 0.79 [2081 0.644 [634 0.5 [5974 4.1 [9 66] [9 94]] [21 88]] [21 62]] [9 100]] [2526 0.79 [2259 3.7 [328 13.7 [9 100] [9 80]] [9 71]] [9 100]]] [9 90]]] [21 100]] [9 100]] [606 1.53 [5775 0.632 [9 100] [9 77]] [9 60]]]] [9 97]]] [3 83]] [5620 30.5 [1325 3.84 [4651 1.79 [1277 0.608 [9 92] [9 100]] [9 70]] [9 51]] [15 54]]] [3 100]] [6184 11.6 [12 87] [12 100]]] [21 93]] [5832 11.8 [1312 0.628 [699 0.631 [4533 0.258 [9 91] [9 100]] [9 100]] [9 100]] [9 71]]] [5322 3.32 [5051 0.797 [6565 0.745 [6148 1.65 [620 7.16 [6091 2.88 [6920 11.7 [1322 14.4 [6294 0.175 [5249 0.64 [6199 14 [745 0.411 [765 17.8 [4414 10.4 [803 0.512 [2023 0.211 [4279 0.873 [5692 6.37 [4663 9.94 [816 1.9 [6935 6.35 [6883 2.39 [6184 60.4 [2994 0.44 [7451 1.39 [2083 0.161 [6726 1.33 [2143 39 [21 100] [21 77]] [21 100]] [21 100]] [21 100]] [21 100]] [1239 15.2 [21 100] [21 44]]] [21 100]] [21 80]] [21 100]] [21 72]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 80]] [21 100]] [21 94]] [21 100]] [21 100]] [21 85]] [21 62]] [4898 1.14 [695 6.1 [5042 8.49 [21 100] [9 83]] [9 62]] [9 87]]] [21 77]] [6150 1.65 [9 78] [9 96]]] [9 72]] [9 100]] [802 39.5 [5412 0.335 [225 1.04 [754 1.57 [1899 1.59 [580 8.09 [21 100] [21 94]] [21 100]] [21 100]] [21 100]] [21 100]] [7451 27.6 [21 100] [21 81]]]]] [3 96]] [7480 5.76 [4374 2.26 [2471 1.25 [7637 1.25 [2752 1.9 [15 27] [6079 0.664 [3884 0.754 [4424 1.96 [2470 17.7 [1400 6.3 [1429 34.4 [12 53] [15 50]] [1906 2.62 [906 10.8 [7491 3.88 [786 3.7 [15 89] [15 100]] [15 100]] [15 100]] [15 66]]] [15 74]] [15 100]] [15 100]] [15 100]]] [12 100]] [15 100]] [12 69]] [15 98]]] [6791 24.2 [4568 0.402 [6061 15.9 [21 100] [21 90]] [21 100]] [5938 4.15 [21 77] [21 100]]]] [4533 0.361 [4611 0.31 [633 9.88 [4956 0.907 [5768 1.18 [4218 25.5 [3 100] [3 94]] [3 100]] [3 100]] [3 66]] [3 100]] [3 100]]]] [2748 0.198 [7512 1.72 [1023 1.27 [1696 0.775 [6517 0.824 [7187 2.51 [1823 1.45 [2390 2.67 [4214 0.684 [4601 5.67 [7176 0.233 [915 0.545 [695 1.45 [1911 4.12 [6959 0.264 [5753 5.15 [185 7.63 [995 7.78 [5170 10 [2752 18.6 [7210 5.86 [144 2.44 [23 7.81 [1239 3.5 [14 21] [5999 1.67 [2225 1.12 [6844 0.87 [1429 6.69 [9 27] [33 48]] [33 91]] [30 30]] [33 66]]] [3931 0.978 [1239 24.7 [23 32.1 [33 46] [1 38]] [33 72]] [33 90]]] [429 4.59 [1 57] [1 36]]] [429 9.21 [33 85] [33 50]]] [33 24]] [6185 0.864 [1888 6.04 [1078 10.4 [232 0.362 [6034 3.4 [250 13.3 [4991 23.8 [2005 5.75 [251 8.43 [6031 23 [4988 3.4 [5374 4.35 [2241 8.45 [5294 10.4 [4253 21.6 [4205 5.7 [1980 50 [673 18.6 [3695 7.15 [429 47.1 [5175 5.26 [2263 12.2 [7169 18.5 [5110 14.9 [7127 16.6 [98 2.51 [1742 3.7 [33 72] [33 85]] [4235 11 [33 48] [33 100]]] [11 20]] [33 96]] [33 66]] [33 100]] [33 100]] [3 54]] [33 44]] [26 61]] [33 90]] [26 85]] [1 50]] [15 33]] [1 50]] [1 50]] [33 100]] [33 41]] [426 16.9 [1 50] [1 100]]] [26 50]] [33 52]] [427 7.94 [33 66] [1 66]]] [17 33]] [2895 9.24 [5170 17.9 [7254 11 [33 82] [33 80]] [4704 38.5 [33 93] [5170 45.5 [33 62] [33 100]]]] [33 75]]] [2939 11.5 [1429 12.2 [7650 2.42 [33 58] [1 55]] [26 30]] [26 43]]] [26 50]] [6653 2.11 [33 92] [33 100]]]] [26 76]] [26 60]] [112 2.22 [5111 10.3 [6185 5.15 [7642 1.55 [260 0.816 [5412 5.19 [429 3.08 [168 4.35 [33 71] [33 86]] [33 38]] [738 4.07 [5172 16.7 [5115 23.8 [2081 8.95 [5170 14 [33 100] [2259 12.6 [33 90] [33 62]]] [33 80]] [33 100]] [33 89]] [33 50]]] [33 100]] [33 100]] [33 66]] [33 33]] [33 100]]] [2526 2.22 [13 28] [17 62]]] [33 45]] [1980 0.678 [1078 8.86 [112 1.33 [9 40] [32 50]] [28 42]] [28 53]]] [9 50]] [427 12.9 [2849 2.65 [5343 0.578 [2259 21.7 [5311 7.14 [2752 23.2 [5911 0.661 [98 5.03 [6524 7.6 [1301 16.1 [260 1.25 [5118 11.7 [109 5.95 [33 100] [33 76]] [33 66]] [33 88]] [33 85]] [33 63]] [5701 7.87 [33 94] [33 71]]] [33 83]] [2526 3.86 [33 73] [33 80]]] [33 92]] [33 62]] [33 71]] [33 76]] [1 57]]] [26 50]] [6058 0.684 [4802 3.58 [5702 7.46 [1429 18.7 [2896 5.13 [33 100] [33 85]] [33 82]] [5692 10.6 [5360 9.26 [33 83] [1 54]] [71 2.92 [1429 3.33 [33 93] [33 100]] [33 100]]]] [33 62]] [33 100]]] [26 84]] [5322 0.616 [5561 0.787 [2143 2.76 [33 93] [33 66]] [33 100]] [33 100]]] [26 75]] [26 80]] [26 58]] [2915 1.6 [26 74] [26 90]]] [1078 2.53 [1783 0.527 [1400 2.07 [673 1.89 [7512 12.4 [5647 7.36 [33 68] [33 87]] [896 1.96 [5360 2.22 [33 51] [33 100]] [1 27]]] [2939 3.71 [5431 10.5 [1429 5.05 [26 76] [26 70]] [26 95]] [26 66]]] [575 3.6 [5431 15.9 [26 84] [26 71]] [26 50]]] [663 0.75 [980 1.89 [719 2.18 [1812 0.57 [1919 0.347 [6528 3.88 [233 5.4 [2752 10.3 [98 1.85 [33 53] [33 72]] [1899 1.22 [26 53] [1 71]]] [1 55]] [1 58]] [1 54]] [2939 3.45 [2879 1.14 [7415 1.05 [33 96] [33 68]] [33 100]] [33 60]]] [5299 0.57 [33 84] [33 100]]] [26 68]] [26 47]]] [5472 1.43 [7512 17.3 [232 0.471 [2963 0.732 [5431 0.599 [248 12.6 [1011 1.14 [2241 3.7 [1 18] [1 62]] [4 25]] [1980 13.4 [7520 2.51 [1783 10.9 [5641 4.98 [913 0.711 [2915 4.74 [3424 0.861 [929 2.44 [6761 8.59 [7253 0.578 [2530 1.66 [26 64] [26 100]] [26 100]] [26 100]] [26 100]] [26 71]] [26 77]] [26 100]] [26 60]] [26 28]] [26 100]] [33 38]]] [791 3.82 [26 66] [26 92]]] [5869 0.695 [26 92] [26 100]]] [33 56]] [957 3.62 [5695 3.36 [6199 4.16 [26 26] [26 50]] [26 85]] [10 87]]] [13 100]]]] [663 24.3 [5174 35.4 [7038 4.57 [7419 1.56 [5099 26.7 [2752 3.41 [4601 18.1 [2526 22.3 [2654 5.48 [26 75] [26 60]] [26 100]] [18 42]] [6199 17.8 [7472 5.44 [879 2.81 [4391 13.2 [2955 9.53 [7601 0.742 [4805 3.64 [4398 7.48 [6406 10.5 [7254 3.99 [2983 5.12 [7301 6.18 [6441 0.552 [7516 1.93 [4200 20.8 [4393 3.04 [3207 1.83 [3993 2.93 [1432 10.2 [377 3.54 [384 17.3 [7255 2.58 [663 0.555 [6472 4.26 [2466 0.455 [1980 1.15 [265 0.756 [26 96] [26 100]] [1078 2.24 [26 100] [791 1.91 [26 100] [26 57]]]] [26 100]] [26 93]] [26 100]] [26 84]] [26 75]] [26 75]] [26 87]] [26 75]] [26 75]] [26 100]] [26 80]] [1980 1.87 [6616 0.813 [184 0.813 [6585 4.26 [26 100] [26 85]] [26 100]] [26 100]] [26 95]]] [26 66]] [26 100]] [26 75]] [26 83]] [26 66]] [26 66]] [26 62]] [19 42]] [26 75]] [328 7.77 [26 90] [26 62]]] [26 61]] [38 60]] [26 63]]] [16 40]] [26 42]] [16 53]] [6471 47.1 [16 50] [26 100]]] [26 55]]]] [5210 0.0539 [2403 0.505 [6009 0.345 [5170 0.208 [6105 0.2 [7488 0.957 [7041 1.6 [6701 0.963 [3436 1.25 [2802 1.47 [5626 0.0619 [2259 46.5 [301 11.8 [2718 2.19 [3581 0.515 [2649 0.926 [2670 5.5 [4614 0.454 [4716 0.102 [2628 2.35 [144 1.62 [1078 25.6 [6027 5.27 [6010 1.02 [1842 8.32 [3332 1.98 [7255 10.9 [5482 2.95 [7512 0.635 [3912 0.517 [4703 2.18 [1062 15.3 [4854 1.47 [5110 1.08 [968 1.45 [1436 6.36 [5732 4.52 [6382 5.29 [2701 6.34 [6457 4.07 [6848 10.6 [5436 7.6 [2752 8.55 [1429 21.4 [4154 24.3 [33 40] [33 41]] [33 19]] [7449 4.43 [2005 2.11 [5641 6.13 [1646 5.78 [4414 5.54 [33 13] [1 13]] [28 60]] [26 42]] [19 28]] [1429 18.3 [12 55] [28 36]]]] [8 55]] [26 41]] [25 57]] [29 87]] [32 46]] [28 83]] [38 23]] [28 85]] [33 35]] [16 19]] [2181 3.31 [5 16] [5 100]]] [33 68]] [37 82]] [397 2.41 [7668 0.816 [7583 1.92 [7601 6.9 [6980 0.818 [383 8.24 [6554 5.18 [2081 10.2 [5130 3.31 [178 8.63 [7682 1.31 [32 9] [17 50]] [25 30]] [18 56]] [12 40]] [17 66]] [18 100]] [17 44]] [32 29]] [1429 3.36 [1 61] [25 44]]] [26 45]] [18 83]]] [532 6.02 [896 11.4 [18 70] [29 50]] [19 80]]] [6 28]] [429 25.5 [35 61] [37 37]]] [6032 10.2 [13 71] [13 100]]] [13 100]] [18 64]] [2091 0.873 [29 58] [2081 15.7 [29 50] [28 41]]]] [650 0.658 [6550 2.14 [2083 2.93 [5455 1.23 [6502 0.415 [906 3.78 [2935 6.17 [5211 1.36 [3713 1.89 [5732 1.59 [3327 1.52 [6853 2.51 [7302 0.478 [6015 3.98 [7241 0.763 [7422 1.21 [4601 3.03 [3959 1.55 [3008 3.44 [1078 7.09 [7446 0.762 [5637 1.09 [29 15] [19 25]] [13 50]] [4501 2.37 [7149 7.49 [178 5.05 [5007 2.76 [144 14.4 [6490 3.31 [29 53] [29 100]] [7665 1.89 [29 39] [22 33]]] [29 85]] [4 28]] [28 42]] [29 100]]] [17 29]] [29 100]] [26 63]] [29 85]] [663 4.02 [26 37] [18 38]]] [29 100]] [18 35]] [28 82]] [11 100]] [23 9.8 [28 88] [28 45]]] [26 100]] [4279 1.06 [5412 1.3 [11 39] [22 100]] [22 100]]] [22 90]] [5647 4.83 [29 67] [29 62]]] [5037 0.904 [22 85] [22 100]]] [29 100]] [29 76]] [2536 0.722 [26 78] [26 68]]] [11 100]]] [1789 0.246 [2890 1.13 [7423 1.72 [1239 26.9 [7472 0.614 [663 0.376 [2951 31.4 [6961 0.787 [7122 10.9 [281 2.44 [6409 6.1 [2714 0.166 [7457 1.87 [2868 3.58 [6830 0.57 [2752 4.27 [5491 4.76 [78 4.49 [6877 0.602 [4851 3.76 [5445 8.2 [2102 6.61 [3136 12.3 [6959 6.85 [190 2.26 [5632 3.47 [2081 19.5 [2939 13.2 [2468 0.709 [7347 13.1 [2663 22.5 [38 27] [16 100]] [16 66]] [38 50]] [7132 18.2 [7063 10.1 [5637 3.73 [5412 8.55 [7009 15.6 [4738 9.8 [7038 0.637 [38 37] [38 89]] [16 100]] [19 50]] [16 40]] [1783 28.1 [38 58] [38 83]]] [5 50]] [16 37]]] [38 83]] [16 87]] [1899 25.9 [3239 1.75 [5692 7.68 [7210 10.8 [5086 1.7 [1262 1.2 [2851 0.109 [2722 10.7 [6227 0.843 [1997 0.502 [7241 11.3 [1807 1.22 [2410 5.88 [6825 9.53 [2849 97.4 [1429 16.2 [2939 20.4 [38 46] [7241 1.35 [3027 7.79 [94 3.7 [2661 10.6 [2225 0.412 [38 76] [38 58]] [16 42]] [38 50]] [38 100]] [6 33]]] [6383 1.2 [38 38] [38 66]]] [16 41]] [8 57]] [5829 24.1 [14 44] [19 50]]] [38 100]] [5 24]] [38 100]] [5 42]] [16 45]] [165 20.2 [38 59] [1980 9.28 [38 100] [38 87]]]] [13 30]] [17 42]] [37 30]] [19 60]] [16 87]] [1980 5.69 [5 40] [6 27]]]] [16 68]] [38 90]] [16 88]] [5 92]] [5637 2.2 [2939 43.4 [16 24] [6199 2.16 [6941 7.46 [2849 52.3 [6 62] [6 100]] [6 50]] [38 25]]] [19 50]]] [1239 1.22 [37 47] [17 63]]] [16 40]] [1897 5.97 [14 91] [14 69]]] [1542 1.78 [6177 1.74 [112 1.46 [2666 3.27 [5154 2.26 [7742 1.4 [2846 1.68 [1078 8.01 [2881 0.8 [3929 1.97 [1239 5.63 [38 20] [16 34]] [6207 12 [5 34] [37 85]]] [16 33]] [6230 1.67 [4279 3.93 [35 18] [19 70]] [5 57]]] [12 71]] [5 46]] [5 25]] [16 75]] [2526 13.1 [28 18] [600 16.4 [19 45] [17 80]]]] [25 60]] [2767 1.83 [37 72] [37 77]]]] [1078 1.36 [1895 3.45 [7 26] [14 50]] [6230 0.454 [19 35] [7 20]]]] [685 2.82 [16 34] [18 54]]] [5 54]] [791 2.52 [5577 2.33 [2650 8.25 [5931 4.92 [2951 7.2 [5801 24 [16 54] [26 26]] [16 71]] [3742 1.07 [95 5.93 [2849 54.4 [16 27] [16 76]] [26 66]] [26 42]]] [7260 12.7 [16 27] [2955 4.27 [7619 6.67 [94 17.6 [1895 19.8 [16 70] [2628 42.2 [16 33] [2714 16.1 [16 77] [16 66]]]] [7 50]] [28 83]] [16 82]]]] [28 62]] [5 33]]] [16 48]] [7260 9.71 [18 71] [18 100]]] [2083 1.77 [2850 7.56 [5007 9.59 [285 2.11 [7347 0.852 [16 35] [16 65]] [14 100]] [16 60]] [6 80]] [14 63]]] [328 1.08 [5894 2.34 [16 56] [18 74]] [719 0.864 [2862 2.81 [18 46] [18 50]] [18 62]]]] [4725 0.745 [4740 4.61 [6134 0.701 [1948 2.33 [7166 6.09 [2733 1.57 [7150 2.44 [6937 2.17 [7343 7.58 [3008 2.06 [194 38.6 [4017 0.978 [2729 3.4 [2720 29.3 [5007 0.19 [2707 38.9 [194 12 [1769 1.46 [38 34] [38 80]] [38 50]] [5683 11.3 [6208 25.1 [2853 1.18 [1896 4.23 [5940 1.13 [2259 29.2 [2722 14.8 [2682 2.3 [7474 9.28 [38 75] [38 100]] [38 100]] [6 44]] [38 50]] [38 85]] [38 50]] [2951 43 [38 81] [38 100]]] [38 44]] [19 44]]] [38 96]] [2081 1.15 [190 7.23 [6 61] [6 100]] [6 100]]] [16 57]] [38 100]] [16 37]] [38 77]] [16 40]] [38 55]] [16 57]] [16 56]] [16 51]] [38 93]] [2650 4.87 [26 36] [16 60]]] [16 63]] [16 56]]] [31 3.04 [719 0.376 [2526 2.3 [7049 1.34 [4369 1.95 [2753 0.998 [2902 1.12 [16 32] [6 28]] [2752 19.8 [37 42] [16 28]]] [32 71]] [32 24]] [2763 1.7 [23 0.197 [2 33] [5 34]] [18 26]]] [132 0.378 [2628 6.06 [7 28] [2616 0.385 [18 58] [2 33]]] [18 65]]] [18 77]]] [2707 35.6 [83 1.65 [2983 2.84 [2881 1.68 [695 0.686 [4939 0.56 [2849 26.6 [38 74] [38 50]] [25 28]] [14 83]] [38 40]] [2748 0.994 [38 87] [38 100]]] [37 26]] [38 89]]] [3238 2.14 [1676 4.43 [6133 4.67 [6353 7.68 [4950 4.65 [5812 7.43 [900 1.97 [7303 0.389 [4571 5.15 [2955 7.53 [83 4.02 [187 13.2 [7759 1.64 [6230 0.957 [4456 1.92 [5673 24.2 [4912 1.96 [429 0.305 [1445 2.34 [2628 35.3 [5010 7.09 [166 5.48 [16 19] [17 61]] [16 61]] [38 53]] [14 40]] [18 29]] [17 42]] [38 66]] [17 87]] [14 75]] [18 90]] [2640 3.31 [1253 0.971 [16 33] [16 40]] [18 44]]] [16 43]] [4851 9.63 [7255 11.4 [4854 0.975 [7281 6.39 [2849 30 [7 56] [38 47]] [19 50]] [16 45]] [38 50]] [6 25]]] [2856 8.07 [7 66] [7 66]]] [17 66]] [18 78]] [17 85]] [6431 6.29 [7 90] [7 100]]] [7 85]] [16 78]] [18 70]] [16 77]]] [6380 4.97 [1089 4.12 [2851 5 [2683 4.06 [5692 1.49 [2651 5.41 [4571 2.11 [94 3.99 [5597 10.6 [2628 8.11 [16 100] [6207 5.9 [4725 1.29 [16 37] [16 88]] [16 86]]] [16 83]] [2955 8.75 [16 85] [16 100]]] [7242 5.59 [7419 9.73 [16 100] [16 70]] [16 72]]] [14 42]] [18 50]] [4854 6.23 [5435 1.12 [7104 0.938 [16 42] [16 94]] [16 57]] [16 28]]] [16 46]] [2199 3.03 [16 100] [16 87]]] [6 46]]] [1478 7.97 [1895 21.6 [2631 5.88 [6216 0.705 [23 18.6 [4011 1.13 [5 52] [5 84]] [5 82]] [6383 1.38 [5 75] [37 55]]] [5 100]] [37 38]] [37 77]]] [2202 0.588 [5641 7.08 [1997 1.82 [2869 0.606 [38 90] [38 55]] [38 93]] [38 48]] [38 50]]]] [5597 2.78 [7572 0.821 [6961 0.375 [1731 0.805 [5090 2.27 [5632 0.0508 [112 9.62 [7354 3.13 [2978 3.13 [16 28] [7 28]] [18 63]] [29 42]] [1400 0.766 [5132 3.09 [1895 10.4 [7560 1.16 [2939 93.1 [2862 3.99 [5801 17.3 [738 0.0508 [2717 1.06 [2712 2.48 [7391 0.262 [2712 0.411 [16 46] [16 36]] [17 44]] [13 53]] [7123 4.04 [6517 3.57 [2849 43.6 [90 3.69 [3238 8.65 [2654 6.25 [2690 4.74 [2712 2.61 [16 70] [6207 1.53 [16 38] [7 42]]] [5 30]] [16 58]] [13 71]] [16 57]] [16 86]] [31 33]] [16 80]]] [2671 3.41 [16 100] [16 90]]] [26 50]] [2650 0.532 [16 60] [16 81]]] [2654 12.8 [3238 3.77 [16 100] [16 83]] [16 66]]] [1078 4.24 [6 53] [6 44]]] [16 14]] [16 46]] [25 53]]] [6 50]] [17 66]] [788 0.45 [4743 2.76 [2526 1.6 [18 40] [2526 8.42 [2707 9.63 [16 60] [16 66]] [7 44]]] [7 75]] [18 45]]] [13 100]] [194 4.11 [7665 6.27 [5637 0.48 [6959 1.79 [16 80] [190 4.41 [16 100] [16 88]]] [16 100]] [4895 0.535 [6 77] [22 42]]] [16 64]]]] [3325 0.51 [2785 1.74 [29 93] [29 100]] [29 100]]] [2691 6.7 [187 3.24 [38 48] [1899 3.47 [2707 8.33 [2466 2.01 [17 37] [17 66]] [5345 3.71 [2939 47.5 [4854 6.95 [7343 9.02 [17 82] [17 96]] [4896 1.02 [17 68] [17 100]]] [17 64]] [17 66]]] [17 36]]] [16 33]]] [2262 4.72 [5189 0.998 [2752 2.43 [5799 0.743 [4859 3.44 [4851 26.3 [4653 0.465 [3008 4.77 [1687 1.13 [5435 3.15 [5102 12.2 [5492 3.6 [1661 8.65 [2732 4.76 [2210 3.13 [5101 1.56 [4946 1.55 [6761 8.05 [1314 2.39 [6832 2.1 [2649 30.1 [6830 27.1 [4851 20.2 [7241 3.89 [2730 2.56 [4674 2.02 [6749 0.661 [60 6.91 [2671 9.06 [5100 28.4 [5099 30.6 [2859 0.516 [5723 12.3 [5067 1.98 [2734 0.971 [5100 11.2 [187 4.54 [16 84] [2713 8.35 [7104 1.85 [6961 1.14 [16 38] [16 81]] [19 42]] [2713 10.5 [1239 6.38 [6 45] [6 85]] [16 50]]]] [2951 14.7 [5100 13.3 [16 78] [16 58]] [2649 10.9 [16 62] [16 94]]]] [6 50]] [16 62]] [6 63]] [6 71]] [16 34]] [16 47]] [18 63]] [2649 6.17 [16 57] [4851 3.6 [6 91] [6 50]]]] [5681 1.4 [6 69] [6 40]]] [2707 18.6 [6 100] [6 62]]] [7 100]] [16 81]] [6409 2.03 [16 32] [6 88]]] [16 90]] [6 48]] [18 60]] [6 80]] [16 100]] [18 93]] [187 6.26 [2942 2.58 [6 62] [6 100]] [6 42]]] [6 100]] [16 66]] [2849 25 [18 86] [6 33]]] [14 77]] [45 1.46 [6 46] [18 41]]] [16 17]] [2849 31.4 [7474 4.83 [16 68] [6 37]] [5673 3.01 [16 100] [16 87]]]] [4851 17.8 [18 22] [6 28]]] [6 80]] [5334 3.29 [6 61] [16 66]]] [187 16.8 [7 54] [18 61]]] [2649 11.5 [6471 3.84 [2733 8.23 [2880 1.29 [190 7.34 [2649 2.54 [4851 2.12 [19 36] [6 53]] [6766 0.437 [18 37] [19 50]]] [6406 3.85 [194 8.04 [4154 2.76 [2656 9.67 [16 31] [2649 7.77 [1896 2.44 [16 80] [16 72]] [5931 9.67 [16 27] [16 70]]]] [7 31]] [19 28]] [18 64]]] [14 61]] [16 100]] [26 66]] [4880 4.4 [6134 0.726 [5017 0.926 [16 36] [18 58]] [83 4.2 [16 46] [2939 39.6 [18 50] [18 37]]]] [5801 6.46 [95 0.876 [16 60] [16 77]] [16 56]]]]] [5429 0.468 [4860 0.84 [6167 0.586 [2376 2.7 [6974 0.392 [7241 7.48 [284 1.99 [383 5.42 [5898 1.89 [7734 0.357 [6257 4.57 [23 35 [7526 1.34 [7203 3.31 [2649 13.2 [2656 6.21 [2714 0.525 [5102 0.312 [2569 0.53 [5692 3.11 [2753 2.73 [16 40] [16 37]] [37 44]] [18 62]] [695 0.798 [7679 0.623 [16 46] [16 75]] [16 71]]] [16 50]] [18 40]] [5673 13 [190 8.24 [18 34] [25 46]] [5100 30.5 [16 60] [18 62]]]] [2716 3.89 [190 8.45 [2644 2.36 [16 88] [16 100]] [16 75]] [18 66]]] [144 3.57 [5 45] [187 9.6 [6 57] [5 33]]]] [16 62]] [18 53]] [695 6.75 [4820 1.26 [1023 1.48 [6832 0.868 [5894 3.71 [4851 5.98 [18 100] [18 57]] [18 50]] [16 58]] [18 62]] [16 50]] [18 100]]] [5673 6.17 [16 61] [16 100]]] [18 82]] [6139 1.02 [19 36] [19 90]]] [16 100]] [18 93]] [14 100]] [6 57]] [18 90]] [16 100]]] [7 98]] [6 90]]] [52 4.82 [2851 3.31 [1895 16.8 [7762 0.173 [5 84] [5 55]] [5 66]] [5 59]] [5 34]]] [2659 10.8 [38 68] [38 89]]] [4517 5.64 [30 74] [30 62]]] [4891 0.952 [2434 0.461 [5187 4.19 [5491 9.57 [305 1.05 [5641 0.288 [5326 3.56 [5099 8.58 [2526 0.436 [38 47] [7255 13.7 [7665 1.89 [26 27] [6 28]] [6 100]]] [2419 1.61 [2713 12.4 [2955 2.24 [6 47] [6 83]] [6 42]] [6 87]]] [30 100]] [38 68]] [30 83]] [14 78]] [7445 0.443 [38 87] [38 70]]] [191 3.5 [18 53] [30 80]]] [7222 3.09 [7260 2.31 [2282 6.44 [6 100] [6 90]] [6 78]] [6 75]]]] [2878 2 [6008 2.68 [196 1.5 [2955 4.79 [719 0.77 [4977 2.79 [96 11.5 [1400 0.684 [1317 29 [5769 3.77 [685 6.05 [2941 1.25 [5894 2.59 [2628 8.49 [5626 9.62 [5692 3.36 [187 2.49 [328 1.87 [25 33] [28 30]] [2881 0.239 [6 31] [6 50]]] [26 43]] [16 48]] [2856 0.612 [2734 0.57 [1786 0.164 [4854 16.8 [6687 10.5 [5480 4.46 [5776 11.6 [1314 0.946 [5643 1.3 [6937 0.205 [7475 0.0619 [7419 0.605 [2955 3.44 [2259 3.56 [7169 6.32 [16 58] [16 36]] [7446 11 [16 36] [25 57]]] [16 41]] [16 71]] [6 36]] [16 100]] [16 100]] [26 55]] [26 33]] [18 60]] [16 88]] [16 31]] [4650 0.328 [38 53] [38 71]]] [2955 4.32 [6 37] [18 75]]] [16 100]]] [7255 1.31 [16 50] [18 83]]] [2868 0.277 [4533 0.239 [1783 1.94 [16 53] [16 43]] [6 66]] [6 62]]] [18 39]] [26 70]] [6 100]] [26 57]] [16 100]] [7474 1.3 [5408 0.743 [5594 0.543 [6 66] [5641 2.03 [16 55] [6 33]]] [6 84]] [6 50]]] [7154 2.56 [18 69] [5100 1 [18 46] [6 70]]]] [7282 0.68 [7132 3.44 [2262 0.549 [23 41.2 [1011 1.21 [1078 10 [5632 3.27 [7611 2.74 [5692 0.344 [1748 0.12 [4937 1.51 [2733 2.63 [1396 2.05 [2644 0.458 [4820 2.36 [6942 9.24 [7169 5.65 [5102 16 [2649 21.8 [6406 3.21 [2628 36.9 [2862 11.3 [192 3.09 [16 60] [6 41]] [16 100]] [7255 2.81 [4854 13.3 [1239 21.5 [38 41] [7 33]] [16 66]] [38 44]]] [16 68]] [6 52]] [16 48]] [6 53]] [6 45]] [6 63]] [187 16.4 [16 70] [16 42]]] [5102 11.5 [6 87] [6 75]]] [1587 2.15 [2729 16.9 [16 56] [16 30]] [18 33]]] [23 8.09 [16 50] [6 93]]] [16 35]] [18 50]] [28 69]] [16 62]] [6 52]] [18 55]] [16 91]] [2689 0.942 [6 85] [6 42]]] [7 46]] [957 2.79 [5100 10.5 [4746 4.21 [5983 37.3 [5673 20.5 [1660 2.5 [5594 0.882 [685 0.522 [5627 7.86 [5983 33.2 [2734 3.42 [7260 1.52 [2685 2.06 [6 86] [6 39]] [5626 8.29 [16 55] [6 62]]] [6 74]] [16 57]] [16 50]] [16 50]] [1895 4.26 [16 56] [16 83]]] [6 92]] [16 100]] [4426 1.38 [6 54] [2978 23.4 [4414 39.9 [6 80] [6 94]] [6 70]]]] [18 45]] [1983 4.67 [16 51] [6 44]]] [18 90]]]] [6732 1.91 [2939 4.74 [1793 0.563 [18 94] [18 62]] [196 9.86 [560 0.897 [2856 0.323 [301 0.441 [4820 0.674 [2978 3.29 [2707 16.7 [4154 0.797 [1895 0.199 [1888 0.495 [6 46] [7 20]] [1748 1.09 [6007 2.28 [18 85] [18 42]] [6 33]]] [18 55]] [2644 1.93 [2849 31.1 [16 83] [16 100]] [2707 23.9 [18 83] [16 50]]]] [6 78]] [16 73]] [19 45]] [7 90]] [2628 13.9 [18 87] [719 1.8 [16 69] [18 90]]]] [16 53]]] [19 87]]] [1596 2.55 [4573 0.404 [6417 2.51 [1646 3.4 [6831 3.2 [5641 0.358 [2662 11 [16 54] [16 84]] [16 88]] [18 42]] [1239 24.8 [16 38] [2662 5.82 [7 50] [7 66]]]] [7 100]] [5187 0.582 [6832 1.33 [7 84] [7 100]] [7 100]]] [5187 2.67 [5594 2.27 [4840 3.54 [2897 1.69 [7039 7.41 [2081 9.11 [5894 2.05 [6 58] [6 33]] [16 70]] [13 50]] [6 75]] [16 83]] [1395 6.27 [2415 0.707 [7206 4.4 [3208 0.573 [45 1.38 [2955 3.78 [6 25] [1896 3.84 [190 7.9 [2653 3.76 [16 66] [18 36]] [6 66]] [18 61]]] [16 87]] [19 36]] [2983 2.85 [6961 3.66 [1896 1.3 [4977 15 [16 46] [16 88]] [7206 8.44 [6 72] [16 71]]] [4977 7.92 [5626 5.76 [7 100] [7 70]] [16 66]]] [6007 4.59 [16 58] [2955 9.61 [7 92] [7 75]]]]] [7 100]] [16 77]]] [7 100]]]] [1687 0.196 [5010 6.71 [1395 3.98 [1660 0.522 [2663 1.34 [5931 1.11 [2955 16.3 [6749 1.52 [7343 2.16 [2983 24.4 [1429 7.82 [6 69] [16 36]] [6 41]] [18 66]] [16 68]] [5103 8.22 [5673 5.5 [2713 19.2 [4937 0.709 [2640 4.13 [6 90] [6 64]] [6 86]] [16 46]] [2939 57.6 [18 50] [16 50]]] [6 100]]] [16 58]] [16 57]] [4854 20.9 [6 77] [6 100]]] [16 53]] [18 65]] [16 64]]]] [1078 2.27 [29 66] [144 2.03 [29 79] [29 100]]]] [6779 0.39 [7473 2.99 [2951 0.485 [27 22] [38 65]] [14 62]] [7206 3.56 [5007 3.16 [190 4.72 [55 4.59 [7009 1.85 [2752 2.35 [1078 3.55 [7241 12.3 [3698 1.08 [3436 13.7 [37 69] [2628 38.9 [37 45] [37 87]]] [37 93]] [5 57]] [5 47]] [5647 2.2 [3980 0.53 [37 56] [35 37]] [37 50]]] [16 42]] [5 36]] [5632 3.46 [23 47.4 [5593 2.1 [4011 0.429 [305 1.21 [6779 12.1 [1899 3.39 [2955 12.2 [6877 8.48 [6 53] [4623 14.2 [37 57] [6 44]]] [37 58]] [5 42]] [2729 3.04 [5 31] [5 66]]] [5 94]] [5 56]] [6 60]] [37 8.18 [4623 29.5 [6779 14.8 [4623 21.9 [2951 7.36 [37 71] [37 88]] [37 100]] [37 66]] [5 55]] [2649 1.85 [2951 9.87 [5 69] [5 64]] [16 42]]]] [6779 10.5 [37 64] [37 81]]]] [16 30]] [6 52]]]] [6424 0.759 [6256 3.89 [4533 0.562 [4414 6.72 [1888 1.19 [7 63] [7 40]] [6 50]] [16 33]] [673 0.719 [5102 7.39 [6833 1.91 [1355 18 [18 77] [7 58]] [7 100]] [18 92]] [18 86]]] [4725 0.508 [6 100] [6 71]]]] [2322 0.932 [7122 4.8 [5322 0.213 [5632 3.72 [2037 8.2 [7734 1.15 [4854 20.2 [2752 4.59 [2599 3.02 [5597 5.81 [5412 1.04 [6371 3.17 [6199 0.871 [1382 0.858 [4431 12.2 [6755 9.15 [4675 5.77 [2851 7.5 [2640 3.07 [6074 3.68 [1454 0.661 [4426 1.73 [6941 5.47 [7242 1.83 [1980 1.14 [7210 2.99 [2551 10 [5350 1.34 [5093 9.43 [16 37] [16 68]] [16 90]] [6 42]] [5100 8.16 [6 40] [6 40]]] [16 58]] [37 44]] [6 57]] [6 80]] [6 75]] [6 72]] [2849 44.3 [6500 1.4 [16 60] [16 66]] [6 50]]] [7 50]] [16 68]] [16 91]] [91 9.97 [18 59] [16 71]]] [6 61]] [1078 3.34 [5104 0.808 [5435 9.75 [5626 2.55 [16 25] [16 76]] [18 72]] [4725 0.922 [18 42] [6 64]]] [18 47]]] [16 61]] [6199 8.69 [16 38] [16 87]]] [4732 5.47 [2370 1.84 [2628 25.6 [7419 15.2 [5099 12.8 [5681 0.18 [2526 6.5 [16 70] [16 54]] [16 86]] [4673 1.09 [5598 8.09 [16 73] [16 62]] [6 58]]] [2526 34.6 [2619 6.67 [2628 20.3 [16 55] [16 81]] [6 37]] [6 92]]] [6 50]] [16 80]] [16 90]]] [16 88]] [2868 6.46 [5007 5.04 [1078 10.1 [2871 3.01 [2412 1.86 [5680 2.24 [3207 0.266 [2849 13.2 [26 30] [5626 8.05 [75 0.488 [2259 11 [16 100] [16 72]] [2526 11.1 [16 100] [16 87]]] [16 71]]] [5 28]] [16 63]] [16 50]] [16 43]] [16 26]] [18 35]] [18 62]]] [23 32.2 [5681 3.08 [6515 2.2 [7041 3.71 [16 47] [6 69]] [38 44]] [2709 2.11 [2037 0.31 [16 42] [18 57]] [6 45]]] [18 56]]] [2955 3.78 [5130 2.07 [18 71] [16 35]] [6207 0.348 [16 55] [16 66]]]] [6933 1.65 [6 60] [6 77]]] [16 65]] [2282 0.42 [1239 12.3 [17 57] [6 61]] [6 62]]] [4986 1.34 [2716 0.715 [62 5.19 [6877 5.03 [221 2.51 [1787 0.263 [2292 6.05 [4673 1.85 [4851 4.72 [7423 2.33 [5626 4.29 [2649 2.37 [7038 3.17 [18 60] [2143 0.473 [2683 13.2 [2259 25.2 [16 51] [16 100]] [16 100]] [16 70]]] [16 70]] [16 33]] [193 3.68 [7104 0.147 [16 75] [2679 13.6 [16 100] [16 83]]] [16 80]]] [1980 1.91 [2681 4.27 [7203 3.45 [5100 5.17 [4820 0.569 [16 60] [16 100]] [16 55]] [18 33]] [18 42]] [18 50]]] [5962 1.36 [5681 0.486 [2978 0.925 [6 50] [16 90]] [16 87]] [16 100]]] [16 40]] [17 37]] [1896 0.446 [16 100] [16 57]]] [4623 12 [16 46] [6 33]]] [6 36]] [5598 0.848 [91 0.827 [16 92] [16 100]] [16 100]]] [18 66]]] [2951 8.67 [6 33] [2619 0.319 [7419 1.99 [37 75] [37 75]] [16 42]]]]] [6940 1.35 [7015 0.809 [1025 0.701 [1429 36.8 [2734 3.31 [3675 4.72 [429 2.24 [7149 0.783 [167 12 [23 37.3 [6342 9.88 [7042 9.48 [1983 0.569 [2853 2.28 [7390 0.331 [166 0.554 [38 98] [38 100]] [38 100]] [38 85]] [38 100]] [38 88]] [38 93]] [38 85]] [38 90]] [2466 4.77 [38 100] [2469 6.59 [38 88] [38 100]]]] [2076 2.16 [5162 7.7 [38 96] [38 83]] [38 77]]] [38 70]] [38 77]] [38 50]] [38 75]] [38 50]] [38 41]]] [2628 22.2 [38 78] [2939 14.9 [5641 1.02 [166 6.44 [38 100] [38 57]] [38 85]] [4939 1.47 [6406 5.46 [4716 2.51 [2441 6.1 [429 0.433 [2955 8.77 [166 0.84 [38 95] [38 100]] [38 100]] [38 100]] [38 91]] [2884 0.511 [38 93] [38 100]]] [38 60]] [38 100]]]]] [6471 0.344 [6199 2.7 [45 7.82 [4431 0.917 [7343 1.66 [413 2.16 [1995 6.85 [6131 6.22 [7552 0.852 [4655 9.72 [33 92] [1 77]] [33 55]] [26 45]] [33 69]] [26 66]] [33 70]] [6 37]] [33 50]] [26 38]] [791 3.4 [424 0.368 [2849 23 [2599 0.25 [995 3.9 [63 1.26 [3007 8.7 [978 0.296 [7693 0.319 [6473 11.8 [328 1.58 [26 71] [26 62]] [26 38]] [26 100]] [5723 2.34 [6830 4.93 [4851 10.1 [7185 0.376 [980 2.41 [26 100] [26 83]] [26 100]] [26 66]] [18 44]] [26 100]]] [6 37]] [19 44]] [6 40]] [6 87]] [76 0.296 [91 1.3 [4200 1.9 [7347 0.341 [2667 3.54 [2951 14.1 [6472 1.11 [26 43] [26 64]] [2939 33.3 [6 44] [16 72]]] [16 50]] [5174 0.532 [62 4.42 [26 83] [16 36]] [6199 13.7 [26 100] [26 81]]]] [26 100]] [248 5.53 [18 66] [6 43]]] [2862 1.66 [16 36] [16 71]]]] [26 100]] [5480 0.129 [1078 8.36 [7722 2.49 [7693 0.467 [5681 2.08 [1429 9.49 [26 100] [26 66]] [7512 0.843 [26 58] [26 83]]] [26 100]] [26 66]] [26 64]] [6732 0.079 [2939 16.2 [26 71] [26 100]] [5130 0.669 [16 42] [26 87]]]]]]] [187 18.5 [1899 0.717 [7665 0.741 [4851 3.13 [30 71] [30 98]] [30 100]] [30 54]] [30 50]]] [5958 7.11 [38 90] [4601 0.486 [7220 4.6 [1895 17.2 [6287 1.11 [2357 8.62 [5605 0.156 [2638 3.65 [2691 1.4 [7072 9.57 [2392 13.2 [3984 0.816 [2888 9.47 [5148 4.67 [6719 0.449 [38 79] [2888 8.63 [2955 0.505 [38 100] [38 72]] [38 75]]] [38 100]] [6108 0.552 [2877 0.351 [5379 4.54 [38 97] [38 85]] [38 100]] [38 100]]] [2357 0.87 [38 91] [38 100]]] [5956 0.994 [7149 9.12 [38 70] [38 83]] [17 50]]] [38 68]] [38 85]] [4889 0.697 [1783 15.4 [38 47] [2885 5.66 [2638 9.31 [3551 2.56 [2466 0.784 [38 86] [38 44]] [38 80]] [38 100]] [19 44]]] [3550 0.87 [38 83] [38 100]]]] [38 91]] [38 53]] [38 73]] [38 53]] [7242 8.58 [2367 3.79 [6384 3.66 [2708 0.805 [5637 5.39 [17 77] [2466 11.7 [38 82] [17 36]]] [2951 2.79 [19 55] [17 75]]] [38 100]] [38 45]] [1429 13.3 [19 60] [17 50]]]] [38 100]]]] [7475 0.0539 [1352 0.448 [5632 0.959 [4235 1.85 [23 17.1 [1395 3.96 [4601 4.46 [2707 27.1 [7370 5.78 [2241 9.05 [38 24] [29 45]] [38 68]] [5068 3.58 [1997 16.7 [3993 0.736 [1445 3.38 [7149 5.08 [4496 17.7 [1980 3.68 [38 100] [38 86]] [38 66]] [38 100]] [38 36]] [38 100]] [38 69]] [38 42]]] [38 37]] [38 96]] [1445 5.81 [2750 0.0585 [28 50] [4017 0.573 [1997 21.3 [2232 3.4 [7332 0.802 [5918 0.103 [5210 14.7 [6382 4.56 [94 4.13 [5209 7.2 [1997 7.01 [38 78] [38 53]] [4050 10.1 [38 96] [2849 44.6 [38 60] [38 91]]]] [38 94]] [17 42]] [38 58]] [17 44]] [2468 1.63 [1587 0.605 [7255 3.92 [38 64] [5 78]] [5 66]] [8 42]]] [5 33]] [23 23.3 [24 92] [38 80]]] [38 100]]] [12 55]]] [38 27]] [2978 0.879 [2081 1.41 [16 50] [38 40]] [16 33]]] [187 7.66 [5 28] [17 66]]] [7402 0.329 [1260 0.189 [7486 1.28 [7210 1.47 [7445 1.07 [5829 2.76 [1563 13.8 [5412 2.9 [2432 4.81 [7242 12 [2241 11.8 [7445 0.98 [7241 2.3 [83 0.143 [190 1.93 [2241 0.617 [38 100] [6199 7.2 [61 2.49 [38 41] [4562 0.874 [17 30] [1262 1.66 [38 100] [1587 1.86 [17 70] [1563 3.61 [38 62] [6719 7.53 [7473 3.82 [38 100] [38 75]] [2939 9.25 [38 100] [4539 8.48 [38 71] [38 66]]]]]]]]] [38 100]]] [7343 13.8 [2862 5.62 [4895 6.39 [166 0.117 [5379 15.5 [6825 0.323 [7391 0.0719 [1783 0.789 [38 100] [38 71]] [38 83]] [1239 9.86 [6720 1.49 [2242 0.981 [38 100] [38 90]] [38 100]] [38 85]]] [38 87]] [38 100]] [38 83]] [38 75]] [38 60]]] [17 37]] [2405 11.7 [38 91] [38 66]]] [38 54]] [38 46]] [5955 7.85 [38 71] [17 85]]] [4563 4.03 [4563 1.62 [19 78] [17 53]] [38 100]]] [38 55]] [17 70]] [4565 0.457 [4896 4.37 [5148 2.5 [7475 2.25 [17 88] [38 62]] [38 66]] [1981 1.45 [38 66] [38 93]]] [19 55]]] [2690 1.89 [5600 1.18 [2076 0.671 [83 6.27 [5637 8.61 [37 5.43 [2241 0.957 [38 88] [7475 7.48 [38 98] [38 85]]] [2112 0.875 [38 71] [38 100]]] [38 76]] [38 50]] [5403 2.05 [1888 1.67 [7390 1.26 [6383 1.2 [38 100] [38 71]] [2678 2.98 [38 98] [38 87]]] [38 85]] [38 66]]] [16 66]] [16 46]]] [2851 2.49 [1899 2.18 [14 42] [38 54]] [4895 0.773 [38 100] [38 53]]]] [38 61]] [4050 0.944 [19 70] [17 83]]] [17 88]]]]] [2714 2.67 [3929 0.184 [430 0.428 [2006 0.879 [896 0.609 [7434 0.279 [1400 1.98 [3413 0.213 [7043 0.387 [2978 2.99 [3069 1.76 [3297 0.238 [4075 0.903 [2093 0.739 [6184 1.72 [3332 2.6 [4154 5.66 [4851 13.9 [3136 0.901 [101 10 [2526 11.1 [3921 1.24 [20 30] [3269 1.54 [1541 1.72 [1888 5.1 [452 0.616 [3213 1.31 [2951 2.11 [3576 20 [4012 3.12 [1179 0.982 [6727 2.26 [3610 2.81 [3978 12.4 [5211 11 [7665 2.31 [836 0.629 [1079 1.12 [3718 1.75 [3248 2.24 [4369 3.96 [3884 5.35 [3687 5.74 [957 9.03 [3921 33.1 [722 1.1 [429 36.1 [37 74] [0 27]] [37 88]] [37 90]] [37 91]] [37 99]] [15 50]] [37 91]] [37 100]] [37 100]] [37 58]] [1899 1.26 [3294 2.3 [3086 1.33 [37 96] [37 100]] [37 100]] [37 100]]] [37 75]] [20 42]] [37 77]] [37 66]] [22 33]] [37 100]] [37 43]] [35 27]] [38 50]] [37 100]] [2787 5.45 [7185 6.15 [3171 0.308 [3691 0.99 [3771 7.53 [37 97] [37 100]] [37 100]] [37 100]] [37 81]] [37 71]]] [31 33]] [37 57]] [33 45]]] [37 30]] [37 57]] [4063 0.876 [37 85] [33 50]]] [37 57]] [37 29]] [37 66]] [13 37]] [19 41]] [15 50]] [3360 2.22 [2466 2.75 [3136 1.63 [4015 0.43 [4861 1.18 [2754 1.88 [3253 0.377 [2752 46.6 [3464 3.36 [37 87] [3338 13.3 [5692 3.45 [3912 0.256 [6333 0.677 [37 100] [37 88]] [37 100]] [37 87]] [37 83]]] [37 71]] [37 50]] [37 83]] [37 87]] [37 100]] [37 77]] [37 50]] [7169 2.6 [3466 0.863 [37 92] [1078 5.1 [37 44] [37 87]]] [37 66]]]] [37 58]] [16 35]] [112 2.9 [37 65] [16 66]]] [3965 4.36 [663 20.8 [37 100] [3715 2.13 [37 80] [37 100]]] [37 90]]] [7305 1.09 [15 35] [31 90]]] [12 100]] [2616 2.46 [13 36] [4 45]]] [38 40]] [13 100]] [7176 1.71 [5285 14.7 [3692 10 [3760 2.59 [5368 0.212 [3778 15.6 [160 6.25 [3922 0.101 [1485 0.386 [2787 0.218 [841 7.2 [3292 0.754 [37 97] [37 100]] [37 92]] [37 100]] [37 100]] [37 100]] [37 62]] [37 92]] [567 0.278 [37 100] [3413 0.726 [37 87] [37 57]]]] [37 87]] [37 66]] [37 66]] [2752 13.6 [12 50] [37 88]]]] [16 66]]] [5480 1.31 [7722 0.351 [6178 0.271 [2628 9.74 [4675 0.311 [491 0.124 [3292 1.57 [3849 1.53 [4282 1.72 [2802 0.181 [4299 0.311 [4655 1.32 [2808 0.125 [7411 2.4 [1600 0.23 [4349 0.879 [3079 3.58 [1025 2.01 [6560 0.681 [1078 46.7 [7405 0.336 [899 0.765 [6230 1.68 [1521 1.46 [1400 2.24 [5211 1.82 [5974 0.154 [4682 0.4 [6457 0.276 [145 13.4 [5732 0.0752 [535 1.6 [2394 2.69 [4326 10.3 [5034 0.76 [5140 2.35 [2579 0.328 [5941 0.0732 [5047 0.457 [3006 0.419 [5564 0.208 [673 2.91 [7742 1.33 [4114 18.2 [1860 0.139 [907 0.538 [2701 0.143 [7009 3.45 [7675 1.3 [2453 2.96 [5403 1.21 [502 4.31 [299 0.699 [3003 0.512 [7615 2 [6767 1.11 [1645 0.0578 [1239 14 [665 0.546 [6154 1.29 [1980 7.1 [705 3.89 [4851 0.976 [1634 0.939 [2752 0.391 [4765 7.39 [7358 3.34 [429 0.157 [6606 8.93 [228 4.93 [5954 5.41 [5448 6.34 [2616 3.08 [6647 3.55 [6484 2.6 [168 6.61 [4704 4.96 [4162 4.67 [772 7.25 [1742 3.08 [7755 0.792 [2331 11.6 [6634 4.07 [23 3.26 [2488 13.7 [7034 6.17 [7665 0.756 [3155 2.65 [418 9.97 [5056 15.5 [4846 8.25 [3334 6.02 [2206 3.16 [6859 10.2 [328 12.9 [301 3.7 [4398 22.1 [2225 4.63 [7656 5.23 [1672 4.67 [1 18] [22 100]] [35 27]] [2110 2.86 [1980 5.38 [1 38] [29 39]] [29 55]]] [31 38]] [30 82]] [2262 7.46 [2202 1.09 [6342 6.94 [2913 10.9 [7301 4.85 [33 11] [18 57]] [26 38]] [1429 25 [15 16] [37 42]]] [22 71]] [34 89]]] [24 66]] [2143 1.98 [35 55] [35 76]]] [12 100]] [1 84]] [1899 20.1 [7 95] [7 70]]] [28 33]] [35 84]] [6853 5.88 [978 5.88 [1548 6.33 [7233 5.62 [310 14.7 [4359 9.42 [2470 20.9 [394 6.33 [4257 13.5 [7419 14.1 [7512 28.4 [7734 1.54 [4235 3.36 [19 8] [20 46]] [18 38]] [1429 39.9 [7585 14.3 [13 9] [32 40]] [6 24]]] [6 72]] [20 100]] [19 43]] [31 39]] [20 100]] [26 91]] [32 50]] [20 100]] [2 25]] [24 26]]] [13 92]] [8 55]] [177 14.5 [7369 1.28 [4498 6.49 [6471 4.52 [4251 4.69 [248 0.446 [3763 15.9 [7043 32.8 [6547 8.2 [6721 3.5 [6363 22.3 [99 3.09 [2232 3.71 [4154 5.66 [214 11 [2259 22.1 [33 13] [30 17]] [13 100]] [33 18]] [29 25]] [19 22]] [12 94]] [30 73]] [14 100]] [25 100]] [15 100]] [5017 4.59 [3008 9.2 [5174 6.81 [33 51] [33 100]] [33 75]] [33 100]]] [12 91]] [26 92]] [0 61]] [7446 3.96 [4 18] [2862 13.7 [38 100] [38 50]]]] [19 73]]] [30 95]] [36 64]] [20 95]] [7085 11.4 [5617 4.39 [6342 6.71 [5371 20.7 [3130 23.5 [33 34] [28 31]] [33 64]] [1 62]] [33 80]] [1 66]]] [24 96]] [34 100]] [248 2.65 [5989 8.15 [1813 32 [33 62] [33 18]] [13 50]] [4703 38.5 [33 89] [33 50]]]] [144 0.776 [19 55] [19 66]]] [25 80]] [30 92]] [1429 16.7 [4892 23.8 [6514 6.62 [7421 12 [4345 21.7 [2259 39.5 [6077 12.7 [2 37] [2 75]] [6 81]] [2 100]] [6 85]] [6 95]] [6 100]] [6 68]]] [32 51]] [2884 0.552 [38 77] [38 100]]] [4 60]] [5617 5.41 [28 67] [28 75]]] [6606 0.971 [7734 5 [3217 1.96 [7443 3.12 [6306 5.06 [524 2.02 [3156 0.205 [1483 2.58 [3055 4.07 [791 48.2 [774 0.192 [1696 0.629 [5769 4.37 [5472 3.2 [5448 3.62 [590 5.21 [3572 4.17 [6189 7.39 [6866 7.82 [5466 5.11 [5891 0.488 [1233 5.2 [915 10.2 [939 9.73 [5976 6.85 [1151 1.05 [6063 1.13 [6619 0.701 [6344 3.3 [2908 1.47 [538 2.35 [1180 3.23 [8 6] [13 100]] [21 55]] [2 79]] [4592 2.39 [15 71] [7171 6.67 [15 75] [15 100]]]] [25 100]] [22 100]] [7401 0.595 [2259 0.494 [3928 1.26 [5 29] [12 57]] [5 48]] [5 55]]] [3 100]] [7101 14.4 [3843 2.92 [7255 10.9 [438 16.1 [6848 5.26 [978 5.59 [7453 3.4 [1429 30 [27 46] [12 12]] [4 33]] [8 26]] [35 85]] [11 100]] [11 88]] [10 44]] [35 37]]] [791 27.6 [3 48] [21 56]]] [4871 2.99 [27 88] [27 100]]] [5386 1.27 [23 1.74 [1653 1.01 [1429 157 [17 44] [19 66]] [38 28]] [1564 7.51 [17 62] [17 80]]] [32 75]]] [12 83]] [6550 20.4 [5 63] [5 100]]] [25 87]] [11 100]] [3 78]] [32 90]] [3068 7.46 [5822 9.43 [6544 10.3 [36 49] [36 85]] [13 100]] [36 100]]] [4 46]] [331 1.17 [26 81] [26 100]]] [4114 2.25 [27 69] [27 87]]] [441 14.6 [518 5.05 [7620 6.02 [4876 13.5 [5812 2.15 [5472 17 [5995 18.5 [896 6.67 [744 5.49 [5049 2.92 [517 8.2 [2241 45.5 [550 1.47 [7665 4.2 [6791 16.1 [21 20] [15 66]] [32 23]] [21 66]] [21 83]] [21 81]] [21 85]] [21 88]] [7512 58 [5 29] [7 32]]] [29 96]] [36 50]] [35 33]] [10 41]] [13 77]] [21 100]] [11 58]]] [0 100]] [8 94]] [35 69]] [21 96]] [3 90]] [27 97]] [1980 2.12 [24 100] [1609 10.6 [588 0.374 [36 54] [24 80]] [24 100]]]] [939 2.35 [1429 90.4 [1669 4.13 [7 70] [7 100]] [7 55]] [24 53]]] [28 92]]] [2939 1.17 [3155 8.36 [3233 1.96 [2029 7.1 [35 70] [35 81]] [35 62]] [35 50]] [35 40]]] [13 81]] [3262 1.05 [5526 1.08 [6988 0.467 [2818 0.652 [6668 0.0926 [1391 9.59 [5749 2.01 [2740 0.917 [4214 4.52 [820 0.69 [5454 1.59 [3155 0.262 [5053 1.01 [1 1.78 [4568 3.55 [3431 1.45 [384 0.729 [3004 0.662 [3067 1.42 [6334 1.1 [6173 1.71 [5090 0.922 [1919 2.02 [6365 1.25 [5668 1.33 [6859 4.32 [1704 1.14 [978 0.0468 [6126 2.28 [4221 7.78 [3916 3 [1181 8.85 [1429 7.46 [7512 5.18 [4401 6.21 [15 12] [35 100]] [125 4.5 [15 10] [32 61]]] [5753 4.9 [6809 1.86 [36 9] [32 100]] [4071 1.3 [28 28] [12 38]]]] [36 93]] [3895 2.44 [4154 34.6 [32 77] [32 45]] [32 100]]] [15 78]] [12 100]] [6177 6.53 [1429 17.6 [6538 2.76 [6310 17.2 [4235 2.67 [978 15.6 [7301 0.353 [23 20] [26 77]] [6619 14.3 [23 27] [25 100]]] [2752 11.8 [16 33] [2 47]]] [7 76]] [2 96]] [312 3.6 [2759 20.7 [4889 2.31 [3732 1.57 [5677 6.16 [5 20] [38 41]] [38 47]] [38 61]] [23 100]] [4 45]]] [25 69]]] [5509 6.58 [429 30.4 [17 86] [2259 2.04 [17 59] [17 44]]] [17 26]]] [6404 2.79 [221 2.49 [1676 0.557 [2753 2.16 [328 8.57 [36 56] [28 80]] [36 73]] [36 50]] [28 60]] [36 100]]] [28 58]] [12 100]] [6984 0.952 [6184 1.67 [4158 4.91 [6076 5.13 [2470 1.09 [144 0.461 [731 1.36 [2 18] [7381 2.88 [1980 2.8 [7512 5.6 [2 20] [17 46]] [8 33]] [17 54]]] [2 42]] [4 88]] [2 66]] [2 77]] [1429 25.7 [7665 5.74 [2 43] [4991 8.09 [2 67] [2 100]]] [2 31]]] [4 100]]] [22 66]] [5972 42.6 [31 100] [31 90]]] [5 92]] [36 100]] [7512 0.159 [36 93] [36 100]]] [23 52]] [36 100]] [5692 1.62 [28 38] [28 87]]] [2526 0.548 [7354 1.23 [286 0.955 [3747 0.735 [5192 9.7 [6761 1.95 [826 2.35 [6520 1.29 [6859 2.11 [5851 0.876 [5999 0.469 [2470 1.54 [7491 21.9 [7512 9.53 [36 37] [12 59]] [12 75]] [11 46]] [36 30]] [12 12]] [7210 2.13 [36 95] [36 100]]] [36 100]] [12 57]] [36 95]] [12 75]] [11 100]] [11 39]] [1899 10.4 [728 8.56 [3424 1.55 [36 91] [36 63]] [36 83]] [36 66]]] [1899 1.19 [5 28] [2628 0.971 [4154 1.23 [4 58] [36 40]] [16 42]]]]] [2411 1.56 [36 77] [36 100]]] [1980 0.655 [35 76] [35 89]]] [6853 0.539 [1559 1.65 [16 3.27 [4611 1.35 [7512 4.25 [144 14.4 [1788 9.43 [24 26] [36 62]] [29 100]] [36 53]] [29 75]] [36 100]] [36 100]] [1436 17.1 [7420 1.02 [6210 0.539 [1218 1.85 [5053 1.8 [1628 18.1 [1096 3.3 [36 91] [36 80]] [24 75]] [36 100]] [36 100]] [36 100]] [36 93]] [24 72]]]] [5647 0.509 [820 15.7 [11 100] [11 91]] [11 100]]] [24 66]] [4 91]] [386 0.967 [23 90] [23 100]]] [2180 0.326 [4279 3.23 [6184 2.42 [22 50] [22 90]] [15 55]] [35 41]]] [1429 29.8 [2521 1.74 [28 92] [28 100]] [144 1.47 [12 33] [906 0.989 [6157 0.0926 [596 2.14 [28 50] [28 71]] [28 100]] [28 57]]]]] [1218 6.99 [2143 1.81 [23 16.1 [12 88] [1899 0.982 [12 70] [12 90]]] [12 100]] [12 85]]] [2 100]] [29 100]] [957 9.62 [663 1.25 [2780 17 [37 100] [37 90]] [37 68]] [37 84]]]] [6781 0.0514 [4154 0.305 [13 94] [13 100]] [13 100]]] [2526 3.05 [3564 1.2 [7377 1.86 [7600 3.4 [328 7.74 [187 0.684 [429 18.1 [721 3.45 [4573 1.09 [7354 7.38 [1239 4.68 [4307 8.2 [6587 11 [4684 4.01 [3929 2.16 [4561 5.05 [7203 10.6 [6380 3.03 [7711 20.3 [3008 12.8 [7122 0.724 [1888 49.5 [7428 10.2 [14 36] [7512 27.3 [23 50] [32 90]]] [26 30]] [26 33]] [17 32]] [5 54]] [32 63]] [14 95]] [32 75]] [663 4.33 [8 58] [17 50]]] [32 75]] [5 81]] [32 100]] [2130 0.595 [26 27] [36 63]]] [36 88]] [19 88]] [7354 3.45 [36 71] [36 100]]] [4574 0.984 [3027 2.42 [1685 3.4 [731 1.03 [4801 1.47 [695 38.5 [3008 7.91 [1580 3.4 [7449 1.48 [6294 0.741 [3604 1.83 [4852 15.2 [3480 16.9 [5851 7.54 [5445 7.69 [4851 55.2 [1011 6.67 [221 1.05 [2259 31.3 [28 26] [791 16.8 [4 25] [32 63]]] [28 42]] [5 33]] [28 89]] [28 100]] [3 20]] [32 100]] [8 58]] [28 91]] [32 28]] [29 38]] [17 37]] [17 39]] [28 100]] [32 100]] [17 64]] [28 100]] [3480 4.83 [32 30] [32 100]]] [32 100]]] [7241 0.301 [18 31] [5 25]]] [5851 0.389 [28 24] [6342 0.389 [28 44] [23 27]]]] [32 100]] [36 100]] [32 52]] [731 1.66 [141 3.36 [6544 2.3 [4061 2.63 [6342 20.1 [5345 6.55 [4852 3.45 [7188 20.3 [7343 23.7 [6583 10.4 [2541 1.43 [3492 6.38 [7590 6.18 [2616 36.1 [2913 16.6 [3917 13.1 [7526 6.33 [6199 23.8 [1783 17.7 [7588 25 [17 15] [17 52]] [26 42]] [38 66]] [1429 13.1 [17 42] [7 70]]] [7 42]] [7 83]] [19 42]] [17 80]] [19 66]] [144 6 [5383 0.511 [6206 18.5 [19 42] [17 100]] [19 50]] [17 33]]] [19 48]] [19 41]] [695 2.87 [7 90] [7 91]]] [8 100]] [17 64]] [8 50]] [3008 2.77 [5 41] [17 82]]] [17 50]] [7 55]] [17 36]]]] [7456 7.25 [5786 4.2 [12 90] [12 100]] [12 100]]] [4338 1.3 [4154 0.409 [906 0.444 [3237 0.978 [663 2.01 [5049 0.732 [3033 5.78 [1696 7.94 [896 1.41 [2106 5.95 [7657 1.72 [3334 3.18 [6541 3.18 [1722 6.36 [371 3.76 [2081 2.53 [3309 9.18 [842 7.47 [6063 0.671 [2987 0.826 [392 3.25 [4552 2.03 [7490 5.62 [7747 3.82 [7396 3.36 [6031 13 [957 8.2 [3959 1.86 [1687 2.33 [1487 4.93 [7305 16.9 [2494 0.982 [6606 1.92 [171 0.642 [7354 2.14 [2193 1.47 [695 3.29 [3851 2.67 [4556 2.54 [1 11] [23 100]] [1062 5.65 [35 75] [35 60]]] [5851 1.61 [5472 3.07 [12 14] [36 71]] [4 41]]] [2058 1.1 [1 30] [1 55]]] [1062 3.3 [23 5.5 [36 40] [1429 27.1 [33 37] [36 90]]] [8 28]]] [5673 14.8 [19 41] [19 63]]] [5999 5.18 [28 87] [28 100]]] [8 50]] [25 85]] [23 95]] [38 32]] [29 92]] [1239 0.81 [1986 10 [27 34] [791 20.1 [14 28] [32 57]]] [27 50]]] [22 60]] [25 100]] [20 100]] [1 68]] [32 100]] [384 2.69 [2919 15.9 [6199 3.82 [2251 1.87 [28 19] [10 54]] [16 28]] [25 71]] [23 89]]] [23 60]] [22 100]] [35 100]] [4017 4.76 [816 2.99 [11 61] [11 100]] [11 85]]] [6199 12.3 [2088 1.17 [4234 1.68 [6809 2.44 [4663 17.5 [5972 0.96 [5982 0.545 [802 29.5 [1913 9.2 [760 5.85 [6349 12.4 [2461 3.65 [6063 5.78 [222 1.02 [2203 2.28 [1623 2.49 [177 20.1 [2004 1.7 [3622 1.49 [296 1.99 [3435 5.53 [2742 4.31 [2001 3.57 [1 17] [29 23]] [4 100]] [35 54]] [32 100]] [29 85]] [2204 0.659 [7085 5.18 [435 6.95 [6791 3.65 [29 13] [11 45]] [11 47]] [23 83]] [29 30]]] [19 100]] [11 100]] [23 23]] [29 24]] [22 100]] [27 73]] [10 100]] [23 96]] [2275 1.39 [6380 0.2 [7331 0.538 [1458 2.64 [2214 2.63 [2212 0.285 [1436 14 [3931 1.04 [2139 4.09 [29 32] [1 45]] [1 53]] [2004 1.54 [1 15] [22 42]]] [29 42]] [1 50]] [1078 3.72 [1899 28.5 [2181 10.4 [1 16] [3 33]] [29 30]] [2081 11.7 [15 66] [15 70]]]] [7 100]] [30 38]] [2526 8.1 [1 13] [1 100]]]] [21 74]] [6998 0.322 [29 91] [29 100]]] [1986 4.07 [7449 19.4 [12 48] [12 100]] [15 71]]] [29 27]] [32 100]] [12 100]] [1919 0.816 [791 2.96 [23 59] [23 84]] [23 90]]] [35 43]]] [21 83]] [33 90]] [12 100]] [12 100]] [12 100]] [2161 18.9 [35 68] [35 63]]] [1436 12.6 [1883 2.65 [5239 2.82 [6983 2.07 [7583 8.46 [2616 4.28 [2004 2.62 [7516 1.94 [896 6.31 [17 58] [7693 4.76 [2 17] [14 33]]] [25 50]] [29 55]] [2764 8.99 [429 33 [5 25] [2 61]] [2 50]]] [25 85]] [31 60]] [4 100]] [2 85]] [7 53]]] [26 95]] [23 73]] [21 88]] [3027 5.1 [2007 3.76 [7665 4.63 [6537 6.33 [663 22.7 [2763 4.28 [3972 1.2 [2004 1.3 [6031 11.2 [23 64.8 [28 11] [3 41]] [22 100]] [29 34]] [37 80]] [22 77]] [2081 24 [144 33 [23 7.76 [32 13] [32 41]] [26 50]] [32 53]]] [2 100]] [1445 3.31 [2 17] [19 42]]] [10 94]] [35 45]]] [23 7.52 [3273 0.867 [11 66] [11 95]] [11 75]]] [2143 13.5 [438 0.117 [585 5.67 [791 46 [2764 4.67 [6538 0.678 [968 0.578 [1991 8.22 [3027 17.8 [820 0.811 [21 13] [11 80]] [23 36]] [23 41]] [28 55]] [2 100]] [2470 0.332 [3953 1.5 [11 44] [11 100]] [11 100]]] [1906 2.28 [21 65] [21 83]]] [21 100]] [2149 0.176 [11 54] [11 91]]] [435 7.07 [21 77] [21 53]]]] [1881 1.19 [5267 0.223 [2944 8.28 [3527 11.1 [4208 0.838 [6300 0.826 [761 1.01 [398 1.94 [2342 4.59 [429 52.4 [3622 0.861 [2540 1.39 [1783 3.23 [4630 10.3 [2939 1.11 [2184 6.53 [4336 1.87 [1072 0.581 [5692 1.09 [5011 0.123 [110 1.87 [6093 4.5 [3928 10.8 [2847 1.06 [756 4.13 [1094 2.15 [2476 8.54 [5753 7.58 [2168 1.42 [24 6.17 [685 4.7 [7623 53.6 [248 5 [1932 7.53 [2099 6.53 [4601 22.7 [2913 5.46 [23 13] [3 42]] [4279 25.2 [8 57] [26 63]]] [23 40]] [28 36]] [4161 8.52 [29 22] [26 66]]] [35 55]] [23 55]] [4161 0.414 [29 85] [29 85]]] [29 57]] [7512 2.15 [429 9.72 [2143 13.3 [2 15] [2 36]] [28 64]] [29 50]]] [15 100]] [2058 2.32 [5753 0.739 [23 27] [28 37]] [23 42]]] [3 63]] [22 95]] [12 53]] [13 90]] [12 81]] [29 82]] [567 12.7 [2259 15.1 [28 22] [28 78]] [23 66]]] [4 40]] [35 87]] [23 61]] [4161 6.11 [2752 0.365 [29 76] [5692 11 [6015 1.18 [2091 7.34 [6809 5.71 [1995 3.64 [2178 4.82 [1429 57.2 [28 17] [29 60]] [29 64]] [22 37]] [32 100]] [32 58]] [12 81]] [25 40]]] [19 36]]] [11 33]] [6382 5.54 [6899 0.864 [2466 0.548 [2190 0.131 [251 6.21 [2072 5.2 [968 0.272 [695 4.05 [33 11] [28 31]] [1 41]] [4 44]] [1 83]] [19 42]] [18 21]] [33 76]] [38 1.95 [32 55] [3 100]]]] [2241 5.87 [12 78] [2232 17.1 [23 61] [23 87]]]] [29 100]] [3 31]] [2260 4.5 [2268 8.21 [23 19] [34 42]] [19 92]]] [978 2.82 [23 50] [23 87]]] [23 100]] [28 100]] [29 100]] [26 73]] [3 87]] [3931 0.743 [1986 0.699 [32 20] [1899 5.46 [11 70] [10 41]]] [12 64]]] [26 59]]] [1991 1.12 [6851 5.62 [3008 8.7 [4279 13.5 [5812 2.27 [2225 1.18 [7461 3.11 [2280 1.37 [7176 1.21 [2081 20.8 [4424 1.36 [23 35] [23 71]] [23 84]] [23 15.5 [33 75] [33 100]]] [4175 2.99 [24 75] [24 100]]] [23 68]] [1919 0.394 [23 92] [23 100]]] [1078 30.7 [2 90] [4 87]]] [24 25]] [25 91]] [24 100]] [23 96]]]] [6606 2.73 [28 91] [28 100]]] [4992 0.405 [2764 6.7 [1888 23.3 [1083 0.697 [999 0.537 [667 23.9 [1072 0.592 [6735 0.603 [2 65] [2 95]] [2 100]] [2 50]] [138 0.644 [2 94] [2 100]]] [2 93]] [13 42]] [4 57]] [2 91]]] [4157 0.698 [4478 2.22 [5272 0.204 [6844 1.03 [2370 1.25 [5592 0.585 [233 0.471 [607 2.18 [1303 2.51 [5408 8.59 [4889 3.95 [7665 9.83 [1582 2.72 [6772 0.111 [429 30.8 [4505 4.1 [5692 4.76 [3807 1.82 [4866 0.526 [2122 20 [1622 2.41 [1851 0.606 [5184 0.928 [5889 0.477 [5174 1.84 [1943 1.63 [6611 1.47 [5528 0.79 [2011 5.6 [4865 1.16 [3667 4.9 [1189 3.75 [1054 1.15 [6634 2.81 [328 6.9 [2020 4.93 [429 0.0807 [4732 3.95 [6078 1.03 [1646 6.02 [6328 7.59 [7395 5.34 [1 12] [32 100]] [4517 5.78 [11 31] [2 60]]] [3027 1.48 [7 30] [7 83]]] [1980 15.6 [4 24] [28 90]]] [6 100]] [1332 1.44 [2913 9.92 [2537 8.83 [929 2.42 [6328 0.621 [21 6] [24 22]] [23 80]] [23 90]] [6011 3.85 [7428 1.04 [144 3.82 [3 63] [25 30]] [21 45]] [11 42]]] [9 87]]] [35 57]] [5524 0.334 [7646 2.26 [6643 15.7 [1436 14.1 [5185 0.534 [4559 0.644 [6260 1.49 [33 15] [9 37]] [14 90]] [9 100]] [1429 62.4 [4 12] [15 62]]] [1 90]] [33 61]] [11 100]]] [1452 10.1 [30 100] [30 87]]] [1783 38.3 [5809 5.68 [3989 1.25 [2260 0.33 [24 26] [11 66]] [21 57]] [24 60]] [11 25]]] [6419 1.27 [28 68] [28 100]]] [35 70]] [3 100]] [29 52]] [1391 0.642 [15 100] [15 84]]] [2081 5.97 [3694 0.722 [1841 8.35 [28 87] [28 100]] [28 100]] [28 85]]] [7629 2.26 [6848 8.02 [2290 10.1 [4971 0.285 [1955 1 [2154 0.384 [3545 1.53 [4154 13 [7208 0.111 [2122 8.04 [2469 0.454 [1252 3.9 [1438 0.826 [1078 0.703 [429 18.8 [1 22] [31 43]] [2199 3.06 [1245 12.7 [1 10] [35 71]] [26 33]]] [17 44]] [35 40]] [19 63]] [31 58]] [30 50]] [3446 2.72 [29 17] [33 100]]] [13 40]] [28 45]] [1938 17.7 [2246 0.849 [2248 0.73 [2023 5.47 [2278 5.9 [2137 3.14 [2225 3.13 [1244 19 [2207 0.677 [35 24] [35 75]] [35 29]] [29 68]] [29 50]] [1 66]] [29 52]] [10 42]] [1 28]] [35 100]]] [30 70]] [1 61]] [35 80]] [35 93]]] [33 74]] [2181 2.17 [2199 0.184 [2232 7.53 [32 29] [3 75]] [2259 26.8 [328 0.368 [1436 2.56 [32 72] [38 33]] [32 36]] [15 25]]] [1913 13.5 [1452 2.13 [17 54] [17 81]] [14 38]]]] [2227 0.699 [4703 0.891 [1783 32.8 [28 66] [28 91]] [28 80]] [28 100]]] [13 97]] [11 100]] [1954 29.2 [35 36] [29 44]]] [3 100]] [10 100]] [5017 0.881 [663 1.92 [7449 2.2 [4215 1.22 [2600 2.39 [1888 3.14 [4214 2.46 [4156 3.6 [5753 19.2 [3308 2.24 [33 43] [8 36]] [28 72]] [33 91]] [33 100]] [18 25]] [33 100]] [33 100]] [12 19]] [18 28]] [33 100]]] [32 100]] [4219 7.72 [6906 3.32 [1239 76 [5831 2.11 [583 6.54 [7428 10.3 [800 10.1 [144 3.61 [7314 7.58 [6114 5.24 [1253 1.52 [7352 26 [1429 4.48 [915 1.36 [3151 4.67 [589 3.94 [556 8.57 [4179 6.85 [816 15.4 [747 3.55 [2526 44.1 [29 9.36 [4154 9.26 [7241 10.8 [7085 10.2 [5412 7.75 [1078 15.2 [21 39] [23 22]] [21 68]] [7086 5.15 [21 45] [21 75]]] [3 75]] [429 59.8 [3 58] [3 100]]] [9 59]] [24 90]] [21 90]] [35 57]] [3 91]] [21 100]] [21 81]] [21 100]] [4956 2.99 [21 71] [3 37]]] [2752 0.65 [2199 10.7 [2526 5.66 [1458 5.12 [1456 6.17 [3 25] [17 33]] [30 40]] [9 23]] [21 64]] [23 19]]] [35 60]] [1259 6.71 [1436 2.13 [23 14] [11 30]] [11 42]]] [35 22]] [3 90]] [11 25]] [21 100]] [5999 35.1 [3 40] [3 75]]] [917 3.94 [3 80] [3 40]]] [7169 2.11 [9 82] [9 83]]] [6261 1.86 [2143 14.2 [48 2.2 [1445 4.35 [1899 25.6 [2081 11.4 [2993 4.27 [2178 5.44 [6149 4.27 [9 52] [9 100]] [3 53]] [3 61]] [2081 20.3 [21 77] [21 66]]] [31 60]] [31 66]] [9 94]] [29 35]] [2270 1.5 [6883 9.02 [9 89] [9 71]] [9 100]]]] [9 100]] [3 100]]] [4279 13.4 [2093 14.5 [2939 1.72 [2143 5.68 [429 13.6 [1841 1.05 [6772 4.93 [30 77] [7169 2.33 [4704 1.25 [30 94] [30 100]] [30 100]]] [791 1.42 [22 33] [30 100]]] [9 42]] [30 98]] [30 100]] [30 100]] [30 61]]] [3 100]] [168 17.6 [310 8.42 [7540 5.75 [6199 1.86 [4969 16.4 [7419 9.3 [285 5.05 [429 2.07 [2939 33.4 [2466 3.55 [4895 2.99 [2616 11.3 [7609 9.43 [1913 9.99 [695 9.9 [7665 28 [4154 6.31 [3008 10.1 [2123 5.03 [4235 4.42 [6 14] [33 41]] [1 28]] [25 44]] [18 30]] [6 44]] [33 23]] [10 22]] [8 57]] [5988 9.43 [2035 6.02 [1316 18.5 [6 75] [6 100]] [6 100]] [6 100]]] [38 43]] [22 29]] [6 94]] [7623 12.8 [2251 4.95 [1769 7.19 [7067 15.2 [7512 47.6 [2275 6.06 [7301 8.13 [7461 2.99 [6732 7.42 [7449 1.85 [6 14] [3 20]] [24 36]] [4 40]] [6 100]] [6 81]] [429 50 [24 87] [24 100]]] [24 100]] [18 20]] [12 25]] [6 57]]] [1980 3.14 [33 42] [33 90]]] [4534 20 [5716 4.95 [6 90] [6 100]] [6 100]]] [7 100]] [33 20]] [1314 21.7 [221 15.5 [6 93] [6 90]] [6 100]]] [26 61]] [1079 12.4 [19 43] [19 100]]]] [4737 6.33 [2549 8.46 [6 66] [6 84]] [6 100]]] [7038 9.19 [1 11.1 [6424 5.49 [1078 18 [4843 5.88 [6 81] [6 100]] [6 100]] [6 88]] [6 100]] [6 46]]] [6098 4.88 [2566 28 [6 93] [6 68]] [6 75]]] [3 96]] [7208 0.655 [250 5.04 [6791 0.53 [33 87] [33 100]] [33 54]] [33 72]]] [4991 0.204 [3308 0.599 [1239 68.3 [15 100] [15 85]] [15 100]] [15 71]]] [7153 2.09 [5717 0.982 [6 90] [6 100]] [1429 5.33 [6 71] [6 89]]]] [1313 0.845 [33 68] [5491 18 [33 95] [33 83]]]] [10 100]] [7085 4.01 [286 1.93 [1986 1.68 [4560 1.02 [6883 5.53 [5086 0.274 [5370 1.45 [5509 1.57 [126 4.21 [505 10.8 [1997 1.48 [392 1.96 [3 10] [7 45]] [3 46]] [4651 8.02 [1345 14.6 [1253 3.5 [9 62] [9 62]] [9 55]] [9 33]]] [9 87]] [13 26]] [9 100]] [4 46]] [9 73]] [9 60]] [9 83]] [10 41]] [23 17.6 [9 83] [9 66]]]] [719 1.52 [1757 0.632 [33 84] [33 100]] [33 100]]]] [6342 3.79 [248 2.28 [15 100] [15 97]] [15 100]]] [1 1.74 [791 17 [2369 0.759 [5753 12.1 [2284 1.2 [7255 1.62 [2178 0.471 [6103 0.337 [4398 1.64 [31 77] [31 100]] [31 88]] [31 100]] [31 100]] [31 100]] [31 80]] [31 100]] [31 46]] [31 53]]] [7369 0.337 [4574 7.67 [5067 0.56 [301 10.5 [5439 9.71 [1116 35.6 [4865 1.13 [5851 1.11 [6294 4.13 [2107 2.67 [4663 7.31 [3 88] [3 100]] [3 100]] [3 87]] [3 100]] [3 100]] [3 60]] [30 100]] [30 100]] [3 100]] [3 50]] [3 100]]] [27 99]] [1975 5.06 [1374 1.94 [1919 12.6 [663 2.67 [1311 5.65 [6 77] [6 100]] [6 70]] [6 93]] [7419 0.518 [6 88] [221 5.47 [6 44] [16 55]]]] [6 100]]] [1943 15.1 [5025 2.86 [4897 2.18 [4602 6.49 [4279 11.3 [27 28] [2915 1.88 [26 91] [26 100]]] [26 100]] [26 100]] [35 66]] [26 63]]] [5976 1.31 [371 6.85 [4967 1.59 [536 1.93 [141 2.33 [2167 0.709 [5267 2.51 [4312 2.09 [5332 6.67 [7169 5.3 [6074 1.27 [7233 4.35 [4865 2.92 [6544 3.14 [31 44] [31 100]] [3 100]] [31 100]] [31 100]] [1888 6.12 [3 50] [31 87]]] [31 100]] [3 68]] [31 93]] [31 100]] [31 100]] [3 100]] [31 100]] [3 83]] [3 100]]] [6732 1.24 [7085 10.7 [7449 14.4 [5386 0.87 [3931 2.82 [5871 4.27 [774 5.26 [2457 4 [1239 51.7 [3227 2.49 [1240 1.5 [24 65] [2752 17.8 [24 93] [24 89]]] [19 44]] [10 27]] [24 100]] [24 40]] [2 30]] [32 83]] [3 36]] [24 44]] [23 33]] [4851 2.2 [3653 1.86 [24 90] [24 100]] [24 50]]]] [429 28.6 [5797 1.77 [7574 6.16 [5093 10.5 [5349 2.74 [6399 16 [2030 3.81 [2752 3.13 [7153 1.19 [2526 2.77 [6 72] [7222 2.86 [7236 7.51 [7419 1.39 [6 97] [6 100]] [6 70]] [6 100]]] [6923 0.813 [6 95] [6 100]]] [6 46]] [2259 75 [6514 6.83 [6398 2.7 [6 66] [6 100]] [6 100]] [1899 13.5 [6 66] [6 100]]]] [6 40]] [299 2.75 [6 100] [6 53]]] [6 75]] [5598 3.27 [6 96] [16 75]]] [6 73]] [32 55]]] [826 1.33 [7665 1.72 [2849 27.7 [4959 2.77 [7016 13.1 [699 1.82 [2259 6.67 [6342 48.7 [6924 1.3 [7413 4.43 [7606 3.76 [968 1.42 [178 2.3 [3345 2.3 [6185 2.92 [782 3.11 [4865 4.35 [1888 15.2 [4369 9.32 [6380 6.81 [3905 10.9 [1239 12.9 [2526 7.77 [685 5.91 [6199 9.82 [663 9.71 [5439 13.2 [338 11.2 [4761 15.9 [4611 17.1 [4630 10.1 [1210 9.75 [6935 2.92 [248 3.23 [1729 5.35 [6103 4.76 [6363 3.23 [7512 27.8 [5 14] [13 61]] [12 71]] [25 33]] [22 37]] [33 41]] [1 28]] [5 60]] [25 64]] [37 50]] [12 88]] [26 100]] [13 40]] [12 26]] [13 22]] [26 40]] [5 34]] [112 10 [2081 16.2 [9 20] [3 85]] [9 45]]] [17 35]] [9 88]] [13 92]] [13 25]] [3 100]] [13 100]] [3 60]] [5 45]] [5 39]] [28 53]] [13 58]] [9 90]] [26 94]] [12 100]] [1509 2.09 [5942 1.21 [7354 4.62 [5542 7.83 [3929 15.5 [2436 3.36 [2483 2.21 [6853 3.18 [4865 1.54 [2628 7.38 [6727 12.5 [1957 0.818 [3302 2.54 [1906 5.05 [728 8.15 [6363 3.26 [3664 5.85 [4663 0.209 [6791 20.3 [5828 12.1 [7241 45.7 [12 10] [32 71]] [8 100]] [8 44]] [12 66]] [36 88]] [22 37]] [36 53]] [21 55]] [2 41]] [19 50]] [8 42]] [26 44]] [3 100]] [36 75]] [31 80]] [36 72]] [12 84]] [13 100]] [978 7.76 [36 39] [8 80]]] [28 81]] [19 66]]] [5412 1.87 [791 17.5 [9 100] [9 80]] [9 50]]] [1626 4.93 [22 65] [22 92]]] [4 100]] [2849 44.4 [38 53] [38 100]]] [4213 3.4 [584 0.565 [642 0.686 [207 1.81 [2628 0.952 [7034 1.6 [6091 1.77 [56 6.45 [99 1.18 [4765 3.15 [6311 2.13 [7101 2.01 [7665 8.85 [5 29] [2592 4.76 [2398 2.09 [6074 2.18 [4224 4.67 [7711 3.94 [7716 4.5 [7684 2.49 [6269 1.31 [7623 4.36 [7693 5.72 [6131 5.05 [663 22.1 [4929 7.34 [5 36] [4 55]] [17 40]] [13 26]] [5 60]] [12 90]] [5692 9.35 [13 83] [13 87]]] [5 57]] [12 100]] [5514 18.1 [5 88] [5 100]]] [13 100]] [6077 5.54 [13 100] [31 70]]] [12 97]] [4 83]]] [22 30]] [5 88]] [13 87]] [26 54]] [26 80]] [13 96]] [23 3.65 [7198 2.56 [13 99] [13 100]] [13 100]]] [6989 1.12 [4 47] [2 100]]] [5 81]] [5833 4.63 [4154 7.26 [896 5.35 [36 45] [2753 7.12 [1429 15.4 [5 36] [2616 10 [5 66] [5 50]]] [5 42]]] [896 22.7 [5 42] [19 44]]] [19 45]]] [4 90]] [12 100]]] [7139 1.9 [1899 8.95 [802 1.63 [6205 2.44 [826 23.3 [2426 1.68 [12 44] [12 100]] [12 80]] [12 100]] [12 100]] [12 80]] [12 66]]]] [939 0.289 [345 0.945 [7665 17.9 [145 1.93 [7654 1.74 [6811 0.489 [1068 2.44 [5512 1.62 [1998 2.07 [4414 19.1 [6862 4.95 [6124 0.99 [6332 2.99 [1776 1.73 [4218 3.31 [248 3.05 [957 3.6 [5413 17.2 [6871 9.05 [2297 2.7 [5110 3.6 [2199 0.231 [1078 1.39 [4895 4.5 [2902 2.76 [4517 2.99 [6529 1.83 [791 2.2 [29 38] [29 65]] [29 100]] [29 75]] [29 87]] [29 57]] [5693 8.95 [1023 2.04 [7101 12 [23 31.2 [5970 1.75 [435 0.741 [5007 6.13 [3310 1.12 [1986 10.6 [4154 19.9 [2178 1.29 [6446 2.79 [2764 1.16 [306 6.07 [552 2.76 [4991 2.51 [7169 1.69 [112 1.44 [1078 36.7 [29 71] [29 95]] [29 97]] [29 75]] [29 66]] [29 100]] [29 92]] [29 100]] [29 100]] [29 100]] [15 50]] [29 62]] [29 100]] [1239 2.73 [2081 2.42 [7461 2.73 [1177 4.18 [5007 16.4 [29 100] [1429 30.5 [29 100] [29 88]]] [29 100]] [29 100]] [29 100]] [29 100]]] [29 100]] [29 100]] [29 76]] [29 85]] [29 100]] [29 60]]] [1913 0.4 [1078 4.14 [1980 2.75 [29 57] [29 88]] [2752 2.92 [29 96] [29 100]]] [29 100]]] [7413 3.82 [5753 1.93 [15 48] [12 84]] [12 100]]] [29 100]] [29 57]] [32 72]] [32 68]] [5851 12.4 [540 2.05 [4517 5.58 [1062 12.3 [112 0.555 [2939 1.32 [2902 1.61 [29 78] [29 100]] [29 100]] [29 100]] [791 13.5 [29 100] [29 50]]] [29 100]] [29 100]] [29 75]]] [15 62]] [12 100]] [11 66]] [12 62]] [34 54]] [29 51]] [12 53]] [12 100]] [12 52]] [32 100]] [15 100]] [29 96]] [13 40]] [15 100]] [145 8.07 [6112 0.578 [5969 17 [663 9.98 [910 0.734 [896 5.58 [4114 1.54 [6490 0.673 [7352 0.404 [7169 5.64 [2806 0.852 [3960 0.52 [2251 0.544 [29 95] [29 100]] [29 100]] [29 100]] [29 86]] [29 85]] [29 100]] [29 88]] [29 57]] [29 100]] [6800 2.73 [221 1.01 [29 86] [29 90]] [29 100]]] [29 71]] [29 100]] [29 62]]]] [1018 1.48 [802 14.2 [6883 3.76 [4279 5.34 [328 2.95 [907 20 [616 3.82 [816 1.04 [615 8.26 [7491 10.2 [21 50] [15 55]] [9 75]] [21 70]] [3 100]] [21 75]] [6276 0.695 [791 19.6 [6892 3.14 [6148 8.49 [7169 3.3 [9 40] [21 54]] [1598 2.82 [9 42] [9 77]]] [21 100]] [21 63]] [9 100]]] [429 29 [3 50] [3 96]]] [1304 1.63 [538 4.66 [6802 0.524 [9 64] [9 60]] [10 50]] [9 100]]] [5832 0.327 [817 1.4 [4751 1.8 [2251 12.5 [505 0.978 [2178 22.3 [7088 10.8 [583 0.578 [546 5.56 [1062 8.12 [4663 15.9 [907 2.96 [21 50] [803 0.319 [328 4.5 [4918 2.18 [7451 0.826 [5393 12.6 [21 84] [3 55]] [21 97]] [21 100]] [791 44.1 [21 51] [21 81]]] [21 100]]] [21 68]] [3 50]] [21 100]] [915 6.91 [9 68] [21 78]]] [9 40]] [21 70]] [9 50]] [3 55]] [9 100]] [21 66]] [9 95]]] [3 100]]] [4897 10.1 [7439 2.82 [4562 0.167 [38 36] [4651 0.55 [38 58] [167 0.807 [38 90] [17 50]]]] [97 1.12 [6384 0.739 [2849 39.6 [187 0.276 [38 55] [38 100]] [7472 4.26 [61 54.6 [17 54] [7440 7.62 [38 100] [38 88]]] [38 100]]] [38 93]] [38 68]]] [38 100]]] [5011 2.09 [4115 2.33 [4326 1.16 [3095 12.8 [2241 0.938 [5410 9.43 [7665 4.2 [5969 8.02 [221 5.15 [7656 7.94 [1391 2.82 [27 60] [22 28]] [16 37]] [2 15]] [23 62]] [12 25]] [21 40]] [23 20]] [429 5.88 [29 17] [27 41]]] [3406 1.38 [1078 27.8 [27 100] [27 83]] [27 100]]] [27 81]] [29 87]]] [2961 0.399 [665 1.66 [7517 4.46 [4630 1.47 [2331 2.82 [322 2.07 [6552 1.22 [312 1.35 [2487 1.41 [7568 25.5 [7305 2.3 [4279 1.5 [7532 4.5 [7571 1.45 [2130 2.51 [178 2.42 [5576 3.65 [1078 6.86 [4345 1.37 [7354 3.31 [328 39.4 [4 51] [25 31]] [7 33]] [2 85]] [4 34]] [2 88]] [2469 0.477 [7665 20.9 [1980 0.982 [4 22] [25 24]] [25 53]] [24 50]]] [31 63]] [2913 4.67 [31 90] [31 100]]] [31 100]] [5673 0.994 [2260 15.6 [7571 3.45 [2616 2.94 [2 26] [2 71]] [31 100]] [18 83]] [19 33]]] [25 58]] [2526 43 [2 35] [2 70]]] [31 100]] [6581 1.98 [4079 1.46 [6173 1.33 [4 38] [31 100]] [31 100]] [4 100]]] [4 96]] [4 100]] [31 100]] [31 66]] [25 75]] [2939 0.557 [2 76] [2 100]]] [4 100]]] [826 1.18 [985 1.35 [6949 2.28 [6791 12.2 [4253 8.21 [2780 0.835 [719 1.1 [7169 22.7 [201 11.1 [4312 5.92 [6377 12.8 [5170 1.03 [7515 2.7 [2143 14.4 [4390 1.04 [2752 9.78 [663 24.7 [26 38] [25 41]] [7354 8.91 [23 22.7 [1081 1.89 [4200 0.467 [4203 5.7 [2178 2.76 [2005 3.35 [1078 10.9 [2530 7.7 [26 61] [25 91]] [5694 3.65 [26 70] [26 100]]] [25 61]] [25 45]] [26 77]] [26 100]] [7512 4.89 [2799 0.826 [26 84] [26 100]] [26 69]]] [184 4.27 [25 37] [26 85]]] [18 58]]] [4205 1.04 [26 85] [26 97]]] [25 37]] [25 100]] [2469 4.22 [2259 12.6 [7520 3.39 [2913 19.6 [2763 5.91 [5171 21.6 [5643 1.3 [7169 2.22 [23 14.8 [26 81] [26 74]] [26 100]] [26 80]] [26 64]] [26 100]] [19 57]] [26 75]] [26 93]] [16 44]]] [25 80]] [3 55]] [25 56]] [25 55]] [5403 3.44 [33 33] [31 100]]] [38 63]] [6189 18.7 [25 65] [25 87]]] [25 64]] [6791 12.9 [25 81] [1 57]]] [2753 1.06 [26 88] [26 100]]] [7742 2.7 [5692 5.05 [7043 1.49 [25 72] [25 100]] [25 80]] [25 100]]]] [5071 0.103 [5555 1.05 [328 46.4 [1772 0.127 [14 98] [14 100]] [14 94]] [14 100]] [14 100]]] [7370 2.31 [5267 9.83 [5100 1.23 [4424 1.33 [7445 7.12 [4876 3.64 [6184 24.6 [995 4.68 [4154 3.31 [3207 2.53 [7009 14.2 [5693 0.436 [3675 1.27 [257 3.07 [731 53.2 [5753 1.81 [26 88] [26 71]] [26 70]] [26 87]] [26 81]] [26 97]] [26 66]] [26 60]] [26 100]] [26 43]] [26 38]] [26 45]] [26 54]] [26 100]] [26 41]] [26 50]] [38 71]]] [6751 0.703 [5972 0.756 [5393 0.797 [4219 13.2 [7512 2.35 [5047 39.6 [3 100] [3 95]] [3 87]] [3 97]] [3 100]] [3 100]] [3 100]]] [1479 0.417 [5555 0.216 [7210 3.52 [1638 0.124 [5412 4.84 [3726 0.71 [4636 0.332 [3094 2.22 [4565 0.326 [7401 1.2 [3598 0.0785 [2039 1.08 [6943 7.04 [429 35 [4867 0.517 [1773 4.52 [248 14.1 [6812 0.38 [5290 0.328 [4637 0.851 [5941 10.9 [5999 1.92 [791 27.1 [4639 5.79 [1786 0.0984 [5753 4.89 [17 30] [3 46]] [30 70]] [17 63]] [17 89]] [14 72]] [3 30]] [3996 1.93 [17 61] [19 43]]] [1714 1.45 [4687 4.22 [17 68] [17 100]] [17 38]]] [6812 4.85 [32 100] [32 87]]] [429 8.06 [3 57] [32 67]]] [5753 2.05 [17 59] [17 96]]] [3 100]] [906 14.6 [3 67] [3 100]]] [32 94]] [1445 0.185 [32 51] [32 87]]] [5891 14.9 [3599 1.24 [4639 1.4 [251 0.157 [38 71] [32 63]] [32 50]] [6076 0.619 [32 94] [32 100]]] [6944 1.33 [2170 0.192 [5725 0.403 [6380 3.42 [4630 26.7 [5893 16.1 [6809 1.47 [429 19.5 [3 42] [17 37]] [32 100]] [17 57]] [4630 30.8 [3598 3.61 [17 62] [17 50]] [17 92]]] [1997 0.123 [17 46] [1653 3.33 [5843 0.322 [1726 0.524 [1664 8.11 [17 80] [17 66]] [17 100]] [17 66]] [17 50]]]] [17 80]] [17 90]] [32 100]]]] [1573 0.187 [4637 2.6 [7072 0.422 [5891 16.7 [17 50] [17 88]] [17 100]] [19 44]] [17 100]]] [1952 5.92 [2284 0.231 [6364 0.85 [5893 25.1 [2161 0.453 [1948 14.9 [4130 0.123 [1078 3.61 [2993 0.234 [5290 0.126 [6358 0.869 [4639 1.21 [17 60] [3269 0.891 [5893 11.6 [19 27] [17 40]] [17 60]]] [19 33]] [4089 0.723 [17 55] [17 92]]] [19 83]] [35 58]] [1769 0.827 [38 100] [38 71]]] [19 46]] [19 46]] [19 64]] [19 80]] [38 61]] [19 62]]] [3424 0.165 [19 76] [19 100]]] [3 100]] [32 93]] [14 57]] [2212 0.841 [14 100] [14 71]]] [4865 1.81 [4564 1.65 [1429 65.6 [1429 46.1 [3 78] [2259 30.3 [3 69] [3 41]]] [6382 1.31 [5941 24.9 [14 34] [3 62]] [14 54]]] [17 77]] [3 100]]] [4915 1.95 [1997 0.685 [14 100] [14 87]] [14 90]]] [4630 0.29 [7316 0.347 [3 88] [3 100]] [3 100]]]] [4527 0.132 [6940 2.22 [2412 9.76 [4986 6.26 [1366 6.72 [2029 7.25 [2282 5.66 [7512 34.1 [7236 0.497 [1997 4.68 [2450 11.5 [4727 6.45 [2388 0.719 [1275 12.4 [5396 5.81 [1355 11.4 [1899 4.5 [7491 1.23 [1314 0.527 [4712 4.93 [4822 4.43 [4725 6.06 [6 85] [6 66]] [6 54]] [6 100]] [6 100]] [6 100]] [2569 13.4 [6 100] [6 83]]] [6 75]] [5408 9.46 [6 85] [16 62]]] [6 56]] [5397 3.94 [6 100] [6 71]]] [7665 12 [299 2.79 [16 70] [6 100]] [6398 0.453 [2406 0.647 [1429 8.16 [6 78] [6 100]] [6 75]] [6 100]]]] [6 57]] [6 100]] [6 50]] [6 50]] [16 55]] [7416 0.978 [6749 14.8 [6 98] [6 66]] [6 100]]] [5396 7.2 [2262 1.96 [6 53] [6 55]] [6 77]]] [16 55]] [6 90]] [4514 0.759 [16 45] [6 62]]] [16 41]]] [2232 0.577 [6148 0.319 [5115 0.81 [7726 1.19 [1899 26.1 [1242 0.222 [6056 1.23 [2894 1.25 [6524 10.9 [1452 1.48 [2896 0.917 [23 5.85 [33 48] [2764 11.2 [7398 3.49 [5412 1.18 [5192 1.48 [1783 22.4 [33 69] [33 100]] [33 100]] [33 91]] [33 71]] [33 75]]] [33 100]] [3 27]] [7 47]] [33 93]] [276 9.8 [33 94] [33 87]]] [1 28]] [33 37]] [33 100]] [7139 6.12 [7330 4.98 [2902 3.26 [1391 9.82 [5668 2.06 [33 95] [33 98]] [33 85]] [33 100]] [33 60]] [33 90]]] [22 28]] [15 35]]] [4948 1.46 [4309 0.879 [1206 0.379 [5753 1.3 [6339 1.62 [5730 1.86 [328 1.09 [2913 2.02 [4564 1.87 [7600 0.849 [7692 2.33 [4154 9.07 [616 3.6 [7618 0.627 [429 60.4 [1079 2.3 [4801 3.94 [4396 0.666 [3485 9.35 [4422 3.4 [7251 0.725 [6742 1.12 [1239 5.43 [2790 4.13 [23 14.9 [2331 2.04 [2207 1.58 [4012 3.27 [610 8.47 [6853 3.03 [6436 6.02 [968 1.31 [14 41] [2752 29.9 [4851 13.8 [663 8.86 [28 58] [28 57]] [32 53]] [28 83]]] [2259 8.83 [14 74] [14 100]]] [6859 39.5 [695 1.47 [28 83] [1078 24.9 [28 100] [28 90]]] [28 60]]] [28 100]] [28 100]] [3 50]] [32 92]] [6732 16.5 [216 12 [23 77.4 [7149 3.14 [7615 4.98 [4312 4.41 [14 66] [3 80]] [3 100]] [14 50]] [2259 9.08 [14 42] [3 76]]] [6199 11.8 [3 82] [3 87]]] [28 61]]] [14 100]] [1116 2.65 [7314 9.92 [968 2.18 [7210 1.53 [1078 8.89 [2048 6.33 [4444 10.1 [7140 2.15 [3 58] [3 85]] [33 27]] [3 50]] [14 42]] [14 29]] [28 68]] [3 75]] [3 100]]] [28 100]] [28 73]] [32 45]] [32 100]] [28 93]] [32 100]] [28 80]] [3008 11.5 [1769 18.2 [916 1.03 [3 67] [3 100]] [21 40]] [28 46]]] [20 100]] [915 2.65 [3 95] [3 100]]] [685 2.49 [4170 2.62 [3008 7 [4288 2.16 [2081 5.65 [32 32] [3 73]] [32 83]] [32 83]] [32 100]] [28 77]]] [2259 5.23 [14 89] [32 65]]] [32 90]] [3 72]] [550 2.62 [4680 16 [2002 3.11 [5693 1.95 [6260 2.86 [429 56.5 [4383 4.2 [2143 12.3 [6853 4.42 [6091 2.35 [1078 20.3 [32 69] [32 91]] [32 97]] [32 85]] [3 80]] [32 100]] [3 58]] [3 91]] [32 100]] [3 100]] [3 85]] [32 100]]] [968 0.931 [1664 8.02 [534 1.31 [14 60] [3 94]] [3 77]] [28 91]]] [4171 2.96 [32 97] [32 100]]] [6340 3.97 [28 66] [28 92]]] [975 0.422 [1239 20.9 [4898 7.47 [4561 0.701 [7665 5.56 [1078 6.07 [7413 1.79 [2753 5.62 [221 10.2 [5019 2.83 [6524 5.68 [28 54] [28 80]] [28 88]] [28 96]] [14 81]] [28 50]] [5813 8.86 [2796 5.08 [203 1.98 [631 0.383 [1980 18 [7255 0.885 [6294 0.414 [4956 7.91 [28 89] [28 71]] [28 100]] [28 63]] [28 45]] [28 100]] [14 50]] [28 70]] [28 62]]] [7548 3.11 [32 44] [14 75]]] [32 40]] [14 100]] [3 77]] [631 17 [28 100] [28 90]]]] [717 0.267 [2259 9.26 [28 100] [28 92]] [28 100]]] [7449 21 [4369 2.02 [32 97] [32 100]] [32 85]]] [7318 1.31 [4218 1.01 [3 95] [3 100]] [3 100]]]] [5034 5.16 [3726 11.9 [5011 0.503 [2752 1.56 [2923 5.79 [810 1.82 [7210 4.07 [3708 0.17 [4364 14.2 [777 1.52 [2701 3.31 [4327 4.13 [4154 21.4 [27 75] [27 26]] [19 30]] [29 90]] [27 100]] [15 50]] [35 100]] [27 50]] [27 100]] [26 42]] [3003 0.978 [2701 2.37 [328 48.7 [1429 19.2 [1157 1.08 [3527 6.67 [1899 21.7 [3027 3.55 [27 24] [27 90]] [2 34]] [27 100]] [27 100]] [28 21]] [25 50]] [29 84]] [27 100]]] [29 100]] [32 100]] [32 76]]] [6298 2.59 [5500 0.293 [871 1.19 [5759 1.39 [5462 1.96 [22 54] [30 85]] [7285 14.3 [4703 1.9 [221 0.114 [1862 0.169 [1239 2.11 [30 93] [30 100]] [30 100]] [30 100]] [30 80]] [30 80]]] [30 100]] [871 0.444 [1937 7.17 [6636 0.115 [1454 8.35 [30 100] [30 85]] [30 100]] [30 77]] [4398 7.93 [28 57] [30 97]]]] [2259 85.7 [31 100] [31 71]]]] [5041 0.816 [505 1.19 [6092 1.65 [802 13.1 [6199 15.8 [1906 13.4 [1285 3.12 [3130 7.58 [695 7.51 [4810 1.13 [6015 2.13 [1332 5.87 [7139 2.96 [504 6.67 [4407 3.5 [553 1.9 [791 27.1 [7032 2.04 [1429 10.9 [21 100] [21 93]] [21 100]] [21 97]] [21 100]] [9 55]] [21 71]] [21 100]] [9 100]] [21 97]] [21 100]] [21 100]] [21 87]] [9 62]] [21 71]] [21 62]] [5918 1.98 [4417 6.96 [5042 12.5 [1769 8.99 [21 100] [21 77]] [688 6.85 [21 88] [21 100]]] [21 92]] [9 83]]] [9 53]] [9 67]] [5927 0.811 [806 27.3 [660 29.4 [915 0.464 [5249 1.12 [5303 50.5 [4663 31 [4154 0.822 [2179 0.989 [905 2.15 [7452 1.03 [1986 1.14 [7451 2.99 [6184 42.9 [21 99] [21 97]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 98]] [21 68]] [21 100]] [21 100]] [21 75]] [21 92]] [21 100]]]] [5734 1.54 [1745 0.365 [4369 3.75 [4396 0.273 [6581 2.33 [4042 1.3 [5742 2.73 [2902 0.0505 [3008 8.85 [3606 3.4 [802 4.64 [87 5.21 [4398 5.59 [1783 53.9 [4030 0.298 [6184 8.07 [73 3.88 [5034 0.346 [3458 0.539 [377 0.179 [5745 4 [5753 2.37 [2939 5 [6416 1.78 [3972 11.9 [865 1.44 [5314 4 [6621 1.53 [241 3.11 [5005 5.88 [3368 0.64 [6413 2.07 [5462 2.03 [907 1.89 [5601 5.56 [1101 0.784 [1761 9.43 [7081 1.51 [5007 22.5 [4012 4.76 [728 2.06 [7340 1.15 [2913 0.731 [429 0.125 [28 31] [28 50]] [3 33]] [32 100]] [8 40]] [28 100]] [15 90]] [28 91]] [14 92]] [28 60]] [14 50]] [3 57]] [4200 2.28 [7210 1.16 [2759 10.7 [28 80] [28 100]] [28 50]] [28 87]]] [13 30]] [36 100]] [7 100]] [15 100]] [7449 1.44 [4704 2.7 [28 97] [28 57]] [28 87]]] [19 50]] [13 81]] [15 100]] [13 100]] [15 25]] [6652 7.21 [1986 6.78 [28 76] [28 100]] [28 71]]] [1078 6.67 [15 94] [15 100]]] [4205 12.6 [4332 2.44 [6300 2.98 [6389 2.34 [377 19.2 [4663 1.52 [1906 1.61 [685 27 [112 0.345 [4205 1.25 [1062 0.343 [1429 76.4 [1980 1.78 [5007 8.02 [28 100] [28 83]] [28 100]] [28 84]] [28 100]] [28 100]] [28 100]] [28 66]] [28 85]] [28 81]] [28 80]] [28 82]] [28 100]] [28 71]] [28 75]]] [15 85]] [144 10.7 [7317 0.87 [7252 2.03 [2420 1.8 [1206 0.244 [7585 2.15 [5368 0.346 [534 1.67 [7198 0.384 [906 0.816 [5809 4.41 [2259 9.8 [23 4.88 [28 90] [855 0.813 [5753 1.6 [791 2.37 [28 90] [28 100]] [28 100]] [28 100]]] [28 75]] [28 60]] [28 97]] [28 100]] [3 100]] [5753 2.87 [28 100] [28 83]]] [14 100]] [28 94]] [19 44]] [28 100]] [28 100]] [28 69]]] [13 100]] [6077 2.07 [2259 4.68 [28 54] [28 87]] [13 100]]] [36 95]] [791 12.8 [6294 4.13 [5943 0.388 [13 57] [28 100]] [32 60]] [13 100]]] [31 67]] [13 95]] [791 15.7 [3 81] [21 64]]] [15 100]] [5567 2.37 [178 5.28 [6524 3.07 [3008 31.2 [6382 2.56 [28 38] [14 90]] [36 45]] [28 100]] [6 75]] [14 100]]] [2526 0.925 [5673 1.8 [6709 1.89 [864 2.22 [377 0.179 [6363 0.96 [23 17.3 [7081 0.266 [28 94] [28 100]] [28 89]] [28 93]] [5632 2.21 [7169 0.38 [1911 0.283 [2903 2.99 [28 100] [28 80]] [28 100]] [28 100]] [28 85]]] [1239 1.94 [28 100] [28 72]]] [28 91]] [28 50]] [28 50]]] [32 45]] [36 100]] [6977 0.686 [17 42] [17 88]]] [2143 3.07 [3698 0.146 [906 2.76 [4154 8.23 [28 100] [28 87]] [28 85]] [28 100]] [28 66]]] [7185 3.81 [957 1.18 [6416 1.93 [6681 1.11 [7343 6.09 [32 79] [32 100]] [32 100]] [13 100]] [32 100]] [13 33]]] [1564 7.62 [5941 1.62 [14 34] [14 57]] [3 42]]] [5734 42.5 [2526 26.1 [4997 0.818 [3 42] [7 100]] [7 58]] [6 77]]]] [78 2.56 [7460 1.9 [296 3.11 [7514 0.586 [4288 3.83 [4799 2.39 [2799 3.5 [4218 8.13 [5994 1.12 [5412 3.91 [6031 6.86 [7512 4.35 [2704 0.675 [2772 2.11 [6389 17 [6363 1.9 [132 1.96 [144 37.4 [112 4.33 [7169 1.2 [791 10.2 [19 28] [28 23]] [38 33]] [2701 6.02 [37 20] [29 95]]] [159 5.15 [2143 13.5 [6544 6.49 [3905 3.67 [19 13] [32 44]] [14 60]] [12 37]] [2 37]]] [32 38]] [22 50]] [28 66]] [32 91]] [29 100]] [144 21.4 [1888 2.3 [5 14] [13 52]] [19 15]]] [22 96]] [28 33]] [29 100]] [13 70]] [26 90]] [32 76]] [32 36]] [3548 1.95 [2846 11.8 [7301 5.88 [6513 1.77 [4235 0.787 [1912 0.282 [5021 0.975 [4754 0.094 [1646 3.48 [5899 1.89 [2276 26.7 [663 3.53 [4680 13.6 [144 94.3 [1459 1.95 [2526 2.97 [7169 0.464 [1429 17.2 [1982 7.41 [7009 17.4 [19 73] [13 55]] [1982 19.5 [19 91] [19 68]]] [2108 0.903 [42 58.7 [1899 22.5 [2161 0.411 [176 1.56 [4279 11.7 [19 57] [19 76]] [19 53]] [19 84]] [19 45]] [19 37]] [13 50]]] [19 85]] [14 42]] [19 42]] [22 77]] [31 42]] [42 58.1 [28 50] [13 54]]] [14 42]] [18 83]] [16 22]] [19 28]] [13 44]] [14 36]] [7665 1.27 [19 40] [2 33]]] [18 42]] [19 40]] [1429 6.67 [22 55] [22 90]]] [4 37]]] [32 100]] [29 100]] [7169 2.53 [172 7.37 [169 43.6 [2251 0.304 [19 72] [19 50]] [6201 11.6 [19 44] [19 70]]] [94 7.16 [19 85] [19 66]]] [19 100]]]] [5174 1.08 [2127 1.3 [1888 3.11 [6883 0.877 [1239 94.3 [4089 3.33 [2093 7.66 [2257 0.983 [1646 0.239 [5573 7.09 [3308 15.5 [6320 4.19 [4897 6.16 [2072 1.93 [6459 20 [429 26.9 [234 33.7 [6406 5.56 [6276 1.35 [2068 1.12 [1850 0.145 [361 14.2 [7623 7.46 [4414 0.153 [4253 0.813 [7149 9.51 [1769 0.114 [2753 20.8 [221 0.532 [4703 27.4 [25 99] [25 90]] [25 100]] [25 80]] [25 100]] [25 75]] [25 100]] [25 100]] [25 88]] [25 85]] [25 100]] [25 88]] [25 85]] [25 85]] [25 90]] [25 71]] [25 88]] [25 71]] [25 72]] [25 85]] [25 71]] [25 75]] [25 50]] [25 75]] [25 75]] [25 50]] [25 57]] [25 54]] [25 72]] [25 77]] [25 50]]] [6929 0.222 [415 2.97 [3308 6.34 [2056 0.068 [6082 5.26 [6786 0.879 [1453 0.81 [4704 0.885 [2128 0.505 [159 1.86 [5178 2.18 [221 17.3 [7623 11.1 [5368 26 [6899 7.51 [2259 22.9 [33 65] [4900 21.2 [33 91] [33 75]]] [33 94]] [33 55]] [33 46]] [33 31]] [33 100]] [9 42]] [33 50]] [6457 5.95 [6844 15.7 [6074 6.22 [5701 0.615 [7446 1.66 [5172 17 [5539 10.8 [1943 7.29 [429 4.8 [2178 9.54 [1841 1.6 [143 7.65 [7085 15.8 [7398 8.2 [1457 1.79 [7329 15.6 [6844 0.816 [5889 3.87 [1842 5.1 [7665 0.998 [6082 1.11 [5171 34.9 [2559 17.9 [4956 5.05 [4215 1.11 [6537 8.6 [2964 3.36 [6068 11.9 [1279 13.5 [4517 4.84 [7449 32.2 [2900 20 [2081 0.719 [261 2.47 [1772 26.1 [33 97] [33 87]] [33 100]] [107 1.47 [250 3.19 [33 98] [33 100]] [33 100]]] [33 76]] [33 73]] [33 87]] [33 88]] [33 86]] [33 100]] [33 85]] [33 100]] [33 100]] [33 66]] [33 77]] [33 66]] [33 100]] [33 66]] [33 68]] [33 100]] [33 80]] [33 50]] [33 75]] [33 76]] [33 88]] [33 40]] [33 66]] [33 70]] [33 66]] [33 60]] [33 57]] [33 70]] [7667 0.615 [33 98] [33 100]]] [3 33]] [33 72]] [25 60]]] [33 29]] [30 83]] [13 75]] [1 30]] [11 60]] [1 55]] [429 0.222 [33 78] [23 33]]]] [1309 0.904 [5918 0.246 [6618 0.49 [6703 0.529 [429 78.6 [7429 6.39 [791 23.4 [112 1.8 [5037 0.502 [5753 2.19 [7015 0.154 [743 3.14 [9 63] [21 100]] [9 66]] [21 69]] [9 100]] [1980 0.73 [9 64] [9 100]]] [6191 0.644 [7088 1.03 [21 86] [9 60]] [21 91]]] [21 90]] [6314 0.718 [535 1.27 [6131 1.83 [21 77] [9 90]] [21 100]] [4691 1 [745 0.18 [5193 1.29 [21 98] [21 100]] [21 100]] [21 100]]]] [9 43]] [9 70]] [578 2.24 [4794 1.36 [9 93] [21 81]] [9 100]]] [9 91]]] [7019 0.511 [5827 0.452 [2913 2.16 [567 0.668 [6428 0.265 [2993 6.49 [7354 0.229 [4699 0.902 [5420 0.231 [1055 1.47 [5970 0.525 [3016 1.81 [2562 1.71 [3008 7.41 [7016 0.325 [6722 2.89 [663 4.24 [7441 6.49 [5034 0.966 [6287 1.47 [7010 6.31 [4011 0.411 [2004 1.99 [6683 0.938 [3338 0.846 [5832 1.13 [4690 3.27 [2902 5.69 [384 0.664 [505 0.16 [915 1.04 [6566 6.88 [23 4.04 [4114 7.67 [6155 3.14 [7251 2.26 [5218 2.41 [4851 5.62 [5163 1.19 [2093 9.96 [6031 1.61 [907 4.37 [7619 14.6 [4921 6.17 [7182 2.3 [5225 9.38 [7665 3.01 [2470 7.97 [5753 20 [1599 3.03 [1062 13 [1429 27.2 [6352 10.3 [286 1.87 [939 1.02 [802 9.7 [2694 6.17 [1980 13.9 [6791 9.7 [4235 2.21 [6342 5.78 [30 17] [1 30]] [1 28]] [22 42]] [4154 6.84 [11 40] [22 33]]] [30 62]] [1239 52.5 [21 80] [9 75]]] [29 20]] [23 81]] [11 100]] [2378 6.34 [5192 8.07 [5509 0.644 [30 26] [30 73]] [22 70]] [0 37]]] [11 42]] [11 100]] [2752 9.09 [22 39] [22 66]]] [11 61]] [1239 6.35 [1899 4.34 [30 43] [30 27]] [24 27]]] [1429 4.95 [30 50] [30 81]]] [22 100]] [328 21.3 [30 91] [30 100]]] [13 91]] [21 100]] [6529 1.98 [22 87] [22 100]]] [1429 45.4 [1 33] [1350 1.43 [0 40] [30 100]]]] [30 100]] [705 5.71 [30 41] [12 100]]] [8 58]] [8 66]] [11 53]] [429 27.3 [27 40] [27 61]]] [7176 4.84 [2259 19.9 [5340 5.52 [7759 22.7 [5171 2.67 [4630 0.232 [328 10 [4704 10.3 [7210 29 [30 24] [33 62]] [33 80]] [30 63]] [25 30]] [33 100]] [13 100]] [30 100]] [5225 1.08 [30 61] [30 100]]] [22 35]]] [11 81]] [21 61]] [9 78]] [23 91]] [286 14 [22 58] [23 38]]] [3090 4.95 [4414 10.3 [8 67] [4 75]] [8 100]]] [9 76]] [8 91]] [6686 5.52 [9 63] [9 100]]] [1279 9.43 [2100 9.55 [7061 0.854 [3427 1.68 [6766 0.415 [6970 0.655 [4630 1.01 [2178 1.26 [685 1.3 [5692 3.7 [286 2.59 [23 88] [23 100]] [23 63]] [5368 1.34 [23 97] [23 100]]] [384 0.943 [791 2 [23 87] [23 100]] [23 100]]] [33 33]] [23 44]] [23 83]] [23 100]] [23 100]] [23 27]] [33 50]]] [996 4.32 [8 89] [8 80]]] [30 97]] [1980 9.61 [939 0.8 [11 92] [11 100]] [11 80]]] [6299 4.07 [6757 3.22 [5163 2.22 [4533 2.04 [5918 1.25 [7343 18.9 [1429 89.8 [6199 3.1 [7185 3.48 [1626 3.88 [4876 7.08 [5412 0.525 [5769 1.28 [5692 11.5 [4154 2.92 [6436 1.78 [2081 11.4 [5222 2.02 [6260 5.72 [4061 1.53 [377 9.43 [30 90] [30 100]] [30 100]] [30 50]] [30 100]] [30 75]] [30 100]] [30 75]] [30 85]] [30 100]] [5692 0.645 [10 50] [30 66]]] [30 76]] [30 100]] [30 100]] [2630 1.03 [30 96] [30 100]]] [30 86]] [30 66]] [30 63]] [30 58]] [30 100]] [30 81]] [30 100]]] [11 76]] [70 6.95 [6425 2.9 [5299 3.26 [6389 0.202 [6109 0.47 [22 50] [22 100]] [22 100]] [28 33]] [30 75]] [30 71]]] [30 100]] [22 92]] [4312 6.9 [65 2.88 [7512 13.4 [30 88] [30 53]] [30 100]] [30 100]]] [3224 0.68 [1991 0.975 [4690 2.68 [1013 0.236 [981 0.655 [5828 2.96 [2563 1.38 [3369 4.42 [7119 3.45 [5227 2.89 [3931 4.76 [1919 0.634 [5857 4.27 [8 48] [0 100]] [23 64]] [0 33]] [0 50]] [0 100]] [8 100]] [8 100]] [8 81]] [23 100]] [23 100]] [4455 3.26 [7610 1.77 [6342 8.78 [3269 3.23 [3220 2.33 [6294 1.42 [1436 1.06 [2752 16.3 [2081 3.67 [5692 21.2 [8 94] [8 71]] [8 71]] [8 53]] [8 100]] [8 100]] [8 100]] [8 100]] [8 88]] [8 100]] [0 100]]] [23 100]] [8 100]]] [791 7.13 [24 75] [5211 16.1 [24 98] [24 81]]]] [4414 5.32 [23 95] [23 93]]] [5412 1.47 [11 99] [11 100]]] [7241 0.132 [1062 0.856 [695 4.84 [112 0.778 [407 0.858 [1769 11.9 [5692 6.08 [2081 0.457 [5110 1.32 [1078 16.1 [23 94] [23 71]] [5647 33.8 [22 46] [22 84]]] [23 87]] [22 40]] [8 57]] [23 92]] [22 77]] [22 88]] [440 0.93 [7508 0.855 [2493 1.32 [286 0.438 [685 8.44 [22 57] [23 100]] [435 0.711 [23 85] [23 100]]] [8 100]] [23 100]] [23 100]]] [5110 9.49 [22 93] [8 57]]]] [7142 0.205 [5367 6.34 [7539 18.9 [2093 0.474 [2939 1.64 [1996 0.84 [5491 5.68 [6838 1.06 [4248 2.82 [7522 0.782 [4259 0.902 [2021 4.51 [5136 16.4 [7597 1.21 [4414 1.78 [7163 0.873 [20 97] [20 100]] [20 100]] [20 100]] [20 85]] [20 77]] [20 100]] [20 100]] [20 100]] [20 100]] [20 83]] [20 66]] [20 45]] [4239 3.82 [20 71] [20 100]]] [20 63]] [3404 2.33 [5366 19.8 [20 100] [20 89]] [20 54]]] [20 100]]] [5219 0.816 [8 28] [2502 0.347 [6791 0.477 [1525 1.31 [4601 0.458 [731 1.27 [791 0.608 [8 99] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 87]]]] [1783 6.79 [7512 13.7 [1429 14.3 [30 40] [4984 2.16 [377 9.65 [5393 3.07 [5692 6.76 [2470 2.07 [328 2.49 [30 76] [30 71]] [30 94]] [2470 8.79 [30 100] [30 80]]] [30 100]] [30 60]] [30 100]]] [30 42]] [30 100]]] [1239 10.6 [22 100] [22 85]]] [759 1.07 [2407 0.196 [894 0.407 [4781 2.1 [1215 0.816 [5110 1.2 [5693 5.92 [5753 7.04 [4995 1.77 [1101 13.3 [4235 25.2 [1913 9.23 [5154 1.82 [1429 40.9 [1101 0.589 [1239 8.02 [981 0.754 [23 97] [23 100]] [7508 0.821 [23 90] [23 100]]] [23 100]] [23 33]] [23 85]] [23 81]] [23 62]] [23 77]] [23 50]] [23 54]] [23 53]] [2225 3.02 [5211 22.9 [2023 1.37 [11 55] [11 75]] [5648 18.6 [6184 7.27 [11 50] [11 37]] [22 87]]] [11 88]]] [22 83]] [1253 2.06 [11 90] [11 100]]] [11 100]] [23 100]] [11 90]]] [2241 4.29 [1995 10.5 [429 29.7 [3989 3.03 [6294 2.27 [6391 2.33 [5918 10.8 [422 15.7 [4279 10.4 [2430 8.72 [5642 4.79 [4690 0.852 [1662 6.29 [3251 5.33 [2081 2.47 [1079 7.69 [144 0.444 [286 7.62 [2143 1.94 [7695 0.835 [7321 2.05 [859 9.9 [303 8.15 [1116 0.577 [5225 1.42 [30 92] [30 100]] [30 100]] [6696 2.89 [30 89] [30 100]]] [859 11.8 [30 85] [30 100]]] [30 100]] [30 100]] [30 87]] [30 75]] [2470 0.998 [30 98] [30 100]]] [30 88]] [30 89]] [30 85]] [30 70]] [2752 11.1 [30 77] [30 100]]] [30 75]] [30 71]] [30 88]] [30 87]] [30 60]] [0 100]] [30 73]] [30 55]] [11 36]] [25 50]] [11 28]]] [11 100]] [8 96]]] [4179 0.16 [5472 2.2 [6103 0.162 [1181 1.33 [3557 2.18 [6350 0.57 [701 0.605 [2474 0.373 [2398 0.384 [2748 0.16 [5170 0.3 [685 2.7 [2993 1.35 [1161 1.78 [5972 4.03 [3111 2.2 [2526 0.362 [7741 1.54 [7512 0.281 [1405 2.24 [774 2.62 [248 37.6 [2470 1.61 [7455 0.53 [150 2.73 [5259 6.85 [4374 6.88 [1078 3.85 [2043 0.446 [5467 6.56 [6191 8.35 [3523 4.95 [2002 7.69 [1429 30.3 [5605 1.05 [29 9.72 [2199 8.71 [1906 16.5 [5647 3.36 [5041 2.3 [5312 2.31 [3675 11.9 [15 15] [26 62]] [10 50]] [21 100]] [26 26]] [10 75]] [15 24]] [21 83]] [12 57]] [1454 7.7 [1980 8.32 [32 13] [1400 11.6 [35 35] [3 28]]] [13 27]]] [21 57]] [15 100]] [21 88]] [12 81]] [33 88]] [1401 5.67 [221 4.33 [5843 6.96 [5812 4.81 [1888 0.998 [499 6.73 [83 1.98 [1391 0.797 [2939 14.5 [791 11.1 [791 9.71 [2023 1.95 [328 12.8 [4 13] [429 12.6 [30 55] [27 33]]] [2 37]] [32 45]] [6199 5 [1078 21.2 [15 26] [6091 3.18 [10 45] [12 28]]] [21 60]]] [32 82]] [15 75]] [32 100]] [10 100]] [435 1.66 [32 45] [32 100]]] [12 71]] [10 50]] [28 23]] [12 90]]] [12 69]] [10 100]] [10 100]] [15 61]] [6791 4.51 [2058 0.952 [7649 1.06 [4417 1.82 [1888 2.79 [5753 0.677 [3972 0.248 [5270 2.79 [1062 25.5 [4663 8.04 [7428 0.313 [4168 15.9 [5110 6.12 [1510 5.72 [1980 12.4 [6184 2.44 [4154 11.9 [15 90] [15 100]] [15 100]] [1239 1.56 [15 87] [15 55]]] [15 72]] [15 58]] [15 85]] [15 57]] [15 98]] [15 80]] [31 57]] [15 100]] [15 64]] [1 36]] [15 98]] [15 100]] [15 75]] [15 100]]] [26 55]] [10 76]] [4414 2.44 [7480 37.1 [1400 25.8 [15 100] [429 11.9 [15 100] [15 75]]] [15 81]] [15 100]]] [1219 1.01 [1436 1.39 [939 1.38 [1078 22.3 [5603 1.77 [4154 12.6 [248 12.5 [14 31] [25 36]] [34 10.2 [14 37] [32 100]]] [31 100]] [7210 2.04 [2470 6.51 [7737 1.53 [10 30] [10 47]] [15 60]] [10 77]]] [10 60]] [1980 4.78 [31 41] [31 71]]] [10 86]]] [1429 23.3 [10 80] [14 83]]] [7185 8.7 [429 27.9 [2586 2.96 [7665 9.01 [5871 0.603 [6727 2.92 [248 12.5 [1078 18.8 [5270 1.22 [7665 6.96 [5851 2.95 [4 19] [3 33]] [2 44]] [31 70]] [1239 0.803 [10 62] [4 37]]] [25 56]] [25 50]] [25 75]] [25 30]] [25 92]] [1980 12.1 [23 1.68 [7512 1.11 [688 3.7 [2526 15.2 [27 64] [1429 18.4 [10 40] [2 35]]] [27 85]] [2 39]] [21 27]] [1300 4.13 [10 50] [10 100]]]] [4 60]]] [4283 0.843 [7465 0.914 [15 96] [15 100]] [15 100]]] [2331 1.27 [1546 0.917 [5423 1.01 [6068 22.3 [5467 1.14 [7665 1.51 [5712 1.04 [3603 2.15 [23 38 [917 1.24 [2526 5.82 [4768 23.4 [7085 2.17 [504 2.49 [6727 9.17 [12 48] [15 62]] [15 62]] [15 81]] [12 75]] [12 54]] [21 76]] [12 85]] [12 100]] [12 100]] [5403 1.51 [12 39] [31 100]]] [12 100]] [15 56]] [31 80]] [12 100]] [31 70]]] [5211 1.18 [10 69] [10 100]]] [1239 23.1 [10 28] [5938 1.23 [802 5.09 [21 57] [21 100]] [21 100]]]] [2143 4.76 [1400 22 [6375 2.67 [978 0.393 [26 39] [26 73]] [26 77]] [4279 1.18 [1432 1.12 [673 1.59 [393 2.56 [26 44] [26 62]] [681 3.11 [1011 1.06 [26 84] [26 100]] [26 100]]] [26 88]] [26 57]]] [25 47]]] [5716 0.621 [396 1.25 [1011 2.7 [2259 12 [144 1.39 [2963 2.44 [393 1.5 [7516 1.89 [26 54] [26 94]] [26 100]] [26 87]] [26 85]] [26 52]] [26 77]] [26 100]] [26 88]]] [2268 0.442 [1239 12.8 [5198 0.893 [5776 0.722 [4611 4.31 [2748 5.98 [685 1.26 [26 75] [26 92]] [26 97]] [26 83]] [26 66]] [26 77]] [26 72]] [19 50]]] [2101 0.243 [7287 0.588 [6365 1.04 [7187 1.85 [5972 7.47 [12 74] [12 100]] [4 100]] [12 100]] [12 100]] [12 93]]] [1239 2.03 [7176 1.49 [15 98] [15 100]] [15 100]]] [7731 2.47 [7188 1.27 [1785 0.792 [957 1.15 [10 44] [878 1.15 [10 96] [10 100]]] [10 98]] [12 100]] [36 69]]] [10 100]] [4991 1.26 [472 12.4 [6155 0.684 [5381 2.39 [811 9.43 [7480 10.3 [12 99] [12 87]] [12 55]] [12 100]] [12 100]] [12 80]] [12 100]]] [36 93]] [786 2.22 [4593 0.932 [6768 10.4 [3218 2.48 [5843 0.664 [6581 0.98 [7340 3.84 [5368 4.95 [5206 1.56 [7009 12.3 [1764 14.9 [4071 14.3 [2990 0.162 [701 3.01 [248 2.94 [5447 3.87 [4017 10 [2178 10.4 [5471 0.237 [4235 7.41 [2259 26.3 [5574 0.994 [7453 8.51 [5972 3.48 [12 86] [6729 0.756 [4530 0.787 [6184 0.555 [6342 0.431 [7657 1.72 [5692 0.606 [7409 1.39 [6406 9.43 [12 100] [12 87]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]]] [12 87]] [12 100]] [12 81]] [12 87]] [12 100]] [12 83]] [15 62]] [12 85]] [26 57]] [12 60]] [12 100]] [12 85]] [4 37]] [2752 14.8 [12 73] [12 90]]] [12 85]] [12 72]] [12 76]] [25 44]] [10 57]] [15 100]] [31 100]] [15 100]] [15 81]]] [6184 3.98 [7373 1.14 [2526 13.1 [5345 7.48 [2470 3.76 [7241 18.1 [2232 3.04 [4799 3 [4768 1.16 [7693 1.02 [6199 8.48 [6791 1.22 [2752 37.6 [36 98] [36 88]] [12 50]] [36 77]] [36 100]] [36 90]] [36 78]] [36 60]] [36 75]] [15 86]] [36 78]] [2259 10.2 [9 44] [36 91]]] [36 100]] [36 66]]] [5329 8.93 [3209 0.348 [906 11.8 [1078 28.9 [4430 5.36 [828 0.785 [4768 3.98 [1253 1.82 [4418 1.37 [3218 1.72 [7649 2.13 [2844 3.55 [1403 15.7 [15 98] [15 85]] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 55]] [15 100]] [15 83]] [15 82]] [15 75]] [15 100]] [15 100]]]] [6261 3.34 [13 100] [13 83]]] [7308 0.87 [7381 0.756 [2426 0.3 [5183 0.736 [1740 0.51 [6675 0.938 [2470 1.53 [394 0.817 [673 1.86 [6231 0.377 [685 4.46 [3027 9.6 [5430 1.25 [7659 0.578 [1704 0.883 [3057 0.436 [4309 1.39 [3519 0.978 [6235 2.42 [1116 2.28 [4896 3.65 [874 0.568 [6234 2 [5712 1.07 [7472 3.5 [721 2.05 [5034 2.83 [6471 6.19 [124 1.06 [7354 2.15 [2753 2.98 [826 0.858 [978 2.03 [2751 1.43 [583 2.18 [6530 10.5 [2701 3.67 [5270 1.34 [2826 1.4 [535 2.28 [3892 3.55 [3309 1.04 [4364 15.7 [5467 3.72 [6772 0.84 [5326 9.2 [1333 1.33 [4865 1.73 [6517 3.01 [1400 3.56 [4061 3.15 [574 0.928 [5692 0.924 [5851 25.5 [5564 2.92 [6711 11.9 [6230 6.14 [4279 0.143 [7424 1.81 [7009 5.23 [4630 2.48 [429 19.2 [6342 0.515 [19 10] [15 21]] [5 21]] [13 50]] [22 66]] [19 38]] [19 17]] [6092 2.46 [6569 7.96 [728 20.1 [130 2.88 [7623 1.54 [5844 9.08 [6791 2.62 [1834 3.6 [6848 4.42 [722 21.7 [2526 15.5 [203 3.76 [30 13] [30 75]] [7665 18.2 [5 23] [25 50]]] [7 50]] [5 80]] [33 83]] [3 28]] [32 55]] [34 48]] [4 53]] [14 56]] [3 87]] [32 100]]] [22 100]] [14 100]] [0 55]] [221 1.47 [7734 2.62 [6342 0.901 [5211 5.27 [17 17] [30 62]] [33 50]] [19 71]] [33 42]]] [9 100]] [30 86]] [12 21]] [30 91]] [3 100]] [10 100]] [30 73]] [30 100]] [12 100]] [34 90]] [18 77]] [34 100]] [907 0.898 [21 93] [21 100]]] [791 4.7 [6970 2.3 [5833 3.82 [2811 3.14 [7512 17.1 [2763 2.75 [6124 2.44 [6184 9.01 [429 18.5 [1400 24.8 [6363 1.63 [5 20] [12 100]] [26 61]] [17 28]] [32 37]] [12 84]] [17 66]] [5 40]] [5 78]] [12 66]] [17 90]] [7657 1.36 [3251 0.752 [5693 2.33 [1783 11.4 [1062 1.25 [32 33] [12 38]] [14 70]] [17 29]] [14 76]] [12 100]]]] [6294 1.13 [32 51] [32 50]]] [7185 1.24 [705 3.31 [12 60] [12 100]] [12 60]]] [7 88]] [3 54]] [12 100]] [1078 42.2 [5904 0.506 [3520 2.22 [7009 0.78 [1012 2.89 [862 2.26 [5130 4.34 [3794 3.4 [1429 65.5 [7742 6.95 [1400 8.36 [2268 2.94 [1716 1.66 [688 6.87 [2583 4.5 [429 17.6 [5 25] [5211 2.22 [7712 8.65 [3196 1.41 [6654 2.44 [663 1.92 [3342 1.39 [2764 0.545 [1909 14.3 [5647 7.98 [4154 11.6 [434 1.54 [2913 4 [7689 3.17 [1078 11.1 [5368 9.74 [719 3.54 [6581 16.7 [17 29] [17 58]] [31 57]] [38 44]] [1078 17.9 [17 64] [17 32]]] [458 1.9 [17 80] [17 50]]] [7 61]] [7 27]] [2826 14.1 [5 63] [5 41]]] [1919 5.74 [17 80] [17 37]]] [5 44]] [5 66]] [17 92]] [2259 8.8 [144 4.3 [17 68] [1580 5.93 [4478 4.22 [6230 11.7 [3 33] [17 56]] [19 40]] [17 71]]] [17 38]]] [4766 5.98 [17 100] [17 90]]] [17 77]] [5 80]] [6230 5.75 [23 100] [0 25]]]] [0 100]] [7 47]] [17 92]] [34 77]] [26 32]] [5 65]] [112 2.02 [695 4.97 [2466 3.52 [939 1.49 [602 3.7 [134 11.7 [2913 2.28 [5 49] [5 100]] [17 38]] [17 53]] [5 55]] [17 50]] [17 61]] [17 50]]] [2826 4.29 [19 72] [3905 3.01 [38 70] [16 42]]]] [7 54]] [16 52]] [2259 5.75 [7 91] [7 100]]] [4767 1.04 [4338 3.64 [4218 11.7 [4279 7.61 [1888 11.9 [4110 1.77 [1483 5.1 [5 59] [5 80]] [5 40]] [5 40]] [19 55]] [5 50]] [5 100]] [28 40]]] [2826 9.12 [19 85] [19 100]]] [5637 0.949 [1662 0.506 [19 86] [19 100]] [7 40]]] [35 53]]] [4374 1.72 [1783 0.882 [6242 1.17 [2698 3.3 [1980 9.58 [12 85] [12 45]] [12 100]] [12 100]] [12 46]] [12 100]]] [719 10.1 [1764 2.02 [6535 3.3 [145 15.6 [4573 3.74 [4478 6.67 [7324 0.617 [4946 4.95 [2753 13.2 [5597 0.715 [728 2.37 [5 53] [17 41]] [16 28]] [5 23]] [5 88]] [5 60]] [7 42]] [19 69]] [19 54]] [17 71]] [7 33]] [19 60]]] [3515 1.27 [4154 5.19 [7177 1.78 [4861 5.63 [7590 4.15 [7248 7.73 [23 20.9 [4109 1.13 [7241 18 [6036 1.15 [2929 4.79 [2108 2.82 [7314 6.23 [6970 1.89 [5187 1.96 [5013 4.33 [906 12.4 [6581 1.16 [1913 4.8 [4478 3.21 [1011 4.95 [2628 3.37 [1429 30.2 [5 25] [2259 7.23 [2928 1.55 [939 1.57 [5 56] [5 90]] [5 45]] [5 18]]] [5 80]] [7 53]] [7 86]] [18 36]] [1009 4.8 [978 19.3 [7512 24.5 [5 57] [5 100]] [19 57]] [5 50]]] [5 100]] [19 50]] [7 100]] [18 44]] [7 80]] [16 71]] [5 80]] [7 33]] [18 100]] [5 77]] [2628 2.88 [18 35] [19 50]]] [5 100]] [5 88]] [19 50]] [7 100]] [5154 2.02 [5851 5.08 [7 19] [16 60]] [7 50]]] [19 80]]] [32 100]] [26 84]] [3008 15.2 [3483 1.1 [1429 13.4 [14 43] [1995 1.07 [6045 4.44 [4799 1.95 [3072 1.47 [221 4.5 [14 75] [631 5.57 [30 68] [28 100]]] [32 60]] [32 72]] [14 100]] [28 53]]] [32 100]] [5222 4.76 [30 75] [30 100]]]] [14 65]] [791 5.86 [38 54] [602 2.24 [14 67] [14 75]]]] [663 1.11 [695 6.55 [12 63] [12 100]] [12 100]]] [21 37]] [705 0.412 [12 94] [12 100]]] [2466 4.21 [1745 0.688 [144 7.48 [14 62] [14 44]] [14 77]] [2466 6.42 [32 50] [14 33]]]] [4414 1.39 [30 92] [30 100]]] [2259 19.5 [34 25] [34 86]]] [5907 1.43 [6310 2.26 [494 5.32 [6240 2.95 [2752 29.8 [19 77] [19 53]] [4805 1.78 [19 92] [19 100]]] [19 100]] [19 100]] [19 100]]] [4326 1.78 [32 97] [32 100]]] [7657 0.436 [791 14.1 [6581 3.42 [3675 3.42 [5 76] [3057 6.97 [5 76] [5 94]]] [5 50]] [12 85]] [12 100]]] [2241 2.68 [5673 1.31 [3928 26.5 [3929 10.7 [17 64] [6549 9.25 [17 94] [17 85]]] [7 55]] [19 42]] [19 50]]] [12 100]] [6406 11.3 [1769 0.873 [5 73] [5 40]] [5 50]]] [32 44]] [2259 37.2 [7428 2.2 [1679 3.07 [2752 51.6 [5564 2.39 [1012 3.97 [6862 1.25 [1669 0.846 [407 8.36 [2748 2.02 [5642 2.53 [7737 5.79 [7548 1.1 [7 35] [14 100]] [13 37]] [14 57]] [26 100]] [7 80]] [7 100]] [7 86]] [7 100]] [14 100]] [18 36]] [30 100]] [23 40]] [18 35]]] [7623 4.87 [7255 1.45 [580 1.51 [978 8.76 [5264 2.2 [2831 3.4 [826 6.33 [4279 0.498 [2526 0.967 [5904 6.22 [5412 1.51 [4851 1.03 [6205 3.94 [1429 21.5 [5276 9.01 [10 29] [10 100]] [1679 2.79 [429 31.1 [13 73] [13 100]] [30 79]]] [30 100]] [30 90]] [30 50]] [30 84]] [10 25]] [1239 0.498 [1980 4.28 [30 100] [30 50]] [30 50]]] [12 100]] [22 100]] [13 100]] [25 42]] [21 100]] [826 1.59 [13 55] [12 100]]] [30 94]]] [5174 9.44 [26 87] [16 50]]] [731 0.472 [5345 11.1 [6155 2.53 [26 26] [14 28]] [26 100]] [1400 1.4 [7 62] [26 92]]]] [3346 0.826 [4205 1.1 [7571 1.49 [685 4.26 [6297 0.956 [726 2.9 [328 3 [247 1.79 [7428 4.22 [5846 4.48 [1116 0.396 [4790 1.01 [7583 0.96 [5972 1.99 [3424 2.03 [2616 2.68 [4061 3.48 [144 8.67 [4571 0.426 [6945 4.13 [5034 0.867 [2628 0.971 [1420 1.35 [30 27] [25 100]] [15 60]] [30 59]] [31 100]] [30 71]] [30 63]] [32 42]] [4 77]] [30 44]] [6074 2.07 [31 93] [31 100]]] [25 84]] [31 92]] [30 100]] [31 100]] [12 69]] [30 100]] [6524 5.34 [144 3.57 [6713 0.627 [2526 4.15 [3686 1.57 [429 9.7 [5110 0.792 [30 92] [30 100]] [30 47]] [30 90]] [25 41]] [663 1.18 [30 97] [30 100]]] [2259 20.2 [30 29] [30 93]]] [25 100]]] [31 94]] [2165 0.885 [6977 1.25 [31 93] [31 100]] [31 100]]] [26 35]] [31 100]] [6353 1.05 [2628 1.11 [1679 1.47 [26 78] [30 93]] [30 88]] [30 71]]] [2259 20.9 [31 100] [31 90]]]] [6550 5.65 [5673 4.03 [7169 2.16 [4288 1.75 [30 96] [30 100]] [30 83]] [30 100]] [30 94]]] [7689 0.938 [5034 1.2 [1567 0.856 [5412 2.15 [3905 16.2 [19 44] [17 66]] [32 46]] [1888 1.44 [17 35] [17 58]]] [14 82]] [2939 0.539 [19 74] [5296 0.539 [19 80] [19 100]]]]] [30 87]] [4611 0.571 [7185 0.648 [2701 1.45 [2466 2.42 [791 2.18 [12 66] [7210 3.01 [791 10.6 [12 85] [12 100]] [12 87]]] [12 50]] [12 100]] [12 100]] [12 100]]] [978 15.2 [4805 0.448 [7601 0.659 [6980 0.219 [353 1.22 [485 2.51 [3014 0.297 [6725 1.55 [6575 0.928 [3222 1.97 [6708 3.98 [2470 1.23 [1400 1.75 [141 7.94 [5345 2.61 [5 39] [7241 3.58 [5 83] [5 87]]] [17 36]] [14 76]] [4 100]] [7 93]] [5 85]] [134 6.52 [7512 10.4 [5 100] [5 60]] [5 70]]] [19 47]] [3820 0.963 [3014 14.8 [1783 4.57 [17 67] [19 66]] [1078 11.4 [17 60] [19 87]]] [19 87]]] [1648 2.43 [19 45] [38 60]]] [7 100]] [3576 0.879 [1888 8.82 [17 60] [5 58]] [719 2.86 [5 86] [5 66]]]] [145 0.87 [5732 1.46 [5412 1.56 [2826 15.7 [5 75] [5 55]] [7 71]] [7 100]] [5 77]]] [1632 0.465 [5693 1.87 [2260 0.75 [1783 1.25 [17 44] [17 60]] [19 71]] [4 38]] [19 100]]] [610 0.894 [155 3.63 [7373 8.33 [1557 7.18 [7384 0.935 [6230 13.5 [6557 4.93 [7314 0.564 [6544 0.867 [3563 0.732 [2763 2.9 [5677 5.45 [4588 1.18 [4851 2.22 [5692 3.73 [7241 2.67 [5 26] [7 40]] [5692 5.66 [7 60] [17 50]]] [17 50]] [5 100]] [38 48]] [5 60]] [38 41]] [2260 0.963 [17 38] [17 57]]] [896 4.1 [19 80] [19 33]]] [17 50]] [4479 2.68 [7169 4.38 [17 45] [17 62]] [17 100]]] [17 58]] [7 56]] [5389 2.37 [17 84] [17 63]]] [19 43]] [1899 4.05 [5 80] [5 100]]]]] [31 100]]] [5400 0.445 [4546 0.497 [1180 0.385 [5225 0.935 [2913 0.458 [5403 1.88 [2993 1.78 [4627 0.611 [5694 3.95 [4574 1.36 [2275 0.835 [6529 0.796 [4023 0.818 [6403 0.692 [4168 1.33 [6867 0.631 [6077 0.494 [7373 1.26 [248 7.22 [6569 7.59 [1611 1.03 [7600 0.426 [5757 2.16 [5564 1.31 [5664 4.82 [5980 1.47 [4801 2.06 [3928 0.843 [7501 0.885 [6853 1.39 [2320 3.57 [2509 2.92 [7034 2.7 [2260 3.6 [2331 0.489 [6404 1.5 [7461 2.32 [7533 1.29 [5640 7.41 [5264 1.9 [4021 2.56 [4799 18.8 [4934 4.55 [377 9.15 [826 1.75 [1429 13 [435 4.29 [5267 4.2 [23 2.06 [978 4.67 [13 17] [25 33]] [1 25]] [13 66]] [26 33]] [5316 3.36 [811 2.76 [5270 1.43 [132 2.59 [4624 2.67 [867 3.74 [1557 1.75 [7009 3.68 [5110 7.56 [5510 1.1 [14 36] [14 90]] [12 47]] [13 50]] [14 93]] [13 40]] [14 100]] [32 50]] [36 69]] [36 100]] [32 86]]] [1429 22.8 [12 66] [32 58]]] [14 90]] [14 100]] [36 92]] [36 81]] [13 100]] [13 100]] [14 100]] [12 66]] [36 100]] [36 51]] [5692 4.35 [5972 2.42 [14 36] [36 100]] [36 55]]] [13 87]] [13 100]] [32 65]] [6260 0.935 [36 89] [36 100]]] [32 56]] [14 46]] [32 100]] [12 100]] [13 100]] [14 100]] [29 96]] [1552 0.426 [32 94] [32 100]]] [791 26.7 [14 86] [14 100]]] [14 88]] [2939 6.32 [5413 1.46 [899 13.6 [1899 3.82 [33 32] [33 28]] [25 58]] [29 90]] [1 50]]] [791 23.2 [899 8.65 [6732 1.21 [5472 4.1 [36 77] [36 100]] [14 60]] [14 57]] [36 96]]] [13 95]] [36 100]] [32 100]] [32 100]] [36 100]] [23 25.2 [2902 4.28 [663 8.85 [939 0.398 [1239 1.36 [36 74] [36 85]] [36 57]] [36 95]] [36 75]] [13 37]]] [312 0.835 [434 0.931 [2081 2.38 [36 94] [36 87]] [36 100]] [13 50]]] [32 84]] [14 100]] [2752 28.2 [7657 1.02 [12 83] [12 100]] [12 100]]] [7428 3.39 [5270 0.898 [4030 0.956 [2320 1.07 [2909 1.61 [3646 1.08 [6708 2.62 [36 64] [36 57]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [12 33]]] [4611 4.57 [31 98] [31 62]]] [3907 0.502 [435 0.458 [828 10.1 [1062 4.09 [660 2.63 [4851 3.96 [7695 1.81 [1783 10.2 [1 1.54 [826 3.67 [1783 3.04 [4168 3.6 [2752 6.96 [899 8.42 [32 37] [32 80]] [899 8.63 [32 81] [5034 4.42 [663 4.42 [32 89] [32 100]] [32 100]]]] [32 66]] [32 77]] [23 3.86 [32 100] [32 90]]] [32 63]] [32 60]] [30 100]] [32 100]] [32 100]] [32 97]] [5972 1.27 [32 85] [31 100]]] [23 1.88 [32 96] [32 100]]] [32 100]]] [2902 2.59 [5205 0.53 [30 97] [30 100]] [30 83]]] [13 100]] [36 100]] [1180 0.324 [5605 0.631 [7034 0.532 [7343 0.763 [1899 14.9 [13 100] [13 95]] [13 100]] [13 100]] [13 100]] [13 100]]]] [791 12.8 [4712 3.96 [6220 1.16 [2005 1.31 [2849 10.9 [2616 3.31 [6100 3.05 [1349 5.38 [6 87] [6 100]] [6 60]] [2262 10 [2280 0.0696 [7580 1.45 [2210 6.31 [4736 11.1 [4892 0.775 [221 0.722 [6 98] [6 100]] [6 100]] [6 93]] [6 87]] [6 88]] [2223 0.809 [6 66] [6 100]]] [6 76]]] [6 50]] [7149 1.09 [6 73] [6 50]]] [7149 3.43 [6 85] [6 57]]] [6505 4.39 [6 100] [6 88]]] [6 78]]] [6349 0.364 [4320 0.206 [5827 0.211 [5211 0.528 [3527 2.29 [5369 0.611 [1219 0.197 [5851 1.95 [4331 0.383 [939 6.16 [1460 0.51 [3273 1.94 [4315 2.24 [3633 0.763 [2846 6.25 [4418 26.3 [4170 2.18 [4329 0.419 [4120 3.68 [7340 0.588 [811 1.72 [168 6.33 [3884 6.9 [4332 2.77 [7554 1.43 [2786 0.31 [978 2.92 [5824 2.75 [2488 1.54 [2701 0.229 [296 1.07 [4154 1.45 [3480 1.53 [218 1.42 [3709 0.758 [7441 4.64 [5589 4.85 [1963 9.53 [23 1.63 [820 1.4 [1220 3.07 [2828 0.296 [1094 1.7 [7742 0.418 [2939 8.33 [7052 1.41 [968 0.787 [1163 5.43 [1150 16.7 [2110 13.6 [2421 3.8 [791 1.57 [7354 2.65 [3927 4.67 [701 2.7 [4135 27.6 [1164 7.87 [504 0.715 [1084 3.9 [6801 5.15 [2470 6.56 [2849 9.45 [1116 28.1 [2282 0.732 [1951 5.46 [4444 14 [5099 2.89 [2259 2.57 [5110 28.5 [2052 3.7 [440 2.77 [957 4.35 [2616 7.68 [2154 8.28 [4205 6.33 [6581 4.5 [1078 156 [1242 31.5 [2191 0.617 [6524 7.52 [1 16] [28 45]] [2214 0.603 [1 21] [11 53]]] [23 50]] [2149 57.9 [4418 19.1 [2108 47.4 [1 46] [28 57]] [1 100]] [35 33]]] [17 50]] [27 37]] [35 50]] [2 50]] [4478 9.8 [27 97] [27 100]]] [27 95]] [1 48]] [11 62]] [5242 7.46 [5999 7.46 [1078 107 [7241 6.13 [392 7.94 [3027 7.27 [2232 2.01 [2143 3.17 [6 8] [10 19]] [4 15]] [1 30]] [19 60]] [17 28]] [2752 0.754 [1 29] [33 44]]] [25 58]] [31 27]]] [6 100]] [2201 2.15 [1 76] [1 100]]] [1 44]] [6 53]] [1429 2.99 [30 91] [21 45]]] [29 92]] [15 52]] [6 100]] [27 25]] [27 89]] [4369 31 [31 42] [27 94]]] [27 78]] [10 91]] [8 100]] [18 37]] [5803 12.5 [1783 69.1 [5065 5.26 [7449 0.848 [846 2.44 [774 4.25 [4149 5.54 [906 9.46 [1899 5.73 [2434 8.77 [4011 9.64 [3616 1.15 [3139 0.241 [6445 1.74 [3675 3.65 [5472 5.62 [1980 17.2 [6114 7.94 [5692 7.75 [2252 5.77 [27 18] [32 50]] [25 42]] [29 62]] [2178 32 [11 21] [32 40]]] [36 63]] [35 41]] [35 33]] [11 100]] [27 55]] [28 100]] [36 100]] [36 10]] [32 26]] [23 33]] [27 58]] [35 100]] [1980 10.6 [29 28] [28 23]]] [15 100]] [13 87]] [35 83]]] [36 100]] [1 50]] [35 83]] [10 100]] [855 0.595 [1980 8.81 [28 78] [26 45]] [28 80]]] [11 92]] [10 30]] [4 32]] [2218 4.1 [435 2.72 [4781 0.778 [1 25] [11 83]] [27 45]] [1 92]]] [28 100]] [31 76]] [11 100]] [2050 0.441 [5472 4.59 [430 6.56 [2151 7.43 [660 1.5 [6476 4.92 [2110 0.461 [791 4.96 [6031 5.49 [2241 4.97 [1429 38.1 [1911 41.6 [4533 5.46 [7210 5.1 [6524 3.03 [5906 10.6 [7169 9.38 [3095 0.351 [2149 14.3 [1888 7.78 [1104 4.27 [1 10] [10 44]] [2 41]] [32 50]] [1 57]] [10 45]] [13 100]] [1 72]] [27 25]] [1 50]] [1 71]] [35 25]] [33 28]] [22 85]] [37 14]] [5 33]] [22 100]] [29 77]] [10 50]] [22 44]] [13 100]] [6 40]]] [1 58]] [30 100]] [11 79]] [11 94]] [10 100]] [15 60]] [6960 4.12 [221 5.54 [2466 5.11 [6809 1.82 [4292 2.54 [4231 6.25 [6524 0.975 [4799 2.55 [3177 0.773 [2793 7.94 [2996 2.13 [1429 3.75 [2987 2.86 [27 16] [23 38]] [4601 0.139 [2202 3.58 [3003 2.06 [435 4.47 [906 1.99 [2149 17.4 [5891 2.09 [2181 0.464 [28 17] [15 50]] [14 40]] [14 60]] [28 24]] [23 30]] [27 100]] [2091 1.96 [23 55] [15 50]]] [2225 0.684 [28 69] [28 100]]]] [27 100]] [328 28.7 [27 36] [28 57]]] [8 46]] [4851 5.05 [32 71] [32 100]]] [28 55]] [10 88]] [15 26]] [32 100]] [10 90]] [1995 6.71 [28 50] [28 84]]] [13 100]]] [10 78]] [2704 0.586 [29 87] [144 6.51 [29 100] [29 96]]]] [1112 0.986 [6074 0.527 [13 76] [13 100]] [13 100]]] [1191 9.43 [2752 13.7 [11 50] [11 92]] [11 100]]] [660 3.15 [248 9.23 [731 0.433 [685 1.03 [2470 9.43 [4832 0.813 [2793 2.23 [1089 2.02 [1115 4.46 [655 2.56 [2081 5.68 [2753 9.44 [5692 2.27 [3311 2.35 [6621 16.5 [682 4.85 [7152 8.47 [2241 10.7 [568 13.5 [3008 3.7 [1429 6.37 [23 26] [1605 3.06 [1995 8.6 [7185 3.55 [5 17] [17 27]] [16 16]] [5 100]]] [35 45]] [35 72]] [23 70]] [35 62]] [2 46]] [23 41]] [23 100]] [2 20]] [5 60]] [23 28]] [2 88]] [2 28]] [477 2.79 [5812 7.45 [4 20] [1980 5.03 [2 63] [2 28]]] [4 77]]] [2201 2.07 [23 72] [23 62]]] [6793 2.16 [2 66] [2 100]]] [4 70]] [23 67]] [1888 0.782 [4 16] [4 43]]] [1101 14.3 [394 1.46 [2753 0.534 [4154 0.994 [328 1.43 [4414 2.55 [1400 26 [2799 1.61 [26 52] [26 100]] [25 44]] [16 42]] [4980 8.85 [26 88] [26 100]]] [25 64]] [791 0.534 [26 57] [26 100]]] [26 100]] [19 57]]] [429 19.6 [23 70] [2178 3.27 [23 87] [23 90]]]]] [5007 0.935 [2143 1.85 [29 97] [29 100]] [29 100]]] [10 95]] [2259 25.9 [1429 3.11 [1911 10.9 [2251 2.2 [3003 2.11 [2143 2.18 [27 73] [27 44]] [27 100]] [27 90]] [27 44]] [27 48]] [10 41]]] [4154 4 [15 90] [15 100]]] [19 61]] [1106 1.81 [10 48] [23 40]]] [695 6.1 [1106 9.94 [1108 1.86 [1101 1.23 [791 0.492 [12 23] [7512 1.23 [32 76] [5034 4.68 [32 100] [32 80]]]] [3480 1.23 [32 91] [32 100]]] [32 85]] [2752 18.7 [32 53] [32 86]]] [12 70]]] [499 1.95 [1094 4.35 [2091 17 [27 22] [1 70]] [11 55]] [27 84]]] [27 100]] [32 63]] [1114 8.47 [2913 3.65 [27 53] [15 90]] [27 50]]] [1888 15.2 [2105 2.79 [7522 27.1 [7620 2.99 [2031 3.94 [22 32] [22 100]] [22 100]] [22 75]] [22 57]] [24 33]]] [35 71]] [27 100]] [3277 0.498 [5887 0.578 [1106 3.69 [328 2.26 [3963 5.34 [2752 2.79 [11 33] [2764 2.07 [11 92] [11 100]]] [0 50]] [11 81]] [11 55]] [11 100]] [11 100]]] [27 100]] [3633 9.21 [2180 13.1 [2764 2.48 [1400 7.35 [7491 2.19 [819 0.224 [951 0.593 [2488 1.51 [1233 0.524 [906 3.2 [806 3.78 [3442 0.571 [7512 0.978 [447 0.819 [429 54.7 [448 3.6 [2244 1.46 [2149 4.55 [2130 0.699 [2241 1.61 [2993 2.71 [7340 1.51 [429 14.8 [1 20] [1899 8.07 [7169 6.59 [4772 1.68 [27 52] [15 60]] [27 100]] [1089 12.3 [2081 3.26 [11 26] [28 50]] [27 37]]]] [32 91]] [27 69]] [27 29]] [27 33]] [27 67]] [11 77]] [27 100]] [6272 4.88 [5391 0.69 [2199 0.405 [1062 1.5 [957 1.23 [27 46] [27 100]] [11 50]] [939 24.1 [29 33] [27 66]]] [27 100]] [27 100]]] [27 100]] [5 14]] [11 71]] [32 37]] [906 11.6 [29 35] [27 44]]] [4373 1.01 [1159 0.808 [27 97] [27 100]] [27 100]]] [8 53]] [27 100]] [27 100]] [7505 1.56 [29 46] [27 33]]] [10 41]] [11 51]] [1110 15.6 [27 34] [32 57]]] [35 100]]] [7241 0.461 [2058 4.05 [4329 0.952 [3554 0.568 [2939 10.5 [4135 1.15 [1239 3.57 [3931 6.45 [7449 10.6 [27 71] [15 37]] [27 100]] [12 26]] [27 86]] [15 87]] [27 55]] [27 100]] [27 77]] [27 100]]] [1212 1.06 [957 0.407 [3130 4.89 [4154 9.35 [5851 9.28 [11 16] [27 32]] [1161 0.701 [1995 34.5 [27 50] [27 100]] [27 80]]] [3097 6.16 [27 83] [27 100]]] [1239 8.2 [3027 0.8 [4956 0.649 [7634 0.242 [822 0.25 [1239 0.404 [500 1.27 [4117 1.08 [5412 5.95 [6271 2.99 [27 98] [27 100]] [27 75]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [2752 9.86 [27 100] [27 75]]]] [15 75]]] [7210 8.22 [7512 24.6 [429 5.94 [7512 15.8 [10 46] [36 36]] [939 4.89 [5345 2.16 [10 42] [10 55]] [10 84]]] [7741 1.64 [5244 2.54 [7731 2.56 [1078 62.2 [10 58] [10 92]] [10 100]] [10 100]] [10 100]]] [22 55]]] [3806 0.245 [1617 21.7 [10 100] [10 87]] [10 100]]] [6230 0.871 [2029 2.81 [1239 13.1 [1980 12.5 [1145 0.834 [3406 0.526 [978 6.63 [4124 0.476 [3566 1.96 [2526 2.46 [4331 1.89 [4120 0.581 [7634 2.15 [27 89] [27 100]] [27 100]] [27 100]] [27 100]] [4326 3.08 [27 33] [27 100]]] [27 100]] [4 45]] [27 100]] [27 100]] [2245 5.31 [1992 7.35 [27 81] [27 100]] [10 53]]] [27 45]] [27 38]] [4 28]]] [1055 0.78 [5225 1.25 [7246 0.62 [5655 0.864 [2804 2.18 [7441 0.713 [2343 12.9 [1161 0.971 [3609 5.41 [6920 8.89 [5231 1.19 [6445 3.38 [791 23.8 [5420 0.931 [5693 5.99 [6670 2.54 [7512 10.7 [4520 14.3 [5826 6.75 [5322 11 [2526 9.41 [5034 4.83 [7249 1.99 [6353 0.508 [30 25] [23 42]] [30 100]] [30 83]] [8 79]] [30 72]] [11 81]] [11 100]] [1913 0.835 [23 11.5 [10 67] [22 46]] [20 57]]] [8 88]] [22 91]] [22 51]] [6566 0.287 [1178 1.14 [11 42] [11 100]] [11 100]]] [30 85]] [11 100]] [23 64]] [10 100]] [10 88]] [30 100]] [11 63]] [8 100]] [6660 0.432 [1108 0.291 [5911 4.02 [11 52] [11 100]] [11 77]] [11 100]]] [10 100]] [30 59]] [11 100]]] [11 100]] [6187 0.637 [6092 0.334 [6156 0.886 [23 7.25 [5154 0.513 [6970 1.89 [3616 30.9 [3097 19.6 [2149 39.3 [6026 1.05 [3003 0.134 [2993 5.59 [1899 22.4 [1995 0.261 [7241 1.29 [4125 1.63 [1161 21 [1160 0.684 [957 0.813 [27 92] [27 100]] [27 100]] [27 89]] [27 100]] [27 62]] [958 0.271 [791 0.523 [4369 3.46 [2012 13.4 [27 100] [27 87]] [27 100]] [27 100]] [27 100]]] [27 69]] [10 50]] [27 100]] [10 100]] [27 60]] [27 66]] [27 71]] [10 50]] [27 100]] [10 50]] [5310 0.46 [4320 15.6 [27 77] [10 90]] [10 100]]] [10 100]] [1300 1.79 [10 83] [10 100]]]] [435 11.5 [6294 0.696 [1108 0.287 [4320 0.452 [791 29.3 [5462 2.54 [7737 1.58 [4799 0.935 [3814 2.4 [10 92] [10 100]] [10 100]] [10 100]] [10 80]] [10 60]] [10 100]] [10 100]] [27 50]] [11 36]]]] [7354 0.349 [7307 0.527 [5830 1.89 [1986 0.38 [5865 1.17 [6310 7.53 [978 0.813 [5605 5.03 [939 0.78 [4414 20.7 [2804 4.42 [5235 1.49 [907 1.17 [5211 2.49 [27 32] [791 4.62 [8 66] [0 59]]] [21 100]] [11 100]] [8 100]] [21 83]] [27 60]] [8 83]] [1919 4.7 [5852 1.34 [2628 3.75 [2752 0.624 [1888 1.19 [2526 8.86 [0 76] [6294 17.6 [5219 2.92 [0 82] [2562 14.3 [2488 1.79 [8 98] [8 100]] [8 93]]] [8 100]]] [8 100]] [7185 0.813 [887 4.57 [929 3.18 [1980 4.16 [8 100] [8 66]] [8 77]] [8 80]] [8 100]]] [8 55]] [0 100]] [0 66]]] [0 85]] [0 100]] [1906 1.13 [1997 3.07 [11 32] [21 75]] [21 92]]] [11 100]] [0 100]] [5693 2.79 [1483 0.212 [2259 57.3 [2241 3.12 [4696 0.482 [221 3.63 [6342 16.9 [5224 0.861 [5420 0.39 [5824 8.93 [429 35.7 [8 100] [8 98]] [8 95]] [8 100]] [8 100]] [8 93]] [8 83]] [8 100]] [8 88]] [8 66]] [8 100]] [1482 0.383 [377 1.27 [2571 0.544 [791 21.2 [8 100] [8 70]] [8 100]] [8 100]] [8 100]]]]] [1521 0.574 [4145 0.772 [4342 1.32 [4253 0.931 [2488 3.48 [2517 0.588 [6435 0.177 [2004 0.294 [5820 0.285 [7266 1.19 [2818 0.817 [731 1.9 [1240 1.96 [5034 0.742 [3576 1.61 [5119 0.166 [3714 5.49 [6285 1.93 [3820 5.25 [4214 1.78 [2779 0.207 [6031 0.586 [6582 0.466 [5731 0.147 [741 0.192 [1190 1.36 [1429 15.7 [1157 1.44 [1011 0.567 [5041 1.2 [3442 0.0966 [6730 3.22 [583 0.962 [5473 6.42 [6342 29.5 [1400 3.79 [896 0.915 [6490 0.0357 [3616 3.18 [7665 0.997 [4326 2.29 [852 1.76 [144 4.99 [916 0.504 [3660 6.54 [585 3.76 [6892 1.18 [248 3.02 [939 3.96 [3860 0.57 [4858 2.13 [826 2.36 [3022 12.8 [791 1.11 [4832 3.1 [538 7.69 [6115 4.35 [5308 6.33 [6849 3.06 [6252 4.5 [1051 25 [2944 10.1 [2766 6.86 [2417 2.79 [5815 20.8 [3794 3.64 [6015 21.9 [2518 7.78 [7742 3.31 [1026 4.21 [6926 7.04 [312 11 [1044 0.53 [2752 4.34 [5211 5.98 [2275 7.85 [3240 11.8 [1429 13.8 [2048 3.55 [7169 7.73 [5753 13.2 [1 9] [33 27]] [1783 15.3 [21 29] [9 57]]] [35 50]] [27 36]] [4 77]] [1 66]] [8 55]] [23 23]] [23 88]] [31 36]] [2 94]] [3 50]] [2 47]] [24 100]] [12 37]] [23 62]] [2 50]] [4 87]] [12 38]] [21 83]] [9 38]] [2597 9.43 [4 50] [2 75]]] [6849 11.3 [35 85] [35 100]]] [12 53]] [23 85]] [21 100]] [6927 25.9 [2 63] [2 85]]] [1980 3.14 [929 9.8 [1888 21.5 [429 60.8 [7340 7.04 [245 0.44 [5693 0.705 [286 4.98 [5412 9.2 [4414 11.9 [6199 4.73 [2526 9.92 [2178 2.69 [5824 3.03 [4364 3.7 [23 18.9 [11 13] [22 36]] [23 37]] [11 83]] [21 36]] [2 27]] [21 60]] [11 42]] [28 27]] [23 42]] [2 62]] [9 88]] [32 50]] [21 61]] [2 50]] [23 42]] [1391 6.44 [2752 3.8 [1239 19.8 [2089 5.49 [21 35] [11 66]] [21 66]] [23 34]] [22 40]]]] [24 100]] [6916 1.49 [7085 0.41 [1025 34.3 [11 26] [12 36]] [23 100]] [23 100]]] [23 100]] [11 100]] [1992 1.25 [1 2.18 [5412 1.48 [16 1.61 [1036 1.81 [6957 1.39 [4369 2.79 [3237 1.42 [6653 0.732 [23 28] [11 50]] [11 100]] [27 75]] [27 50]] [35 100]] [27 100]] [23 50]] [11 100]] [27 100]]] [7085 1.29 [2241 2.96 [2081 24.9 [33 45] [15 37]] [14 50]] [33 62]]] [21 100]] [688 1.72 [21 87] [21 100]]] [24 76]] [21 86]] [1783 2.42 [2760 5.56 [1239 7.26 [2 45] [25 62]] [2 36]] [2259 1.44 [2 26] [28 42]]]] [11 95]] [4160 3.94 [1164 1.35 [1899 17.8 [791 1.36 [27 42] [5851 1.38 [27 64] [27 100]]] [12 26]] [27 100]] [2 57]]] [978 16.6 [4674 2.16 [7512 14.7 [5769 4.52 [1436 0.695 [2752 13.7 [7009 7.22 [33 22] [13 44]] [5972 2.2 [2793 2.16 [4 36] [24 83]] [12 45]]] [2 37]] [4 72]] [4235 15 [6098 2.76 [1059 13.1 [13 27] [9 58]] [6 73]] [20 100]]] [6 81]] [2 61]]] [4365 1.15 [1127 1.64 [1089 1.15 [685 3.84 [1129 1.8 [2764 1.87 [2203 0.191 [27 43] [21 55]] [2081 5.34 [11 55] [11 80]]] [27 85]] [27 83]] [27 72]] [27 100]] [23 100]]] [6342 0.562 [23 81] [23 100]]] [6260 2.06 [7185 10.7 [791 7.58 [1919 4.78 [2143 0.792 [4 50] [4 62]] [2 66]] [7544 2.67 [7566 9.43 [4832 2.18 [470 4.59 [7529 1.89 [5659 2 [682 3.3 [663 5.56 [2570 2.51 [2 37] [1 40]] [2 26]] [4 77]] [2 42]] [24 77]] [22 87]] [2 76]] [2 94]] [2 100]]] [4 80]] [7512 16.9 [24 100] [24 71]]]] [2270 0.947 [4370 0.558 [4184 0.578 [826 0.381 [4319 0.626 [2913 1.6 [2616 3.73 [2826 2.35 [7461 2.75 [5419 2.28 [5403 4.76 [5972 1.05 [475 8.26 [4369 2.44 [1980 10.3 [2698 7.25 [978 9.04 [15 27] [2 69]] [12 100]] [10 36]] [10 60]] [10 100]] [1899 7.53 [7453 2.72 [4414 3.7 [7623 9.39 [12 83] [12 100]] [12 100]] [12 100]] [12 77]]] [31 100]] [15 100]] [15 77]] [1078 2.86 [4 88] [4 100]]] [2739 3.27 [1078 6.64 [4 33] [4929 4.76 [2 76] [31 50]]] [4 77]]] [15 84]] [10 100]] [12 46]] [2 84]] [12 100]] [12 92]]] [12 85]] [739 4.2 [791 14.2 [13 54] [13 94]] [13 100]]] [6803 1.01 [4154 11.9 [1 0.358 [6641 0.48 [7425 1.14 [5972 9.62 [793 3.93 [6261 0.921 [7428 2.95 [9 53] [21 76]] [21 90]] [21 81]] [21 88]] [9 88]] [21 100]] [21 100]] [3 100]] [9 85]]] [24 95]] [11 100]] [5042 1.2 [6883 1.28 [21 98] [21 100]] [21 100]]] [312 5.97 [6173 2.88 [1062 12.8 [7566 5.98 [7001 1.51 [5769 6.17 [3531 8.23 [7413 0.886 [429 19.7 [2 21] [429 42.9 [7169 7.14 [2 67] [2 55]] [4 42]]] [2 88]] [22 100]] [4 50]] [2 100]] [4 63]] [2 95]] [31 100]] [7169 5.28 [4 32] [4 88]]]] [6342 4.34 [1062 7.86 [1253 1.58 [4228 1.72 [1025 7.22 [27 90] [27 61]] [10 57]] [27 100]] [27 100]] [27 57]]] [1751 1.02 [2548 2.21 [6521 0.678 [967 0.776 [4417 4.08 [2369 5.2 [558 1.09 [6732 4.74 [4862 0.169 [7512 12.9 [3442 0.517 [435 3.9 [4614 2.28 [1634 1.56 [1405 2.47 [1635 3.13 [906 0.597 [6899 0.272 [4119 4.35 [7433 1.45 [2526 11.3 [6849 2.87 [4149 9.25 [2826 0.644 [1400 5.19 [2793 9.02 [957 16.4 [978 0.837 [2382 6.73 [791 4.13 [5767 5.27 [4571 3.32 [6370 6.66 [5972 6.32 [7185 6.18 [163 2.95 [1813 0.298 [2470 5.89 [5368 1.02 [1 10] [15 37]] [30 53]] [10 22]] [28 55]] [3 50]] [3 38]] [14 81]] [19 71]] [27 37]] [1906 6.81 [3342 11.6 [4781 2.66 [5267 5.92 [4235 6.6 [2526 8.32 [328 4.88 [7381 4.77 [4897 2.32 [2200 6.45 [7623 11.9 [802 3.99 [4011 3.1 [4159 7.28 [3130 0.59 [1043 7.57 [2259 16.5 [28 15] [5972 1.92 [14 12] [36 100]]] [23 75]] [37 20]] [15 70]] [3 33]] [21 50]] [34 41]] [28 60]] [13 66]] [4 61]] [2259 23.8 [1078 5.57 [28 33] [28 45]] [23 33]]] [12 75]] [32 36]] [31 50]] [11 66]] [28 100]] [36 36]]] [12 100]] [2225 1.22 [2081 4.94 [2470 3.94 [429 38.3 [2 24] [4 46]] [4 37]] [23 44]] [23 72]]] [27 82]] [24 81]] [10 28]] [1089 2.4 [5 25] [5 50]]] [27 62]] [35 73]] [7427 5.88 [4154 8.2 [4833 6.13 [5142 3.67 [1454 9.57 [1025 39.8 [6727 0.945 [2143 10.7 [4 23] [23 53]] [2 55]] [1 28]] [23 77]] [2 50]] [2 100]] [2793 2.07 [5819 1.2 [24 50] [2 28]] [6859 6.32 [24 100] [24 86]]]] [24 100]]] [12 100]] [27 90]] [33 84]] [434 0.342 [6569 0.795 [3 11] [12 37]] [1995 0.342 [29 23] [28 66]]]] [14 100]] [15 100]] [13 100]] [29 100]] [7340 2.89 [7461 5.22 [4414 4.04 [2752 26.8 [1997 14.1 [4630 2.72 [978 1.5 [11 47] [23 44]] [11 100]] [24 50]] [23 45]] [21 53]] [23 50]] [32 84]]] [11 100]] [5472 6.34 [7571 1.89 [2913 3.15 [2282 1.09 [5574 11.6 [13 24] [24 61]] [6 100]] [7 33]] [31 62]] [429 20.6 [13 94] [13 100]]]] [3 100]] [791 16.8 [6581 2.76 [4 26] [5 30]] [13 66]]] [1998 1.78 [328 1.09 [12 98] [12 100]] [12 100]]] [850 2.73 [25 30] [13 100]]] [5412 1.39 [12 94] [12 70]]] [2093 0.252 [3439 2.12 [1913 5.59 [28 52] [23 78]] [11 100]] [2764 2.3 [11 75] [11 93]]]] [2259 56.4 [31 33] [31 100]]] [24 100]] [1239 0.606 [1559 1.99 [5597 12.7 [112 0.931 [36 54] [36 100]] [36 100]] [36 100]] [36 86]]]] [5753 6.38 [906 2.1 [2745 2.3 [7419 1.99 [5664 0.763 [2023 1.04 [7491 3.27 [7677 0.678 [6732 16 [144 1.29 [905 3.55 [2 71] [2 75]] [2 92]] [2 33]] [4 40]] [4 62]] [2 80]] [2 100]] [4 57]] [2 37]] [4 36]] [2 55]]] [11 100]] [11 100]] [7665 26.2 [4 100] [4 57]]] [1027 7.3 [917 0.5 [1089 0.637 [7210 1.34 [5883 0.544 [1783 31.4 [859 1.61 [1429 37.2 [2752 14.3 [25 50] [22 63]] [22 100]] [22 100]] [28 33]] [22 100]] [22 34]] [22 100]] [9 50]] [33 70]]] [1049 4.41 [144 2.63 [2597 0.551 [4 46] [2 100]] [4 55]] [2 100]]] [5361 0.362 [6373 2.55 [3644 7.55 [2752 6.59 [33 50] [24 86]] [24 66]] [24 26]] [33 100]]] [791 9.51 [13 71] [13 100]]] [2453 2.16 [24 89] [24 100]]] [26 100]] [11 100]] [2081 1.48 [15 95] [15 89]]] [6709 3.23 [2259 18 [5753 2.76 [5225 0.882 [5036 0.459 [6082 1.15 [5462 2.17 [5730 1.31 [1429 6.88 [3 46] [1025 5.58 [32 46] [28 41]]] [32 100]] [6325 1.7 [3008 0.678 [28 79] [28 100]] [28 66]]] [3 57]] [28 94]] [30 100]] [2199 5.78 [5412 4.65 [28 64] [1899 13.9 [695 0.364 [28 96] [28 100]] [28 77]]] [14 50]]] [7491 6.55 [32 56] [32 100]]] [28 100]]] [3652 1.2 [435 0.377 [2807 2.04 [3016 0.534 [929 1.37 [1047 1.51 [2793 3.09 [23 21] [24 86]] [6732 8.65 [24 90] [24 100]]] [2 30]] [24 94]] [22 100]] [23 21]] [308 10.3 [24 93] [24 77]]]] [6471 0.963 [5978 0.928 [896 5.75 [5403 2.33 [1482 1.69 [7327 1.79 [2453 1.12 [6047 4.77 [1400 0.191 [985 11.1 [3998 1.09 [3328 0.419 [224 1.36 [5597 8.36 [6230 2.86 [2793 1.68 [6537 2.13 [5972 3.82 [2091 2.46 [6342 4.22 [6983 0.998 [7520 0.797 [6367 1.81 [6927 1.42 [4 42] [4 64]] [4 100]] [2 44]] [4 100]] [4 65]] [4 45]] [31 91]] [2 83]] [24 100]] [3929 4.54 [4 30] [17 55]]] [24 58]] [4 96]] [2 77]] [5 80]] [29 45]] [1888 15.2 [682 4.25 [4 73] [4 100]] [4 100]]] [17 72]] [24 100]] [4 100]] [5 100]] [31 100]] [2739 0.745 [2259 6.76 [6538 1.89 [4 43] [2 85]] [2826 4.27 [4 100] [4 76]]] [4 100]]] [31 100]] [731 4.07 [26 71] [26 100]]]] [7495 1 [6665 0.335 [6092 0.548 [4225 0.901 [12 94] [12 100]] [12 100]] [12 100]] [12 85]]] [2608 3.65 [2 82] [2 97]]] [7544 1.26 [2591 0.496 [435 2.58 [178 3.18 [2417 0.952 [7512 16.3 [1190 1.21 [2939 2.72 [1980 0.525 [2 58] [4184 1.07 [2 92] [4 83]]] [4991 1.74 [7324 1.07 [4960 1.12 [2 64] [4 92]] [4 95]] [1640 4.21 [21 42] [2 100]]]] [23 0.531 [2752 12.6 [2 66] [2 100]] [2 88]]] [6077 4.1 [6988 1.42 [6076 3.32 [4 66] [4586 12.7 [2 100] [4 42]]] [2 93]] [6230 2.07 [7449 29.1 [2 44] [4 83]] [4 100]]]] [4 100]] [4832 9.7 [4 100] [4 50]]] [4 58]] [4 100]] [6791 15.9 [6184 0.615 [2081 1.51 [2 94] [2 100]] [2 100]] [2 85]]]] [3474 4.31 [6699 0.939 [286 2.29 [2845 0.543 [820 0.211 [7413 0.132 [1400 1.01 [6491 2.28 [2752 22.6 [906 4.55 [6853 1.41 [2089 2.55 [816 0.347 [3008 3.84 [11 19] [10 36]] [11 42]] [23 68]] [28 71]] [29 42]] [966 2.3 [1918 0.615 [1044 9.88 [7505 0.931 [5693 0.96 [2178 0.693 [5969 1.9 [2199 2.35 [23 88] [23 76]] [23 100]] [23 70]] [23 75]] [23 71]] [23 57]] [23 60]] [23 100]]] [23 97]] [10 34]] [28 64]] [11 100]] [23 100]] [1980 10.2 [791 20.8 [2793 0.998 [23 80] [23 100]] [11 62]] [6360 0.273 [5883 21.4 [286 5.13 [7461 2.16 [23 100] [23 57]] [5412 0.425 [2089 3.87 [23 57] [23 100]] [6115 0.186 [7169 0.316 [23 97] [23 100]] [23 100]]]] [23 50]] [23 100]]]] [29 100]] [7170 1.36 [15 57] [15 100]]]] [11 100]] [5270 1.17 [2342 10.1 [5673 11.5 [7351 13.2 [2411 5.82 [4339 11.4 [7314 0.986 [3653 13.4 [5693 5.21 [5209 5.15 [5267 2.44 [7428 2.77 [5793 1.4 [6449 11.5 [2795 13.8 [144 7.2 [3659 10.6 [5716 6.63 [7373 1.31 [6761 9.18 [429 17.6 [24 100] [24 92]] [24 77]] [24 100]] [24 90]] [24 82]] [24 100]] [24 100]] [24 42]] [24 100]] [24 81]] [6732 1.17 [24 73] [24 87]]] [19 56]] [24 100]] [24 65]] [24 100]] [24 66]] [24 100]] [24 63]] [24 52]] [19 36]] [1389 1.67 [1587 1.9 [6859 1.9 [24 50] [24 66]] [19 50]] [24 100]]]] [466 0.649 [996 0.271 [2494 2.28 [1037 0.644 [1929 1.38 [7712 0.759 [6235 2.62 [7698 0.766 [1180 0.525 [7590 1.81 [6413 3.09 [144 1.25 [7009 10.2 [5219 0.699 [4154 1.1 [13 64] [4154 8.07 [12 44] [8 48]]] [8 100]] [13 91]] [112 4.4 [13 85] [13 71]]] [13 90]] [13 100]] [13 100]] [13 100]] [34 83]] [13 100]] [8 100]] [13 100]] [8 88]] [1493 0.259 [8 69] [8 100]]] [0 75]]] [6744 1.52 [3765 0.539 [184 0.252 [5969 2.01 [2939 4.33 [2740 0.818 [6230 4.03 [2764 10.4 [2795 1.77 [2470 1.58 [3653 2.22 [4765 0.88 [6074 0.212 [6732 0.759 [2553 0.521 [7428 1.25 [5753 1.55 [112 0.967 [2846 2.53 [4256 3.18 [1025 6.38 [1783 0.582 [665 1.32 [2 50] [2 73]] [4 27]] [7449 2.46 [3671 2.93 [6187 14.7 [7381 0.756 [5412 1.51 [663 8.95 [2 56] [2 90]] [2 80]] [2 92]] [2 100]] [2 70]] [2 92]]] [2 57]] [2 100]] [13 50]] [2752 18.7 [2 71] [23 45]]] [4 38]] [2 100]] [7568 3.65 [999 6.43 [573 4.73 [4253 2.83 [1919 1.27 [2 42] [2 88]] [1253 1.65 [2536 0.621 [2 91] [2 100]] [2 100]]] [2 87]] [2 72]] [2 70]]] [1919 14.5 [1997 2.55 [6184 2.34 [2 75] [2674 3 [1047 0.424 [1033 3.07 [4995 0.476 [791 13.1 [1062 0.671 [2 95] [2 100]] [2 85]] [2 100]] [2 84]] [2 100]] [2 75]]] [2 60]] [2 66]]] [9 62]] [24 70]] [4 71]] [24 87]] [23 62]] [4 63]] [4 88]] [6074 8.6 [6989 0.277 [2 66] [5820 0.277 [2 76] [2674 4.51 [2 100] [23 5.62 [6735 2.35 [2 87] [2 100]] [2 83]]]]] [2 66]]] [4338 1.75 [2 48] [4 66]]] [4 46]] [13 100]] [13 80]]] [2081 11.5 [4353 1.94 [4214 8.33 [2525 8.8 [5067 2.68 [4573 3.82 [4279 7.98 [4027 0.945 [209 2.34 [6374 2.09 [1751 1.11 [2324 0.383 [772 5.35 [3016 0.949 [5061 1.77 [791 5.32 [24 83] [24 97]] [24 100]] [24 100]] [24 100]] [24 80]] [24 100]] [24 70]] [24 71]] [24 100]] [24 81]] [24 69]] [24 50]] [1025 29.5 [19 75] [24 85]]] [24 94]] [24 66]] [24 66]]] [1838 1.23 [5833 1.92 [7427 8.02 [5462 2.99 [1919 6.48 [7693 2.44 [4191 4.26 [4678 3.12 [6223 10.2 [4154 2.23 [24 90] [4895 3.58 [3636 14.2 [3642 3.73 [429 5.13 [4347 1.47 [209 0.629 [3660 1.23 [24 94] [24 100]] [24 86]] [24 100]] [1665 0.848 [1927 0.557 [24 99] [24 100]] [24 100]]] [24 94]] [24 93]] [24 87]]] [24 94]] [24 70]] [24 66]] [24 85]] [24 57]] [36 60]] [24 85]] [24 62]] [19 57]]] [30 0.562 [5476 8 [13 100] [5476 8.62 [13 85] [13 100]]] [13 100]]]] [1233 2.16 [695 7.16 [1908 6.33 [3718 1.31 [695 6.44 [4663 3.27 [3381 0.931 [4414 10.7 [5130 0.752 [7085 1.98 [3687 5.62 [3262 2.76 [4781 6.02 [1078 50.3 [37 72] [27 58]] [27 91]] [5154 6.19 [906 1.82 [3262 90.5 [2760 1.07 [3338 5.34 [5647 24.6 [5294 2.33 [4235 1.71 [3492 0.736 [3974 7.04 [957 15.2 [1503 1.26 [37 98] [37 100]] [37 90]] [37 100]] [37 100]] [37 100]] [37 80]] [37 90]] [37 75]] [37 85]] [37 57]] [37 100]] [37 90]]] [37 95]] [37 70]] [16 72]] [37 53]] [37 50]] [37 50]] [35 35]] [37 98]] [37 70]] [2753 5.82 [3779 2.76 [3724 7.89 [2521 1.42 [3191 14.6 [2753 0.816 [707 17.6 [37 98] [37 88]] [37 100]] [37 90]] [37 100]] [37 90]] [37 100]] [2753 7.45 [37 66] [37 98]]]] [27 100]]] [4214 1.4 [1746 0.287 [6581 0.618 [2259 4.75 [2530 0.745 [6869 0.693 [791 12.2 [6538 0.709 [6260 2.89 [6989 0.471 [7197 2.51 [362 0.632 [1883 2.7 [178 3.39 [5654 6.56 [6199 0.763 [5659 0.928 [791 1.13 [7544 7.25 [7568 2.16 [2 21] [2 80]] [2 100]] [24 27]] [2 87]] [4 38]] [4 83]] [4 83]] [2 90]] [4 70]] [2 50]] [2 83]] [24 100]] [2 100]] [791 19.5 [24 52] [2752 12 [2902 4.95 [7067 10.2 [24 85] [24 100]] [24 85]] [24 57]]]] [24 100]] [26 55]] [5637 2.22 [2470 0.873 [1073 7.07 [4851 11.3 [1980 10.2 [25 2.37 [4491 13.6 [2064 5.9 [655 4.03 [7665 3.05 [24 50] [2395 11 [7101 0.661 [4279 7.35 [24 91] [5413 4.87 [1390 1.28 [5675 1.36 [6853 9.07 [24 61] [24 80]] [24 100]] [24 100]] [4 42]]] [19 37]] [24 100]]] [3629 1.72 [7376 12 [24 100] [24 77]] [24 100]]] [24 55]] [24 55]] [24 100]] [1240 0.882 [24 54] [24 100]]] [14 50]] [24 62]] [31 46]] [24 50]]] [4 48]] [24 94]] [7409 0.565 [773 2.7 [6373 2.54 [4339 8.6 [3645 1.09 [1050 13.8 [2342 2.51 [1429 9.43 [3430 0.515 [24 93] [24 100]] [1429 32.4 [631 5.95 [2541 0.96 [4816 3.28 [2793 0.537 [4545 3.66 [24 100] [7381 4.73 [24 75] [24 100]]] [1025 19.8 [24 100] [24 85]]] [4344 2.03 [24 83] [24 100]]] [24 100]] [24 83]] [24 100]]] [24 91]] [24 80]] [3642 0.924 [3665 1.52 [24 90] [24 100]] [19 46]]] [2752 16.4 [24 75] [24 50]]] [208 5.03 [429 7.8 [24 62] [24 88]] [19 87]]] [7512 7.16 [19 50] [19 66]]] [24 66]]]] [3309 0.231 [5005 0.436 [3027 0.252 [695 1.33 [6342 0.131 [7 98] [7 100]] [7 100]] [7 100]] [7 100]] [7 100]]] [7613 0.599 [1036 0.466 [6848 0.96 [5386 2.21 [2434 0.482 [859 0.939 [6393 0.775 [3008 1.24 [5851 0.982 [5753 3.05 [2752 18.4 [6677 3.36 [286 1.51 [7101 2.54 [2628 0.645 [383 2.77 [1078 16.7 [2477 1.3 [1419 2.51 [23 36 [5160 8.34 [811 1.42 [5692 3.62 [1400 1.19 [4703 2.96 [7665 6.14 [4364 5.26 [5732 11.1 [1391 1.09 [2993 2.37 [15 27] [32 60]] [15 66]] [15 100]] [32 66]] [32 35]] [33 40]] [15 90]] [8 18]] [15 93]] [14 55]] [1 16]] [15 100]] [15 100]] [4420 1.56 [15 31] [15 100]]] [7 44]] [31 24]] [35 38]] [23 38]] [35 100]] [4061 2.49 [248 50.7 [5211 3.5 [1 4.78 [4283 0.768 [978 1.79 [802 1.36 [6015 1.47 [4663 7.97 [5972 4.85 [3586 2.99 [2759 3.55 [1995 9.9 [2477 0.982 [6621 7.73 [550 3.18 [328 2.59 [5732 5.53 [3916 1.12 [15 84] [15 80]] [15 100]] [15 78]] [15 100]] [6184 3.39 [15 73] [15 100]]] [15 100]] [15 69]] [35 75]] [15 100]] [12 57]] [1402 4.01 [429 3.6 [15 84] [15 100]] [15 92]]] [15 35]] [4424 0.722 [4664 1.51 [2259 23 [15 100] [15 77]] [15 100]] [15 100]]] [23 26]] [828 0.907 [429 9.88 [15 71] [15 100]] [15 100]]] [15 73]] [30 60]] [26 61]] [30 46]]] [5632 2.33 [15 38] [30 100]]] [7085 9.72 [939 1.9 [1899 6.41 [4684 1.24 [6082 3.96 [4530 5.77 [6134 0.675 [7169 10.2 [1980 17.7 [24 9] [29 62]] [6342 1.71 [4 29] [7210 1.61 [12 16] [27 55]]]] [7 35]] [27 33]] [9 62]] [28 23]] [429 1.53 [2 37] [15 33]]] [27 60]] [23 62]]] [30 52]] [248 0.761 [15 98] [15 100]]] [30 82]] [392 0.964 [30 100] [30 88]]] [6230 1.31 [3 38] [30 88]]] [1980 13.8 [6342 0.378 [2903 6.93 [7742 1.23 [4943 6.68 [144 7.28 [1517 1.64 [4421 21 [7601 1.96 [2058 0.782 [2259 5.93 [7354 3.09 [7255 3.45 [6762 4 [2763 6.46 [4991 15.4 [5023 5.53 [392 7.46 [248 3.7 [5412 10.6 [7169 1.02 [726 4.13 [771 2.7 [6068 9.42 [826 1.98 [7298 1.61 [5462 14.7 [35 63] [35 83]] [35 100]] [35 91]] [35 40]] [35 55]] [35 42]] [35 80]] [12 100]] [35 37]] [35 88]] [35 90]] [30 45]] [35 94]] [12 92]] [35 47]] [5 50]] [35 25]] [35 100]] [5 45]] [35 92]] [8 60]] [5 27]] [5 91]] [5 66]] [5 100]] [5972 4.59 [35 21] [12 83]]] [35 84]]] [6849 54.7 [35 61] [3 44]]] [15 100]]] [7664 6.03 [3308 7.44 [2628 5.48 [6134 1.49 [7314 28.9 [1104 4.09 [4781 4.32 [888 2.04 [7428 8.15 [201 7.06 [7623 13.7 [7139 0.305 [4283 0.226 [2993 6.39 [2488 8.88 [3458 0.588 [5732 1.86 [79 9.02 [6910 1.06 [5491 3.28 [6733 0.671 [2753 2.18 [5066 2.02 [6732 1.29 [4019 1.19 [15 97] [12 66]] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 85]] [15 100]] [15 100]] [12 50]] [15 92]] [15 100]] [15 100]] [15 94]] [15 87]] [12 57]] [15 81]] [15 50]] [15 90]] [15 57]] [15 50]] [15 66]] [15 85]] [15 72]]] [4659 4.34 [2020 1.78 [5641 0.316 [7398 3.07 [906 4.88 [5110 2.13 [5192 1.52 [5643 1.01 [7335 2.25 [7512 3.31 [1877 1.5 [1025 6.66 [292 4.78 [7210 0.659 [7369 6.49 [5154 11.1 [5574 2.86 [6791 27.4 [160 1.46 [2894 3.65 [5170 45.5 [4682 1.35 [5593 5.48 [6845 2.74 [1899 14.5 [5647 15.6 [4253 2.26 [2232 5.03 [23 43.7 [1 90] [1 100]] [1 100]] [1 84]] [1 100]] [5695 3.5 [1 98] [1 100]]] [1 100]] [1 50]] [1 52]] [1 62]] [33 60]] [1 77]] [1 66]] [33 55]] [1 100]] [1 62]] [1 50]] [1 100]] [1 66]] [33 58]] [7561 2.09 [5170 4.23 [7720 1.33 [7623 15.9 [1742 1.46 [1 99] [1 100]] [7583 8.87 [1 100] [1 47]]] [1 100]] [1 75]] [4414 26.3 [1 100] [1 83]]]] [250 2.09 [3333 2.96 [1239 15.8 [1 88] [1980 24.3 [1429 11.6 [1 75] [7335 12.2 [1 75] [1 100]]] [1 63]]] [1 71]] [427 9.49 [1 70] [33 75]]]] [1 40]] [17 0.292 [6537 1.06 [429 3.85 [1 65] [1 100]] [1 90]] [33 63]]] [4656 0.724 [6528 0.858 [1 82] [33 60]] [1 79]]] [328 5.56 [1 40] [33 42]]] [7180 0.926 [7512 5.29 [33 83] [33 42]] [33 100]]] [33 66]] [7642 3.57 [5561 4.34 [1980 15.4 [1 57] [33 100]] [1 57]] [1 55]]] [1 100]]] [5642 0.38 [3639 2.6 [6572 9.46 [4338 2.05 [24 50] [1445 2 [3636 7.65 [5412 3.71 [1899 24.6 [7742 5.25 [939 2.14 [4046 2.57 [3641 14.8 [5274 1.11 [5220 8.73 [5792 34.8 [1712 7.55 [3662 9.53 [3931 5.19 [4357 9.73 [6929 2.37 [6338 6.12 [5425 16 [2827 4.07 [1089 6.44 [2132 3.17 [2453 1.45 [1888 0.602 [429 8.39 [24 100] [24 98]] [24 100]] [4357 0.592 [4029 0.747 [24 100] [24 83]] [24 92]]] [24 80]] [24 91]] [6265 6.98 [24 70] [24 100]]] [24 78]] [24 66]] [24 83]] [24 72]] [24 87]] [24 62]] [24 71]] [24 81]] [24 87]] [24 71]] [24 72]] [24 66]] [24 71]] [24 62]] [24 77]] [24 78]] [2752 26.1 [24 71] [24 100]]] [24 57]]] [24 62]] [24 54]] [24 57]]] [906 0.0287 [4853 0.0394 [1078 22.4 [6732 0.389 [4776 0.446 [5647 26.7 [1842 1.04 [2039 3.39 [131 1.39 [896 0.575 [5455 0.734 [5622 0.678 [2108 0.156 [7428 4.94 [1239 58.5 [4114 0.404 [4414 6.57 [2081 5.72 [29 47] [29 87]] [15 21]] [27 30]] [4 57]] [12 50]] [29 57]] [1841 5.06 [13 50] [11 50]]] [29 100]] [14 35]] [1078 11 [29 91] [29 100]]] [4 53]] [4 46]] [23 43]] [4533 0.605 [2005 0.516 [1986 1.39 [19 13] [15 62]] [23 57]] [22 33]]] [392 1.44 [5472 1.36 [2 30] [13 100]] [28 57]]] [7197 4.01 [434 0.334 [6122 9.96 [2760 0.295 [5378 1.57 [2243 2.28 [978 4.26 [695 5.45 [3325 1.47 [4770 0.486 [5211 4.65 [435 2.38 [4414 7.46 [2225 0.855 [5753 4.05 [23 2.12 [5455 1.05 [29 58] [29 100]] [29 87]] [12 30]] [29 100]] [4424 1.92 [27 81] [29 57]]] [1101 5.14 [29 66] [4768 32.4 [29 100] [29 90]]]] [11 66]] [5007 16.8 [29 100] [29 81]]] [29 100]] [29 55]] [16 18]] [29 100]] [29 100]] [2 33]] [29 100]] [794 0.299 [145 0.657 [4879 1.25 [434 7.41 [29 95] [29 75]] [29 100]] [29 100]] [29 77]]] [29 54]]] [2234 1.85 [29 100] [2199 8.09 [29 100] [29 87]]]] [4154 11.4 [2745 0.349 [688 0.805 [934 0.407 [1078 7.54 [4414 1.82 [429 17.7 [29 50] [29 76]] [15 40]] [7623 2.62 [2146 1.73 [2164 4.81 [221 6.81 [6184 13 [1899 19.7 [4770 0.0287 [5378 0.885 [4663 6.89 [695 2.55 [29 100] [29 85]] [29 83]] [29 100]] [29 100]] [2058 0.198 [1078 28.5 [29 66] [1452 3.64 [23 1.03 [29 96] [29 100]] [29 100]]] [29 100]]] [29 60]] [29 100]] [29 87]] [29 90]] [29 78]]] [11 58]] [12 29]] [23 71]] [29 65]]]] [2062 0.437 [3281 0.532 [5447 2.13 [3597 3.73 [4279 59.3 [5211 1.1 [2470 1.76 [1101 7.36 [3302 1.72 [7197 2.06 [2133 3.5 [5025 1.87 [2130 3 [623 15.1 [968 2.68 [4109 1.28 [5192 15.1 [248 0.216 [2752 15.9 [6152 5.05 [2902 0.669 [2259 54.2 [434 1.27 [1916 16.4 [5931 11.5 [5472 22.5 [1318 5.62 [7305 12.1 [1996 6.63 [2233 0.642 [5299 5.05 [1078 13.3 [6018 4.65 [2628 3.47 [6294 14.7 [6261 4.88 [221 6.52 [3113 0.276 [5972 0.441 [2270 1.38 [5768 0.688 [1899 46.7 [7491 2.59 [4922 0.363 [4210 0.885 [4204 1.11 [5911 41.2 [6883 3.76 [4369 7.61 [5110 1.22 [2023 2.76 [297 0.911 [1899 19.9 [6672 1.93 [5851 14.3 [4292 6.99 [114 1.39 [6074 2.11 [4956 1.82 [6199 0.666 [4282 25.5 [3 100] [2081 4.27 [3 99] [3 100]]] [3 100]] [3 100]] [3 100]] [3 100]] [3 88]] [3 76]] [3 100]] [3 94]] [3 100]] [3 92]] [3 100]] [3 90]] [3 97]] [3 80]] [3 100]] [3 100]] [3 100]] [3 100]] [3 90]] [3 100]] [3 85]] [3 100]] [3 83]] [3 95]] [3 93]] [4279 13.2 [3 100] [3 72]]] [3 80]] [3 90]] [7615 1.8 [802 11.3 [7314 3.6 [791 20.3 [3 58] [3 75]] [3 87]] [3 83]] [3 100]]] [3 75]] [3 66]] [21 37]] [3 71]] [3 88]] [3 76]] [3 66]] [3 50]] [3 80]] [5047 2.01 [3 46] [3 100]]] [3 37]] [3 55]] [3 20]] [2394 0.763 [1239 10 [3 18] [537 4.02 [3 71] [3 100]]] [3 100]]] [3 55]] [13 66]] [3 42]] [3 71]] [24 41]] [35 87]] [35 50]] [4574 1.25 [4154 9.52 [3 64] [3 89]] [3 100]]] [3 50]] [4159 10.2 [3 30] [15 66]]] [15 62]] [620 0.855 [3 47] [3 100]]] [35 31]] [19 50]] [126 0.634 [32 62] [3 95]]] [38 35]] [2062 15.7 [4312 1.42 [3 16] [3 100]] [1 40]]]] [489 1.94 [3274 0.457 [913 0.773 [328 19.7 [5261 1.03 [5692 1.63 [1079 0.901 [3381 0.172 [178 0.942 [1239 1.72 [2470 0.795 [6727 7.66 [2259 4.74 [3042 11.6 [3262 2.3 [1913 4.16 [2207 13.2 [3388 7.58 [2763 4.31 [286 10.5 [4130 2.07 [7149 8.84 [3724 2.01 [7354 2.02 [1899 13.1 [3525 0.545 [1888 5.75 [7512 1.15 [1118 4.21 [7623 11.8 [1078 21.8 [3851 15.2 [3389 6.03 [3042 0.645 [663 12.4 [2542 15.4 [4774 11.6 [35 80] [35 100]] [35 66]] [19 25]] [35 100]] [35 50]] [2 37]] [3332 51.7 [3251 15.7 [2225 2.37 [429 68.5 [3538 4.89 [1511 0.858 [4414 7.32 [1429 49.1 [3540 12 [35 85] [35 100]] [35 94]] [4418 4.39 [35 70] [35 92]]] [35 66]] [35 78]] [35 50]] [1110 1.82 [35 80] [35 42]]] [35 57]] [38 44]]] [35 64]] [2752 10.1 [35 100] [3099 0.873 [35 75] [5023 4.17 [35 100] [35 80]]]]] [35 41]] [35 46]] [35 100]] [35 98]] [13 42]] [13 31]] [35 54]] [38 57]] [35 46]] [35 91]] [939 18.6 [429 30.5 [35 96] [35 86]] [35 80]]] [38 44]] [30 57]] [37 93]] [37 55]] [23 51.6 [2753 4.25 [4154 6.72 [1783 1.27 [1899 3.97 [3234 0.963 [35 32] [35 80]] [4092 5.76 [35 70] [35 100]]] [38 25]] [2752 10.7 [8 36] [32 66]]] [12 57]] [30 77]]] [26 32]] [248 10.2 [3332 3.79 [30 25] [30 68]] [26 80]]] [3748 0.803 [4279 1.54 [1993 0.78 [6653 1.13 [429 22.1 [1587 0.938 [2753 1.81 [1944 2.33 [35 58] [35 73]] [30 57]] [30 60]] [2752 15.8 [35 88] [5 36]]] [33 80]] [35 100]] [2752 7.43 [3 37] [35 51]]] [30 88]]] [5673 4.41 [26 30] [35 50]]] [30 60]] [37 30]] [5693 6.54 [6883 1.03 [6955 2.64 [1084 2.33 [978 0.861 [35 23] [5192 3.35 [26 48] [26 100]]] [8 45]] [26 56]] [5 30]] [35 64]]] [13 100]] [7322 19.1 [1899 4.12 [2161 5.38 [4336 1.99 [5673 13 [35 89] [35 79]] [35 100]] [35 42]] [35 62]] [30 58]]] [328 3.11 [265 5.44 [26 52] [19 66]] [4092 1.15 [26 80] [26 100]]]] [11 100]] [5491 13.1 [3153 23.7 [2225 4.13 [6230 3.36 [4114 2.96 [2259 26.2 [6326 2.69 [2470 1.69 [221 12.8 [771 1.91 [3008 45.9 [5025 1.79 [1055 7 [248 20.5 [685 4.3 [3041 36.4 [1400 1.01 [7097 11.1 [7092 0.0546 [2259 5.87 [3539 8.55 [6199 17.4 [906 0.321 [1094 2.22 [5680 0.554 [5462 0.392 [3861 1.87 [3153 1.17 [35 98] [35 100]] [35 100]] [35 100]] [35 100]] [35 100]] [35 100]] [35 92]] [489 10.8 [35 100] [35 90]]] [35 96]] [3861 1.02 [35 96] [35 100]]] [35 87]] [35 57]] [35 77]] [35 77]] [35 69]] [35 60]] [791 9.03 [35 81] [35 92]]] [35 80]] [35 100]] [35 58]] [35 70]] [35 60]] [35 70]] [35 71]] [35 50]] [35 66]] [35 71]] [35 83]]]] [3089 0.655 [3262 0.952 [5967 2.32 [706 0.494 [632 0.238 [3171 0.353 [2488 1.74 [4326 0.754 [2480 0.556 [978 0.96 [1078 47.3 [1055 0.878 [7411 1.37 [3921 0.928 [6074 0.931 [3292 9.83 [3492 0.514 [5170 8.29 [2759 1.19 [1980 24.1 [7085 0.555 [4895 7.58 [1025 19.5 [3106 0.82 [37 52] [35 33]] [11 66]] [1 37]] [12 27]] [1 42]] [11 37]] [33 88]] [37 48]] [3718 2.79 [429 7.29 [3474 2.86 [3990 4.95 [1783 2.76 [37 58] [11 37]] [37 98]] [37 100]] [2947 5.26 [791 24.2 [3905 3.18 [3492 13.5 [37 70] [37 66]] [3905 33.4 [37 100] [37 83]]] [1239 1.47 [3391 6.29 [3492 26.2 [37 80] [11 53]] [37 100]] [22 30]]] [37 100]]] [37 100]]] [328 4.09 [11 35] [12 27]]] [3700 7.11 [4098 3.94 [3879 1.82 [23 18.1 [3264 10.9 [3615 1.13 [5157 3.11 [4011 19 [3716 0.905 [3907 2.54 [3783 2.2 [3294 3.4 [37 92] [37 100]] [3771 1.1 [37 97] [37 100]]] [37 100]] [37 100]] [37 84]] [37 100]] [37 100]] [37 83]] [37 76]] [3879 11.4 [37 45] [3779 20.4 [37 66] [37 85]]]] [37 100]] [37 57]]] [30 19]] [11 100]] [27 32]] [6544 1.76 [5 12] [17 83]]] [11 100]] [27 65]] [6260 8.47 [5605 0.913 [2081 0.917 [1980 11.3 [8 86] [35 42]] [8 80]] [8 83]] [8 71]]] [2787 3.92 [37 97] [37 85]]] [37 100]] [3781 1.12 [3587 1.96 [4011 1.2 [37 97] [37 100]] [37 100]] [37 100]]] [11 80]] [1089 16.1 [5632 1.66 [2469 1.09 [3633 3.06 [4092 2.6 [3319 11 [1262 1.34 [6719 13.4 [4063 6.48 [328 37.1 [2466 4.51 [708 0.839 [2521 0.212 [429 9.55 [3991 1.59 [3458 0.936 [3113 4.06 [3905 2.99 [4015 1.02 [1239 7.96 [3182 0.08 [3701 9.09 [117 4.06 [1463 2.36 [3692 0.843 [37 87] [37 100]] [37 71]] [37 83]] [37 66]] [37 100]] [37 100]] [37 100]] [50 0.99 [3587 0.0734 [3088 5.73 [37 56] [37 87]] [37 88]] [37 88]]] [37 100]] [37 100]] [37 50]] [6643 0.865 [2488 5.33 [503 4.03 [29 4.73 [2225 0.561 [2844 1.08 [3691 4.2 [3262 26.3 [3781 7.53 [1899 13.3 [49 6.44 [841 2.81 [28 12.6 [1899 1.34 [3867 0.288 [429 32.4 [37 100] [37 98]] [37 100]] [3907 2.73 [3506 0.759 [5267 2.01 [37 100] [37 90]] [37 100]] [37 97]]] [37 70]] [37 100]] [37 77]] [3297 1.14 [37 93] [37 100]]] [836 3.27 [37 93] [37 100]]] [37 86]] [3511 4.29 [429 10.7 [37 64] [939 8.19 [2251 2.44 [2746 4.04 [37 97] [37 77]] [37 80]] [37 62]]] [37 100]]] [37 78]] [37 90]] [4 46]] [37 50]] [37 62]] [37 54]]] [3715 0.885 [706 3.19 [1924 0.554 [4015 1.25 [2752 31.3 [37 94] [38 45]] [37 100]] [37 50]] [37 100]] [4015 0.665 [1179 0.608 [37 87] [37 100]] [37 100]]]] [1429 49.3 [3687 25.1 [3990 0.396 [3292 11.8 [37 100] [3972 0.675 [37 95] [37 100]]] [37 100]] [37 62]] [4016 0.229 [1986 0.456 [7169 0.244 [3772 0.945 [3345 0.805 [2780 5.72 [37 100] [37 95]] [37 100]] [37 100]] [37 100]] [37 100]] [37 100]]]] [37 64]] [38 45]] [37 53]] [37 42]] [37 54]] [37 42]] [101 1.35 [3313 0.756 [3243 3.88 [37 70] [37 100]] [37 100]] [35 58]]] [37 57]] [1533 1.7 [37 36] [37 100]]] [16 66]] [8 36]]] [6199 2.08 [6168 1.61 [3777 15.8 [452 10.1 [3587 0.101 [3912 5.56 [37 100] [3781 0.821 [37 97] [37 100]]] [37 100]] [37 99]] [37 92]] [3771 1.23 [37 75] [37 100]]] [37 97]]]] [968 1.56 [6449 7.74 [1429 113 [1009 0.0878 [5218 4.07 [3056 0.848 [4696 0.124 [3124 0.726 [1495 0.377 [2331 0.581 [328 1.21 [3198 2.65 [5114 1.34 [2575 1.25 [8 99] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 95]] [8 100]] [8 88]] [8 75]] [8 71]]] [2862 0.418 [6499 2.5 [1303 4.38 [7241 1.69 [1997 2.79 [1349 13.7 [5579 4.92 [3020 0.554 [6287 11.3 [5984 0.159 [7405 3.4 [5397 11.1 [6166 1.51 [6422 0.408 [4449 7.72 [2599 0.474 [2436 0.637 [7675 22.6 [2752 0.81 [5358 8.77 [7416 1.87 [2282 12.4 [5093 0.617 [7540 0.633 [6 88] [4716 0.422 [6 96] [6 100]]] [6 100]] [6 86]] [6 100]] [6 83]] [6 25]] [6 83]] [6 100]] [6 80]] [6 80]] [1919 13.6 [5983 0.215 [1374 0.18 [2602 4.42 [7580 3 [2526 80.8 [6 98] [6 87]] [6 87]] [6 87]] [6 100]] [6 100]] [1883 1.39 [6 86] [6 83]]]] [4449 1.17 [7255 0.381 [4713 0.564 [6 100] [6 58]] [6 55]] [6 100]]] [2029 5.56 [6 89] [6 50]]] [429 11.4 [2388 4.03 [6801 0.398 [6167 7.08 [2549 9.64 [6 100] [6 85]] [6424 3.6 [6 96] [6 71]]] [6 100]] [6 93]] [6920 0.83 [6 100] [6 90]]]] [5984 14.9 [6 100] [6 81]]] [7512 8.11 [18 55] [6 95]]] [4737 0.503 [6 80] [6 62]]] [6 57]] [16 57]] [6 64]] [18 42]] [2566 14.8 [2275 7.52 [6 73] [6 50]] [6 100]]] [5577 0.736 [5717 1.77 [7259 0.962 [6100 0.472 [2549 11.4 [2030 9.82 [1911 1.36 [2079 1.5 [2275 8.28 [6 93] [6 80]] [6 100]] [6 66]] [6 75]] [6 79]] [2616 11.2 [6689 2 [7234 0.234 [6 95] [6 100]] [6 71]] [6277 9.29 [5597 4.91 [6 83] [6 69]] [16 60]]]] [6 61]] [6 100]] [16 62]]] [6 50]]] [6256 1.42 [2241 0.353 [7324 1.36 [5632 0.0659 [2983 0.728 [5736 2.94 [2955 0.479 [7261 0.542 [6538 0.659 [4535 14.6 [6184 2.29 [978 2.99 [4851 9.83 [1922 4.22 [3088 0.576 [4549 4.67 [2637 3.11 [23 12.6 [1919 1.06 [1400 0.742 [2340 2.13 [4006 0.768 [4832 3.5 [2695 1.44 [5220 4.59 [5812 0.625 [6124 2.89 [2688 5.15 [6809 3.55 [4889 3.65 [7611 3.65 [2649 0.703 [2957 1.74 [6284 4.27 [3929 1.38 [695 3.69 [499 2.24 [1698 1.28 [5972 4.21 [6471 1.25 [6578 4.67 [3779 3.14 [6409 2.89 [4092 2.46 [819 3.27 [7268 3.5 [6874 2.67 [3658 6.33 [812 6.56 [4655 5.75 [190 3.23 [3554 4.56 [6960 2.92 [6653 8.52 [7267 5.85 [1640 0.423 [896 9.53 [5447 4.83 [196 2.2 [4605 5.49 [2359 6.02 [2562 2.82 [3990 6.33 [6758 2.79 [2412 9.09 [968 2.83 [6207 36.8 [6238 10 [7032 18.5 [7421 8.74 [6983 6.85 [6159 24.5 [2526 4.91 [5626 13.4 [3622 4.2 [301 16.6 [429 6.25 [6643 8.2 [2897 42.3 [6208 7.59 [5831 11.2 [3107 22.7 [1224 6.55 [2939 40.6 [1429 40.4 [2011 2.3 [324 0.935 [2470 6.72 [2939 17.2 [33 8] [7149 20.3 [3027 9.67 [26 9] [35 28]] [6 25]]] [31 40]] [15 50]] [25 26]] [2629 5.35 [5 10] [7 77]]] [2683 10.4 [3095 27.6 [38 31] [27 54]] [16 46]]] [2 87]] [2939 8.2 [5 77] [5 100]]] [15 100]] [38 58]] [1896 12.1 [16 46] [38 42]]] [13 87]] [7301 4.76 [6529 5.05 [5758 0.0827 [2814 2.24 [6766 5.62 [663 14.5 [7168 1.32 [17 4.95 [5034 15.9 [4398 8.93 [2151 0.323 [1911 20 [2944 4.5 [2951 21.5 [1995 12.1 [6732 8.75 [5851 11.7 [663 4.28 [2470 21 [32 7] [4 66]] [10 25]] [27 41]] [6 36]] [27 57]] [38 54]] [791 32.9 [21 64] [24 44]]] [11 37]] [17 27]] [15 63]] [14 90]] [30 57]] [11 75]] [5 30]] [29 100]] [15 60]] [30 75]] [22 50]] [28 76]]] [30 85]] [29 100]] [16 51]] [2470 3.6 [2628 26.6 [24 10] [4 21]] [4 100]]] [38 90]] [4 92]] [6 50]] [31 77]] [17 85]] [38 66]] [1980 17.6 [28 45] [2 25]]] [6 90]] [38 81]] [37 92]] [2752 17.7 [8 90] [23 75]]] [7 100]] [8 92]] [18 44]] [7271 4.07 [31 29] [31 100]]] [5 31]] [4 42]] [4 100]] [2939 16.1 [33 79] [1 45]]] [4154 3.96 [31 66] [31 87]]] [5 35]] [7369 2.44 [38 45] [38 81]]] [426 13.9 [1 95] [1 63]]] [5 100]] [24 92]] [2939 15.6 [20 42] [20 100]]] [4 100]] [27 100]] [35 81]] [16 42]] [37 93]] [31 98]] [310 24.2 [6471 41 [5777 10.6 [5777 9.81 [2939 12.7 [26 54] [3531 2.79 [26 62] [26 100]]] [16 55]] [26 73]] [26 100]] [26 100]]] [6230 21 [12 59] [12 50]]] [25 100]] [27 87]] [6983 5.15 [5034 10.8 [5 16] [2628 17.9 [14 100] [14 80]]] [4 54]]] [1489 4.48 [3779 3.89 [791 6.32 [5 36] [12 65]] [37 100]] [12 100]]] [24 90]] [1899 3.48 [12 35] [12 70]]] [4897 2.66 [1897 5.4 [5753 0.703 [6499 1.9 [6 33] [16 50]] [16 73]] [19 33]] [6 64]]] [28 76]] [2951 5.53 [2849 17 [2616 4.95 [6 58] [6 100]] [6 60]] [6 56]]] [32 100]] [38 97]] [12 71]] [3077 3.13 [2536 12 [3929 0.313 [7363 2.52 [7563 4.85 [7265 0.75 [2398 11.9 [4 25] [12 96]] [4 66]] [5 88]] [4 95]] [12 100]] [4 83]] [17 66]]] [24 100]] [2694 35.8 [30 100] [2696 11.8 [30 100] [30 77]]]] [5816 0.302 [7293 1.79 [2943 5.53 [7169 1.54 [4 70] [12 63]] [2 61]] [4 77]] [4 92]]] [1429 13.4 [791 10 [28 100] [28 72]] [28 100]]] [31 100]] [5817 1.68 [4154 12.8 [729 1.45 [1539 0.752 [5812 0.134 [350 7.2 [2818 0.99 [6578 3.94 [7176 1.5 [7085 10.1 [3117 5.49 [3829 2.49 [7457 6.96 [5467 1.44 [4279 3.16 [6134 1.53 [2939 17.2 [2969 11.3 [31 29] [12 62]] [12 26]] [12 33]] [31 56]] [3557 2.99 [12 95] [12 100]]] [31 80]] [31 100]] [31 100]] [12 50]] [12 63]] [31 100]] [12 100]] [2700 2.51 [12 100] [12 66]]] [6732 2.67 [12 92] [4 50]]] [12 100]] [31 100]] [15 34]] [12 100]]] [6989 5.37 [6926 5.73 [4338 17.9 [4 27] [4 50]] [2 78]] [2 77]]] [2664 7.61 [2650 0.291 [7372 1.07 [7415 1.75 [2696 4.82 [5597 2.87 [2889 7.2 [2651 2.73 [4743 3.65 [4977 16.7 [2377 1.66 [6778 0.715 [5576 3.76 [187 9.43 [2849 6.59 [43 3.63 [429 4.04 [5299 2.89 [5140 8.38 [1980 10.6 [203 6.49 [5769 6.67 [2259 22.6 [2753 13.2 [7665 21.4 [12 27] [19 41]] [5 24]] [36 22]] [23 40.4 [4 50] [4 80]]] [14 63]] [7 16]] [33 92]] [33 100]] [168 10 [2902 10.2 [7512 6.72 [5034 2.82 [1400 2.13 [5412 9.14 [4364 6.02 [12 19] [1 50]] [4 55]] [5692 2.24 [12 89] [12 88]]] [3 33]] [2826 7.09 [4 10] [5 61]]] [5 61]] [36 70]]] [4 100]] [91 1.31 [6831 6.1 [5037 0.744 [2856 9.54 [3928 0.938 [1748 3.73 [187 0.34 [5170 2.73 [7449 22.6 [7422 3.36 [2143 3.55 [166 12.4 [5722 9.04 [194 1.42 [23 74.8 [5626 21.6 [5673 3.94 [5345 14.4 [2862 13.6 [38 34] [38 41]] [14 20]] [2628 35.4 [1429 49.4 [791 8.15 [16 30] [16 57]] [17 36]] [38 85]]] [16 60]] [2851 1.36 [16 21] [16 55]]] [16 46]] [6 53]] [38 60]] [6199 15.4 [38 42] [1 16]]] [16 66]] [38 93]] [16 27]] [5626 0.139 [1899 5.49 [5435 1.02 [38 26] [17 100]] [38 39]] [19 29]]] [38 57]] [37 43]] [16 71]] [16 46]] [1596 4.81 [18 52] [16 66]]] [18 37]]] [2655 1.33 [2853 7.94 [1789 3.66 [2023 3.19 [6830 8.35 [2709 15.2 [16 31] [16 100]] [18 42]] [38 52]] [38 100]] [16 60]] [16 75]]] [7381 8.03 [2 39] [2 100]]] [1769 2.86 [165 6.55 [37 45] [6 50]] [5 44]]] [38 90]] [5900 11.1 [6 78] [16 54]]] [5137 3.88 [7 77] [16 100]]] [1429 2.86 [14 77] [14 100]]] [2850 7.36 [5 59] [5 33]]] [1997 1.17 [2713 11.2 [4725 6.06 [7512 3.56 [16 66] [6 100]] [16 83]] [16 50]] [38 41]]] [2646 4.2 [30 89] [30 57]]] [5141 16.1 [2987 2.04 [33 100] [33 71]] [33 100]]] [2707 5.75 [5681 1.57 [16 75] [16 77]] [7419 16.5 [1896 4.07 [16 96] [16 100]] [16 66]]]] [7150 20.7 [2940 14.1 [3742 1.1 [193 7.4 [5681 5.2 [7445 9.43 [6445 15.3 [7347 9.8 [7260 28.5 [7619 1.79 [16 40] [28 44]] [16 70]] [1895 23.8 [16 64] [16 33]]] [6 20]] [16 92]] [16 73]] [16 60]] [7343 13.2 [26 36] [16 76]]] [26 37]] [6199 30.7 [13 33] [16 55]]]] [28 89]]] [6732 2.47 [6853 2.96 [736 2.75 [312 24.3 [6077 4.81 [3558 4.95 [495 1.71 [3932 2.24 [31 57] [31 91]] [4 50]] [5 33]] [31 100]] [4 66]] [5 50]] [6857 4.07 [31 94] [31 100]]] [1888 0.489 [36 28] [4 52]]]] [31 100]] [791 25.5 [3780 2.43 [1783 5.08 [37 100] [37 83]] [37 92]] [37 83]]] [2081 16.2 [10 87] [10 60]]] [2713 0.725 [7249 1.82 [5219 5.35 [7020 2.39 [1896 1.67 [3051 4.85 [4210 4.95 [1429 21.9 [2939 0.194 [3008 16.2 [4762 7.46 [2656 5.18 [6982 6.34 [3105 5.05 [30 47] [30 100]] [4 100]] [16 40]] [16 42]] [30 71]] [2591 2.28 [429 3.9 [7711 3.88 [2657 6.02 [5931 2 [2470 2.99 [2939 10.2 [1429 2.53 [7 36] [16 71]] [5100 11.2 [7267 3.7 [3936 14.8 [6941 25.4 [7132 13.2 [2959 10.9 [2940 6.85 [16 22] [6 92]] [4 66]] [4 66]] [16 71]] [5 36]] [4 100]] [6 60]]] [4 94]] [16 41]] [4 70]] [5 63]] [4 45]] [4 55]]] [5192 6.99 [30 33] [14 37]]] [30 100]] [7245 2.35 [30 98] [30 100]]] [16 32]] [4 72]] [8 100]] [30 100]] [78 2.2 [304 1.69 [2719 1.64 [6074 12 [5363 7.31 [2351 1.11 [2616 6.02 [6 51] [6 77]] [16 57]] [4738 4 [5 58] [30 100]]] [6 27]] [2628 32.2 [16 30] [6 71]]] [30 100]] [95 4.9 [16 50] [18 45]]]]] [2960 3.21 [5848 0.304 [7365 0.79 [2752 11.9 [695 4.23 [4549 3.76 [2749 1.34 [5769 1.59 [7268 3.28 [2913 2.96 [312 2.32 [1483 2.13 [112 17.2 [7559 3.1 [472 2.11 [5585 8.77 [7133 4.93 [5753 11.4 [7381 1.07 [2977 1.03 [7260 3.22 [3870 1.08 [1062 6.38 [1011 1.31 [639 6.06 [3905 9.11 [4 14] [19 50]] [4 100]] [5 20]] [8 23]] [8 100]] [16 44]] [8 100]] [5812 17.5 [3554 3.02 [5 23] [17 66]] [4 62]]] [33 38]] [4 95]] [31 93]] [17 35]] [31 100]] [19 66]] [8 90]] [527 1.14 [4 68] [4 100]]] [5 60]] [1888 2.2 [2752 6.6 [4 100] [4 57]] [4 100]]] [1919 2.35 [23 0.945 [4 37] [6581 0.531 [791 5.4 [4 91] [4 50]] [4 100]]] [2 64]]] [26 78]] [31 100]] [312 11.4 [7697 1.89 [1769 5.6 [5472 3.4 [7210 1.53 [791 15.6 [7381 13.9 [4 56] [2 35]] [7 27]] [4 81]] [4 66]] [4 85]] [31 100]] [4 100]]] [7177 2.01 [6982 15 [6241 1.27 [2482 1.79 [5522 1.25 [6088 0.971 [5978 1.79 [6396 3.51 [2526 18.1 [2607 2.11 [3517 0.963 [495 4.07 [6732 4.05 [429 23.6 [663 13.1 [1911 1.47 [6342 4.95 [6581 5.25 [4991 3.69 [7742 6.72 [1429 10.1 [26 33] [1980 9.08 [1899 0.707 [19 27] [12 42]] [19 50]]] [5 33]] [12 55]] [5 81]] [7 46]] [5 45]] [19 49]] [6621 4.59 [5412 2.65 [5753 3.43 [112 1.2 [17 20] [17 55]] [5 70]] [1668 1.45 [17 34] [19 87]]] [17 75]]] [4101 3.38 [6588 4.86 [7314 5.12 [7269 0.632 [19 20] [5 50]] [7 33]] [5 100]] [5 100]]] [5 100]] [19 100]] [5 76]] [4992 1.05 [7354 7.01 [6310 1.64 [4288 10.2 [3558 8.65 [407 0.593 [3652 2.92 [4959 3.55 [2966 3.6 [328 4.7 [5648 9.75 [7512 2.67 [4184 10.9 [8 29] [4 43]] [5820 2.93 [4 24] [4 78]]] [2 60]] [4 50]] [4 90]] [4 100]] [24 100]] [24 83]] [7 33]] [2 55]] [17 71]] [5969 3.7 [18 58] [18 78]]] [2 100]]] [3078 8.89 [6395 11.1 [17 66] [21 50]] [17 100]]] [31 100]] [1640 13 [2 80] [2 66]]] [19 85]] [31 100]] [2616 1.98 [7512 20.3 [5753 10.5 [6581 7.44 [5 92] [19 36]] [5 44]] [5 50]] [4478 1.99 [2968 6.21 [5 38] [5 71]] [7 85]]]] [4 97]] [7 100]]] [2595 1.14 [719 7.2 [6230 1.27 [5753 0.867 [2752 13.1 [5817 1.99 [2902 1.36 [5412 7.75 [7363 31.5 [4 100] [4 62]] [4 87]] [4 100]] [4 100]] [1025 0.79 [4 95] [4 57]]] [4 80]] [4 100]] [4 100]] [4 100]]] [4 100]] [6989 1.61 [4586 14.1 [5847 1.65 [4 85] [4 100]] [4 36]] [663 6.77 [6991 1.66 [7665 9.3 [2 75] [978 19.2 [2 100] [2 85]]] [2 100]] [2 50]]]]] [6793 3.32 [7328 6.67 [7133 0.693 [43 0.593 [6982 0.482 [2957 1.73 [2616 0.608 [6394 5.15 [7712 0.963 [2826 2.49 [2570 26.5 [2149 0.818 [144 3.83 [5170 1.26 [2849 36 [968 1.68 [6074 1.42 [1025 2.46 [1429 12.3 [4414 11.4 [25 25] [15 50]] [33 13]] [2 47]] [2 61]] [28 60]] [16 73]] [33 88]] [5576 1.9 [7665 0.77 [2 69] [7512 12.5 [13 50] [2 71]]] [896 6.49 [2 96] [2 80]]]] [4 40]] [4 37]] [5 27]] [2 83]] [15 100]] [1073 1.31 [7009 0.454 [228 1.11 [7512 12.7 [4 54] [2 30]] [7512 12.4 [2 92] [2 77]]] [4835 3.08 [978 13.3 [2 91] [2 100]] [2 50]]] [1429 8.17 [2 90] [4 50]]]] [31 73]] [4253 4.55 [4 75] [4 100]]] [4 95]] [4 100]] [31 100]] [2 100]]] [3121 11.6 [2259 36.6 [38 45] [4562 6.41 [2951 7.01 [7220 14.8 [7222 2.57 [192 2.66 [2862 6.36 [6199 2.76 [7157 6.51 [38 91] [38 65]] [38 100]] [38 71]] [38 60]] [38 71]] [17 42]] [5955 13.7 [2707 6.59 [38 87] [38 70]] [6 42]]] [38 96]]] [17 50]]] [1011 3.38 [2570 18.9 [5368 2.99 [1011 3.11 [4253 15.8 [7083 0.713 [5574 1.11 [2 44] [7568 6.76 [6732 7.42 [5820 7.25 [5576 21.9 [2 100] [2 66]] [2 71]] [2 100]] [573 3.5 [2 100] [2 50]]]] [2 100]] [2 64]] [2 66]] [2 72]] [2 60]] [567 7.68 [140 2.56 [663 5.49 [134 1.37 [2 90] [2 100]] [2 100]] [2 100]] [2 85]]]] [5308 9.12 [791 7.12 [31 100] [31 80]] [31 60]]] [5211 1.43 [1436 0.0578 [7344 0.554 [7123 2.12 [3400 0.705 [6878 0.308 [4426 0.191 [2669 0.821 [5681 1.33 [6098 2 [2327 0.637 [194 3.76 [3107 1.39 [1429 14.3 [5170 1.43 [2713 0.555 [2259 49.8 [4564 4.34 [7512 1.27 [7049 2.33 [4950 4.65 [2656 4.13 [5439 7.8 [4920 1.49 [6372 8.2 [2672 2.16 [167 4.57 [5010 8.44 [5918 57 [2723 14.2 [2707 31.7 [7136 2.05 [5931 10.6 [7139 5.52 [5983 8.75 [2852 0.522 [7134 3.03 [6159 1.38 [5189 7.3 [4478 0.87 [38 54] [5 54]] [38 100]] [38 33]] [7 90]] [16 44]] [16 22]] [38 33]] [6 37]] [38 100]] [6199 1.94 [6839 8.28 [6848 8.08 [2733 3.82 [6721 3.46 [190 27.2 [2685 7.2 [2055 0.694 [6757 52.7 [4851 12 [2720 10.4 [3993 0.665 [6390 7.17 [6375 2.61 [5673 38.7 [3095 4 [4717 11.3 [2948 4.59 [5570 10.5 [38 80] [17 40]] [38 89]] [38 50]] [38 100]] [17 42]] [38 36]] [38 66]] [38 100]] [16 50]] [6 35]] [14 37]] [38 42]] [6 31]] [38 100]] [17 40]] [16 61]] [16 50]] [16 58]] [5874 10.8 [2259 6.63 [38 75] [2849 10.4 [38 75] [38 93]]] [38 92]]]] [16 48]] [36 50]] [7 50]] [38 56]] [16 30]] [16 51]] [38 40]] [16 40]] [16 38]] [7 100]] [2939 37 [16 57] [16 50]]] [16 20]] [14 41]] [2687 42.7 [5957 1.22 [187 2.26 [6825 2.21 [7489 21.7 [38 55] [38 100]] [38 100]] [7136 2.54 [2364 4.33 [38 76] [1429 2.02 [38 95] [38 100]]] [38 97]]] [1980 3.77 [2392 8.72 [16 66] [17 50]] [38 82]]] [38 45]]] [5492 4.07 [4879 21.7 [7423 8.05 [2876 0.834 [6761 15.9 [6 52] [16 76]] [7149 0.834 [16 55] [16 71]]] [6 100]] [6 82]] [14 94]]] [2649 11.9 [26 59] [6 55]]] [6207 21.4 [2862 0.529 [4920 2.21 [1638 0.397 [2681 6.97 [7371 2.12 [2707 45.1 [7475 10.7 [1660 0.605 [4912 6.47 [7726 1.96 [2259 18.4 [2891 11 [6961 7.27 [5099 2.11 [5904 1.04 [1396 9.81 [2722 7.46 [1239 61.2 [6409 4.34 [7343 16.3 [23 45.4 [7619 7.3 [7354 0.734 [1980 6.37 [429 8.51 [1783 14 [2955 9.22 [429 1.09 [38 50] [37 36]] [37 18]] [16 27]] [16 42]] [38 35]] [28 44]] [7 55]] [5 53]] [38 60]] [16 41]] [17 59]] [16 71]] [38 100]] [19 100]] [2861 3.5 [2951 10.6 [6 30] [18 33]] [2707 19.4 [16 72] [28 55]]]] [16 95]] [7 84]] [167 6.1 [4851 1.76 [1895 14.4 [38 52] [5 29]] [6 62]] [14 37]]] [14 41]] [14 64]] [5597 0.605 [16 43] [16 84]]] [38 100]] [1239 46 [38 58] [17 33]]] [2952 0.529 [17 41] [19 37]]] [26 88]] [14 100]] [17 47]] [4563 0.529 [2426 1.31 [7347 5.19 [166 8.85 [7474 0.768 [2466 15.1 [83 0.645 [6207 0.87 [6 71] [5 40]] [5 69]] [16 44]] [6383 4.15 [38 32] [7255 0.891 [38 55] [38 81]]]] [16 42]] [16 100]] [38 83]] [4535 59.8 [38 75] [38 100]]]] [38 77]]] [3897 5.97 [5 82] [5 33]]] [5189 8.2 [7049 1.96 [6761 3.02 [2866 11.9 [5100 4.63 [37 7.52 [1239 16.7 [5901 2.96 [38 39] [16 37]] [6 34]] [5 66]] [6 63]] [37 63]] [6 82]] [16 83]] [38 90]]] [6031 0.358 [5 62] [2889 4.68 [5 85] [5 100]]]] [7224 3.02 [4891 8.01 [221 1.47 [4851 19.8 [2720 4.37 [6 70] [6 100]] [6 100]] [6 84]] [6 60]] [16 50]]] [1919 1.29 [6574 0.956 [5874 0.935 [6422 3.79 [6370 5.76 [5363 16.4 [7038 0.548 [1239 6.01 [5099 2.29 [6199 4.06 [5999 2.29 [6959 5.42 [7390 1.19 [6199 0.0506 [5878 2.98 [6406 8.17 [2178 0.956 [3675 3.41 [95 1.35 [7255 1.17 [38 49] [38 39]] [17 33]] [38 71]] [38 70]] [6 30]] [19 55]] [38 81]] [6 36]] [16 71]] [16 50]] [2656 2.66 [6207 6.71 [38 41] [38 56]] [2867 4.69 [5681 11.4 [6 58] [16 80]] [28 27]]]] [2734 3 [6940 51.3 [2660 7.42 [5641 2.16 [6 42] [16 69]] [7255 11.7 [16 70] [16 50]]] [6 66]] [6 65]]] [6177 15.9 [6432 20.6 [2891 5.86 [7419 2.97 [95 0.379 [7154 1.59 [1660 1.17 [6 29] [6 66]] [18 50]] [2939 26.1 [2951 11.5 [6134 5.05 [5801 3.77 [18 42] [16 47]] [19 57]] [16 57]] [18 37]]] [5637 1.2 [6 50] [2259 2.63 [16 100] [16 71]]]] [7 75]] [7 88]] [7 88]]] [23 8.11 [6 50] [2858 7.4 [6199 6.33 [5681 6.33 [5673 5.74 [16 53] [16 85]] [2282 5.46 [1283 4.2 [7419 11.1 [16 50] [16 100]] [16 84]] [6 75]]] [248 0.986 [2719 0.929 [18 50] [16 87]] [16 60]]] [26 50]]]] [38 84]] [6791 0.722 [1980 1.82 [83 7.27 [16 69] [16 50]] [2259 4.62 [16 47] [16 66]]] [16 50]]] [7038 13.1 [6 84] [16 50]]] [7 42]] [2939 47.5 [5673 4.5 [17 72] [17 92]] [17 33]]] [1239 21.6 [6 100] [6 87]]]] [4956 0.821 [7 97] [7 100]]] [4527 11.4 [2037 0.696 [4851 0.191 [7419 1.12 [16 33] [23 22.8 [16 75] [16 100]]] [6959 5.9 [94 3.56 [5641 2.17 [2951 9.47 [2709 0.191 [2939 30.2 [190 8.27 [6 28] [26 33]] [18 50]] [96 0.475 [6 41] [6 37]]] [2649 6.7 [4431 15.3 [7041 3.43 [2939 31.1 [6 20] [16 42]] [6 50]] [6 80]] [4851 11.1 [16 50] [2259 6.62 [5723 3.53 [5673 10.1 [5102 10.1 [6 62] [7149 7.07 [16 55] [16 75]]] [6 52]] [16 55]] [16 81]]]]] [2951 1.61 [16 88] [4414 6.15 [18 40] [16 77]]]] [18 46]] [2628 20.5 [16 72] [6500 8.53 [1897 6.44 [2849 19.7 [6 50] [5985 14.1 [5681 3.18 [2951 4.51 [6 80] [6 58]] [6 46]] [6 100]]] [16 42]] [16 72]]]]] [6 85]] [16 100]]] [663 0.616 [791 1.58 [1268 3.18 [2849 78.4 [187 3.44 [37 64] [37 34]] [5 62]] [6 66]] [16 30]] [328 0.435 [37 54] [37 87]]]] [1078 12.8 [6031 1.72 [2849 40.7 [2466 4.55 [5 100] [5 72]] [5 98]] [5 71]] [3107 10.3 [3547 2.36 [5 100] [5 50]] [38 44]]]] [4623 10.8 [7354 0.541 [4738 4.44 [4154 8.78 [1400 15.2 [3691 0.715 [2649 11.4 [4731 3.1 [2749 1.4 [2727 1.67 [248 4.93 [2680 1.77 [5716 2.9 [1660 0.363 [1980 11.8 [7167 33.3 [5007 15.6 [5491 1.58 [2728 2.24 [194 7.7 [2939 114 [7104 1.32 [5673 15.6 [5723 0.606 [16 56] [16 77]] [26 75]] [16 48]] [6 25]] [6 57]] [2616 2.89 [2678 2.35 [16 100] [2656 10.4 [1395 2.12 [2178 0.657 [2939 79.6 [6517 1.23 [4728 4.83 [6 48] [16 42]] [16 60]] [7232 49.1 [2853 1.69 [7123 54.6 [7149 5.34 [2733 16.6 [16 42] [30 38]] [16 54]] [6 40]] [16 62]] [16 100]]] [16 71]] [6 66]] [16 80]]] [6 100]]] [6 50]] [7 27]] [18 50]] [16 80]] [2678 3.32 [16 75] [16 100]]] [16 50]] [7 66]] [16 63]] [18 46]] [26 53]] [7122 18.5 [16 100] [16 83]]] [2728 1.18 [7 37] [6 75]]] [37 83]] [26 100]] [26 70]] [16 86]] [14 26]] [5 34]]] [5981 1.33 [429 4.19 [7489 23.8 [38 78] [23 7.99 [6850 7.8 [38 100] [38 97]] [2439 8.69 [38 97] [38 84]]]] [38 100]] [38 100]]] [7066 0.946 [2713 1.24 [6953 1.59 [1445 0.921 [1638 0.574 [1899 21.2 [7390 1.05 [5345 1.18 [312 2.08 [5209 0.0585 [5570 4.52 [187 5.04 [7009 3.05 [1899 2.51 [38 100] [2466 6.22 [166 1.62 [7260 6 [38 75] [5 28]] [38 33]] [5 30]]] [24 40]] [2850 1.42 [1980 6.49 [7369 0.199 [6824 0.931 [38 50] [38 62]] [2939 42.4 [38 92] [38 75]]] [38 90]] [14 50]]] [1436 11.3 [32 66] [17 33]]] [38 89]] [5 27]] [38 31]] [5130 0.931 [2429 2.52 [38 74] [38 100]] [38 100]]] [7472 0.537 [5 30] [38 50]]] [14 100]] [2862 0.469 [5952 1.15 [38 23] [38 77]] [7476 1.11 [38 69] [38 27]]]] [17 64]] [16 30]] [5891 6.48 [17 90] [14 28]]]] [305 0.743 [190 3.08 [30 38] [6 18]] [7314 14.8 [30 100] [30 87]]]]] [47 2.04 [2958 1.63 [24 72] [2958 20.3 [429 20.9 [24 79] [24 93]] [24 98]]] [24 97]]] [2737 0.763 [7281 1.24 [302 1.42 [2867 0.138 [2711 0.441 [2683 0.319 [2752 4.73 [2667 2.05 [4937 0.501 [2680 1.11 [2748 0.109 [2632 1.48 [187 3.78 [4154 0.658 [1239 56 [2468 1.58 [4851 6.45 [2947 0.481 [2469 5.2 [2682 2.82 [2713 1.08 [6940 15.3 [4427 8.27 [5681 1.61 [328 9.9 [7185 2.73 [7423 8.67 [2949 0.976 [1429 28.3 [7101 0.885 [38 61] [16 66]] [2628 33 [6 33] [14 57]]] [38 100]] [16 100]] [38 50]] [16 36]] [16 37]] [1 33]] [16 100]] [16 63]] [38 71]] [17 37]] [38 100]] [16 39]] [38 57]] [7 56]] [38 60]] [5037 0.783 [5150 4.12 [94 6.14 [165 2.57 [1429 11.9 [2656 4.18 [1078 8.7 [5100 1.01 [38 28] [7260 0.642 [2727 1.92 [6 38] [187 24.6 [6 57] [16 62]]] [16 52]]] [18 42]] [18 36]] [4427 8.75 [4854 4.87 [1899 2.06 [38 48] [25 25]] [6 30]] [16 80]]] [38 66]] [16 90]] [6 60]] [16 52]]] [5 77]] [38 70]] [6959 4.56 [7 89] [7 57]]] [6 48]] [2672 16.6 [2940 4.5 [83 2.99 [791 1.83 [16 58] [26 50]] [16 75]] [18 47]] [6 90]]] [791 1.14 [1899 4.08 [62 1.17 [5641 4.06 [2983 22.9 [2628 25.4 [16 36] [16 57]] [18 57]] [16 88]] [16 50]] [6 44]] [26 38]]] [4613 0.813 [6791 1.05 [7665 5.29 [5680 1.33 [5363 1.67 [5681 5.1 [2709 5.83 [2729 41.4 [45 0.147 [7123 10.6 [5007 0.348 [2683 4.84 [7041 3.94 [7 28] [16 83]] [16 87]] [16 50]] [16 60]] [16 86]] [5 25]] [16 31]] [7231 10.1 [1429 3.49 [6 50] [6 42]] [16 56]]] [14 45]] [5 35]] [6 83]] [26 50]] [26 66]]] [2683 5.7 [3435 12.9 [5681 0.392 [3436 7.23 [5 57] [6 33]] [37 63]] [37 78]] [37 55]]] [6473 0.273 [2881 0.415 [2683 9.58 [1078 2.02 [7150 4.55 [4738 2.43 [2628 37.8 [2868 0.377 [7260 5.57 [6 50] [16 100]] [1895 0.317 [16 78] [16 100]]] [16 33]] [16 33]] [2978 5.74 [26 50] [16 57]]] [19 33]] [28 54]] [16 75]] [26 69]]] [30 67]] [2661 17.1 [4739 2.09 [5099 1.69 [4426 12.3 [2862 0.669 [16 20] [16 75]] [16 46]] [2644 0.833 [2749 7.22 [2709 5.92 [2282 0.603 [2983 2.36 [16 84] [5545 0.697 [4851 27.2 [7255 4.57 [6940 6.98 [6499 2.9 [16 45] [6 66]] [5102 4.3 [6 86] [16 60]]] [28 45]] [6 77]] [18 55]]] [6 77]] [2709 7.33 [5412 0.574 [1980 0.751 [6 81] [6 90]] [6 60]] [1253 2.57 [6425 5.77 [6015 0.978 [6961 1.57 [5099 6.17 [5628 0.89 [16 55] [16 54]] [5626 8.5 [18 62] [6 62]]] [6 66]] [6 62]] [16 62]] [16 42]]]] [26 87]] [2713 6.68 [16 80] [16 36]]]] [5 27]] [5628 25.9 [6 53] [6 83]]]] [38 90]]] [4571 1.16 [2913 2.76 [7344 1.1 [4673 2 [4851 1.91 [2749 1.35 [6779 1.18 [1913 2.31 [7623 3.06 [2654 0.684 [5628 0.341 [1078 5.21 [1852 1.22 [2551 0.0955 [6727 0.594 [5641 10.5 [2616 4.88 [1981 0.443 [5692 3.13 [3207 2.03 [5732 4.67 [6517 2.94 [2655 0.642 [7759 4.27 [4939 1.3 [1661 4.95 [7301 0.608 [6961 8.64 [2983 23.2 [2707 2.36 [13 28] [4663 2.61 [16 60] [16 100]]] [33 42]] [18 55]] [38 60]] [33 55]] [2259 1.13 [16 70] [16 100]]] [28 70]] [2628 41.8 [16 100] [16 85]]] [28 45]] [6687 13 [7 75] [16 54]]] [5 25]] [14 26]] [16 72]] [7 71]] [16 23]] [35 33]] [6 72]] [7 60]] [16 40]] [6 75]] [4870 2.99 [134 3.8 [7066 0.805 [4663 10.7 [7132 0.441 [194 8.2 [7474 3.86 [7149 5.89 [7203 21.8 [76 7.19 [2867 3.18 [2728 1.64 [5595 1.69 [5100 29.5 [7232 0.948 [5902 1.24 [7260 4.33 [187 2.26 [16 63] [6100 1.27 [4738 4.84 [7665 4.17 [5412 1.12 [4895 13.9 [6848 3.72 [7390 3.68 [2978 5.34 [2862 9.28 [2466 8.33 [16 85] [16 71]] [16 100]] [16 37]] [16 75]] [16 60]] [16 42]] [16 77]] [16 54]] [16 100]] [16 66]]] [7347 0.384 [2259 4.42 [16 100] [16 66]] [16 100]]] [16 44]] [6 28]] [6 36]] [2712 5.43 [6 62] [16 75]]] [16 89]] [2867 7.05 [28 27] [16 53]]] [2707 29.1 [7 44] [16 83]]] [2259 5.75 [2939 125 [16 20] [16 30]] [32 44]]] [192 8.55 [1899 3.31 [2713 0.62 [5681 6.14 [16 44] [16 77]] [26 50]] [13 33]] [16 87]]] [7203 2.39 [16 95] [16 100]]] [16 38]] [6383 0.609 [23 5.08 [16 50] [13 64]] [16 42]]] [14 50]] [17 46]] [16 31]] [18 27]]] [13 29]] [7 62]] [2859 0.478 [37 41] [4717 5.31 [37 85] [37 33]]]] [663 6.11 [4717 11.5 [4611 0.699 [5594 5.92 [26 60] [26 90]] [26 50]] [26 53]] [26 77]]] [2470 0.244 [2979 2.39 [361 0.652 [2954 0.843 [2683 2.33 [94 5.1 [88 3.62 [2748 0.634 [2713 8.92 [2984 9.03 [5577 3.47 [2707 2.09 [30 50] [2867 5.04 [7446 1.24 [5632 2.36 [7203 1.16 [16 38] [26 66]] [5598 0.994 [3238 4.12 [7169 1.72 [2466 6.1 [6687 3.77 [2978 6.24 [6406 6.37 [5010 3.42 [4414 3.98 [2849 24.4 [16 42] [16 81]] [16 78]] [30 42]] [16 36]] [16 33]] [7 28]] [16 66]] [16 41]] [6 71]] [16 92]]] [6 56]] [29 33]]] [28 66]] [16 70]] [5099 19.8 [6 63] [2983 5.77 [1596 1.79 [5435 3.67 [2707 27.7 [5595 0.555 [7419 2.42 [6 58] [16 62]] [6 100]] [16 59]] [16 66]] [16 80]] [3 33]]]] [2526 3.19 [26 64] [6 42]]] [37 60]] [6687 4.1 [18 50] [6 71]]] [5724 0.196 [16 68] [16 77]]] [30 85]] [18 50]] [1596 0.153 [6 47] [6 100]]] [30 60]]] [6380 0.424 [6133 0.129 [5099 2.04 [2259 23.2 [16 100] [6 50]] [5104 1.09 [4889 5.34 [6 83] [6 58]] [16 42]]] [6 87]] [2939 30.5 [37 50] [16 90]]]] [5579 0.537 [7406 0.203 [38 100] [38 85]] [38 100]]] [5931 0.754 [30 74] [30 100]]] [6123 0.843 [5188 0.588 [7 68] [7 100]] [30 40]]]] [5972 2.73 [144 5.99 [6216 0.69 [722 6.32 [5820 0.967 [5438 0.956 [5602 0.77 [6207 2.39 [6550 1.42 [4154 5.5 [2862 2.25 [4 29] [5 66]] [2 37]] [4 91]] [38 50]] [31 63]] [16 62]] [4 100]] [5 78]] [6982 0.507 [4 53] [2745 4.36 [2555 0.713 [1429 25.7 [2005 2.28 [1925 2.92 [6988 2.17 [4 100] [4 85]] [4 100]] [2939 13.1 [4 100] [4 83]]] [736 3.41 [4 100] [4 72]]] [4 100]] [4 83]]]] [2658 1.04 [145 6.46 [5 43] [16 56]] [144 13.9 [4 100] [4 80]]]] [31 50]]] [6103 0.671 [7370 0.0539 [63 0.525 [6833 1.24 [187 0.691 [1072 0.215 [4550 8.7 [6826 0.565 [2025 0.325 [1429 24.4 [695 0.476 [2716 1.04 [2939 49.9 [4398 4.27 [2943 1.85 [38 11] [4 61]] [31 72]] [38 65]] [2951 33.1 [16 38] [16 70]]] [4338 0.545 [6184 0.68 [4 41] [2 71]] [2 50]]] [3095 1.8 [1078 22.1 [4573 0.364 [7623 2.62 [2093 5.44 [2064 3.57 [6382 3.82 [2168 0.214 [2466 0.968 [2629 12.2 [5509 0.321 [19 9] [12 40]] [10 33]] [25 33]] [12 40]] [17 66]] [33 37]] [7 25]] [17 33]] [19 30]] [7512 2.86 [6 21] [4 50]]] [29 36]]] [4 66]] [2225 0.269 [14 43] [17 62]]] [31 100]] [5887 1.22 [4 64] [2 91]]] [2644 0.0671 [2670 3.54 [7121 1.23 [7038 10.8 [2868 0.166 [3882 0.328 [4880 2.71 [62 0.236 [2890 0.383 [5673 11.3 [5809 0.149 [83 3.29 [6779 2.12 [2941 10.8 [5594 3.42 [7347 5.33 [5597 0.898 [2246 0.336 [221 0.193 [1783 18.6 [2689 0.69 [7242 2.21 [2939 67.5 [2251 2.36 [2466 0.25 [6 27] [2628 20.6 [14 37] [5 20]]] [38 100]] [38 77]] [5 31]] [17 50]] [23 16.1 [38 50] [38 88]]] [30 57]] [38 57]] [6 53]] [16 33]] [16 55]] [16 57]] [37 66]] [16 90]] [38 50]] [38 75]] [5 50]] [1895 1.87 [16 33] [26 33]]] [2628 28.7 [190 7.65 [6 42] [6 80]] [4880 7.32 [6 71] [16 50]]]] [5 100]] [1239 36 [37 6.83 [1429 10.7 [6207 8.24 [6199 1.77 [16 44] [16 72]] [30 36]] [6 33]] [16 44]] [6 50]]] [16 100]] [7255 1.15 [6 50] [6 77]]] [17 80]] [2863 0.427 [5100 0.134 [187 21.7 [2978 7.44 [1783 20.3 [2689 3.21 [7260 1.88 [16 70] [16 90]] [2717 9.01 [2717 4.43 [16 40] [26 37]] [16 85]]] [30 36]] [6 44]] [6 50]] [2717 0.549 [2143 0.94 [2734 0.437 [194 0.7 [6 66] [6 100]] [6 60]] [6 55]] [2682 3.94 [5962 3.5 [16 35] [16 88]] [6 61]]]] [7 83]]]] [4743 1.09 [5187 1.04 [37 0.937 [7 42] [16 60]] [7 75]] [7 100]]] [7206 4.73 [6431 0.404 [2262 1.25 [6098 2.9 [1983 2.36 [6815 0.137 [6717 0.392 [5931 0.522 [5032 0.497 [7679 0.723 [1820 3.25 [1783 24.8 [2690 0.283 [16 80] [16 100]] [1787 0.527 [16 28] [16 71]]] [16 50]] [16 50]] [6 57]] [18 28]] [6 33]] [4527 0.137 [2661 4.08 [5412 0.299 [7042 2.72 [5641 0.584 [16 63] [4977 0.736 [16 100] [16 85]]] [6830 1.75 [16 37] [16 66]]] [2939 24.6 [26 50] [6 46]]] [16 100]] [6 85]]] [7 38]] [6 33]] [1820 1.38 [6 73] [16 62]]] [7 100]] [16 32]]] [6027 0.471 [1239 10.3 [5148 5.13 [5981 0.412 [2717 0.52 [1454 0.796 [1452 1.2 [2853 12.6 [7370 14.1 [45 11.2 [7343 0.366 [200 0.117 [187 20.9 [2873 3.41 [38 67] [38 100]] [31 44]] [6720 0.618 [1262 2.29 [2659 0.916 [2108 0.612 [1789 0.823 [4533 0.528 [2869 0.667 [6342 0.898 [69 1.93 [38 98] [38 62]] [38 88]] [38 80]] [38 100]] [1800 1.79 [200 1.06 [38 85] [38 100]] [38 100]]] [38 66]] [38 100]] [7149 1.22 [2112 6.26 [1961 1.19 [7332 3.22 [38 78] [7445 3.46 [2006 1.65 [38 95] [38 100]] [38 84]]] [19 57]] [2111 6.78 [38 50] [6824 1.83 [38 75] [38 62]]]] [38 100]]] [3983 3.75 [2951 2.94 [1396 5.75 [5954 12.5 [5673 22.8 [23 40.7 [2851 5.75 [38 100] [7369 6.72 [38 90] [38 100]]] [38 100]] [38 88]] [38 77]] [38 75]] [6720 0.986 [17 57] [2939 10.2 [7472 3.59 [38 68] [19 46]] [37 8.33 [2887 5.56 [38 97] [38 90]] [38 71]]]]] [38 64]]]] [1789 2.2 [2849 19.3 [38 91] [38 52]] [38 93]]] [19 37]] [12 37]] [12 71]] [16 44]] [7473 3 [38 52] [5 46]]] [2862 7.24 [16 91] [16 71]]] [14 30]] [5560 0.57 [38 100] [38 78]]] [1260 0.189 [4687 0.45 [1980 11.1 [2881 1.21 [5896 0.524 [4562 3.16 [1445 0.524 [7390 3.4 [5981 1.69 [2849 6.24 [5210 1.42 [38 69] [38 100]] [1429 38.1 [2648 0.717 [1687 3.51 [2075 1.16 [1981 2.92 [4939 1.09 [187 2.12 [38 58] [187 20.2 [7255 4.66 [38 81] [38 100]] [38 50]]] [26 44]] [38 42]] [38 44]] [199 3.64 [38 45] [26 61]]] [5 46]] [4896 0.534 [38 38] [6133 1.45 [17 52] [38 100]]]]] [1997 3.63 [17 44] [17 55]]] [3110 5.71 [2955 7.53 [7474 15.3 [38 65] [38 100]] [5210 2.09 [38 83] [38 100]]] [13 33]]] [7332 1.41 [6380 11.7 [4050 1.09 [17 66] [2951 14.7 [8 33] [17 40]]] [38 71]] [26 35]]] [38 100]] [4610 5.34 [17 100] [17 60]]] [17 44]] [38 75]] [17 100]] [1429 30.2 [2143 3.9 [38 55] [38 50]] [7343 6.55 [2469 12.9 [200 0.545 [17 58] [38 44]] [14 63]] [17 100]]]]] [7402 1.48 [19 47] [17 77]]]] [7391 0.394 [18 25] [39 0.421 [2646 1.05 [4716 3.2 [7304 3.55 [2939 16.9 [4050 5.36 [38 96] [38 63]] [4009 1.25 [7369 2.38 [38 100] [38 83]] [38 100]]] [38 83]] [7122 4.96 [38 73] [38 80]]] [38 87]] [38 100]]]]] [6687 4.59 [2865 0.489 [4854 0.888 [5100 0.519 [7419 1.51 [6199 9.58 [18 49] [7343 10 [1239 27 [18 65] [18 92]] [18 100]]] [18 100]] [6959 8.44 [5099 29.6 [18 88] [2849 33.3 [18 55] [18 80]]] [18 100]]] [4859 7.08 [7260 6.56 [1355 4.7 [2707 23.8 [4540 6.46 [2951 7.36 [91 4.92 [6940 8.42 [2655 0.525 [2939 18 [18 89] [18 70]] [18 60]] [6 42]] [16 57]] [5723 3.12 [18 83] [6 50]]] [6 50]] [18 41]] [18 85]] [18 95]] [5099 21.3 [7 50] [18 100]]]] [7 100]] [7 28]]]] [7693 4.08 [1400 0.271 [2202 13 [4517 5.68 [23 10.5 [268 3.17 [1062 0.669 [312 0.395 [731 26.8 [4663 18.8 [679 0.855 [7512 0.935 [25 99] [25 100]] [25 100]] [25 90]] [25 85]] [25 100]] [25 100]] [25 100]] [7330 0.879 [7084 11.4 [685 7 [1981 2.22 [2526 7.21 [5432 5.84 [25 100] [25 83]] [25 100]] [25 100]] [25 83]] [25 87]] [25 100]]] [25 81]] [25 76]] [1239 0.194 [7310 0.277 [2770 0.677 [1646 3.35 [5692 0.557 [6528 8.07 [25 100] [25 97]] [25 100]] [25 90]] [25 100]] [25 100]] [25 100]]] [791 4.47 [25 92] [25 100]]]] [2526 2.21 [1747 0.106 [7340 0.235 [6231 0.729 [783 0.24 [4612 0.217 [4615 0.281 [4270 0.504 [2259 12.4 [865 0.317 [5260 3.2 [3768 0.818 [3205 1.19 [144 10.5 [7534 0.444 [4235 32.7 [2799 0.109 [724 1.36 [5400 0.263 [1552 1.31 [4390 0.524 [736 1.65 [392 1.15 [2488 1.17 [4613 0.448 [6584 0.201 [684 3.82 [4602 1.98 [5970 0.494 [4189 0.155 [6529 1.08 [3896 0.464 [1611 0.441 [6333 3.29 [6544 0.827 [2826 1.44 [5757 1.18 [2470 2.77 [5904 0.28 [7591 1.27 [1980 0.119 [7693 0.671 [1025 3.3 [4170 5.81 [6177 6.23 [7535 17.2 [7324 4.06 [6591 1.77 [7034 3.6 [6106 2.96 [5554 1.19 [6855 7.1 [221 1.54 [6581 13.5 [7382 2.59 [7548 2.74 [6342 3.64 [3357 3.82 [6294 6.07 [5429 3.31 [7687 0.354 [5972 0.662 [6152 5.54 [312 8.11 [170 4.39 [14 39] [19 72]] [31 46]] [14 100]] [36 58]] [168 75.5 [19 76] [19 50]]] [5 38]] [17 21]] [14 90]] [6347 3.54 [20 22] [36 46]]] [14 83]] [24 86]] [5 42]] [673 6.27 [25 17] [25 57]]] [31 92]] [14 100]] [32 100]] [13 100]] [6581 12.1 [17 73] [896 18.4 [429 30.3 [17 60] [5 45]] [5 60]]]] [429 41.4 [5 77] [5 100]]] [24 72]] [25 69]] [32 100]] [1429 10.6 [978 3.4 [1025 27.8 [14 40] [2 71]] [2 53]] [7698 2.79 [6264 3.23 [24 42] [24 100]] [13 100]]]] [134 0.671 [7185 7.04 [6184 5.51 [721 1.68 [7590 13.2 [36 23] [13 50]] [36 76]] [25 57]] [14 64]] [26 40]]] [2058 1.76 [7329 2.92 [6103 11.5 [6537 1.98 [2935 1.95 [5871 4.65 [4956 5.52 [6526 1.96 [7548 1.12 [6524 6.06 [4198 0.901 [2143 10.8 [673 14.2 [312 1.39 [6883 0.547 [5647 4.61 [36 14] [29 35]] [4 40]] [24 58]] [26 81]] [25 30]] [19 66]] [1 54]] [791 11.4 [14 100] [14 81]]] [25 100]] [36 73]] [14 100]] [20 41]] [2 58]] [31 57]] [1 80]] [19 46]]] [36 84]] [1783 2.12 [19 48] [19 100]]] [5972 1.72 [7381 1.42 [6982 4.27 [31 67] [4 71]] [4 100]] [429 23.3 [31 100] [31 83]]]] [29 83]] [5953 0.531 [710 0.945 [653 2.65 [3391 0.747 [7722 4.38 [14 30] [1557 2.06 [7009 3.27 [2829 5.63 [2259 6.6 [4968 2.46 [5891 2.29 [377 1.47 [14 63] [14 100]] [14 87]] [7 22]] [14 50]] [14 100]] [5 64]] [3554 1.31 [17 41] [17 60]]]] [19 42]] [7325 19.7 [5 90] [5 50]]] [14 100]] [19 60]]] [5972 1.67 [3971 2.7 [5034 1.34 [14 58] [6732 0.668 [4876 3.63 [285 8.1 [14 95] [14 93]] [14 83]] [14 100]]] [14 100]] [31 81]]] [5 38]] [7343 18.9 [14 100] [14 77]]] [2962 2.37 [23 5.87 [32 57] [31 60]] [31 100]]] [2259 5.26 [7 28] [36 60]]] [24 73]] [5192 1.43 [29 97] [29 83]]] [26 93]] [7697 1.99 [682 20 [31 100] [31 90]] [31 100]]] [17 44]] [5207 0.967 [26 95] [26 83]]] [5198 4.08 [13 100] [13 94]]] [324 2.59 [7569 0.894 [1911 3.54 [4969 2.75 [5695 0.688 [3130 0.225 [7343 2.71 [5566 0.106 [7737 4.53 [392 40.9 [2752 7.31 [14 57] [1611 0.821 [5345 3.7 [1436 0.945 [7677 0.843 [14 78] [14 100]] [14 100]] [14 75]] [14 100]]] [28 57]] [25 60]] [14 100]] [14 44]] [28 37]] [26 91]] [7 100]] [14 36]] [14 100]] [7 44]]] [6575 7.73 [3516 0.25 [6865 1.35 [602 3.27 [978 6.58 [7009 2.22 [384 1.9 [7384 5.26 [7233 1.08 [5753 1.04 [7413 1.4 [5 25] [2 18]] [5 40]] [31 83]] [17 72]] [26 66]] [5 83]] [144 4 [17 35] [144 6.3 [19 81] [2259 1.66 [17 57] [19 66]]]]] [2259 3.78 [695 3.02 [17 100] [731 9.84 [17 71] [978 14.5 [17 100] [17 62]]]] [17 50]]] [5 100]] [19 100]] [17 73]]] [26 95]] [32 97]] [13 89]] [5267 1.98 [6910 1.4 [5972 0.569 [5429 0.552 [5390 1.87 [673 7.64 [2760 0.34 [7325 3.24 [6588 0.262 [1429 17.6 [4 38] [913 0.545 [5692 10.9 [2628 1.13 [17 63] [19 27]] [35 25]] [17 45]]] [6310 0.262 [17 67] [17 100]]] [5 71]] [3928 0.993 [17 84] [17 100]]] [26 90]] [16 46]] [5 68]] [4080 1.13 [1888 2.25 [31 100] [31 80]] [31 100]]] [19 43]] [26 25]]] [5870 0.907 [1906 0.193 [26 82] [26 100]] [26 60]]] [3008 0.96 [4196 2.79 [4277 1.11 [4690 2.46 [20 88] [20 100]] [20 100]] [20 100]] [20 100]]] [7722 9.69 [5509 2.54 [2826 8.93 [4587 2.12 [17 63] [17 54]] [17 100]] [19 62]] [17 61]]] [5429 1.55 [5034 3.8 [2199 3.34 [44 13.5 [5472 1.86 [7738 1.95 [665 3.07 [5680 3.31 [169 2.13 [3415 0.623 [177 5.26 [22 19] [4895 2.25 [19 91] [19 60]]] [19 84]] [7169 3.36 [99 18.6 [2081 6.59 [5674 17.3 [19 78] [19 62]] [1429 19.5 [19 55] [18 42]]] [19 44]] [5 25]]] [22 44]] [2 100]] [5878 0.797 [7139 1.14 [6571 5.31 [1982 1.09 [4414 0.635 [19 65] [13 33]] [19 54]] [19 53]] [18 27]] [19 94]]] [2488 3.11 [13 60] [13 100]]] [30 87]] [7514 5.98 [22 41] [19 33]]] [14 94]] [5 68]]] [725 4.85 [1888 1.98 [5 92] [5 100]] [5 66]]] [13 99]] [682 6.39 [896 10 [7274 5.38 [1618 1.79 [6077 0.324 [7092 1.89 [17 0.592 [1429 28.8 [13 71] [13 100]] [13 100]] [13 100]] [13 100]] [17 40]] [13 87]] [13 52]] [13 52]]] [13 100]] [6732 0.899 [6977 2.5 [682 1.88 [6865 2.05 [4309 1.09 [7354 1.67 [2793 3.59 [168 5.29 [5734 2.18 [2004 8.72 [2701 5.61 [6261 0.34 [7697 0.62 [325 0.864 [5790 3.85 [3483 3.18 [6578 2.92 [2445 4.43 [719 16.7 [4170 1.64 [874 1.37 [1240 1.08 [2939 4.68 [2929 1.47 [5405 2.89 [7419 11.1 [685 0.523 [3053 1.92 [7698 3 [811 2.2 [601 3.83 [5472 0.468 [7317 1.09 [5972 4.99 [7139 0.897 [6106 1.19 [6853 12.1 [2913 1.72 [968 4.89 [6333 6.72 [6436 1 [6403 1.32 [3008 11.1 [6970 0.897 [5725 9.75 [7343 7.66 [2259 55.9 [7588 12.5 [2752 5.51 [6547 3.07 [14 50] [14 100]] [4876 0.157 [5904 4.93 [14 67] [14 80]] [14 50]]] [5 60]] [19 33]] [3 33]] [31 100]] [4 36]] [6 45]] [32 100]] [14 100]] [32 100]] [32 100]] [899 1.78 [32 60] [32 100]]] [24 73]] [32 100]] [5891 1.8 [7665 34.2 [1888 0.898 [7409 2.54 [14 43] [14 100]] [14 100]] [14 41]] [14 87]]] [36 60]] [14 92]] [1911 4.35 [24 1.42 [3646 2.73 [5753 3 [36 84] [36 90]] [36 100]] [13 100]] [36 100]]] [36 100]] [2752 8.1 [36 56] [36 90]]] [36 81]] [32 100]] [6342 0.473 [4571 0.609 [14 59] [1742 3.26 [14 71] [17 26]]] [14 73]]] [6 88]] [31 100]] [3698 1.69 [2752 5.2 [429 1.36 [31 42] [31 66]] [30 31]] [31 83]]] [31 44]] [24 100]] [36 100]] [32 95]] [5 52]] [404 2.24 [112 6.06 [248 8.73 [144 2.64 [19 30] [7149 1.66 [7245 3.68 [19 62] [14 40]] [19 57]]] [13 21]] [36 54]] [19 35]]] [31 100]] [32 100]] [4040 1.86 [112 7.23 [36 100] [36 92]] [36 100]]] [31 100]] [31 100]] [695 1.36 [36 94] [36 100]]] [1888 1.07 [13 68] [13 100]]] [2259 38.9 [29 81] [3 72]]] [7 100]] [1997 10.5 [4326 0.414 [429 7.88 [1078 3.63 [5674 3.27 [19 43] [19 55]] [1936 4.55 [7737 7.57 [19 95] [19 57]] [19 57]]] [36 35]] [19 78]] [14 46]]] [1980 6.37 [4533 1.61 [24 81] [24 40]] [36 33]]] [394 1.1 [36 85] [19 40]]] [32 93]] [4545 6.49 [2793 1.26 [2331 3.28 [2259 15.3 [6867 3.81 [7 33] [36 100]] [7373 2.6 [36 95] [36 83]]] [36 80]] [4154 22.6 [19 50] [24 83]]] [36 57]]] [7032 2.99 [6983 0.686 [2259 29 [7559 1.61 [31 76] [31 100]] [36 62]] [31 100]] [31 100]]] [3915 1.38 [14 79] [14 66]]] [5418 0.661 [5472 0.582 [4349 1.42 [4170 4.1 [6977 1.54 [3480 2.24 [5510 0.759 [2752 6.13 [36 22] [14 46]] [14 100]] [36 85]] [14 75]] [32 66]] [2795 4.14 [24 90] [24 100]]] [4799 11.8 [5812 0.355 [4851 0.499 [7250 0.754 [7169 2.11 [6859 0.982 [7698 5.33 [4312 1.61 [896 10.5 [4034 1.59 [2993 0.582 [36 85] [36 100]] [36 100]] [36 75]] [36 100]] [13 54]] [1078 7.01 [36 93] [36 100]]] [695 3.88 [13 63] [36 100]]] [36 100]] [36 100]] [13 100]] [36 64]]] [13 84]]]] [1078 29.6 [36 100] [36 70]]] [2778 1.04 [2636 5.13 [5425 6.37 [36 100] [36 66]] [36 87]] [36 93]]] [4296 0.122 [1062 5.29 [723 1.84 [7245 3.33 [6373 4.26 [1649 0.677 [2326 0.146 [6294 1.96 [36 100] [36 90]] [36 100]] [36 100]] [36 76]] [36 83]] [36 62]] [36 66]] [36 100]]] [13 100]] [2826 0.87 [2259 7 [2913 4.05 [814 0.356 [5703 1.34 [663 0.695 [31 63] [13 50]] [13 100]] [13 100]] [2259 4.17 [31 91] [31 100]]] [6732 0.4 [1078 36.8 [31 100] [31 95]] [31 50]]] [13 77]]] [5316 0.383 [6077 0.265 [2628 8.46 [4184 0.99 [1899 16.5 [2962 0.632 [7600 0.376 [3075 0.901 [957 1.14 [914 1.07 [32 80] [32 100]] [1899 2.89 [5730 1.14 [4799 7.06 [32 100] [32 87]] [32 100]] [32 91]]] [32 100]] [899 0.441 [144 0.904 [429 40.9 [6076 0.715 [1429 24.8 [896 0.829 [32 91] [32 100]] [32 100]] [32 100]] [32 84]] [32 100]] [23 12.3 [32 100] [32 97]]]] [31 90]] [32 73]] [13 70]] [896 2.86 [31 100] [17 42]]] [31 54]] [112 1.49 [6103 0.418 [5641 1.23 [4571 0.967 [4895 2.97 [6382 6.28 [3008 0.492 [1239 3.83 [6544 0.383 [4168 0.77 [5316 3.43 [6230 0.935 [32 76] [32 100]] [2320 1.12 [7449 0.306 [3905 21.2 [32 100] [32 85]] [32 100]] [32 100]]] [32 100]] [32 100]] [32 91]] [32 100]] [32 85]] [7428 1.85 [32 100] [32 83]]] [32 90]] [32 75]] [32 100]] [32 100]]]] [722 1.34 [850 0.619 [36 100] [4956 0.653 [7377 1.5 [36 85] [36 100]] [36 100]]] [7377 4.28 [36 66] [36 100]]]] [5574 0.379 [1703 0.291 [5892 0.0763 [7583 0.677 [3905 0.481 [6589 0.162 [6173 0.682 [7330 0.609 [7324 0.757 [5653 1.04 [6098 0.595 [3056 1.07 [7584 0.704 [2795 0.621 [4960 0.42 [811 2.39 [1919 1.96 [1389 0.293 [7516 0.276 [5732 0.297 [2793 1.29 [6584 0.102 [2752 1.78 [731 0.703 [3008 0.296 [2526 34.7 [7535 4.67 [5099 1.71 [31 13] [6 83]] [24 85]] [2594 5.52 [2616 11.4 [6 35] [221 14.3 [6732 11.6 [6 70] [5 20]] [6 60]]] [5 79]]] [6136 0.813 [6 76] [4674 2.67 [7421 19.6 [6 100] [6114 11.1 [6 84] [6 100]]] [6 100]]]] [736 18.9 [4 25] [5 71]]] [3998 0.389 [682 0.195 [3205 1.07 [5403 1.18 [6179 0.592 [2745 5.83 [4342 0.371 [896 3.94 [6550 3.38 [4832 1.69 [2834 0.87 [774 5.26 [6581 6.9 [4205 3.52 [7512 0.568 [5812 1.9 [25 30] [2 50]] [5594 0.334 [5359 2.13 [99 3.09 [5261 1.6 [5472 0.797 [1429 7.49 [7305 1.11 [731 9.82 [5142 0.617 [2902 0.738 [248 1.78 [4929 3.04 [7 25] [4 60]] [25 80]] [2 66]] [4 50]] [4 66]] [5692 0.914 [25 100] [25 66]]] [2027 0.949 [4611 2.03 [2846 1.75 [4690 0.56 [2628 0.393 [4154 7.78 [5767 0.423 [384 5.78 [7354 6.94 [2760 0.284 [695 14.3 [1783 3.67 [7 26] [26 25]] [14 42]] [17 57]] [7 57]] [7 100]] [17 62]] [24 77]] [5198 0.65 [695 1.93 [17 48] [38 30]] [38 23]]] [4 71]] [32 42]] [26 30]] [22 66]]] [36 79]] [13 100]] [14 55]] [25 100]] [16 81]]] [26 80]] [5 63]] [655 2.67 [7 50] [24 90]]] [25 100]] [2 85]] [5 56]] [6333 1.77 [6927 1.07 [655 2.97 [3130 3.46 [4929 1.28 [726 0.571 [7032 0.581 [7381 1.27 [673 1.14 [2910 8.83 [6524 0.44 [5698 2.35 [1630 1.85 [6313 5.48 [203 0.876 [7301 1.39 [7009 8.07 [221 1.49 [957 1.71 [2616 15 [567 4.43 [2552 1.59 [2083 1.01 [3837 1.37 [663 15.4 [6230 5.52 [7009 4.65 [5462 0.707 [6310 3.44 [5192 2.82 [2902 3.2 [736 0.736 [1980 4.36 [2259 15.5 [5 34] [36 36]] [12 33]] [5 43]] [2 40]] [4 23]] [5 50]] [5 57]] [18 66]] [5 60]] [17 55]] [5 100]] [2 33]] [2 42]] [1 42]] [5 21]] [5 70]] [4 40]] [5 87]] [18 36]] [5 88]] [19 60]] [19 45]] [24 86]] [7 58]] [5 100]] [999 2.7 [1081 4.44 [25 47] [25 93]] [25 69]]] [7563 1.63 [17 3.29 [931 1.87 [2840 0.787 [23 8.35 [7723 0.608 [1078 28.7 [2826 0.79 [7598 0.829 [5 35] [17 80]] [4806 0.657 [7241 3.81 [978 11.7 [5 27] [17 84]] [17 66]] [17 80]]] [4 60]] [38 36]] [5 87]] [17 50]] [5 36]] [6581 2.36 [2 36] [5 50]]] [5 100]]] [2 39]] [17 29]] [6732 5.31 [4 91] [4 44]]] [4 77]] [1025 2.44 [24 64] [2 42]]] [2 91]] [4761 0.392 [791 8.85 [5154 4.29 [2826 0.711 [5 42] [5 84]] [5 37]] [4107 1.01 [3592 1.82 [4414 1.36 [3313 0.901 [1888 5.39 [5154 2.54 [6310 8.25 [5 73] [5 62]] [896 12.6 [5 87] [5 100]]] [5 44]] [695 0.743 [5 93] [5 100]]] [5 60]] [5 100]] [5 100]]] [5 57]]]] [24 100]] [2745 11.3 [429 20.1 [2570 5.99 [1 33] [1 86]] [17 25]] [1 72]]] [25 100]] [31 97]] [2143 0.561 [429 31.2 [5 100] [5 81]] [5 58]]] [7697 1.09 [4 41] [31 100]]] [2849 2.32 [5 90] [5 58]]]] [5952 0.201 [2259 3.39 [1704 1.17 [4841 2.47 [5904 0.501 [2826 13.8 [999 1.37 [5509 6.66 [3008 0.816 [21 0.664 [7742 1.39 [2913 2.11 [17 45] [5 80]] [5 75]] [5 57]] [17 68]] [7512 59.4 [3260 1.11 [2526 84.7 [5 75] [5 40]] [5 100]] [5 60]]] [5 30]] [17 65]] [19 85]] [17 63]] [17 100]] [2826 5.56 [2616 3.95 [5345 1.64 [7512 21.7 [17 57] [5 76]] [5 77]] [5 80]] [5 51]]] [23 0.664 [1888 8.07 [3798 8.9 [5812 6.14 [35 40] [19 90]] [728 1.28 [17 50] [16 33]]] [38 80]] [1078 6.88 [17 72] [17 55]]]]] [885 3.13 [5789 0.818 [5413 3.21 [4344 0.467 [286 4.27 [1240 0.998 [24 31] [3661 2.89 [6853 3.28 [24 90] [24 100]] [24 100]]] [24 100]] [7700 0.437 [24 88] [24 100]]] [24 89]] [24 100]] [24 100]]] [7588 0.33 [5744 1.1 [5476 0.297 [6181 2.09 [1852 0.894 [3011 0.734 [5034 1.13 [7068 0.515 [5734 0.609 [7210 0.808 [3014 6.1 [5309 3.14 [17 18] [18 54]] [17 100]] [4 23]] [1783 4.37 [7 75] [7 97]]] [5316 0.441 [36 100] [38 50]]] [14 94]] [36 100]] [7 100]] [7 100]] [13 100]] [17 44]] [5744 4.81 [17 60] [17 100]]]] [7515 0.416 [2902 0.482 [2616 7.68 [431 4.57 [4200 0.88 [2526 7.34 [1025 1.51 [6177 2.87 [26 78] [25 100]] [26 92]] [5431 2.01 [2580 0.734 [328 2.26 [1078 1.43 [25 58] [221 3.58 [25 87] [25 100]]] [328 6.03 [26 77] [26 57]]] [1980 9.67 [25 100] [25 88]]] [26 70]]] [26 80]] [25 88]] [25 91]] [5429 4.38 [248 43 [6294 1.53 [5694 0.156 [5431 0.278 [26 73] [26 100]] [26 100]] [26 80]] [7516 6.13 [5412 0.543 [25 57] [25 66]] [26 85]]] [26 100]]] [5647 3.53 [25 100] [25 87]]]] [631 0.569 [5866 1.29 [2517 9.97 [6859 6.33 [7494 0.756 [4279 0.741 [1239 2.98 [7512 16.4 [24 66] [24 100]] [25 30]] [24 100]] [24 75]] [24 100]] [24 71]] [24 100]] [24 100]]] [5316 3.05 [3636 0.986 [5820 0.288 [4205 2.49 [5034 6.77 [221 1.67 [7708 1.04 [1128 0.74 [2470 1.15 [2259 7.35 [7354 1.49 [6926 0.537 [1059 1.33 [261 3.15 [899 0.813 [2811 1.69 [4832 1.86 [5515 1.77 [3794 0.516 [5432 2.56 [3928 2.73 [6216 0.581 [6537 1.18 [3220 1.04 [1062 0.857 [7188 0.886 [1899 22.7 [573 2.77 [4145 0.792 [6592 1.42 [2526 21.2 [1911 1.67 [5 13] [2 37]] [7693 5.07 [2 55] [26 28]]] [25 100]] [24 100]] [5812 15.5 [6230 1.13 [17 27] [17 69]] [2576 10.5 [7568 4.26 [1919 16.7 [4 29] [4 50]] [17 46]] [4 60]]]] [6184 3.95 [2763 15.1 [2 31] [2 55]] [2 62]]] [38 27]] [2826 0.64 [5914 1.51 [2571 2.92 [7185 4.14 [2763 3.65 [17 25] [1023 5.69 [1919 6.85 [4279 8.42 [4279 3.21 [4 63] [2 50]] [4 85]] [1980 2.89 [19 33] [2 42]]] [2 66]]] [4 54]] [2 77]] [2 92]] [7722 7.78 [17 31] [17 57]]]] [5654 2.64 [5 91] [5 40]]] [2 66]] [5 86]] [728 4.83 [3929 6.55 [17 66] [17 94]] [17 62]]] [25 100]] [38 46]] [5 100]] [5652 1.2 [3667 7.02 [2 87] [4 57]] [2 55]]] [6396 1.04 [17 42] [17 100]]] [13 85]] [25 51]] [5694 0.569 [2 82] [2 44]]] [7032 0.722 [7665 17.5 [2763 3.04 [2 50] [429 25.2 [2 72] [2763 5.56 [2 100] [2 90]]]] [2 50]] [2 100]]] [899 4.99 [660 2.57 [5887 4.04 [5412 6.99 [985 1.49 [5 35] [7 72]] [429 26.5 [18 71] [18 84]]] [18 75]] [7 41]] [899 8.37 [13 63] [36 91]]]] [2752 1.34 [6167 4.72 [6514 1.65 [6 64] [6 100]] [6 66]] [1557 0.998 [1751 3.51 [7722 6.1 [2421 0.773 [7566 1.26 [1980 7.06 [312 1.95 [24 34] [24 90]] [2 50]] [24 75]] [24 80]] [24 30]] [36 62]] [17 62]]]] [4742 1.87 [7187 1.47 [248 7.16 [2628 0.675 [5692 4.16 [4 71] [4 90]] [6920 0.283 [7665 13.7 [4 100] [4 89]] [4 100]]] [25 80]] [4 77]] [4 57]]] [5 100]] [1911 1.37 [2628 3.85 [5 100] [5 50]] [5 66]]] [2368 0.871 [2529 0.933 [5211 0.445 [1075 1.26 [1072 3.85 [25 33] [2 70]] [25 69]] [1 71]] [6377 0.384 [791 6.24 [25 55] [25 84]] [25 100]]] [6 100]]] [2763 4.88 [14 83] [14 100]]] [2763 5.72 [26 72] [14 44]]] [1429 5.66 [6982 0.867 [1073 5.82 [2536 2.27 [2 100] [2 71]] [2 60]] [4 77]] [4 61]]] [24 85]] [7 68]]] [5972 4.48 [2259 6.96 [31 61] [5725 1.2 [1400 7.37 [811 5.73 [36 60] [36 85]] [31 92]] [31 100]]] [31 96]]] [4832 10 [4959 2.25 [4 95] [4 100]] [4 80]]] [5007 2.13 [2341 3.85 [5867 8.48 [5641 0.512 [6131 0.893 [6373 3.32 [3879 1.38 [5904 0.713 [5969 3.92 [7203 2.7 [24 100] [4338 17.2 [24 75] [24 100]]] [24 88]] [24 87]] [24 87]] [24 58]] [7373 2.38 [5198 2.21 [772 0.855 [24 94] [24 100]] [24 73]] [24 57]]] [7693 0.485 [24 90] [24 66]]] [24 57]] [4279 11.4 [24 75] [24 66]]] [1078 4.41 [2616 3.48 [6261 0.699 [2259 21.6 [19 70] [19 60]] [24 75]] [24 71]] [24 83]]]] [663 3.16 [2526 32.2 [4742 1.91 [7665 20.6 [6732 2.68 [2 70] [1062 1.36 [2 100] [2 75]]] [1 88]] [2 58]] [1078 3.65 [1 66] [1899 9.33 [2 66] [4 78]]]] [6276 0.988 [6363 1.59 [1986 5.42 [7491 2.79 [2013 0.847 [3667 3.03 [2 100] [1073 0.631 [2 90] [2 100]]] [2 100]] [2 87]] [2 75]] [2 77]] [2 44]]]] [899 1.33 [4895 3.86 [7708 0.429 [719 2.8 [5647 5.44 [7677 2.71 [5403 2.23 [328 4.39 [896 10.6 [5154 0.186 [7593 0.381 [929 0.511 [5 51] [5 81]] [4 42]] [458 1.54 [3211 1.33 [5 93] [5 66]] [5 62]]] [6575 2.58 [731 1.11 [5 88] [5 96]] [5 80]]] [26 57]] [31 100]] [5 18]] [3056 5.34 [5692 5.75 [5 100] [2 50]] [5 100]]] [7563 1.9 [7248 0.942 [5 72] [5 100]] [5 100]]] [1482 2.58 [5 100] [5 83]]] [38 54]] [13 56]]] [194 2.28 [5480 0.239 [7281 7.12 [4449 1.09 [1303 0.136 [7667 0.181 [3020 0.388 [6 95] [6 100]] [6 100]] [221 8.16 [6 62] [6 92]]] [2526 64.1 [4725 1.48 [6 50] [6 100]] [6 100]]] [6 70]] [6 50]] [6 62]]] [4187 6.14 [3765 0.701 [2493 0.664 [6184 1.29 [13 44] [144 1.29 [13 50] [2 42]]] [13 100]] [13 100]] [2 41]]] [7325 0.127 [1429 25.4 [5413 0.958 [573 1.13 [5769 0.388 [7241 1.24 [5 21] [5 77]] [4 93]] [5769 0.873 [4 42] [4 100]]] [2905 3.48 [4332 4.3 [6074 0.431 [4 83] [429 20 [4 100] [5659 0.431 [6982 3.33 [4 100] [4 85]] [4 100]]]] [4 77]] [4 80]]] [7563 1.81 [7326 0.205 [6984 0.382 [458 0.445 [7169 3.2 [695 1.32 [5 55] [5 66]] [4517 0.377 [12 37] [5 87]]] [5 100]] [4 100]] [7735 1.23 [2607 0.437 [6353 0.364 [3249 0.842 [3381 0.805 [23 17.1 [7693 1.17 [6550 0.225 [3841 4.12 [1546 11.3 [3576 8.44 [6575 7.37 [2628 8.35 [5 96] [5 88]] [5 80]] [5 75]] [5 71]] [5 72]] [2902 0.582 [5 96] [5 100]]] [5 83]] [5 66]] [18 57]] [5 50]] [5 63]] [5 42]] [5 42]]] [5 100]]] [5692 3.85 [929 2.05 [130 1.77 [642 4.78 [4200 4.6 [458 0.545 [2526 9.03 [7381 3.68 [1062 2.22 [5 56] [5 100]] [5 55]] [3313 0.89 [7414 3.56 [906 3.35 [5 97] [5 86]] [5 50]] [5 100]]] [5 100]] [5 62]] [5 27]] [38 54]] [5 60]] [7248 0.456 [7566 0.277 [5 90] [5 100]] [5 100]]]]] [6537 2.92 [5692 0.786 [6791 3.4 [429 0.773 [13 18] [25 91]] [25 50]] [6457 0.695 [25 50] [25 100]]] [1 50]]] [5405 0.195 [5753 3.08 [31 100] [6857 0.627 [31 98] [31 100]]] [31 100]]] [957 0.245 [17 1.54 [4279 13.2 [5641 0.759 [1888 3.26 [4110 2.6 [7016 2.93 [1919 0.768 [3999 1.04 [5 57] [5 100]] [5 100]] [12 42]] [5 92]] [3576 1.27 [2842 1.58 [5 85] [5 100]] [5 66]]] [19 66]] [719 1.22 [19 60] [19 66]]] [5 94]] [5 87]]] [2929 1.71 [811 0.519 [2259 7.5 [5019 3.42 [5297 0.751 [6980 0.283 [3312 0.72 [3515 0.254 [7563 0.824 [3592 0.21 [5907 0.28 [1690 0.677 [3928 0.907 [5904 1.3 [1400 3.06 [3519 1.85 [6581 1.02 [5420 1.87 [2605 2.02 [2526 16.9 [6791 5.76 [703 0.596 [2760 4.29 [17 1.55 [1911 3.36 [429 29.1 [978 2.38 [14 37] [688 0.624 [5 26] [7 91]]] [567 2.4 [494 6.19 [2526 8.88 [17 37] [7 64]] [4 33]] [38 57]]] [4 44]] [38 22]] [17 91]] [7 100]] [17 100]] [1151 1.31 [7 59] [17 50]]] [31 100]] [13 80]] [7203 5.09 [485 2.06 [4001 0.931 [7590 10.5 [4571 1.81 [3056 1.3 [2178 4.09 [7586 1.87 [7561 1.72 [5192 3.67 [6342 0.196 [5693 3.3 [6358 1.93 [5192 2.06 [731 3.24 [7188 8.6 [7742 0.629 [17 55] [17 44]] [2541 4.89 [494 8.77 [19 71] [7512 23.9 [17 66] [17 75]]] [38 40]]] [4061 3.47 [6413 1.11 [1783 2.76 [1630 1.5 [7192 5.13 [17 65] [19 62]] [17 100]] [17 40]] [17 55]] [17 33]]] [17 91]] [17 87]] [17 31]] [17 100]] [17 88]] [17 36]] [5412 4.09 [17 76] [17 100]]] [19 42]] [5 50]] [17 46]] [17 44]] [5 44]] [4457 2.55 [6891 3.06 [649 1.23 [5692 2.02 [5510 0.264 [178 1.79 [3503 0.836 [3732 4.68 [17 80] [17 50]] [17 94]] [38 40]] [17 90]] [5198 1.53 [144 0.773 [17 50] [2753 0.889 [17 33] [19 62]]] [35 46]]] [16 53]] [6977 1.68 [19 66] [17 50]]] [38 87]]] [19 70]]] [19 100]] [14 64]] [7253 1.46 [1838 0.659 [19 75] [19 100]] [19 66]]] [5345 0.759 [7169 2.13 [5 50] [5 75]] [5 90]]] [144 5.4 [2752 11.9 [7665 16.1 [17 100] [17 46]] [719 3.19 [5647 2.07 [17 72] [2939 0.387 [17 100] [17 85]]] [17 100]]] [19 76]]] [5673 4.95 [19 100] [19 88]]] [5 80]] [2826 0.321 [5 73] [5 100]]] [7185 4.94 [2241 0.585 [3905 4.38 [19 60] [7381 1.02 [19 86] [19 100]]] [19 62]] [7 50]]] [7 94]] [5412 0.898 [642 0.56 [4895 4.64 [7009 0.581 [5509 2.46 [5953 0.341 [6591 9.16 [1429 54.3 [17 87] [17 77]] [17 66]] [17 70]] [5 33]] [5 87]] [17 66]] [5 87]] [1919 4.5 [602 3.32 [3929 0.483 [17 58] [17 100]] [17 100]] [1011 4.2 [2536 0.437 [17 94] [17 57]] [2628 5.85 [3 36] [17 70]]]]]] [1919 1.92 [3732 0.703 [728 1.63 [19 76] [19 83]] [728 3.11 [19 96] [19 87]]] [19 50]]] [3332 1.82 [724 0.442 [6597 1.59 [6584 1.3 [35 40] [35 81]] [35 100]] [17 33]] [35 100]]] [7533 3.38 [7356 1.35 [6233 0.631 [5405 1.1 [360 0.78 [2339 0.571 [7563 4.18 [6040 0.655 [4997 1.48 [5729 4.33 [6621 0.9 [377 5.96 [3928 5.61 [7188 9.37 [6581 3.05 [178 2.29 [7354 1.54 [14 31] [36 84]] [7 33]] [1783 0.493 [6550 4.41 [17 57] [19 63]] [17 60]]] [7 50]] [17 77]] [7 100]] [7 57]] [7 66]] [7 100]] [14 50]] [5 100]] [36 100]] [7 100]] [31 100]] [31 100]] [36 92]] [7 65]]] [7068 0.347 [5725 0.843 [36 46] [31 100]] [1738 0.309 [36 88] [36 100]]]] [1400 0.478 [31 75] [31 100]]]] [2605 0.144 [6530 0.295 [2580 0.629 [3742 0.562 [3100 0.858 [7576 1.16 [5429 0.682 [7720 1.55 [5413 4.59 [4279 5.49 [4851 0.293 [2586 2.61 [7329 1.29 [25 40] [25 100]] [25 100]] [7665 33.3 [6074 1.93 [7381 0.618 [7 83] [1078 10.3 [7 100] [7 87]]] [7 100]] [7 60]]] [25 54]] [1 83]] [1 90]] [25 95]] [25 100]] [3635 0.858 [1 96] [1 100]]] [7 100]] [25 100]] [1567 0.445 [1899 1.56 [5812 2.41 [7 80] [7 100]] [7 51]] [36 100]]] [5371 1.26 [2005 0.379 [2986 0.673 [1429 15.3 [7583 2.08 [25 72] [826 0.695 [6460 0.693 [7665 20 [25 100] [25 88]] [25 100]] [25 100]]] [25 72]] [25 100]] [25 100]] [25 50]]]] [5677 0.09 [5412 1.75 [21 0.962 [3905 4.84 [1704 6.9 [7595 0.639 [4661 0.137 [17 68] [6584 0.289 [17 71] [17 100]]] [17 100]] [17 100]] [1726 4.09 [7722 5.83 [4414 0.315 [5741 0.703 [1707 3.64 [7712 1.68 [7333 2.54 [2939 1.55 [17 93] [17 66]] [17 69]] [17 50]] [17 33]] [38 57]] [6581 2.84 [17 85] [17 100]]] [2616 6.28 [14 50] [17 87]]] [19 71]]] [7192 1.56 [1584 0.626 [17 69] [17 40]] [17 46]]] [1704 0.367 [4630 0.168 [1011 2.02 [17 55] [2753 1.11 [3905 5.08 [978 13.8 [17 100] [17 83]] [17 84]] [17 66]]] [17 71]] [602 3.55 [6310 0.106 [7722 2.68 [17 90] [17 100]] [17 100]] [17 90]]]] [4478 1.17 [1011 3.37 [1889 0.27 [7590 0.708 [6313 0.794 [19 56] [5844 0.659 [17 54] [19 42]]] [7188 2.1 [19 71] [19 92]]] [19 68]] [17 83]] [17 50]]]] [3517 0.381 [1239 6.05 [7200 1.44 [3928 5.88 [6725 1.37 [7075 0.624 [5838 0.452 [1740 1.43 [5522 2.07 [4937 0.178 [567 1.26 [7472 3.21 [4861 3.62 [3908 1.45 [6653 0.665 [429 19.2 [4851 3.23 [929 1.54 [728 0.271 [17 100] [19 55]] [38 71]] [14 50]] [2005 0.179 [5971 0.319 [6708 0.278 [5157 9.25 [6575 2.29 [1666 0.392 [5892 0.469 [7512 29.3 [5198 1.29 [7210 1.76 [4870 0.945 [17 93] [17 100]] [17 87]] [17 71]] [17 80]] [17 100]] [2526 8.58 [17 62] [17 100]]] [5157 1.99 [17 62] [17 33]]] [17 37]] [17 66]] [17 58]] [19 53]]] [4805 4.21 [17 100] [5155 3.6 [17 71] [17 100]]]] [19 55]] [19 45]] [38 86]] [7185 2.09 [731 9.21 [17 87] [19 50]] [19 63]]] [19 45]] [5155 2.14 [35 83] [17 53]]] [4568 1.75 [2259 1.97 [6310 1.72 [19 50] [19 85]] [19 40]] [38 57]]] [19 44]] [17 100]] [5413 0.741 [1899 1.55 [6535 2.48 [17 33] [19 84]] [17 71]] [19 53]]] [3317 2.76 [1239 3.59 [2628 2.92 [17 100] [17 85]] [17 85]] [17 83]]] [17 100]] [19 53]] [5640 0.675 [3077 2.87 [7512 25.8 [2967 0.103 [2628 9.61 [5732 12.1 [6550 8.8 [7682 1.7 [19 100] [4083 0.626 [19 100] [719 1.52 [19 100] [19 60]]]] [19 87]] [19 88]] [19 75]] [5192 1.36 [6436 0.617 [19 100] [19 85]] [19 71]]] [19 70]] [5905 2.44 [1072 2.08 [6727 1.07 [19 100] [19 76]] [19 78]] [19 60]]] [1011 0.922 [26 53] [7520 1.33 [19 76] [19 100]]]]]] [6988 0.168 [3659 0.303 [5972 3.52 [6851 0.538 [5792 0.226 [4146 0.78 [5891 1.09 [5320 0.245 [4895 0.237 [3008 1.06 [5820 0.393 [3905 0.458 [643 0.276 [3929 0.586 [7324 0.226 [5692 0.548 [4 34] [1073 5.53 [5412 2 [4288 2.08 [434 1.99 [2592 0.268 [906 0.482 [2259 1.31 [7665 9.86 [2 77] [4 41]] [896 2.89 [4 100] [4 81]]] [4 87]] [4 100]] [2 63]] [4 37]] [2 60]] [1 50]]] [573 0.175 [4 84] [4235 2.44 [4 100] [4 87]]]] [5 55]] [2 100]] [17 41]] [5240 0.344 [7584 0.645 [5753 0.534 [7568 2.1 [567 1.73 [6977 0.38 [5771 10 [23 1.23 [4 71] [4 100]] [4 75]] [4 66]] [4 40]] [2 54]] [2 80]] [2 88]] [4218 0.344 [4 100] [4 90]]]] [3018 0.508 [7419 1.48 [17 40] [16 42]] [24 95]]] [29 26]] [22 53]] [17 95]] [24 100]] [24 100]] [24 100]] [31 100]] [7667 1.15 [4216 1.25 [7591 0.731 [24 100] [5192 0.914 [5211 1.84 [24 75] [24 100]] [2533 0.143 [24 100] [24 83]]]] [24 71]] [24 78]]] [5771 15.1 [2811 0.74 [6935 0.458 [663 1.7 [4835 1.59 [5692 1.16 [1069 1.79 [5647 0.434 [2 69] [2 100]] [2 55]] [4221 0.988 [1911 5.48 [2597 2.53 [641 2.16 [1239 0.259 [2553 2.13 [2 100] [2 91]] [2 100]] [2 88]] [2 92]] [2 60]] [5659 1.09 [2 66] [2 100]]]] [5412 2.62 [2 55] [2 71]]] [2674 0.827 [5814 0.444 [6109 0.154 [667 0.81 [2 100] [2 90]] [2 80]] [2 44]] [7677 2.77 [2628 3.87 [6076 1.39 [2 100] [2 71]] [999 4.11 [2 100] [5692 10.7 [2 100] [2 87]]]] [2 75]]]] [5851 1.31 [2 85] [2 50]]] [5192 1.68 [2 57] [2 50]]] [791 5.22 [4 63] [2 100]]]]]]] [560 0.694 [5092 0.936 [338 0.93 [1429 16.2 [2399 0.946 [2562 0.239 [1400 3.9 [7722 0.742 [5073 0.787 [6530 0.341 [2752 14.9 [4282 1.36 [5360 0.233 [7512 1.12 [2321 0.852 [5041 0.418 [2470 4.43 [5226 1.26 [1186 4.41 [6031 0.934 [907 0.91 [968 1.23 [4288 2.01 [6529 4.68 [978 0.358 [5482 1.76 [5368 2.16 [4690 3.65 [695 22.9 [5225 6.35 [4480 1.62 [397 1.91 [580 1.47 [828 3.4 [5211 10.9 [5270 3.19 [2726 1.32 [1672 1.78 [4165 5.71 [5832 0.952 [2440 1.12 [4684 1.25 [537 1.42 [4630 12.8 [906 5.43 [7505 0.748 [663 0.352 [2707 1.72 [802 6.91 [250 6.86 [23 9] [33 62]] [9 48]] [16 41]] [16 23]] [11 66]] [9 29]] [11 58]] [3 100]] [5753 0.816 [1078 12.7 [15 38] [27 62]] [1 25]]] [38 81]] [9 100]] [22 100]] [22 100]] [738 1.29 [18 50] [18 60]]] [1239 9.1 [6276 1.62 [10 73] [10 100]] [10 42]]] [22 85]] [32 45]] [9 69]] [18 70]] [9 47]] [791 30.2 [22 84] [22 100]]] [22 74]] [8 75]] [9 69]] [791 1.75 [29 32] [4326 0.766 [6015 11.4 [1253 3.55 [4769 1.78 [2752 10.4 [2143 0.743 [29 63] [29 44]] [22 41]] [29 100]] [9 57]] [21 90]] [29 100]]]] [5673 2.37 [6735 0.412 [2108 0.511 [5693 2.59 [5647 7.47 [7665 2.67 [5799 2.35 [5482 2.41 [4690 0.659 [1899 7.45 [23 33] [286 0.253 [1 20] [23 100]]] [8 76]] [22 35]] [23 71]] [26 50]] [23 57]] [2 57]] [23 69]] [2 50]] [18 47]]] [22 84]] [23 85]] [5034 0.982 [5219 1.49 [6395 3.07 [3308 1.05 [2081 3.07 [429 40.4 [8 74] [22 45]] [3 18]] [11 50]] [8 100]] [8 97]] [28 75]]] [4407 2.45 [4991 0.182 [556 0.432 [4748 7.11 [5481 2.92 [4417 2.3 [6310 0.488 [7359 0.717 [21 54] [21 75]] [21 100]] [21 100]] [9 87]] [9 100]] [21 100]] [9 66]] [3 33]]] [5753 8.15 [22 88] [0 28]]] [29 69]] [5692 0.747 [22 53] [22 80]]] [900 2.24 [4852 0.728 [695 6.46 [7132 2.88 [7449 26.3 [5755 0.46 [1239 13.2 [11 71] [21 80]] [11 100]] [11 44]] [4 100]] [11 64]] [11 100]] [4 83]]] [21 100]] [968 0.852 [8 89] [8 100]]] [1025 1.48 [2740 1.18 [5254 0.803 [5753 2.99 [2868 1.86 [2470 9.24 [4504 2.06 [7537 0.258 [1 0.983 [6323 0.879 [5211 2.12 [1888 1.85 [7491 1.79 [4601 2.11 [5140 1.77 [7734 3.38 [1913 0.568 [2616 2.8 [5099 3.13 [33 21] [6 50]] [26 38]] [6 70]] [377 1.75 [2342 0.986 [18 68] [19 50]] [18 83]]] [33 100]] [26 78]] [2081 3.81 [29 100] [29 42]]] [532 2.26 [7677 1.48 [18 41] [13 33]] [19 60]]] [8 40]] [29 100]] [26 70]] [7665 6.97 [19 43] [7537 8.75 [18 100] [18 71]]]] [5647 0.898 [19 47] [19 80]]] [26 61]] [5100 3.1 [18 48] [16 69]]] [4571 0.184 [864 0.244 [7512 24.2 [5484 0.911 [7665 3.65 [10 25] [33 34]] [29 44]] [10 82]] [38 60]] [23 83]]] [10 100]] [4 100]] [2739 6.79 [7449 0.431 [6260 1.38 [5753 7.89 [4851 1.23 [1047 0.846 [6185 1.86 [2 29] [33 42]] [2 69]] [4 88]] [10 37]] [24 87]] [5480 6.34 [2 33] [29 70]]] [4 100]]]] [4682 0.369 [4214 1.34 [5574 1.17 [33 91] [33 100]] [33 100]] [33 100]]] [7077 1.8 [3 94] [3 83]]] [5755 0.402 [877 0.221 [5226 0.614 [5120 1.12 [929 0.697 [5692 4.12 [5731 0.724 [695 12.8 [573 2.05 [5904 1.61 [6885 0.362 [673 1.9 [7354 5.22 [6871 0.636 [968 13.1 [2701 0.564 [3095 1.66 [719 1.56 [3492 1.93 [145 5.17 [2616 0.428 [5211 0.659 [3959 0.649 [685 3.04 [2091 0.232 [791 2.04 [1429 4.42 [12 16] [4 33]] [1226 9.73 [23 47] [23 100]]] [1980 9.07 [10 28] [29 41]]] [5753 1.38 [23 71] [23 100]]] [29 72]] [6791 2.54 [6203 4 [435 0.832 [5871 1.47 [996 1.9 [23 50] [5486 1.43 [23 92] [23 100]]] [22 57]] [23 93]] [22 100]] [23 76]]] [25 29]] [22 84]] [8 75]] [2 28]] [23 78]] [7461 1.65 [939 0.835 [29 96] [29 100]] [29 100]]] [8 100]] [906 1.22 [29 92] [29 100]]] [18 67]] [1025 5.38 [5170 2.37 [5480 8.07 [26 69] [26 93]] [429 7.8 [26 80] [26 57]]] [26 87]]] [1980 1.31 [23 72] [23 100]]] [1262 3.89 [19 72] [19 100]]] [4 60]] [5110 3.7 [22 47] [22 90]]] [11 100]] [5693 2.27 [864 1.39 [7254 0.84 [5217 1.13 [248 8.63 [1911 0.355 [6920 0.728 [857 1.93 [695 1.25 [23 43] [1078 4.71 [22 54] [22 95]]] [22 100]] [23 100]] [22 60]] [26 94]] [22 100]] [1 36]] [22 100]] [859 0.997 [899 2.88 [7335 5.57 [660 8.99 [2526 23.7 [5662 7.71 [26 33] [1 50]] [18 54]] [29 90]] [23 87]] [791 28 [29 85] [29 100]]] [22 71]]]] [429 9.81 [26 85] [7354 4.05 [791 1.58 [23 66] [688 1.65 [1025 1.6 [23 89] [938 0.262 [429 28.8 [23 80] [23 100]] [23 100]]] [23 91]]] [18 45]]]] [22 100]] [384 0.678 [6663 0.703 [7139 0.895 [5692 2.44 [1025 0.963 [11 37] [5226 3.42 [11 100] [11 68]]] [887 1.37 [22 80] [11 73]]] [11 100]] [11 100]] [23 100]]] [22 100]] [2145 0.393 [2143 4.1 [11 100] [11 80]] [11 100]]]] [36 0.487 [1391 0.921 [328 2.25 [6853 1.22 [660 2.04 [429 24.6 [5410 13 [7176 1.53 [22 97] [22 100]] [22 100]] [22 55]] [29 63]] [22 100]] [22 63]] [22 100]] [22 100]]] [248 1.16 [29 90] [29 100]]] [7340 0.928 [2748 1.37 [1068 2.54 [899 1.1 [7512 38.9 [5132 1.26 [575 0.431 [6537 0.754 [1078 32.6 [7245 0.152 [7568 0.326 [673 2.95 [429 28 [364 1.69 [7241 3.19 [7512 29.8 [248 16.5 [695 1.79 [7404 1.79 [18 24] [6 100]] [18 23]] [26 66]] [26 48]] [19 64]] [18 77]] [29 37]] [5198 0.254 [4279 1.71 [7516 5.26 [6585 5.47 [26 57] [26 100]] [26 93]] [26 100]] [26 66]]] [2 68]] [19 30]] [2259 2.95 [22 27] [22 78]]] [4585 1.47 [6074 1.47 [2 66] [2 100]] [2 57]]] [26 100]] [5198 1.66 [16 38] [18 90]]] [26 59]] [5970 0.559 [2081 0.688 [5668 0.816 [29 26] [29 87]] [29 100]] [29 100]]] [4312 2.23 [29 47] [29 77]]] [1899 4.48 [1884 3.45 [26 93] [26 80]] [26 62]]] [18 57]]] [732 0.488 [7185 4.46 [7449 3.35 [4533 0.266 [1333 0.832 [7314 2.9 [5574 1.31 [4613 1.37 [7210 0.941 [1911 5.12 [328 1.29 [1078 22.5 [3895 0.843 [5605 1.13 [1888 13.3 [26 41] [26 86]] [12 28]] [12 100]] [12 54]] [26 64]] [12 44]] [26 24]] [26 100]] [2 50]] [26 100]] [10 100]] [2813 0.756 [662 1.23 [1391 3.52 [4288 1.03 [6926 0.293 [4533 3.77 [1429 5.91 [10 50] [4 60]] [12 33]] [2 100]] [10 30]] [15 93]] [2 55]] [12 100]]] [6393 0.795 [4478 0.778 [5488 1.07 [906 7.2 [5692 3.71 [7411 1.38 [15 50] [15 77]] [12 63]] [12 100]] [12 96]] [21 66]] [15 100]]] [6347 1.56 [5013 0.079 [4929 0.59 [5211 0.457 [4851 0.36 [5207 1.82 [1899 0.498 [6517 1.32 [6848 4.27 [26 86] [26 44]] [26 100]] [248 22.4 [12 33] [328 0.797 [26 77] [26 62]]]] [26 60]] [1432 0.36 [2526 11.7 [5170 0.792 [23 10.4 [7681 2.37 [4603 2.3 [5192 2.69 [7665 28.4 [26 100] [26 92]] [26 77]] [26 100]] [26 44]] [26 87]] [26 100]] [2526 36.8 [26 100] [26 93]]] [26 100]]] [26 50]] [26 66]] [5799 0.158 [5695 0.864 [26 100] [26 57]] [16 50]]] [26 64]]] [5904 4.58 [4946 1.31 [980 2.86 [980 2.69 [328 5.58 [1078 5.24 [1023 1.24 [7187 17.3 [26 100] [719 2.04 [26 83] [26 100]]] [26 100]] [695 4.06 [26 96] [26 80]]] [6585 0.734 [1078 3.25 [26 84] [26 50]] [26 100]]] [26 62]] [26 100]] [26 55]] [19 66]]]] [2004 0.639 [4929 0.121 [5420 0.836 [5226 0.398 [7453 0.695 [968 0.893 [3492 0.82 [6553 2.96 [5267 4.56 [5225 0.688 [1101 0.775 [2143 5.44 [1068 1.06 [6031 3.94 [883 4.73 [1429 10.5 [8 58] [8 91]] [0 94]] [22 100]] [23 57]] [23 100]] [23 92]] [23 78]] [23 100]] [0 100]] [1391 1.39 [4154 0.743 [8 65] [8 100]] [0 100]]] [2488 0.96 [6560 1.31 [8 94] [8 100]] [8 100]]] [23 100]] [7210 2.25 [2081 3.22 [22 57] [23 100]] [22 50]]] [22 52]] [1068 1.94 [8 100] [8 71]]] [5225 0.352 [998 0.47 [685 0.898 [1025 2.49 [23 73] [23 100]] [23 100]] [23 100]] [1429 9.85 [23 100] [23 77]]]]] [3905 2.84 [8 96] [8 77]]] [7016 0.308 [5224 0.126 [809 0.284 [4398 6.68 [1493 0.412 [5484 1.52 [2550 0.413 [5587 2.09 [5211 3.25 [5290 0.307 [6214 0.327 [6063 0.581 [2705 0.435 [2385 0.402 [284 0.949 [5640 7.16 [896 4.41 [4964 0.68 [7734 0.875 [6585 3.14 [221 4.25 [6365 0.935 [2726 0.0511 [4926 0.283 [2809 0.3 [791 6.44 [5007 0.358 [7354 3.5 [248 15.9 [3310 0.349 [1899 10.2 [2469 1.05 [5972 9.34 [178 7.36 [543 4.35 [6537 2.07 [7425 5.49 [5480 33.4 [5403 1.62 [4279 1.61 [3309 0.973 [3308 6.71 [1576 24.6 [2241 0.94 [5692 5.94 [3079 1.52 [7413 1.36 [4764 1.09 [394 0.657 [18 13] [26 50]] [23 28]] [4 23]] [37 100]] [18 34]] [1 25]] [2 100]] [11 37]] [7 44]] [19 12]] [3 61]] [18 33]] [18 64]] [2 57]] [32 53]] [1429 57.8 [18 75] [18 40]]] [12 78]] [38 63]] [6074 2.25 [5692 2.3 [23 23] [33 25]] [2 20]]] [29 58]] [429 4.86 [26 65] [26 20]]] [1078 11 [7354 13.6 [5154 1.8 [7169 2.55 [1023 3.85 [18 72] [18 38]] [18 100]] [18 37]] [731 12.1 [16 17] [19 52]]] [18 64]]] [4507 2.56 [7665 2.2 [178 1.13 [5007 7.09 [35 36] [12 26]] [6 45]] [1062 3.26 [38 52] [19 30]]] [18 62]]] [6091 2.28 [5476 0.327 [286 8.77 [3294 0.6 [939 4.38 [721 1.48 [3960 1.57 [3771 1.74 [5003 3.47 [7472 1.59 [2232 1.45 [3325 2.17 [6665 0.659 [5472 0.945 [3374 4.54 [4218 2.89 [5972 11.7 [6733 0.739 [6320 2.25 [2917 0.436 [883 4.21 [7623 4.29 [822 1.6 [2093 0.64 [5034 3.46 [1601 1.69 [2701 3.88 [7453 2.96 [1788 3.27 [5900 7.4 [2616 2.53 [23 0.759 [850 0.867 [826 0.818 [6342 4.29 [802 2.39 [23 16] [3 44]] [23 25]] [11 33]] [13 66]] [1078 0.944 [3 18] [2 13]]] [18 85]] [7 46]] [10 85]] [23 77]] [29 91]] [29 63]] [28 33]] [4 17]] [21 53]] [12 41]] [0 50]] [3 80]] [21 66]] [26 81]] [12 100]] [14 77]] [37 77]] [13 51]] [12 94]] [29 100]] [28 39]] [38 100]] [7 100]] [37 100]] [29 100]] [36 75]] [2259 3.71 [29 67] [18 33]]] [37 100]] [23 81]] [13 100]] [4374 0.813 [12 51] [12 100]]]] [7699 2.72 [736 6.26 [18 50] [18 71]] [1429 47.6 [18 100] [18 66]]]] [567 0.183 [392 0.778 [1783 3.26 [978 2.38 [18 62] [18 84]] [19 27]] [18 87]] [18 100]]] [4889 0.16 [5637 0.631 [388 1.66 [2732 1.18 [144 1.36 [18 74] [16 38]] [16 100]] [16 44]] [5627 1.73 [2846 0.611 [4897 3.42 [2826 1.42 [7391 1.06 [16 76] [16 83]] [16 70]] [16 50]] [18 60]] [6 44]]] [16 76]]] [12 100]] [5632 1.45 [1888 1.71 [328 0.756 [6015 1.38 [29 26] [29 100]] [685 1.4 [5034 1.04 [1899 0.835 [22 28] [10 22]] [28 100]] [28 92]]] [4 26]] [7 40]]] [26 89]] [5099 0.818 [364 0.631 [4920 3.85 [1668 0.469 [5130 9.09 [1078 43.4 [7419 3.81 [685 4.42 [7210 0.982 [5900 6.75 [18 72] [6 55]] [16 25]] [5281 4.74 [18 93] [18 77]]] [19 44]] [16 50]] [16 81]] [2259 8.25 [18 70] [19 80]]] [18 57]] [6 50]] [7603 0.284 [221 1.32 [6136 0.502 [6091 2.57 [5635 0.252 [18 80] [18 62]] [16 33]] [18 50]] [16 87]] [16 92]]]] [2259 41.6 [7210 5.53 [4 82] [4 42]] [4 93]]] [7038 0.412 [1913 2.59 [2749 0.816 [802 1.21 [5635 1.28 [2628 7.94 [7381 0.0611 [7588 1.04 [5454 3.59 [6044 8.34 [1432 5.85 [3515 1.46 [4684 0.942 [4159 0.715 [6791 12.3 [5753 11.2 [6082 0.255 [4743 3.01 [185 1.42 [1883 1.4 [6230 17.1 [4541 0.998 [6134 3.91 [398 6.89 [6959 5.14 [7472 0.77 [23 22.1 [5873 12.6 [6131 0.733 [2081 7.5 [278 3.31 [899 4.79 [1007 10.3 [5192 11.1 [673 9.44 [1705 6.13 [152 8.79 [2905 3.36 [1089 1.22 [5776 7.24 [1177 1.5 [736 5.57 [144 4.87 [3989 1.22 [1769 21.3 [2831 1.22 [6353 5.61 [5129 2.83 [5480 21 [7245 2.65 [2570 10.3 [653 3.09 [5132 14.1 [1078 8.41 [7248 0.221 [791 10 [1429 53.9 [18 100] [18 90]] [1429 34.3 [18 46] [5482 3.45 [18 64] [18 100]]]] [18 100]] [1253 4.83 [1783 8.19 [18 100] [18 93]] [18 85]]] [18 88]] [18 100]] [18 83]] [18 83]] [18 59]] [18 25]] [18 62]] [18 100]] [18 42]] [18 100]] [978 8.83 [18 63] [18 82]]] [18 47]] [18 100]] [18 50]] [16 40]] [18 57]] [18 70]] [18 71]] [18 80]] [18 46]] [18 55]] [18 35]] [16 60]] [29 42]] [18 55]] [18 53]] [18 39]] [38 66]] [16 50]] [16 44]] [13 50]] [673 15.2 [18 100] [18 87]]] [16 26]] [6 30]] [18 35]] [13 28]] [35 57]] [36 44]] [16 37]] [18 37]] [18 31]] [18 52]] [26 100]] [18 100]] [29 100]] [26 100]] [610 0.462 [736 1.09 [328 0.449 [38 30] [14 44]] [3 28]] [5 87]]] [7356 1.22 [5348 1.88 [1078 22.9 [5517 1.96 [18 29] [16 66]] [4 44]] [16 50]] [18 54]]] [16 64]] [13 100]] [26 100]] [29 36]] [16 45]]] [899 1.15 [13 72] [13 100]]] [4504 4.16 [5011 6.28 [7354 12 [5871 0.0689 [19 47] [18 66]] [18 77]] [2526 8.95 [7734 2.51 [19 54] [19 100]] [18 53]]] [18 60]]] [6373 1.29 [2756 0.447 [2712 0.402 [7332 3.44 [7742 4.25 [6715 0.399 [1007 1.94 [6670 0.585 [2806 2.82 [2939 7.87 [5753 2.76 [7665 14.2 [6294 1.59 [5156 1.18 [5596 0.8 [2526 6.25 [724 3.03 [738 3.35 [5099 5.94 [5904 1.62 [939 2.68 [7285 1.31 [2260 7.03 [7169 0.711 [2526 1.08 [4927 4.32 [18 40] [18 66]] [18 25]] [18 60]] [18 30]] [10 78]] [19 80]] [7734 7.75 [7665 8.4 [18 42] [19 100]] [19 95]]] [13 46]] [18 75]] [19 100]] [2268 3.58 [2259 7 [16 66] [18 55]] [19 56]]] [19 90]] [18 100]] [19 58]] [23 15.7 [2385 10.3 [328 6.5 [18 68] [18 100]] [7188 15 [7512 24.1 [18 64] [18 87]] [18 57]]] [16 71]]] [1429 29.8 [18 38] [18 86]]] [7734 0.908 [10 76] [5 36]]] [19 90]] [19 90]] [18 68]] [18 100]] [7665 6.96 [18 69] [18 100]]] [7340 1.78 [19 84] [19 100]]] [16 50]] [2268 0.225 [18 100] [18 77]]] [429 16 [19 91] [5345 0.574 [18 37] [19 62]]]]] [126 0.554 [939 4.65 [1094 7.94 [29 100] [29 62]] [1062 9.31 [392 0.354 [29 95] [29 100]] [29 85]]] [29 100]]] [22 100]] [29 100]] [5299 1.94 [10 80] [10 77]]] [3956 2.74 [2847 1.55 [1670 0.449 [6660 1 [384 0.368 [6413 0.174 [1 0.87 [996 0.709 [663 0.585 [5233 0.593 [5482 1.8 [1913 17.8 [3905 0.726 [5824 3.23 [434 8.53 [1219 2.59 [859 1.3 [2753 3.5 [7354 3.07 [5605 1.05 [2562 3.16 [1783 4.92 [7210 1.08 [4154 5.72 [22 89] [1062 3.33 [22 63] [22 80]]] [22 73]] [22 63]] [5225 5.7 [23 42] [23 91]]] [23 40]] [8 53]] [22 94]] [93 1.95 [22 92] [22 100]]] [22 100]] [22 100]] [11 80]] [0 33]] [23 60]] [4279 2.02 [217 2.38 [22 82] [22 100]] [18 33]]] [22 100]] [2200 0.775 [711 0.585 [2753 2.59 [906 2.54 [5199 2.15 [1980 4.7 [22 82] [22 97]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]]] [23 67]] [4414 1.78 [11 55] [11 57]]] [0 69]] [4414 1.35 [23 47] [23 75]]] [5226 6.33 [2151 1.98 [11 95] [11 83]] [11 69]]] [22 100]] [22 100]] [8 100]]] [23 100]] [685 1.86 [7019 0.688 [4690 7.62 [1783 1.07 [5757 0.307 [978 2.16 [8 57] [1483 0.413 [8 76] [8 100]]] [0 100]] [8 75]] [3929 0.885 [3222 0.304 [5211 23.2 [906 1.53 [8 88] [8 100]] [8 100]] [8 100]] [8 100]]] [8 100]] [8 100]]] [1820 0.905 [6388 2.22 [6033 0.797 [5007 2.03 [7512 0.931 [22 69] [2707 2.34 [5597 1.98 [394 13.5 [324 2.37 [4478 7.9 [5187 5.56 [1219 2.85 [4369 6.41 [791 21.2 [394 7.69 [549 0.907 [1631 2.62 [2752 8.93 [4926 6.43 [18 57] [7512 28.6 [2752 1.12 [18 100] [18 80]] [18 54]]] [1705 10.9 [1429 17.8 [16 28] [722 3.16 [4946 0.521 [2571 0.811 [735 0.773 [397 10.5 [1011 9.43 [2536 2.47 [5130 1.12 [2445 3.97 [788 2.42 [6862 4.21 [18 87] [18 66]] [2434 1.15 [7665 11.5 [18 83] [18 50]] [18 75]]] [18 70]] [18 100]] [18 66]] [18 60]] [18 100]] [18 100]] [18 100]] [18 100]] [18 80]]] [7 57]]] [2763 3.51 [1888 4.53 [791 4.88 [18 50] [18 71]] [16 75]] [18 75]]] [18 100]] [7354 5.95 [18 83] [18 33]]] [29 40]] [19 77]] [18 46]] [18 100]] [18 40]] [18 36]] [16 37]] [1899 2.47 [978 3.32 [18 83] [18 60]] [2526 4.21 [18 42] [16 75]]]] [1429 29 [23 18.7 [5099 1.39 [18 75] [18 85]] [16 40]] [695 2.67 [16 100] [5518 1.17 [2716 2.31 [18 50] [18 42]] [16 66]]]]]] [685 6.14 [7742 1.82 [6708 2.83 [5198 0.617 [190 1 [6199 3.94 [7259 3.59 [1062 5.56 [7259 0.904 [392 5.54 [19 56] [19 40]] [18 40]] [18 30]] [18 55]] [18 66]] [19 85]] [19 90]] [18 37]] [7512 16.7 [5480 9.44 [18 83] [18 50]] [18 42]]] [4926 4.8 [6732 10.8 [1023 1.11 [4859 4.32 [7520 2.92 [7665 9.56 [2813 4.49 [18 66] [18 55]] [18 55]] [18 75]] [16 36]] [18 75]] [18 100]] [7665 1.36 [18 100] [18 87]]]]] [22 100]] [22 100]] [6 35]]] [8 100]] [2178 3.19 [1062 6.72 [5491 2.7 [2 14] [2 70]] [11 49]] [5991 4.9 [11 45] [11 86]]]] [4288 0.787 [4611 2.4 [877 0.263 [7604 0.99 [7343 0.675 [22 97] [22 100]] [22 88]] [22 100]] [22 62]] [22 100]]] [4929 0.219 [5765 0.607 [695 0.428 [7323 0.181 [1239 3.1 [791 5.85 [8 100] [8 63]] [8 46]] [8 100]] [4154 0.914 [22 55] [22 100]]] [22 100]] [8 100]]] [2837 3.83 [2993 0.595 [7176 0.377 [1059 1.99 [1986 0.911 [5647 2.16 [22 88] [22 57]] [22 100]] [2 66]] [1078 28.7 [22 100] [22 87]]] [22 63]] [22 100]]]] [5079 0.599 [2466 2.21 [5799 10.7 [324 1.25 [5952 1.2 [1030 11.4 [6581 15.9 [7132 0.779 [6550 0.626 [5429 3.17 [23 5.25 [5170 5.76 [1 1.08 [510 3.82 [985 3.22 [398 11.4 [7665 3.73 [7665 2.94 [1429 3.48 [394 5.05 [26 100] [26 77]] [26 100]] [26 85]] [26 100]] [26 87]] [26 85]] [5695 2.2 [2927 1.55 [2913 12.1 [26 81] [26 100]] [26 75]] [26 100]]] [26 77]] [26 83]] [26 71]] [4601 7.02 [26 100] [26 75]]] [26 100]] [26 66]] [26 66]] [26 77]] [26 50]] [26 100]] [26 55]] [26 63]] [25 42]]] [5368 3.9 [5282 0.208 [4487 4.29 [4673 0.624 [2841 0.255 [6031 0.805 [663 1.01 [22 100] [22 77]] [22 100]] [22 100]] [22 100]] [22 60]] [22 100]] [5844 6.01 [22 83] [22 100]]]] [2716 0.64 [1078 9.85 [4748 1.76 [2259 27.5 [2200 5 [7623 16.8 [2849 5.64 [7425 8.28 [4977 22.6 [5937 1.1 [7734 1.47 [145 6.11 [5983 9.46 [5637 0.363 [2005 4.94 [1072 1.02 [2760 4.95 [7425 3.57 [6732 2.14 [5215 0.956 [6353 0.162 [1671 15.5 [132 1.96 [5412 0.494 [4154 6.29 [7185 39.9 [18 52] [4 33]] [3 75]] [3 26]] [18 76]] [16 71]] [18 86]] [1980 2.07 [22 91] [22 100]]] [7169 5.93 [7354 1.41 [18 36] [18 70]] [18 60]]] [16 58]] [18 100]] [18 100]] [7 28]] [18 73]] [19 43]] [695 9.14 [29 62] [18 62]]] [4893 0.858 [1429 40.1 [5851 4.7 [5268 0.17 [4939 16.3 [1187 0.376 [5348 12.9 [4509 7.35 [791 9.2 [279 25.9 [4859 28.1 [284 3.11 [4414 17.7 [5267 4.59 [1186 2.46 [695 35.8 [7736 15.9 [6732 5.75 [134 16.7 [7197 0.44 [4530 0.488 [384 2.25 [5161 0.664 [4647 1.78 [144 12.7 [7737 3.41 [5971 3.57 [144 5.35 [4533 2.94 [18 82] [18 100]] [18 57]] [18 100]] [18 75]] [18 100]] [18 66]] [18 89]] [18 89]] [18 86]] [18 62]] [18 54]] [1429 7.46 [18 92] [2939 1.25 [6732 8.99 [18 60] [16 50]] [18 85]]]] [18 52]] [18 52]] [18 46]] [16 50]] [16 50]] [733 0.924 [6353 0.894 [7512 22.8 [18 54] [18 92]] [16 33]] [26 66]]] [16 44]] [18 60]] [2607 3.62 [6230 1.66 [5154 2.9 [4504 6.52 [2526 12.3 [7185 13.4 [18 51] [18 100]] [1899 5.55 [18 100] [18 75]]] [18 83]] [18 90]] [4414 2.43 [18 38] [16 50]]] [16 50]]] [18 100]] [6 27]] [19 57]] [16 80]] [18 44]] [791 2.65 [18 90] [18 100]]] [532 2.01 [5637 14.9 [7445 4.16 [6910 3.12 [2752 12.7 [547 4.42 [647 1.69 [788 6.87 [5130 3.49 [2081 1.25 [7737 1.2 [248 4.27 [7520 1.66 [791 4.5 [18 83] [18 100]] [18 100]] [18 100]] [18 100]] [18 100]] [18 84]] [18 66]] [18 100]] [18 83]] [4946 0.766 [7731 3.61 [5160 3.25 [738 3.48 [7512 24.7 [18 92] [18 42]] [18 85]] [18 85]] [18 57]] [18 100]]] [7354 1.75 [18 60] [18 85]]] [18 75]] [18 50]] [328 9.58 [5482 10.3 [18 96] [18 63]] [18 66]]]] [6 44]]] [21 80]] [16 33]] [1078 2.2 [6027 2.3 [18 85] [18 100]] [18 100]]] [6471 3.79 [1631 3.01 [7232 5.09 [5662 0.362 [7419 6.62 [5931 1.08 [4937 5.42 [6732 0.711 [560 16.9 [144 7 [5103 2.03 [1997 1.21 [7231 3.95 [5482 7.05 [94 2.39 [78 2.11 [64 0.795 [7301 1.5 [6659 10.3 [5485 11 [18 78] [18 57]] [18 93]] [18 100]] [18 62]] [18 100]] [18 45]] [18 40]] [18 50]] [2628 14.1 [18 85] [5900 9.98 [18 50] [16 50]]]] [957 4.11 [2713 0.879 [18 71] [16 50]] [18 88]]] [16 37]] [16 40]] [1899 2.15 [5632 3.08 [18 100] [18 85]] [18 80]]] [16 62]] [1980 1.16 [2868 0.502 [16 40] [16 42]] [18 44]]] [30 44]] [7260 1.57 [18 45] [18 100]]] [19 57]] [16 43]] [685 3.88 [282 0.383 [18 33] [26 72]] [18 38]]]] [12 100]] [21 42]] [276 16.1 [6757 0.372 [7009 2.51 [964 3.79 [7733 0.677 [6027 1.2 [7734 2.68 [1783 1.23 [24 19] [18 57]] [7566 3.91 [719 0.64 [1078 3.5 [2259 33.5 [18 42] [19 42]] [18 60]] [6658 2.97 [4571 0.873 [18 72] [19 83]] [18 100]]] [18 42]]] [16 40]] [18 100]] [2259 43.2 [560 9.11 [19 62] [19 75]] [6 40]]] [19 40]] [19 77]] [6 75]]] [9 70]] [731 1.21 [6397 2.23 [435 1.19 [6659 0.223 [2260 0.699 [1739 1.11 [5011 1.98 [1980 1.1 [5225 1.02 [6827 5.29 [404 8.77 [4663 0.842 [4533 1.74 [6312 1 [7210 5.26 [2536 1.92 [1009 5.02 [7210 3.51 [1705 1.68 [5878 5.05 [2813 4.05 [7735 6.74 [532 10.4 [7736 6.1 [5693 0.873 [7722 1.05 [5632 1.77 [4414 7.61 [2752 33.6 [429 60.9 [18 72] [18 38]] [22 42]] [18 42]] [18 77]] [18 37]] [18 88]] [18 86]] [19 42]] [18 45]] [18 96]] [18 77]] [18 100]] [18 66]] [8 33]] [18 53]] [18 33]] [16 40]] [18 57]] [22 25]] [7 33]] [2526 1.29 [18 90] [18 100]]] [22 100]] [7513 4.11 [178 0.524 [5482 6.1 [1023 3.91 [5110 0.803 [328 8.63 [791 14.6 [18 57] [791 26.4 [22 38] [22 62]]] [18 100]] [22 69]] [6 25]] [18 69]] [18 60]] [18 100]]] [7516 0.8 [7354 3.71 [18 28] [19 58]] [18 71]]] [1739 4.65 [18 88] [18 100]]] [19 44]] [5776 2.65 [278 4 [1888 1.09 [1079 3.11 [788 13.1 [560 3.34 [18 88] [18 58]] [18 27]] [19 72]] [2707 1.86 [19 51] [19 37]]] [18 66]] [19 91]]] [221 0.664 [22 40] [18 33]]] [144 6.38 [2701 2.01 [29 50] [29 100]] [6397 5.06 [29 100] [29 50]]]] [2248 0.406 [6205 2.97 [3585 2.34 [6342 1.03 [2846 4.71 [532 8.52 [6853 1.36 [4533 1.54 [422 1.38 [5386 1.16 [7742 1.42 [733 2.39 [187 2.46 [1078 31.3 [112 0.641 [4716 3.91 [384 6.41 [5904 1.03 [2201 0.11 [5485 1.82 [1888 3.1 [392 0.881 [144 1.42 [7354 4.02 [18 58] [18 100]] [18 100]] [18 100]] [279 1.02 [18 83] [18 60]]] [18 63]] [18 70]] [19 62]] [18 92]] [18 100]] [18 62]] [16 33]] [18 90]] [18 61]] [18 91]] [18 38]] [18 55]] [18 100]] [18 50]] [18 50]] [19 55]] [1783 1.65 [19 45] [18 70]]] [16 87]] [26 42]] [19 66]]]] [7302 0.833 [2259 9.63 [5681 1.59 [7186 0.749 [277 0.38 [4050 0.407 [2649 3.53 [18 85] [16 37]] [18 100]] [5894 3.23 [16 42] [18 55]]] [6 37]] [5482 2.33 [384 2.63 [4859 2.29 [7260 5.31 [16 73] [18 38]] [18 85]] [18 71]] [19 68]]] [5894 1.41 [5632 4.99 [16 71] [16 88]] [695 2.03 [6833 3.79 [19 50] [19 33]] [16 62]]]] [19 82]]]]] [5403 1.2 [1640 0.0445 [560 0.549 [4854 0.0346 [535 1.02 [7370 0.0623 [6177 4.05 [2488 1.55 [978 1.08 [3087 0.155 [2470 1.7 [5732 0.0505 [7657 0.142 [4338 5.97 [3079 1.75 [2461 1.01 [4673 2.19 [7340 2.05 [4769 0.0355 [3849 1.15 [4703 2.2 [2939 12.1 [631 0.296 [915 1.21 [6230 2.23 [6110 0.321 [4865 0.272 [144 0.0878 [7685 1.1 [1634 1.54 [5705 0.402 [791 3.07 [4326 3 [1899 37.4 [4535 39.4 [5598 0.827 [2292 3.01 [1645 0.467 [2106 0.235 [3003 0.419 [384 1.56 [7419 0.435 [2818 0.349 [6899 0.988 [2594 1.68 [6638 0.0797 [2701 0.143 [4120 0.537 [5170 2.89 [6544 5.65 [6634 0.175 [168 2.11 [3905 0.0954 [5218 2.39 [1638 0.207 [534 0.618 [6063 0.452 [4959 0.539 [6581 8.57 [537 0.808 [1078 62.8 [7512 0.0814 [2232 0.962 [1895 0.678 [4282 2.52 [7615 0.945 [4279 1.01 [2913 0.143 [1576 0.651 [6484 1.06 [6471 1.09 [1710 3.55 [6768 0.451 [4682 6.9 [968 2.24 [328 0.337 [2752 0.414 [5225 2.76 [4397 8.77 [2550 4.76 [7623 102 [1948 2.86 [4802 3.28 [5632 8.33 [178 15 [4778 5.49 [429 5.38 [3379 0.635 [6809 2.82 [248 4.98 [5219 22.2 [1737 7.04 [7038 0.194 [1708 9.42 [3866 22 [5589 8 [1556 3.02 [5531 7.1 [1772 27.8 [5892 8.32 [1 17] [14 51]] [33 55]] [1436 6.72 [13 43] [7 66]]] [0 93]] [30 100]] [20 91]] [28 68]] [16 38]] [20 85]] [8 100]] [286 21.2 [6378 4 [6733 5.88 [5532 8.36 [1639 6.25 [6528 2.22 [5491 28.2 [1429 27.5 [673 15.8 [7415 6.67 [33 31] [33 75]] [26 46]] [1025 11.2 [2263 1.3 [33 14] [3 35]] [20 33]]] [4 33]] [7623 16.8 [1 52] [33 54]]] [10 60]] [13 50]] [38 53]] [33 91]] [2 47]]] [32 100]] [1 50]] [504 15.8 [727 8.77 [695 0.934 [4317 2.11 [3404 20.5 [951 1.57 [429 95.4 [4235 8.64 [5918 3.94 [448 5.24 [1431 2.49 [6380 3.14 [976 2.82 [3 11] [27 100]] [3 55]] [3 52]] [27 71]] [9 47]] [33 18]] [27 48]] [27 100]] [27 100]] [3 91]] [10 23]] [10 100]] [27 83]]] [15 100]] [25 49]] [2272 1.49 [5211 5.49 [7445 4.95 [16 32] [16 78]] [30 66]] [7 89]]] [2259 41.5 [1 40] [1 66]]] [4414 0.0541 [2849 23 [1249 14.5 [35 23] [35 68]] [26 40]] [29 50]]] [3971 4.95 [3566 7.37 [2257 0.832 [1930 21.3 [1950 4.93 [4114 19.1 [4991 18.3 [35 38] [1 75]] [27 36]] [35 57]] [35 80]] [2257 11.7 [1 100] [35 60]]] [25 35]] [14 44]]] [8 91]] [28 100]] [30 87]] [3972 10.2 [5809 11.4 [6103 2.82 [5812 9.49 [3292 4.79 [4092 1.71 [6155 0.555 [711 1.29 [248 11.2 [5211 0.858 [7428 18.5 [5524 0.634 [2143 48.2 [2881 7.5 [3691 0.631 [112 6.5 [4832 4.7 [5347 4.07 [1078 16 [1400 0.882 [6859 2.76 [6216 9.96 [5007 32.8 [12 10] [15 65]] [12 100]] [36 40]] [12 46]] [5480 4.42 [5647 21.1 [4017 5.4 [3027 10.7 [35 10] [1 27]] [8 25]] [11 57]] [18 26]]] [27 100]] [2 67]] [663 18.4 [2259 17.5 [221 4.59 [1062 2.26 [28 23] [29 75]] [15 33]] [36 73]] [22 23]]] [37 68]] [13 50]] [23 56]] [11 94]] [12 58]] [4210 6.85 [2562 2.59 [6031 1.38 [2178 2.2 [5368 3.53 [712 3.6 [286 20.7 [6260 9.62 [1562 5.75 [5480 0.5 [2811 4.39 [2526 1.98 [5223 8.77 [30 35] [11 100]] [23 41]] [22 41]] [22 60]] [30 100]] [22 75]] [23 100]] [22 75]] [11 45]] [1429 7.12 [23 66] [23 42]]] [22 100]] [8 74]] [30 100]]] [203 12.4 [2023 2.96 [25 24] [11 33]] [26 100]]] [22 88]] [1239 7.52 [12 75] [10 66]]] [35 80]] [957 12.2 [5692 15.3 [3299 14.5 [37 61] [37 100]] [37 100]] [37 100]]] [7009 4.76 [6342 44 [2 28] [12 100]] [12 89]]] [12 78]] [15 79]] [37 54]]] [4807 14.3 [1184 2.84 [3920 0.131 [3219 3.86 [6711 2.48 [3514 0.174 [2989 2.86 [6457 0.494 [1862 3.12 [3297 0.451 [6848 1.06 [1239 6.25 [5122 1.34 [6524 6.36 [4008 7.25 [787 3.44 [5419 2.22 [3334 4.5 [7734 1.51 [4968 11.4 [5972 10.5 [407 13.1 [3944 2.42 [3292 6.61 [28 10] [37 89]] [35 88]] [248 33.4 [23 21] [26 73]]] [12 60]] [30 48]] [18 58]] [12 100]] [5252 2.22 [15 54] [15 100]]] [35 100]] [34 100]] [11 36]] [30 100]] [6537 4.52 [6845 1.93 [5211 3.89 [1793 0.73 [5889 4.48 [3475 5.88 [405 6.34 [5496 1.69 [1319 7.72 [2174 1.09 [7470 3.92 [392 3.64 [33 16] [28 26]] [21 38]] [1 69]] [33 71]] [11 83]] [28 73]] [15 100]] [19 42]] [29 90]] [30 57]] [33 53]] [33 76]]] [35 60]] [37 94]] [30 100]] [1783 18.8 [25 85] [25 100]]] [28 76]] [35 100]] [30 59]] [15 83]] [4218 2.2 [8 57] [8 100]]] [1980 15.6 [11 86] [11 60]]] [34 89]]] [2607 3.69 [7059 3.31 [7208 0.53 [328 13 [5753 7.73 [4690 6.48 [6986 4.76 [3470 2.35 [4414 2.41 [1062 28 [5588 1.4 [1594 2.56 [6074 2.11 [4235 2.92 [968 26.5 [5034 1.63 [5851 10.5 [28 20] [4 37]] [906 3.11 [28 64] [28 91]]] [429 40.5 [28 57] [2752 4.67 [28 35] [28 80]]]] [5 25]] [33 30]] [4 100]] [12 50]] [8 80]] [2752 21.2 [328 5.68 [3 9] [9 33]] [28 62]]] [11 100]] [8 100]] [8 100]] [1062 4.13 [28 63] [28 90]]] [3989 2.16 [28 36] [12 95]]] [7208 14.9 [11 100] [11 83]]] [7085 3.31 [3 28] [11 100]]] [8 100]]] [7769 9.09 [33 72] [13 50]]] [31 100]] [6647 65.6 [5795 0.834 [4564 0.474 [2394 4.76 [30 91] [30 100]] [30 100]] [30 71]] [30 50]]] [134 31.7 [6879 2.18 [7424 1.43 [26 71] [26 80]] [16 28]] [16 54]]] [25 79]] [4898 1.31 [2752 0.743 [1340 18.6 [7149 9.09 [2 47] [2 69]] [2 82]] [2 39]] [21 50]]] [6517 9.69 [2002 7.46 [328 67.2 [6722 0.761 [4611 4.65 [30 38] [30 75]] [30 100]] [26 54]] [3 62]] [30 100]]] [4336 7.61 [6436 3.8 [5668 3.29 [2795 2.36 [5990 1.62 [7766 7.15 [4424 1.51 [2011 0.889 [3833 3.12 [429 15.2 [5501 1.61 [3167 0.245 [2893 3.11 [6471 6.72 [4157 2.59 [5271 4.29 [5940 0.579 [4964 4.25 [2033 9.3 [377 2.72 [2109 0.703 [23 46.6 [6914 7.46 [2562 3.94 [5110 8.75 [7225 0.404 [6078 9.9 [5225 1.92 [4571 0.474 [1776 8.99 [4210 5.11 [2752 5.88 [6625 1.17 [33 6] [2 63]] [4533 2.2 [23 14] [28 22]]] [3 41]] [35 76]] [19 23]] [30 80]] [31 87]] [22 100]] [30 52]] [8 90]] [13 90]] [7255 9.61 [31 23] [12 44]]] [24 70]] [28 60]] [23 63]] [4 81]] [4915 0.579 [3 22] [14 92]]] [32 74]] [33 95]] [1980 1.8 [26 90] [26 54]]] [26 80]] [8 100]] [30 87]] [1980 34.5 [1078 0.655 [1062 2.62 [5410 7.69 [3 41] [3 100]] [3 35]] [28 23]] [2081 23.1 [23 58] [2178 2.46 [3 100] [3 63]]]]] [26 61]] [2628 5.83 [7009 7.21 [2002 4 [1764 0.527 [5211 4.52 [1980 37.2 [5034 2.99 [29 25] [14 36]] [29 41]] [22 66]] [14 25]] [29 47]] [32 66]] [12 30]]] [23 29]] [3 73]] [31 94]] [24 68]] [28 61]] [5753 2.35 [30 90] [30 88]]] [35 82]]] [5435 3.88 [3 86] [30 71]]] [1078 14.8 [3 93] [3 75]]] [5639 1.73 [6959 8.01 [7482 5.05 [6824 0.966 [4940 2.39 [4457 0.688 [7624 2.33 [3579 1.45 [5492 5.75 [7354 10.3 [3581 2.51 [3419 4.52 [1596 2.18 [7488 23.2 [6779 2.07 [5435 2.46 [414 1.36 [76 1.07 [1484 11.4 [94 16.7 [6380 5.38 [2646 2.86 [2849 86.5 [1436 2.52 [1429 44.7 [38 24] [38 53]] [12 35]] [38 42]] [16 23]] [38 71]] [18 62]] [5 70]] [16 70]] [21 50]] [16 30]] [37 52]] [38 100]] [6 46]] [37 75]] [5 84]] [5 42]] [14 100]] [16 50]] [30 100]] [16 33]] [16 93]] [37 46]] [38 81]] [16 60]] [16 92]]] [2099 15.2 [5153 3.73 [1710 4.35 [3705 0.953 [7369 2.31 [6611 0.99 [7623 8.05 [2178 1.15 [1783 0.492 [2049 0.227 [2216 1.64 [1429 38.6 [3027 41.7 [7210 13.1 [2203 0.463 [4159 22.5 [1239 41.7 [2069 6.06 [1764 11 [5368 0.971 [7210 2 [5412 6.94 [3008 10.6 [248 46 [2526 8.68 [1 15] [23 35]] [27 42]] [25 41]] [15 30]] [2 30]] [17 28]] [25 50]] [0 37]] [1 25]] [28 66]] [23 42]] [12 60]] [1 77]] [1454 20.8 [1259 1.85 [1961 0.949 [2081 2.52 [1 14] [1913 7.52 [1 30] [29 40]]] [29 75]] [23 37]] [1 83]]] [1 53]] [29 58]] [7469 2.7 [5989 6.31 [1445 0.24 [2165 0.573 [6380 5.4 [1899 2.09 [1 16] [1997 0.192 [7210 1.38 [5 14] [31 25]] [4 22]]] [17 66]] [1 37]] [2235 2.11 [18 37] [10 43]]] [22 63]] [15 72]]] [2101 3.98 [7469 1.62 [429 9.45 [2093 0.186 [3878 2.15 [2138 0.324 [2003 30.2 [2752 4.08 [5999 27.7 [2939 1.55 [29 26] [29 55]] [1 58]] [1457 0.818 [2793 8.11 [23 21] [23 100]] [17 33]]] [23 75]] [2182 4.58 [2132 3.26 [2048 3.72 [29 59] [2251 9.5 [29 62] [1 44]]] [2072 0.593 [28 36] [2127 5.95 [23 57] [29 33]]]] [35 66]]] [19 50]] [3130 5.09 [1448 2.06 [2161 3.75 [2235 19.7 [1440 2.74 [791 1.44 [2169 2.24 [1437 1.68 [2155 5.84 [2151 8.25 [29 16] [2127 0.198 [15 18] [26 50]]] [11 50]] [2 66]] [23 42]] [13 55]] [11 50]] [1 45]] [1 58]] [12 50]] [1 63]]] [23 32]] [4 42]] [2540 24.5 [12 40] [1 44]]]] [2232 10.5 [1 46] [7628 2.22 [35 62] [32 33]]]] [28 72]] [5637 1.7 [15 34] [15 83]]] [1 66]] [30 100]] [4021 0.652 [24 59] [24 50]]] [23 30]]] [6524 0.967 [7265 1.17 [7716 1.1 [721 3.81 [6578 3.53 [2369 0.69 [7517 0.873 [4726 0.821 [5443 3.76 [2602 1.98 [6853 1.14 [1116 2.04 [5211 0.835 [4309 3.14 [4712 6.86 [14 1.25 [4889 7.49 [7569 3.91 [7516 2.59 [1025 5.1 [5480 0.107 [7580 3.07 [2752 0.326 [177 1.42 [4 8.38 [3934 6.49 [1335 1.65 [7233 10.2 [1601 3.63 [7568 8.47 [5409 4.91 [7255 4.55 [1161 3.36 [392 28.4 [4939 12 [7512 16.3 [2447 2.22 [1717 1.48 [26 11] [32 100]] [26 100]] [3012 13.5 [6362 18 [6 11] [6 92]] [36 100]]] [6 83]] [18 53]] [2259 10.2 [10 73] [10 50]]] [1769 2.51 [2412 9.51 [7245 1.54 [13 69] [18 36]] [6 93]] [7665 32.3 [7 33] [13 80]]]] [6 86]] [2 34]] [19 100]] [32 85]] [6 89]] [32 88]] [6 93]] [19 89]] [5254 1.35 [5467 1.27 [3480 4.6 [3721 3.23 [204 3.53 [5973 5.78 [7501 5.88 [4946 4.15 [3000 2.44 [5472 2.62 [1144 2.09 [3728 3.82 [6696 4.2 [3676 2.65 [1400 0.25 [14 16] [14 44]] [12 75]] [14 94]] [32 100]] [10 100]] [36 81]] [36 100]] [14 81]] [12 100]] [12 100]] [22 76]] [32 84]] [36 64]] [12 92]] [10 100]]] [6 100]] [2385 5.37 [5626 0.529 [2748 7.16 [2849 17.5 [6353 20.8 [4478 5.38 [6347 3.45 [107 1.11 [5480 56.4 [18 37] [33 50]] [33 100]] [13 54]] [33 71]] [18 73]] [16 44]] [26 100]] [18 42]] [18 68]]] [1059 7.41 [5812 1.93 [5972 15.6 [2617 28 [2526 5.78 [13 39] [24 28]] [2 60]] [31 85]] [2 46]] [26 29]]] [26 48]] [14 93]] [2450 10.9 [6 74] [6 100]]] [36 100]] [6100 4.42 [6 65] [6 94]]] [32 96]] [2526 4.09 [6350 2.04 [429 23.3 [20 53] [23 54]] [10 100]] [5211 12.1 [8 37] [23 28]]]] [30 83]] [36 62]] [6 97]] [30 87]] [6 90]] [429 1.75 [369 2.48 [25 43] [13 42]] [28 66]]] [31 93]] [31 100]] [5052 3.55 [2339 1.5 [5412 2.65 [36 38] [36 70]] [36 100]] [36 71]]] [13 65]] [4833 40.5 [7383 3.45 [2 82] [2 100]] [2 100]]] [721 2.76 [3333 2.02 [3323 0.736 [2143 5.74 [112 12.7 [695 14.3 [2259 48 [1072 2.01 [1429 9.62 [1995 2.79 [7008 4.67 [253 2.82 [1 47] [25 100]] [25 100]] [22 55]] [1 59]] [1 57]] [1 91]] [7 63]] [36 60]] [1 74]] [1 78]] [7254 6.67 [2081 18.3 [1 100] [1 71]] [1 100]]] [36 93]]]] [2752 0.225 [774 0.898 [4362 0.522 [6145 4.95 [515 3.18 [4232 1.25 [4320 1.5 [7032 12.7 [441 0.949 [2180 1.53 [380 0.699 [6439 8.47 [3130 32.6 [296 5.99 [6670 6.67 [4231 1.45 [429 32.4 [400 13.5 [4663 7.99 [2849 1.52 [3931 1.2 [4106 4.67 [4011 7.46 [1201 13.5 [4331 22.9 [2259 67.5 [2187 3.09 [2232 27.4 [1943 1.89 [5753 5.91 [1258 0.431 [1078 135 [2081 32.5 [2132 5.68 [2064 19.5 [1239 1.63 [695 30.7 [5211 26.3 [3130 4.91 [1 18] [27 27]] [10 28]] [10 60]] [1957 1.63 [1 31] [1 57]]] [35 75]] [23 25]] [35 18]] [2168 8.23 [1 41] [25 54]]] [1 71]] [29 22]] [1 48]] [15 21]] [2128 0.518 [1 57] [1 100]]] [2081 12.4 [30 33] [28 18]]] [27 100]] [14 75]] [28 33]] [8 100]] [1 93]] [16 38]] [1187 9.41 [4279 5.88 [2143 4.57 [1 44] [4772 5.62 [1 37] [29 40]]] [27 73]] [1 70]]] [35 90]] [27 78]] [10 84]] [10 100]] [10 100]] [27 22]] [27 92]] [27 92]] [3227 12.7 [1087 11.5 [2225 9.43 [4159 2.76 [1 44] [15 31]] [4292 18.4 [2251 20.1 [1 18] [1 63]] [27 53]]] [1 71]] [22 50]]] [429 75.5 [438 12.2 [1 22] [11 42]] [2234 1.26 [27 100] [27 75]]]] [1220 7.25 [31 34] [31 100]]] [27 82]] [6959 2.26 [10 80] [10 100]]] [27 94]] [10 100]] [10 92]] [27 69]] [726 2.44 [3531 2.76 [3619 1.55 [2793 0.272 [7612 0.413 [2259 2.96 [4312 13.2 [5662 7.79 [5322 8.28 [4159 13.1 [248 12.1 [1101 30.6 [27 17] [1101 35.6 [23 50] [11 55]]] [25 23]] [15 56]] [23 42]] [22 45]] [28 77]] [1078 103 [2064 2.22 [10 48] [10 50]] [1 38]]] [10 47]] [2143 3.58 [1078 138 [27 57] [23 27]] [27 26]]] [27 80]] [27 100]] [10 77]]]] [5976 1.34 [429 79.2 [3 100] [3 98]] [3 100]]] [3929 2.46 [7665 5.83 [4 29] [5729 19.3 [5 34] [17 94]]] [5 63]]] [4 91]] [418 0.266 [331 0.855 [335 1.75 [7141 2.99 [6904 1.05 [4790 1.07 [22 94] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]]] [6760 4.26 [2225 1.72 [5154 3.4 [4414 1.81 [4218 5.49 [5509 3.7 [3 96] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]]] [4920 1.56 [6310 0.398 [248 2.1 [14 100] [14 82]] [14 100]] [14 77]]] [3927 3.82 [2752 17.6 [7578 4.67 [711 3.6 [10 62] [10 100]] [10 100]] [2575 1.56 [10 80] [8 100]]] [8 100]]] [345 3.55 [3559 2.86 [7399 2.04 [2628 25.2 [5480 8.71 [5007 10.8 [2846 2.51 [7188 21.2 [5904 3.57 [6401 1.18 [7690 13.9 [2913 1.72 [206 4.48 [1530 1.79 [5972 2.2 [7512 39.5 [3916 9.64 [7682 6.06 [2939 6.74 [6583 1.77 [1017 15.2 [3262 4.35 [3912 3.03 [6554 2.02 [4170 5.75 [1980 27.5 [286 0.873 [7255 6.34 [4154 12.8 [429 15.6 [3910 2.59 [1919 1.07 [2526 17.2 [695 17.5 [1769 34.2 [1429 57.3 [4530 8.24 [3008 40.2 [4611 5.38 [14 17] [36 30]] [3657 5.88 [36 66] [36 100]]] [30 37]] [14 51]] [7 50]] [14 57]] [7 21]] [17 30]] [1 33]] [7169 10.8 [7588 4.85 [14 17] [17 75]] [3 25]]] [14 41]] [12 20]] [33 28]] [17 33]] [36 67]] [2849 5.88 [17 43] [17 50]]] [36 30]] [37 100]] [31 81]] [17 37]] [17 45]] [17 84]] [32 52]] [14 45]] [36 74]] [429 7.31 [2342 0.785 [32 36] [14 100]] [28 27]]] [36 100]] [32 53]] [4308 6.67 [14 62] [14 100]]] [5472 1.75 [32 58] [36 100]]] [19 85]] [7 59]] [14 66]] [15 71]] [8 78]] [31 47]] [36 100]] [32 90]] [15 100]]] [5753 1.92 [7687 1.99 [7076 3.99 [19 46] [36 66]] [7687 5.01 [19 100] [7512 54.7 [168 87.8 [6201 5.38 [19 87] [19 87]] [18 50]] [19 56]]]] [28 29]]] [2151 2.22 [30 96] [30 100]]] [6403 4.59 [5972 1.33 [4218 9.43 [5472 2.08 [2752 16.9 [14 42] [7665 35 [1704 4.07 [2199 2.07 [14 90] [14 80]] [17 81]] [7585 19.6 [4851 3.7 [14 100] [14 45]] [7585 23.4 [32 100] [32 55]]]]] [36 80]] [3 75]] [23 9.06 [36 45] [2752 14.1 [3 100] [31 50]]]] [32 100]]] [7722 1.55 [4802 0.931 [4214 0.684 [7512 5.36 [6473 0.711 [5561 2.88 [5360 3.97 [426 5.47 [2199 25.9 [7623 0.632 [4279 29.2 [5429 2.11 [6040 1.05 [1400 2.24 [2759 6.64 [1833 4.67 [4205 4.13 [685 4.76 [4017 1.86 [2225 1.37 [5368 10.8 [6199 17 [178 28.6 [5172 0.355 [5617 7.25 [1620 5.88 [7314 20.5 [5972 2.39 [33 75] [33 75]] [33 41]] [33 36]] [2 25]] [33 95]] [26 85]] [33 66]] [33 90]] [8 40]] [26 66]] [26 50]] [26 90]] [13 100]] [26 100]] [26 70]] [33 76]] [26 80]] [14 66]] [2251 1.93 [1996 0.736 [4991 4.35 [1429 11.8 [1337 0.903 [33 89] [33 100]] [7169 2.07 [33 77] [33 100]]] [33 59]] [33 100]] [1 40]]] [33 100]] [1 74]] [33 93]] [1287 2.37 [33 97] [33 100]]] [26 65]] [5140 1.58 [33 32] [33 95]]] [5999 32.3 [6031 0.369 [7210 3 [4235 5.26 [33 98] [33 71]] [5110 3.48 [33 57] [33 100]]] [33 77]] [33 75]]] [7623 23.8 [2143 0.489 [33 95] [33 81]] [33 75]]] [2081 3.83 [26 72] [33 50]]]] [27 84]] [685 2.89 [6074 2.99 [155 11.2 [6601 2.92 [2199 0.571 [258 6.17 [663 3.6 [7176 3.88 [29 39] [12 50]] [29 68]] [15 100]] [29 78]] [15 100]] [29 90]] [15 88]] [29 95]]] [2092 4.55 [1997 0.0862 [1783 32.4 [30 96] [30 90]] [30 100]] [30 88]]] [5 65]] [99 1.83 [2466 9.4 [2164 0.328 [6960 1.54 [5530 21.2 [5530 3.57 [7169 20.2 [7060 3.31 [6862 2.82 [7726 3.07 [5295 2.28 [2199 8.02 [2004 8.87 [2195 1.1 [2329 2.02 [4398 39.3 [1078 11.1 [1742 12.7 [1722 0.666 [33 40] [33 91]] [2 42]] [33 70]] [33 66]] [33 100]] [33 66]] [33 58]] [33 100]] [33 40]] [14 50]] [33 100]] [33 47]] [1 33]] [33 100]] [14 37]] [33 37]] [33 75]] [2 27]] [13 36]]] [5692 16.9 [2023 4.42 [12 96] [12 75]] [12 77]]] [6500 0.688 [6853 17.6 [1320 2.12 [6048 2.07 [1783 0.549 [392 2.7 [2224 6.79 [5647 2.22 [5454 6.67 [4851 4.08 [7122 17.4 [1275 2.89 [7421 5.16 [16 24] [23 7.71 [2143 3.83 [7419 40.4 [7185 1.73 [300 16.5 [2611 20.3 [1980 12.2 [4731 2.3 [3020 7.25 [2526 79.7 [1980 2.65 [6 82] [6 100]] [6 63]] [6 100]] [6 100]] [6 60]] [6 100]] [6 70]] [6 77]] [6 91]] [6 80]] [6 53]]] [6 33]] [16 50]] [2752 13.7 [6 25] [16 45]]] [36 75]] [2 23]] [6 91]] [18 45]] [1429 17.2 [90 2.94 [16 38] [18 60]] [63 4.98 [6294 0.227 [7347 4.3 [16 68] [16 100]] [16 100]] [6 40]]]] [16 91]] [5090 0.876 [4726 6.06 [6 92] [6 100]] [6 54]]] [24 63]] [16 79]]] [5219 5.26 [6959 4.52 [7512 0.336 [429 15.9 [1226 1.74 [4927 3.76 [4017 4.85 [1742 6.67 [26 32] [23 50]] [26 62]] [18 70]] [23 72]] [3457 2.49 [23 68] [35 90]]] [7067 3.76 [6581 4.51 [26 30] [6585 7.65 [26 75] [26 98]]] [7 75]]] [7301 3.88 [18 36] [407 13.8 [1383 4.35 [6 88] [7038 4.45 [6 80] [6 100]]] [6 71]]]] [8 92]]] [3531 5.49 [2081 1.77 [4991 5.75 [685 2.13 [27 100] [27 95]] [27 100]] [27 100]] [27 100]]] [2296 1.79 [7085 1.01 [2767 2.3 [2202 0.84 [3463 0.235 [6184 8.46 [2123 2.06 [1429 78.9 [1451 4.98 [4414 26.1 [35 67] [37 42]] [1 25]] [1 30]] [2020 8.69 [35 66] [35 50]]] [1 28]] [35 94]] [23 57]] [1 35]] [33 75]] [35 75]]] [4414 1.08 [1645 2.13 [15 88] [15 100]] [15 100]]] [4726 1.29 [6 78] [7222 1.37 [4726 17.9 [6 95] [6 54]] [221 20.9 [6 88] [6 100]]]]] [7446 1.52 [7038 6.62 [1239 6 [6 57] [2177 8.13 [2707 1.42 [5462 0.464 [7238 3.43 [1239 35.2 [1919 10.3 [6138 12.4 [7564 0.971 [5408 12.5 [1919 2.31 [7549 8.07 [7149 1.28 [7513 3.12 [6 88] [6 100]] [6 64]] [6 100]] [6 100]] [6 60]] [6 100]] [6 71]] [6 76]] [4513 11.4 [2526 36.6 [5598 4.27 [6 72] [6 100]] [2300 0.728 [6 100] [6 90]]] [5597 11.7 [6 100] [6 71]]]] [6515 1.65 [6 66] [6 100]]] [6 42]] [16 42]] [6 60]]] [190 3.19 [6 65] [16 87]]] [16 92]]] [38 79]] [4158 0.501 [2068 0.172 [6205 1.59 [6098 10.4 [2763 1.64 [2020 6.39 [3130 0.805 [7369 3.11 [7742 5.6 [2001 2.7 [2259 0.743 [1911 1.52 [4114 11.3 [2849 47 [7665 10.2 [1980 45.4 [2199 16.6 [2170 0.629 [394 2.75 [2011 0.573 [2212 5.1 [1997 5.66 [2029 0.564 [6342 0.0646 [1436 11.6 [7626 28 [2064 1.38 [2097 5.78 [1899 61.7 [1 19] [1445 13.3 [1456 6.74 [1 30] [1 61]] [1 35]]] [1 70]] [29 52]] [35 46]] [2130 1.21 [23 33.7 [1 19] [12 27]] [1 45]]] [2 17]] [1 30]] [1997 42.3 [23 17] [31 75]]] [1 66]] [2232 1.04 [29 76] [29 87]]] [28 45]] [2151 3.69 [1 27] [1 36]]] [1 32]] [1456 5.33 [2178 2.3 [2108 8.47 [1939 13.6 [23 19] [23 100]] [7 60]] [1 25]] [1 52]]] [1783 5.15 [33 17] [1 42]]] [12 46]] [25 25]] [1456 1.51 [1 19] [1 50]]] [1 10]] [23 27]] [4 29]] [15 27]] [3227 12.4 [2164 0.352 [2039 2.56 [1 43] [29 38]] [1 100]] [29 52]]] [2178 15.9 [1899 43.6 [1 50] [35 53]] [35 55]]] [4555 0.438 [695 9.74 [1921 3.88 [1995 7.98 [7176 14.6 [5647 15.2 [7354 44.1 [1459 3.88 [23 21] [23 44]] [36 85]] [1 20]] [12 60]] [3 33]] [35 37]] [36 43]] [23 100]]] [4732 1.82 [6 92] [6 100]]] [2178 1.39 [7 96] [7 100]]] [2259 53 [2237 1.74 [1448 3.6 [2241 0.949 [1078 0.531 [1899 48 [2259 5.15 [35 33] [28 33]] [2170 0.213 [2138 1.39 [1 50] [29 50]] [29 62]]] [1 47]] [2245 0.464 [29 41] [10 28]]] [25 50]] [28 50]] [1 30]]] [23 23]]] [328 4.67 [774 0.317 [4799 3.65 [961 2.13 [1078 44.7 [4210 2.06 [1397 5.75 [4207 4.2 [3940 0.84 [5412 10.6 [499 8.2 [1995 6.25 [2913 2.56 [27 8] [32 78]] [27 33]] [27 100]] [5412 17.4 [2 23] [28 58]]] [32 90]] [29 93]] [27 100]] [30 76]] [2128 1.09 [2913 7.41 [4601 0.139 [4178 1.79 [2796 3.27 [23 7.41 [4993 19.2 [4353 2.84 [4114 2.89 [7512 1.45 [4331 8.34 [957 0.849 [4355 5.99 [4160 10 [2180 20.2 [4295 0.747 [27 67] [30 30]] [17 42]] [27 30]] [15 40]] [27 100]] [27 100]] [10 32]] [6125 1.65 [27 94] [27 100]]] [27 27]] [10 57]] [36 25]] [27 83]] [27 100]] [28 100]] [30 62]] [14 23]]] [27 100]] [32 100]] [5393 4.79 [27 92] [27 78]]] [2039 1.3 [2752 13.4 [2199 15.5 [2199 5.05 [1078 5.61 [25 23] [1089 4.22 [7245 0.666 [14 17] [18 40]] [6 33]]] [18 66]] [28 83]] [27 35]] [28 63]]]] [5455 0.297 [7434 0.178 [1391 4.95 [4398 4.42 [112 1.19 [1239 19.4 [5941 0.066 [6124 4.62 [5972 2.26 [4279 61.1 [2323 0.87 [959 0.334 [3313 4.11 [7411 2.78 [7722 2.6 [6026 0.697 [3019 1.49 [5473 1.49 [1717 0.634 [4282 6.34 [884 0.407 [4207 1.1 [4852 2.37 [6529 0.262 [3338 0.458 [1995 0.659 [2320 2.59 [6853 3.4 [6582 0.879 [701 4.89 [1047 9.03 [1471 2.54 [5420 1.3 [531 0.68 [4601 0.358 [3292 3.5 [957 0.926 [3262 2.22 [1426 0.534 [4309 4.79 [1659 0.469 [5225 1.22 [2752 3.18 [2917 13.5 [1696 1.9 [5779 11.7 [1638 3.23 [3111 0.623 [5762 0.715 [3820 3 [5482 2.76 [4631 6.33 [5049 1.43 [5034 0.0966 [5218 2.24 [791 54.2 [4154 10.5 [896 6.33 [429 58.7 [5211 10.1 [2225 5.98 [7542 9.16 [6283 0.576 [4993 0.0726 [6981 6.38 [7255 28.4 [5629 1.92 [276 1.61 [35 7] [33 71]] [15 100]] [13 50]] [7 41]] [1429 33.3 [4993 3.59 [7428 3.2 [2 100] [2 75]] [2 42]] [15 50]]] [2287 2.52 [18 91] [18 62]]] [32 82]] [1454 8.63 [3928 1.09 [441 9.08 [2056 1.77 [1459 3.3 [802 6.88 [1986 1.14 [29 23] [27 23]] [21 71]] [3 50]] [13 42]] [3 50]] [4 40]] [29 62]]] [1 8.85 [22 26] [11 100]]] [6544 7.46 [2002 5.75 [4918 6.73 [6935 8.77 [791 52.9 [3744 5.96 [2939 0.522 [429 128 [7442 6.15 [21 23] [11 83]] [21 79]] [5 28]] [939 34 [35 100] [35 83]]] [3 38]] [10 28]] [21 100]] [21 85]] [3 69]]] [660 20.1 [5430 20.1 [5462 13.4 [688 14.8 [721 4.13 [2225 5.75 [6866 1.71 [2232 3.31 [494 17.9 [2526 12.8 [5 10] [2 19]] [14 45]] [25 50]] [5 95]] [1 100]] [36 73]] [7 84]] [14 54]] [5 90]] [13 66]]] [5630 5.88 [7241 1.6 [3130 8.51 [802 2.07 [3905 11.1 [3622 5.26 [221 4.33 [1161 11.1 [6524 2.18 [5641 7.77 [2184 2.13 [29 8] [3 78]] [26 57]] [1 75]] [1429 13 [10 57] [7 16]]] [29 45]] [29 100]] [4801 5.62 [32 81] [32 100]]] [6672 5.38 [3 78] [3 100]]] [2521 10.8 [22 76] [3 30]]] [2259 11.5 [33 36] [10 75]]] [15 100]]] [802 3.36 [2241 0.967 [6311 10.1 [859 12.1 [3667 7.04 [5480 48.6 [5994 18.3 [2913 20.8 [1899 21.7 [6544 24.6 [6791 7.69 [906 6.85 [35 10] [21 78]] [1 38]] [36 66]] [2 14]] [21 29]] [29 100]] [22 43]] [35 42]] [22 85]] [35 42]] [22 14]] [21 49]]] [10 98]] [1980 23.4 [5211 6.17 [4312 1.22 [802 0.849 [730 5.62 [1980 9.09 [4533 2.02 [7548 6.67 [14 29] [32 88]] [3 61]] [2259 1.17 [28 42] [3 70]]] [28 100]] [3 97]] [3 54]] [30 89]] [3 97]]] [2259 36.1 [5410 8.47 [21 92] [9 83]] [21 66]]] [11 92]] [1025 3.45 [4159 1.75 [7057 3.36 [29 45] [19 41]] [29 63]] [29 71]]] [3824 3.13 [13 45] [13 100]]] [10 51]] [36 93]] [14 100]] [896 9.8 [36 100] [36 90]]] [791 5.87 [26 63] [1696 16.9 [26 80] [26 96]]]] [1980 50.3 [3 77] [21 64]]] [673 2.78 [4556 2.54 [5812 5.03 [4221 2.54 [859 0.588 [7481 11.9 [877 3.36 [3310 1.63 [5472 0.597 [3908 3.83 [2081 5.88 [328 2.17 [3884 5.74 [7449 3.44 [6350 1.69 [3728 5.51 [2562 1.53 [4799 9.03 [2526 3.62 [248 7.63 [3803 0.938 [435 4.18 [5995 1.87 [2701 6.77 [5211 3.21 [28 15] [30 30]] [29 64]] [29 97]] [221 3.92 [11 34] [30 42]]] [11 100]] [221 4.94 [29 32] [29 94]]] [610 0.385 [2813 7.88 [791 9.43 [18 12] [7354 2.54 [5692 5.32 [3008 0.931 [4 13] [17 39]] [5 17]] [18 25]]] [18 94]] [5 82]]] [32 54]] [2628 3.55 [23 46] [23 75]]] [32 88]] [10 82]] [5527 1.41 [435 4.31 [6727 25.1 [1239 10.4 [2562 4.13 [5480 4.91 [1911 13.1 [826 2.06 [2110 2.09 [7457 7.89 [7461 25 [29 18] [22 32]] [32 52]] [36 50]] [15 41]] [28 50]] [6732 4.96 [2813 2.67 [29 48] [29 100]] [1429 8.71 [29 50] [18 50]]]] [23 61]] [11 24]] [23 45]] [29 50]] [29 100]]] [15 98]] [328 14 [6708 2.66 [2616 5.24 [5007 3.12 [1391 1.86 [4279 9.36 [28 28] [28 61]] [35 55]] [29 33]] [2 57]] [3698 1.28 [28 76] [28 100]]] [624 0.797 [397 5.46 [2023 8.32 [6713 3.23 [2259 35.8 [7343 20.9 [5753 7.01 [5480 2.54 [6152 5.68 [2701 3.14 [5871 4.35 [4135 1.63 [28 24] [23 33]] [14 64]] [29 81]] [28 66]] [18 34]] [28 50]] [14 21]] [14 36]] [30 54]] [23 42]] [16 37]] [28 100]]]] [4611 10.8 [6015 1.2 [764 5.03 [2548 0.4 [4364 6.17 [1451 8.6 [2701 0.801 [2251 10.1 [6566 0.535 [6301 4.07 [7493 2.49 [1226 4.14 [4781 1.41 [1899 3.33 [23 23] [11 16]] [1078 37.1 [11 41] [11 72]]] [23 94]] [23 69]] [28 100]] [11 64]] [23 66]] [29 89]] [2241 1.16 [29 38] [29 60]]] [23 71]] [23 72]] [23 100]] [1429 13.1 [28 50] [29 46]]] [10 41]]] [32 77]] [5472 30.4 [36 87] [23 37]]] [29 59]] [22 97]] [15 100]] [6438 4.07 [7623 2.65 [22 49] [10 46]] [30 100]]] [7491 9.17 [7449 49 [4414 11.4 [15 69] [15 100]] [15 96]] [15 100]]] [3698 5.49 [2556 1.18 [2616 0.761 [968 1.48 [5472 4.2 [5654 7.58 [771 1.62 [5648 10.4 [5692 7.25 [2143 3.32 [4832 1.44 [14 17] [2 50]] [2 34]] [28 22]] [4 22]] [35 83]] [5 43]] [13 100]] [28 100]] [2 35]] [719 0.59 [4 100] [4 90]]] [28 77]]] [23 98]] [2530 3.86 [4288 5.07 [2005 5.14 [4533 1.91 [4540 2.44 [5692 1.27 [26 37] [5429 2.22 [419 0.519 [26 49] [26 100]] [26 100]]] [18 84]] [25 36]] [1 57]] [1 88]] [26 68]]]] [2752 28.1 [1215 12.1 [6438 1.63 [6427 3.27 [5034 0.873 [2628 11.7 [5871 2.33 [5647 12.5 [22 56] [22 100]] [30 90]] [23 68]] [5122 13.7 [30 98] [30 77]]] [22 100]] [4210 24 [30 100] [30 63]]] [22 89]] [23 47]]] [7472 1.21 [1689 0.574 [1577 1.98 [971 6.96 [2259 39.4 [695 3.71 [5270 0.271 [3898 0.32 [1452 0.575 [5843 6.25 [6777 0.356 [6342 1.98 [4559 5.5 [4643 1.78 [17 69] [17 88]] [17 43]] [17 38]] [14 40]] [17 26]] [17 35]] [17 93]] [19 30]] [14 66]] [14 35]] [19 71]] [14 83]] [19 50]] [38 52]]] [5327 2.22 [4369 3.88 [7665 2.79 [3027 2.96 [1161 6.71 [32 52] [35 100]] [32 100]] [32 97]] [32 88]] [32 100]]] [5218 2.02 [1078 55.8 [10 81] [10 100]] [10 100]]] [37 95]] [5480 4.98 [2752 12.1 [976 1.04 [3160 3.3 [7298 2.09 [810 1.2 [1078 13.6 [896 20.8 [2280 3.82 [30 19] [36 44]] [7 53]] [1219 1.87 [814 5.38 [4968 8.81 [756 4 [27 43] [30 100]] [30 83]] [32 50]] [10 75]]] [27 100]] [30 100]] [27 100]] [27 100]] [688 5.74 [4968 1.31 [4884 3.51 [756 4.33 [2793 5.2 [5211 2.25 [5650 2.96 [7548 1.03 [3424 2.02 [6091 1.66 [826 10.7 [28 17] [32 70]] [28 50]] [37 77]] [32 57]] [37 75]] [30 34]] [27 60]] [30 100]] [32 100]] [30 80]] [5 47]]] [1888 3.31 [18 55] [18 77]]]] [2760 2.24 [5462 0.255 [7149 6.33 [7512 4.59 [37 73] [1 25]] [37 100]] [37 100]] [37 85]]] [5660 0.617 [6184 0.632 [23 38.4 [2259 10.7 [5211 2.14 [5668 2.99 [5431 6.77 [6524 1.62 [2083 8.7 [26 58] [3 25]] [25 28]] [26 100]] [1 100]] [11 33]] [5110 6.55 [26 14] [30 60]]] [26 83]] [11 31]] [4 43]]] [7 100]] [1429 4.35 [5753 4.76 [1078 1.89 [23 73] [2199 1.81 [23 91] [23 100]]] [6732 2.46 [28 29] [28 83]]] [859 0.805 [2081 10.6 [28 67] [23 33]] [22 82]]]] [28 100]] [24 60]] [791 29.6 [10 84] [10 59]]] [7620 2.65 [4 97] [4 100]]] [4040 7.68 [296 2.89 [655 1.68 [2752 20.9 [721 1.58 [1116 2.33 [2793 0.931 [7068 1.23 [7529 1.99 [6 2.28 [1239 1.56 [2525 2.59 [1899 8.95 [7243 6.33 [30 30] [36 100]] [36 100]] [24 81]] [24 64]] [10 71]] [24 81]] [36 100]] [24 76]] [30 100]] [36 100]] [36 55]] [24 93]] [10 100]] [24 65]]] [32 67]] [5223 0.147 [934 0.219 [3860 0.293 [1 0.873 [6260 0.285 [5647 0.294 [4781 1.71 [3439 1.12 [438 5.49 [2320 1.45 [6492 3.8 [5851 5.93 [1457 0.945 [775 0.945 [384 1.87 [2833 2.2 [4972 2.13 [1159 0.476 [957 5.35 [6112 2.26 [3309 0.668 [7324 5.23 [6427 6.55 [2226 5.71 [6800 0.904 [5766 2.67 [5812 2.07 [791 9.15 [7512 8.33 [7197 3.71 [27 11] [1 44]] [10 50]] [6301 2.86 [2807 3.43 [1217 6.07 [429 32.1 [896 0.364 [4292 5.17 [5110 5.6 [1101 12.5 [2768 4.18 [1095 4.56 [1445 4.55 [2275 2.51 [811 10.3 [2628 2.22 [28 9] [14 20]] [12 70]] [36 36]] [1 27]] [10 50]] [17 25]] [1110 6.33 [28 26] [28 50]]] [11 35]] [15 66]] [29 30]] [11 24]] [11 57]] [22 100]] [28 100]]] [35 45]] [28 100]] [15 100]] [28 20]] [22 100]] [23 100]] [11 80]] [29 100]] [2178 7.53 [27 44] [10 27]]] [27 68]] [27 100]] [29 100]] [23 92]] [2232 3.81 [27 45] [27 92]]] [15 72]] [1089 4.09 [27 38] [27 100]]] [28 100]] [32 81]] [23 23]] [11 100]] [11 67]] [4154 0.582 [5225 1.17 [859 5.69 [5662 4 [11 38] [791 13.9 [11 50] [7335 2.68 [11 92] [11 100]]]] [22 81]] [22 47]] [877 0.982 [2091 7.75 [429 44.6 [5647 6.71 [22 44] [22 75]] [7512 2.82 [29 44] [29 72]]] [28 37]] [22 100]]]] [22 48]] [1980 3.68 [10 40] [5655 0.678 [792 0.907 [11 69] [11 100]] [11 94]]]] [11 100]] [11 80]] [567 0.686 [5110 7.45 [11 90] [11 100]] [11 100]]]] [2780 2.3 [5412 1.73 [939 4.55 [4013 0.608 [6375 1.23 [28 45] [28 83]] [28 96]] [15 28]] [28 88]] [37 100]]] [2705 2.16 [31 3.3 [6031 1.12 [429 50.6 [1764 2.96 [5034 0.262 [2091 0.719 [5765 2.34 [7491 2.18 [1253 1.05 [5480 1.77 [22 28] [22 95]] [28 83]] [22 66]] [22 100]] [28 26]] [6184 1.41 [28 90] [28 50]]] [22 88]] [22 52]] [2143 1.12 [5282 5.88 [2259 1.29 [859 2.6 [22 91] [22 100]] [22 100]] [22 81]] [22 100]]] [28 83]] [29 100]]] [2589 2.3 [6575 3.4 [6572 4.2 [1769 4.27 [8 63] [8 100]] [8 100]] [8 100]] [8 100]]] [29 93]] [3111 1.5 [2788 0.975 [7665 1.19 [36 52] [36 100]] [36 100]] [36 100]]] [1916 1.28 [802 1.81 [2218 0.787 [7449 12.1 [2280 2.76 [23 20.6 [5034 2.56 [907 5.15 [2178 4.53 [5753 1.37 [3 33] [1 25]] [3 75]] [3 100]] [3 81]] [3 80]] [13 38]] [3 100]] [1 60]] [4184 4.2 [657 3.18 [526 6.24 [2259 4.11 [3 98] [3 96]] [3 88]] [3 100]] [3 100]]] [3 33]]] [7334 0.28 [5618 0.176 [2064 0.559 [284 0.452 [7255 3.67 [6809 4.25 [32 66] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]]] [5753 8.64 [1911 1.78 [7012 3.27 [619 3.5 [7590 2.42 [5637 6.85 [13 75] [13 100]] [13 100]] [13 100]] [13 100]] [13 50]] [13 50]]] [1205 3.55 [1239 2.76 [24 82] [24 100]] [1025 34.3 [24 100] [3019 7.58 [24 72] [791 32.2 [24 100] [24 85]]]]]] [429 15.7 [10 80] [1980 6.16 [10 95] [10 100]]]] [2616 0.382 [901 8.64 [5165 0.441 [7591 0.5 [1429 7.01 [5345 11.9 [210 7.41 [3905 25 [7665 42.2 [7542 2.67 [2526 1.49 [2705 0.573 [913 1.79 [1429 4.47 [4601 5.52 [5034 7.11 [2081 6.9 [1400 4.13 [1239 1.68 [1899 0.99 [2 16] [26 21]] [1 27]] [36 76]] [36 38]] [6732 5.26 [32 77] [32 75]]] [26 57]] [14 57]] [26 38]] [29 100]] [23 19.6 [4613 1.07 [2745 5.43 [1025 14.3 [2 21] [24 42]] [1 45]] [26 100]] [1 100]]] [32 88]] [2083 6.49 [1986 4.59 [14 33] [32 66]] [1 75]]] [4851 11 [14 46] [429 29.6 [14 90] [14 100]]]] [2225 0.949 [26 81] [26 100]]] [7590 4.67 [14 100] [36 44]]] [2411 6.21 [6859 4.91 [3647 1.66 [3067 1.08 [7723 1.39 [2385 1.62 [6865 5.06 [2913 3.91 [6396 6.37 [7579 2.79 [3917 1.63 [5753 9.8 [5412 14.4 [5693 1.61 [7321 6.24 [968 11.8 [7583 3.27 [99 2.46 [673 2.7 [6413 12.2 [3480 0.99 [3432 4.27 [3905 8.77 [7566 8 [328 14.8 [5412 1.93 [7548 2.99 [7413 4.35 [1400 2.86 [14 24] [4851 2.86 [14 63] [36 58]]] [5 63]] [14 75]] [13 28]] [5412 0.526 [14 88] [14 55]]] [13 37]] [14 65]] [36 100]] [36 69]] [5 50]] [26 25]] [7665 34.1 [36 66] [1 33]]] [7 40]] [32 100]] [14 100]] [896 6.76 [3008 2.26 [2752 19.1 [7169 1.9 [14 46] [18 22]] [14 83]] [32 71]] [14 30]]] [13 33]] [36 31]] [14 90]] [7595 5.59 [32 57] [36 100]]] [17 60]] [32 81]] [36 50]] [19 43]] [18 94]] [36 100]] [36 100]] [5192 7.84 [36 81] [36 69]]] [36 100]]] [5345 1.16 [36 90] [36 69]]] [14 100]] [36 100]] [2742 1.33 [7187 1.58 [6847 1.35 [774 6.5 [7185 9.94 [7563 6.22 [4851 1.47 [6311 6.59 [6524 3.35 [7354 2.3 [4145 3.4 [1068 2.85 [1980 22.7 [2259 27.3 [3929 1.77 [637 1.08 [3667 1.68 [906 4.72 [6977 3.97 [1253 2.48 [5 15] [2 100]] [5 87]] [4 25]] [2 80]] [2 100]] [6 37]] [6 43]] [25 66]] [4 52]] [24 100]] [7590 1.4 [18 29] [18 85]]] [25 58]] [5 42]] [906 3.4 [494 2.37 [5 39] [17 33]] [17 33]]] [4154 10.1 [7722 17 [5 100] [2594 4.76 [5 100] [5 57]]] [5 61]]] [2628 9.08 [6732 11.5 [17 53] [19 47]] [5 36]]] [24 100]] [24 100]] [26 100]] [4 100]]]] [850 1.12 [1036 3.89 [222 2.67 [7665 1.03 [7411 7.26 [35 42] [4956 3.7 [5897 0.782 [4533 9.43 [4968 8.86 [6883 4.95 [7512 4 [4061 2.49 [6853 1.93 [2993 4 [5491 5.59 [756 5.49 [4799 3.4 [1980 2.44 [7465 4 [5480 5.88 [15 74] [23 57]] [15 100]] [5462 12.4 [15 64] [35 100]]] [15 88]] [30 100]] [15 100]] [30 50]] [30 100]] [30 83]] [14 47]] [35 50]] [35 90]] [35 78]] [35 80]] [35 53]]] [4414 6.49 [4205 1.03 [248 4.99 [2752 6.45 [36 43] [7623 3.28 [6581 3.22 [2752 13.5 [36 44] [14 21]] [5 50]] [30 100]]] [32 46]] [14 33]] [4 41]]] [7 50]] [35 78]] [35 87]]] [7343 1.39 [5267 0.864 [3512 1.48 [4107 2.11 [1888 19.5 [5 83] [5 75]] [5 100]] [5 100]] [37 50]] [37 55]]] [10 100]] [2091 3.7 [7722 0.668 [5316 3.56 [7354 2.28 [2331 1.54 [7210 3.48 [2913 3.24 [32 61] [32 100]] [32 83]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]]] [2251 9.83 [1437 3.53 [26 76] [26 100]] [26 70]]] [7449 14.2 [1429 9.62 [616 1.77 [5980 1.37 [7491 32 [7009 6.76 [5974 2.07 [5812 6.26 [4270 3.45 [537 2.65 [12 34] [3 100]] [36 100]] [12 95]] [21 82]] [12 82]] [12 50]] [12 100]] [3 100]] [6404 0.599 [5812 1.69 [7354 0.513 [6732 2.87 [1911 0.979 [5052 2.09 [6665 0.775 [7018 1.83 [7176 0.849 [6261 1.21 [5469 1.92 [6155 1.25 [4611 5.12 [6761 4 [5472 1.59 [203 3.11 [5647 0.901 [3148 2.22 [1218 1.99 [695 5.02 [4154 16.5 [5871 3.76 [12 56] [30 81]] [3 83]] [719 11.3 [36 66] [31 50]]] [36 100]] [36 100]] [12 79]] [36 100]] [36 97]] [36 62]] [7512 2.62 [36 80] [36 100]]] [12 100]] [12 100]] [36 100]] [3548 2.44 [7512 8.93 [12 100] [36 57]] [12 100]]] [36 100]] [12 100]] [36 100]] [957 2.12 [1746 1.17 [906 11.6 [2259 17.9 [36 60] [36 100]] [36 72]] [36 100]] [36 58]]] [7571 3.75 [36 71] [3482 1.52 [36 91] [36 100]]]] [4279 10.2 [7374 2.31 [2275 7.76 [36 100] [36 90]] [36 87]] [36 90]]] [874 0.769 [3928 0.843 [12 89] [12 100]] [12 100]]] [36 100]]] [791 32.3 [688 2.49 [5412 13.4 [12 71] [12 57]] [9 44]] [1429 16.1 [7461 5.78 [2259 17.9 [5692 2.49 [12 51] [21 56]] [12 53]] [15 50]] [12 88]]]]] [2824 1.13 [12 74] [7185 2.28 [12 93] [12 100]]]] [6812 0.38 [4059 14.3 [3317 0.609 [5015 1.07 [1659 4.17 [14 68] [5564 0.124 [7066 0.206 [3065 0.36 [1618 0.752 [250 4.48 [1564 15.5 [5297 0.566 [1980 2.05 [5836 0.457 [1773 1.57 [6776 1.08 [17 66] [17 40]] [851 20.6 [17 100] [17 50]]] [1714 1.5 [17 54] [4565 0.271 [22 38] [19 50]]]] [17 31]] [14 37]] [6380 20.5 [17 80] [17 41]]] [19 45]] [5412 0.548 [19 100] [19 88]]] [2023 14.9 [6227 0.167 [4851 0.204 [4564 0.615 [5840 0.195 [19 65] [19 50]] [6159 0.296 [5941 1.38 [16 50] [17 57]] [4639 1.17 [38 54] [5840 0.66 [19 87] [1653 1.49 [17 60] [19 55]]]]]] [38 72]] [19 82]] [2257 0.558 [19 50] [19 84]]]] [7169 1.64 [5892 0.861 [10 30] [1678 0.101 [250 0.556 [5837 1.83 [1564 5.79 [4059 1.06 [6562 0.121 [17 87] [17 100]] [17 42]] [17 62]] [17 93]] [1588 0.426 [17 57] [17 50]]] [2219 0.365 [1899 0.0687 [791 25.5 [17 100] [17 83]] [17 88]] [17 77]]]] [14 66]]] [4803 0.177 [6780 8.05 [1588 2.3 [1997 0.797 [14 100] [328 0.0796 [2342 0.588 [14 100] [14 87]] [14 100]]] [14 95]] [3682 3.18 [14 100] [14 66]]] [14 100]]]] [4535 8.94 [14 37] [35 100]]] [1773 3.26 [1678 5.12 [5895 3.68 [1715 4.52 [7428 1.4 [4783 1.3 [5844 1.01 [1621 0.395 [3694 5.04 [3599 0.817 [3598 2.39 [5412 1.27 [6076 6.35 [17 48] [17 100]] [17 33]] [32 57]] [1664 7.57 [17 41] [14 28]]] [14 85]] [14 62]] [17 84]] [14 66]] [3 40]] [14 100]] [17 90]] [17 63]] [17 90]]] [1512 1.18 [7334 0.783 [5893 1.79 [17 76] [17 83]] [17 90]] [17 85]]] [3053 0.153 [5893 12.4 [5412 0.0792 [250 0.434 [4574 0.967 [284 0.942 [32 81] [32 100]] [32 100]] [1436 2.97 [32 100] [32 85]]] [32 100]] [32 83]] [32 52]]]] [1280 2.18 [5831 1.01 [1333 2.61 [7088 1.13 [5564 1.17 [7623 1.93 [6772 0.111 [1047 17 [5170 0.337 [5048 1.08 [1592 3.09 [4154 5.68 [7318 2.02 [534 2.23 [1623 1.67 [6515 1.66 [6261 3.5 [1753 17.8 [6100 0.808 [3020 1.73 [1240 13.2 [939 0.255 [1340 0.639 [6897 2.76 [225 2.92 [1451 1.31 [5937 1.27 [896 0.246 [5336 13.9 [5439 8.14 [5219 7.76 [5892 10.3 [572 2.49 [791 27 [1051 5.38 [917 1.12 [7729 2.7 [2701 1.79 [4219 0.624 [906 11.9 [2259 19 [7009 18.3 [2150 3.52 [1913 26 [2048 5.08 [5509 6.86 [2005 1.01 [6935 9.15 [5532 4.19 [808 14.1 [1954 2.86 [5889 7.05 [2089 7.1 [5211 3.63 [1769 7.62 [3130 3.39 [2048 0.83 [4279 5.68 [4897 6.36 [2913 11.9 [28 8] [2 23]] [23 30]] [3 58]] [13 36]] [11 25]] [3 26]] [22 28]] [23 66]] [32 62]] [35 40]] [22 75]] [3 60]] [30 35]] [23 41]] [9 46]] [29 36]] [29 55]] [23 44]] [9 70]] [2039 16.6 [4726 6.44 [2027 2.84 [2108 12.1 [1783 8.73 [1262 2.56 [6159 0.569 [2164 3.48 [1429 5.25 [3 23] [1244 13.7 [2059 0.808 [1062 8.95 [7197 0.978 [7512 3.36 [5753 4.32 [2023 1.26 [1452 13.7 [2 9] [11 37]] [17 33]] [21 42]] [36 36]] [0 40]] [17 25]] [23 44]] [29 50]]] [1 45]] [15 66]] [23 40]] [7449 4.32 [2526 14.5 [2130 2.93 [2053 1.94 [5940 0.137 [1445 8.68 [2199 2.57 [7665 3.58 [3409 2.91 [1062 3.97 [3 20] [1 30]] [19 44]] [3 60]] [26 27]] [3 66]] [19 64]] [7 40]] [19 27]] [6 29]] [8 60]]] [1 71]] [11 81]] [6 60]] [35 81]]] [21 56]] [3 100]] [29 80]] [1 90]] [21 48]] [10 52]] [826 0.568 [570 3.4 [1365 14.5 [906 7.2 [4771 4.42 [6713 5.49 [1913 44.6 [585 6.02 [2202 11.6 [5692 1.96 [2763 7.92 [2048 13.7 [1959 2.4 [2764 2.99 [1986 25.5 [7512 5.25 [1905 3.45 [21 18] [29 66]] [14 26]] [33 30]] [11 44]] [35 41]] [26 28]] [12 36]] [21 33]] [3 66]] [21 100]] [1 60]] [9 54]] [21 33]] [21 71]] [3 50]] [21 92]] [11 40]]] [9 100]] [3 82]] [8 100]] [21 85]] [9 100]] [5007 2.56 [1783 2.35 [6 20] [14 37]] [18 38]]] [328 16.8 [21 83] [9 82]]] [7445 4.43 [7428 5.29 [1446 0.5 [17 10] [15 60]] [21 44]] [24 33]]] [21 100]] [9 83]] [2761 6.27 [6959 1.55 [11 35] [11 44]] [4 50]]] [2091 3.21 [2181 1.19 [11 26] [25 37]] [11 28]]] [24 78]] [6 96]] [6 100]] [22 100]] [9 54]] [4725 2.04 [6 78] [6 70]]] [11 100]] [3 95]] [3 100]] [2143 0.134 [2293 2.08 [5697 0.96 [1017 0.592 [5972 1.02 [3379 1.73 [1361 4.59 [1645 3.15 [4210 3.73 [5423 0.364 [5368 0.544 [7335 15 [2120 1.98 [743 2.65 [23 13.9 [4851 0.921 [5019 4.76 [2081 1.67 [4158 10.1 [5412 12.7 [1429 8.55 [6091 5.38 [3 50] [3 83]] [3 20]] [21 45]] [26 44]] [2083 4.64 [26 14] [23 53]]] [3 100]] [3 33]] [3 55]] [3 100]] [429 12.6 [32 33] [24 33]]] [3 57]] [11 20]] [32 90]] [3 100]] [15 100]] [3 100]] [10 95]] [3 91]] [4312 1.78 [906 4.98 [3 90] [3 100]] [3 100]]] [3 100]] [5 40]] [7369 1.71 [537 2.56 [6294 0.197 [1986 9.92 [1783 2.29 [4312 4.67 [1429 36.7 [3072 1.37 [896 1.43 [2199 7.41 [3 32] [3 91]] [26 50]] [26 100]] [29 53]] [3 100]] [32 25]] [12 30]] [1429 31 [21 54] [17 75]]] [3 100]] [4279 16 [29 87] [29 100]]]]] [4952 3.45 [23 2.42 [3 80] [3 100]] [3 83]]] [3 100]] [5171 0.99 [33 67] [33 95]]] [886 3.82 [4154 20 [655 6.49 [24 59] [6573 5.15 [24 96] [24 85]]] [24 84]] [24 100]]] [1957 3.02 [30 73] [30 100]]] [4159 0.444 [1293 1.51 [7210 0.0359 [2119 4.92 [1742 0.724 [1279 0.497 [6776 1.29 [5295 4.04 [5322 3.51 [1899 20.2 [4279 3.51 [5637 3.04 [33 25] [1 66]] [33 40]] [27 30]] [33 70]] [33 60]] [14 71]] [33 80]] [1 53]] [10 38]] [1078 2.57 [1 44] [16 27]]] [33 100]] [33 75]]] [14 100]] [4767 2.41 [9 56] [17 33]]] [4114 9.52 [10 89] [10 100]]] [9 91]] [429 92 [9 69] [9 100]]]] [4282 1.8 [6865 0.766 [2259 18.1 [6713 2.3 [811 1.77 [7338 0.213 [3905 1.79 [3099 0.717 [2701 1.25 [562 1.89 [29 1.08 [7583 2.16 [968 2.12 [5227 3.69 [5400 6.87 [23 7.86 [1429 24.5 [1304 2.89 [663 0.894 [7169 0.684 [29 20] [4 16]] [663 18.3 [4533 0.942 [22 18] [28 69]] [4414 7 [22 30] [11 20]]]] [15 44]] [2780 0.821 [6853 5.07 [6711 2.41 [7548 2.56 [5225 0.566 [771 5.82 [2526 5.6 [6184 5.64 [5637 10.2 [1997 7.35 [5110 0.826 [1986 10.5 [2897 2.99 [1753 4.31 [4154 1.55 [2759 2.89 [37 21] [29 60]] [28 31]] [22 71]] [28 66]] [22 77]] [22 62]] [29 66]] [13 40]] [22 57]] [5 25]] [30 80]] [5211 23.3 [30 52] [22 90]]] [14 88]] [22 100]] [2832 8.24 [1559 2.37 [36 64] [36 100]] [36 50]]] [37 87]]] [695 1.58 [822 1.04 [7472 6.11 [2362 2.37 [7314 25.1 [7449 5.95 [2752 1.55 [5246 3.36 [5410 13.9 [286 2.26 [5697 3.41 [7343 17.9 [537 1.72 [2624 13.6 [630 3.31 [23 78 [5462 2.58 [791 37.3 [5871 6.38 [4478 9.46 [2251 4.18 [1429 2.82 [9 41] [21 20]] [1 37]] [9 80]] [30 80]] [21 38]] [21 57]] [3 65]] [9 90]] [21 83]] [3 100]] [9 75]] [21 50]] [9 66]] [3 75]] [21 66]] [2029 2.04 [1906 2.49 [5972 1.41 [1025 1.97 [6621 4.12 [5660 0.668 [1078 11.4 [2526 9.28 [22 10] [5 38]] [22 38]] [33 37]] [22 36]] [37 50]] [12 50]] [2 33]] [29 30]]] [29 20]] [3 76]] [3 100]] [38 83]] [9 53]] [5345 1.06 [22 19] [22 58]]]] [5400 22.2 [13 83] [13 100]]] [6524 1.96 [1239 2.39 [22 40] [22 100]] [22 93]]] [2081 6.57 [5799 3.8 [377 5.89 [28 75] [28 57]] [28 100]] [12 33]]] [7241 2.16 [36 66] [36 71]]] [5851 2.07 [663 1.9 [9 73] [9 42]] [9 55]]] [9 89]] [6446 1.71 [5969 2.15 [6199 10.3 [2753 11 [7512 9.13 [5482 1.39 [1177 2.18 [2701 5.94 [29 55] [5692 0.795 [6653 2.56 [6491 4 [4159 8.34 [6015 2.51 [29 91] [29 100]] [29 80]] [29 100]] [29 100]] [15 50]]] [29 100]] [29 100]] [29 57]] [29 66]] [29 57]] [29 100]] [29 100]]] [1 95]] [4375 1.13 [1078 21.6 [2526 7.69 [695 1.82 [32 23] [36 47]] [17 47]] [32 62]] [32 87]]] [22 77]] [36 78]] [6151 1.19 [9 62] [9 100]]] [7241 0.654 [7601 0.544 [5892 3.8 [4815 1.42 [859 1.31 [4270 1.01 [3905 17.2 [5851 1.2 [850 1.9 [5972 1.27 [7542 1.07 [3004 2.76 [663 4.97 [429 47.2 [1181 3.88 [1429 15.3 [32 22] [22 19]] [36 100]] [114 4.47 [429 60.5 [21 71] [3 30]] [3 45]]] [6732 2.7 [32 22] [22 62]]] [36 100]] [36 66]] [36 90]] [36 100]] [28 20]] [32 77]] [36 97]] [22 45]] [36 100]] [3 69]] [906 5.13 [2902 6.66 [36 100] [36 80]] [36 80]]] [7520 0.677 [2325 0.975 [7512 1.31 [36 52] [6260 1.04 [7512 9.91 [36 100] [36 74]] [36 100]]] [36 100]] [36 100]]]] [3313 2.65 [7374 1.43 [36 89] [36 100]] [5 71]]] [7409 0.971 [537 1.39 [3 56] [3 100]] [3 100]]]] [1713 1.53 [5760 0.258 [7223 1.56 [875 2.38 [3633 0.745 [3195 0.0515 [3219 0.675 [404 2.21 [1279 0.247 [7009 4.76 [5448 0.41 [6211 1.49 [4596 3.31 [5831 4.21 [4398 18 [968 3.69 [5170 6.14 [2412 2.44 [3989 7.72 [1 1.54 [3554 1.1 [4634 1.37 [4400 2.15 [6342 6.27 [1400 7.02 [906 11.7 [29 10] [11 30]] [15 66]] [15 50]] [12 61]] [695 5.44 [5 50] [12 84]]] [37 71]] [20 43]] [27 30]] [15 100]] [33 76]] [10 37]] [6393 2.26 [7255 19.5 [6199 1.28 [3281 4.76 [15 33] [27 60]] [31 30]] [31 77]] [15 100]]] [15 91]] [15 100]] [15 100]] [32 70]] [13 48]] [11 53]] [5809 1.82 [15 60] [15 100]]] [15 100]] [12 79]] [4405 8.15 [35 66] [791 34.5 [35 85] [35 100]]]] [1783 57.1 [30 85] [30 100]]] [30 100]] [30 100]] [31 100]]] [5312 1.23 [7369 0.183 [6524 0.633 [663 1.22 [3884 1.13 [6606 4.27 [5851 17.8 [2846 0.221 [3156 1.26 [1753 1.13 [5809 2.99 [7770 1.44 [2827 1.74 [3667 1.61 [6379 1 [1301 1.71 [859 0.78 [4895 8.39 [6997 10.6 [5528 1.71 [107 2.59 [5617 1.9 [7176 6.03 [7241 1.22 [1841 10.5 [2913 0.879 [429 14 [22 18] [504 5.84 [5412 15.9 [5605 3.31 [5462 12.7 [6653 1.81 [22 34] [22 57]] [35 45]] [22 100]] [22 64]] [22 82]]] [30 31]] [30 71]] [22 79]] [5217 1.63 [5851 1.54 [4154 10.6 [22 79] [22 100]] [22 62]] [22 100]]] [9 36]] [33 100]] [15 100]] [2 50]] [33 26]] [22 100]] [10 42]] [35 66]] [35 83]] [22 100]] [22 100]] [15 100]] [22 100]] [35 100]] [7512 19 [22 100] [22 80]]] [0 68]] [28 62]] [15 100]] [5192 1.68 [22 89] [22 71]]] [4898 2.56 [6732 20.3 [877 0.531 [4312 9.17 [6524 11.4 [2939 0.826 [22 98] [22 83]] [22 84]] [22 66]] [22 100]] [22 66]] [22 57]]] [31 29]] [7169 4.03 [15 66] [15 100]]]] [2822 5.95 [4663 1.6 [7251 0.505 [4373 0.178 [2848 0.659 [12 95] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]]] [7305 0.673 [6490 2.24 [6800 0.914 [5969 8.2 [6734 0.89 [4154 1.79 [5647 2.01 [1944 1.63 [6753 0.75 [1783 6.07 [4500 2.51 [5455 8.07 [29 83] [29 100]] [29 100]] [29 75]] [29 100]] [29 100]] [29 70]] [29 100]] [29 100]] [29 71]] [29 100]] [29 83]] [29 85]]]] [7343 11.6 [7583 1.51 [6261 0.554 [3480 0.688 [906 8.81 [7512 40.5 [7428 0.739 [3905 25.6 [4037 3.29 [7520 10.5 [1 0.778 [4569 1.39 [429 6.59 [36 93] [36 100]] [36 100]] [36 100]] [36 90]] [36 81]] [36 85]] [36 100]] [36 90]] [36 83]] [36 100]] [36 100]] [4270 0.869 [6524 3.98 [19 62] [17 3.11 [7009 0.495 [36 94] [36 100]] [36 53]]] [36 100]]] [7665 31.4 [36 57] [36 100]]]] [6227 11.2 [4764 0.147 [2130 0.675 [7241 1.22 [7520 1.5 [6342 1.19 [5267 0.347 [5532 1 [13 97] [13 100]] [13 100]] [13 100]] [13 62]] [13 42]] [13 92]] [13 100]] [1976 0.0514 [13 76] [13 100]]]] [5480 1.28 [4680 4.5 [5253 24.8 [4513 3.68 [4895 2.24 [799 0.821 [1913 30.7 [5133 33.3 [7672 1.62 [23 2.67 [2104 0.283 [2466 0.615 [5931 16.2 [2039 0.65 [3794 8.2 [5412 5.01 [4414 31.3 [7113 8.71 [7665 96.3 [4259 0.669 [7149 0.975 [7737 5.38 [1062 7.06 [5934 11.4 [4360 0.805 [4699 0.645 [7756 3.82 [7759 2.65 [20 97] [20 100]] [20 100]] [20 100]] [20 100]] [4235 70.8 [20 90] [20 100]]] [20 92]] [20 91]] [20 100]] [20 100]] [20 89]] [20 85]] [20 83]] [20 96]] [20 81]] [20 87]] [20 92]] [20 62]] [20 100]] [20 62]] [20 75]] [20 82]] [20 75]] [20 81]] [1 33]] [4513 13.4 [20 71] [20 100]]] [20 71]] [20 100]] [20 53]]] [7687 0.135 [1 1.14 [5211 1.23 [6853 1.55 [6446 0.431 [7514 0.0878 [596 0.903 [5526 0.654 [2705 0.379 [2385 0.12 [2259 16.2 [1025 29.7 [5413 1.28 [6799 4.9 [7734 1.07 [1238 0.508 [5753 4.86 [5090 3.96 [3934 0.152 [2787 0.295 [7737 1.17 [656 3.4 [2701 2.42 [145 0.234 [5820 3.62 [4320 1.17 [6584 3.29 [3520 3.07 [3327 2.33 [931 8.68 [248 3.81 [1429 80.3 [155 8.09 [6530 3.63 [4995 1.96 [7558 2.7 [7009 4.63 [6848 12.5 [3610 0.818 [3130 28.5 [4170 2.42 [5400 6.71 [1687 2.25 [1716 5.44 [2753 10 [1075 2.66 [1400 1.1 [4497 6.49 [957 11.2 [3878 4.28 [3959 2.56 [3464 6.55 [6544 12.5 [5154 1.16 [5246 3.94 [6581 2.96 [6397 2.38 [695 5.2 [4897 14.5 [5308 8.13 [1047 2.89 [5320 3.01 [6031 10.9 [5260 10.8 [4768 4.29 [2752 29.8 [5480 4.5 [2793 16.3 [1900 1.24 [221 6.77 [1079 3.35 [2023 14.7 [14 6] [12 50]] [10 21]] [30 36]] [11 35]] [27 60]] [18 58]] [2259 1.88 [2767 2.86 [906 1.13 [2846 14.5 [28 21] [22 71]] [29 60]] [22 62]] [36 27]]] [29 34]] [13 87]] [22 91]] [12 70]] [24 54]] [12 72]] [10 54]] [28 24]] [19 37]] [1078 7.75 [19 21] [19 45]]] [14 92]] [19 42]] [14 80]] [37 60]] [29 100]] [38 46]] [27 36]] [28 75]] [23 18.4 [4374 1.48 [12 29] [12 90]] [32 40]]] [2 81]] [2143 8.08 [131 0.885 [22 44] [112 3.54 [29 50] [14 33]]] [22 61]]] [28 100]] [14 56]] [13 100]] [32 81]] [1 66]] [37 53]] [35 77]] [22 37]] [13 100]] [2 86]] [28 44]] [29 15]] [37 43]] [7683 1.56 [2101 1.64 [251 1.25 [6581 0.133 [29 25] [26 71]] [1 100]] [1 100]] [1 100]]] [2 88]] [11 100]] [19 100]] [3964 6 [17 44] [17 100]]] [10 62]] [2 100]] [7149 0.405 [5812 6.99 [673 5.77 [7512 4.43 [3928 3.35 [3687 4.78 [3208 2.72 [1742 1.59 [806 0.96 [3972 5.25 [2793 0.683 [7185 7.92 [2127 1.07 [3464 4.51 [3872 1.2 [7722 2.06 [429 0.966 [19 17] [145 10.7 [23 7.8 [3 50] [28 20]] [29 25]]] [19 77]] [32 100]] [37 92]] [19 55]] [12 62]] [168 10.8 [14 41] [36 87]]] [37 55]] [29 47]] [28 45]] [13 30]] [37 60]] [37 53]] [14 23]] [26 88]] [22 39]] [16 14]]] [1429 69.2 [1104 0.77 [3960 0.77 [29 93] [29 100]] [29 100]] [29 68]]] [13 100]] [4320 0.46 [1161 3.36 [168 11 [22 47] [19 75]] [10 88]] [10 100]]] [28 50]] [29 90]] [1429 22.6 [22 42] [22 100]]] [2802 0.752 [2786 2.42 [6524 5.18 [2048 1.07 [4395 2.13 [2232 1.57 [4684 0.785 [5198 1.57 [6375 1.99 [29 15] [25 37]] [36 66]] [28 31]] [28 100]] [28 100]] [1 75]] [28 76]] [29 100]] [29 90]]] [10 94]] [2929 7.39 [18 73] [18 71]]] [29 92]] [6732 3.35 [5662 0.477 [5692 1.26 [7665 15 [5757 0.864 [7449 2.35 [2081 2.42 [29 38] [1 87]] [29 92]] [29 100]] [14 29]] [1 48]] [261 1.45 [1919 1.98 [1 82] [2 63]] [1 100]]] [2 35]]] [3013 1.89 [26 30] [26 100]]] [1169 0.64 [2920 0.0805 [14 0.296 [2445 2.73 [148 0.271 [3646 1.59 [672 1.87 [7571 0.743 [6260 3.26 [5472 2.16 [7766 1.97 [2794 5.66 [6328 9.35 [4011 3.01 [7560 1.66 [5455 0.914 [6350 0.549 [221 3.85 [2214 2.59 [5972 1.05 [3343 10.2 [6009 5.55 [6490 1.22 [6363 8.7 [957 1.94 [4458 4.15 [7665 1.96 [791 25.8 [2260 1.06 [1710 0.531 [6524 3.35 [3308 3.81 [2752 1.05 [19 12] [2081 10.1 [7168 1.77 [5296 0.12 [2119 0.768 [2072 0.85 [6131 1.86 [1997 5.02 [1899 20 [6791 0.804 [163 5.92 [10 13] [14 62]] [22 63]] [37 30]] [32 42]] [14 36]] [29 66]] [19 30]] [19 37]] [25 50]] [32 46]]] [29 71]] [28 51]] [30 100]] [6205 16.8 [7739 0.326 [5007 5.15 [14 20] [18 23]] [18 46]] [14 40]]] [2807 5.05 [22 46] [22 100]]] [112 0.835 [4154 1.06 [1943 1.25 [5034 2.01 [392 9.77 [7735 3.07 [19 19] [7 46]] [14 57]] [14 78]] [19 55]] [14 22]] [14 68]]] [14 72]] [10 44]] [7254 15 [22 68] [22 100]]] [29 80]] [30 100]] [28 92]] [36 87]] [13 70]] [5345 0.377 [30 22] [6 40]]] [10 100]] [29 100]] [6 78]] [28 85]] [11 34]] [36 80]] [4154 19.1 [10 94] [10 66]]] [1400 2.76 [36 75] [36 90]]] [36 78]] [4312 0.498 [36 100] [36 71]]] [10 100]] [36 100]] [2914 0.517 [4663 9.71 [7314 5.93 [1769 3.55 [1078 38.9 [4279 6.42 [3 72] [3 85]] [30 75]] [3 57]] [3 100]] [3 100]] [30 97]]] [328 8.46 [19 41] [30 33]]] [36 97]] [30 100]] [36 100]]] [2813 0.258 [5692 0.725 [18 53] [18 80]] [18 100]]] [663 11.2 [29 100] [5480 7.71 [29 87] [29 100]]]] [29 100]] [5999 19.4 [28 100] [28 80]]] [680 0.408 [4218 4.24 [1696 2.06 [4535 9.93 [2846 0.574 [2241 4.49 [4601 0.274 [5056 0.221 [1900 7.75 [6471 0.782 [169 0.0878 [791 1.93 [3008 4.28 [2120 4.37 [2434 3.81 [216 5.17 [99 18.3 [19 63] [19 45]] [4154 3.7 [19 54] [3 66]]] [16 40]] [14 58]] [19 41]] [13 13]] [176 39.6 [5067 16.3 [1245 0.205 [5539 0.176 [3820 17.6 [1944 4.31 [6201 33.2 [4326 12.5 [7739 3.18 [3993 3.86 [2752 2.24 [1936 4.73 [4235 2.51 [5776 4.14 [101 3.89 [1951 0.414 [2280 3.97 [19 71] [19 50]] [19 100]] [19 50]] [14 37]] [19 30]] [19 70]] [19 33]] [19 58]] [1078 25.4 [2048 1.02 [19 83] [19 100]] [19 67]]] [19 46]] [14 45]] [19 60]] [17 42]] [13 54]] [19 100]] [19 36]] [19 53]]] [26 75]] [26 28]] [7737 8.2 [1899 19 [19 50] [18 85]] [18 50]]] [7665 11.8 [19 100] [19 86]]] [19 84]] [1079 0.982 [6031 0.574 [22 28] [22 91]] [28 44]]] [22 87]] [26 53]] [2 22]] [18 100]]] [2178 4.47 [7210 0.423 [2407 1.63 [4768 8.78 [29 97] [29 75]] [29 100]] [7512 3.67 [29 100] [29 88]]] [29 87]]] [5972 0.805 [429 13.3 [6668 0.221 [28 33] [3136 10.8 [28 100] [28 66]]] [36 60]] [6131 0.503 [2331 1.04 [2763 3.17 [36 100] [36 80]] [36 100]] [36 100]]]] [7491 0.263 [809 0.107 [6634 0.411 [7767 0.346 [6199 0.857 [791 8.38 [1742 3.65 [5845 0.904 [2696 5.12 [92 5.38 [4210 2.05 [2225 1.01 [7176 1.02 [377 2.99 [4414 2.65 [1400 3.71 [30 39] [10 100]] [30 61]] [30 80]] [22 85]] [22 61]] [30 95]] [30 100]] [30 100]] [10 100]] [22 57]] [2914 1.96 [5218 2.82 [5468 1.74 [4486 0.882 [1055 1.83 [2766 0.722 [2993 4.16 [4326 1.99 [5368 1.93 [5199 0.942 [7343 1.65 [6074 6.87 [5122 2.99 [7722 1.1 [119 0.301 [434 0.901 [7169 4.55 [5692 20.5 [7016 1.48 [5420 1.73 [4533 0.891 [5765 1.92 [6711 2.38 [22 88] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 70]] [22 81]] [22 66]] [22 97]] [22 63]] [30 100]] [22 62]] [22 60]] [22 100]] [22 68]] [22 55]] [30 33]] [22 42]] [11 100]] [22 100]] [10 100]] [10 77]] [30 100]]] [5412 1.59 [1995 2.81 [896 1.87 [30 58] [30 80]] [22 72]] [5225 1.02 [22 77] [22 100]]]] [10 100]] [30 100]] [22 100]] [6246 0.174 [144 1.64 [22 63] [791 13 [23 28.6 [22 90] [22 66]] [22 100]]] [22 100]]]] [1899 8.67 [791 1.8 [1899 0.802 [36 27] [19 25]] [392 1.04 [2999 0.262 [5480 2.11 [7695 0.356 [328 3.81 [2411 0.654 [1417 0.452 [1712 1.92 [429 36.3 [6867 0.596 [5977 2.24 [4611 1.94 [3905 0.398 [36 45] [7067 1.13 [36 100] [36 71]]] [1 3.73 [1783 0.84 [36 90] [36 100]] [7722 8.63 [36 100] [36 83]]]] [36 100]] [36 100]] [663 1.31 [11 41] [36 50]]] [1738 6.47 [36 100] [36 88]]] [10 100]] [36 100]] [36 29]] [10 80]] [22 56]] [36 100]] [11 50]]] [6732 0.603 [774 1.21 [1025 5.2 [36 38] [11 55]] [10 100]] [5779 2.41 [3 27] [36 100]]]]] [2023 0.167 [5368 1.15 [6502 0.677 [2251 1.75 [169 48 [1944 10.7 [7085 2.25 [2342 0.756 [2178 9.45 [1888 2.31 [170 2.55 [2913 10.3 [429 2.61 [2069 0.496 [6036 0.952 [6310 6.23 [7445 6.87 [78 17.2 [7245 1.83 [1899 8.79 [4517 0.994 [19 68] [19 100]] [19 53]] [19 58]] [4154 13.6 [19 100] [19 85]]] [19 50]] [19 85]] [19 84]] [19 100]] [18 66]] [30 75]] [173 2.76 [19 72] [19 46]]] [19 46]] [19 35]] [19 42]] [18 36]] [14 55]] [19 87]] [1078 23 [19 30] [19 60]]] [19 100]] [30 22]] [2093 3.63 [7241 2.84 [41 0.483 [6201 9.51 [1239 7.67 [19 91] [2026 5.69 [19 88] [19 66]]] [19 75]] [19 100]] [19 77]] [19 71]]]]] [2280 7.07 [1429 6.11 [5047 2.4 [3 100] [3 86]] [6320 3.96 [2023 2.41 [5510 0.461 [1783 0.158 [256 0.328 [5940 0.995 [328 2.79 [3 99] [3 100]] [3 100]] [3 100]] [3 100]] [3 80]] [5891 2.54 [3 100] [3 91]]] [7210 12 [3 100] [3 93]]]] [3 83]]] [7428 0.848 [4160 3.35 [5480 0.171 [5940 0.521 [1078 9.43 [877 2.26 [6524 5.24 [22 47] [22 80]] [22 100]] [2752 11.4 [22 70] [22 99]]] [3 54]] [22 100]] [22 72]] [1995 0.449 [22 57] [22 88]]]] [724 1.64 [6581 3.73 [2752 5.56 [7512 7.9 [5439 24.8 [2694 3.23 [7210 14.4 [590 1.28 [1242 1.24 [4602 3.17 [6809 2.46 [1679 3.14 [622 0.924 [6524 3.81 [155 5.6 [5640 0.818 [1434 6.25 [663 0.649 [538 1.54 [4572 1.99 [2270 8.7 [4312 11.9 [751 0.867 [6234 3.35 [5617 9.09 [2164 2.6 [2628 3.26 [6260 3.24 [5851 25.7 [2259 21 [1062 5.24 [802 8.02 [5110 5.56 [7512 5.76 [1198 5.96 [248 3.76 [1078 21.4 [2199 8.27 [5851 3.59 [3 8] [35 33]] [29 58]] [10 17]] [33 50]] [35 27]] [5 37]] [30 38]] [21 87]] [15 44]] [23 45.3 [4768 0.377 [5692 2.39 [30 9] [14 28]] [35 40]] [30 57]]] [0 34]] [3 53]] [30 42]] [29 33]] [33 75]] [802 2.3 [1783 0.533 [3 37] [3 81]] [3 94]]] [3 100]] [32 66]] [34 54]] [30 86]] [574 3.93 [21 87] [9 84]]] [328 1.3 [1239 16.7 [32 19] [14 33]] [29 44]]] [34 57]] [18 57]] [19 46]] [28 40]] [3 100]] [2939 1.96 [1429 73 [429 15.9 [30 75] [30 58]] [14 30]] [30 100]]] [32 100]] [1078 7.28 [26 55] [26 100]]] [15 70]] [3 100]] [2259 1.87 [3 20] [429 0.928 [30 78] [30 50]]]] [30 100]] [30 100]] [1198 3.14 [2616 1.33 [957 20.1 [756 1.3 [2143 8.68 [6859 1.39 [5673 1.95 [791 5.41 [14 15] [7381 12.8 [5692 2.49 [14 28] [14 51]] [5 77]]] [392 2.16 [14 28] [19 40]]] [36 71]] [3 28]] [30 100]] [14 100]] [4 20]] [6 37]]] [732 1.16 [7722 0.816 [5700 0.87 [5163 0.28 [7620 0.697 [5564 0.956 [7188 2.37 [494 2.26 [5480 2.76 [2990 1.14 [6714 2.24 [2426 1.43 [7009 3.21 [134 2.21 [4374 2.66 [1429 21.4 [710 2.59 [3579 6.68 [5316 2.09 [1161 1.25 [14 20] [10 71]] [32 80]] [7 76]] [14 100]] [7665 10.8 [5225 2.45 [874 0.766 [6569 2.51 [6231 2.04 [5684 2.33 [3316 2.49 [3211 4.75 [5110 3.27 [2054 1.2 [2752 35.1 [5034 3.69 [4479 7.1 [2628 5.68 [7734 3.82 [5588 2.69 [6550 5.88 [6732 1.81 [602 7.16 [6342 1.26 [6034 0.967 [7411 4.27 [1679 1.47 [6848 1.44 [6363 6.15 [2178 1.69 [6524 12.9 [407 1.86 [6091 7.04 [3251 7.17 [12 21] [14 75]] [7 44]] [7 50]] [7 54]] [14 41]] [12 69]] [5 75]] [4279 1.62 [30 85] [30 100]]] [5 100]] [14 33]] [37 29]] [14 34]] [5 50]] [17 66]] [29 77]] [7 29]] [7260 2.28 [5 43] [5 50]]] [17 72]] [14 87]] [7601 1.4 [2826 1.65 [4414 11.9 [7742 3.14 [30 27] [5 50]] [22 35]] [2526 1.96 [14 39] [2841 4.35 [5 38] [5 100]]]] [5 100]]] [22 80]] [2818 1.01 [30 46] [12 100]]] [12 83]] [12 80]] [30 100]] [30 72]] [14 75]] [2259 13.9 [2753 3.64 [6230 19.7 [5972 17.7 [12 90] [12 100]] [12 71]] [12 100]] [12 66]]] [4061 1.38 [6231 9.62 [6711 7.52 [23 19.6 [6675 2.03 [30 96] [30 100]] [30 88]] [30 80]] [30 83]] [30 100]]] [5693 1.63 [14 51] [6436 2.86 [14 75] [14 100]]]]] [12 100]] [4071 1.75 [2260 2.49 [1239 3.53 [4851 12.7 [17 25] [7 62]] [663 10.1 [7 40] [14 30]]] [4 20]] [5 80]]] [5 51]] [1899 1.5 [5972 12.4 [12 66] [12 100]] [12 100]]] [22 90]] [7449 2.51 [12 91] [12 100]]] [6155 2.9 [5034 2.33 [1911 1.53 [2385 8.24 [7497 0.534 [6199 0.366 [6015 7.2 [22 41] [29 100]] [18 43]] [22 100]] [19 60]] [22 88]] [14 57]] [18 72]]] [14 55]] [1783 11.4 [12 62] [14 60]]] [14 96]] [5480 1.21 [14 27] [2752 40 [22 100] [22 95]]]] [791 23 [30 100] [30 85]]] [906 0.77 [68 3.33 [613 15.1 [30 98] [30 80]] [30 75]] [30 100]]] [4369 1.58 [3905 4.1 [1899 8.77 [721 2.22 [2846 2.58 [685 8.07 [1611 0.732 [4200 4.15 [7188 8.25 [7585 0.535 [6333 1.58 [7324 1.4 [567 1.11 [7583 2.04 [1429 6.56 [14 31] [7354 1.58 [2143 5.24 [4478 2.53 [3554 2.8 [14 77] [14 69]] [14 55]] [5 33]] [18 27]]] [7 57]] [29 37]] [5 78]] [5 45]] [14 90]] [5 50]] [5 46]] [14 100]] [14 29]] [6401 1.32 [112 1.01 [14 58] [663 6.14 [14 100] [14 60]]] [32 100]]] [7677 2.79 [5412 2.36 [14 100] [14 90]] [14 88]]] [2259 3.57 [1888 1.46 [5 33] [4 36]] [14 42]]] [7169 4.67 [2636 2.13 [14 86] [7 71]] [14 66]]] [32 86]]] [392 1.68 [26 93] [26 100]]]] [4222 0.659 [6238 0.465 [1885 0.713 [7187 3.27 [6936 1.85 [4832 2.37 [2842 0.821 [6887 3.47 [7516 2.82 [7665 17.6 [7725 5.96 [5007 9.6 [6589 0.741 [328 6.76 [2902 8.33 [5819 1.2 [2259 19.5 [5641 6.49 [6131 2.51 [5 30] [19 25]] [5 57]] [4 41]] [17 70]] [5 66]] [14 77]] [19 66]] [5 55]] [4 90]] [1668 1.6 [5412 6.68 [4200 2.22 [7512 17.8 [3905 18.4 [602 5.14 [1023 4.87 [17 70] [26 62]] [14 45]] [17 90]] [738 29.4 [5 36] [17 66]]] [5 100]] [14 62]] [17 90]]] [26 100]] [5692 3.16 [6550 1.62 [6581 21.7 [5 100] [5 82]] [5 100]] [5 57]]] [429 7.43 [5 60] [5812 9.45 [5 97] [5 71]]]] [4 83]] [896 5.55 [17 75] [5 50]]] [26 100]] [6199 1.42 [26 44] [26 87]]] [6584 3.72 [17 50] [19 70]]] [17 62]]] [4110 1.9 [5484 1.98 [6544 1.26 [3008 10.2 [3008 4.43 [7210 5.84 [2826 7.6 [5413 0.661 [722 3.04 [17 30] [17 55]] [5 40]] [6230 15.2 [19 48] [17 30]]] [5 46]] [19 36]] [17 76]] [2570 1.26 [17 65] [17 100]]] [18 72]] [5 92]]]] [609 1.64 [4751 0.86 [4219 0.227 [5047 0.463 [2752 2.41 [5831 0.5 [4948 1.31 [6048 3.28 [1018 0.466 [4918 2.46 [1332 1.22 [1239 57.3 [5937 0.592 [6653 1.1 [4197 3.23 [688 0.632 [6892 1.55 [163 2.67 [6015 5.06 [524 9.27 [1980 22.2 [4279 4.6 [1783 3.67 [791 27.7 [7085 13.9 [6791 5.85 [5918 3.94 [766 5.75 [23 36.4 [5439 3.14 [3 36] [21 60]] [3 69]] [3 100]] [21 37]] [9 38]] [4414 3.86 [21 40] [21 66]]] [21 64]] [3 62]] [3 96]] [2203 2.67 [371 20.1 [21 47] [21 100]] [21 90]]] [21 100]] [5046 2.09 [517 2.73 [21 81] [21 100]] [3 88]]] [3 93]] [21 100]] [4235 5.23 [542 1.6 [916 0.115 [1986 0.446 [1980 21 [660 8.22 [21 71] [21 85]] [21 64]] [21 57]] [6015 24.4 [21 73] [21 100]]] [21 100]] [9 72]]] [3 100]] [21 89]] [21 78]] [6342 4.45 [766 0.578 [5046 5.35 [7139 0.999 [328 2.46 [21 49] [7210 2.85 [9 81] [9 57]]] [21 60]] [3 58]] [9 53]] [9 75]]] [5693 0.797 [823 3.82 [9 85] [9 71]] [9 60]]] [7086 0.932 [21 98] [21 100]]] [3 98]] [917 5.15 [4414 8.04 [21 86] [21 100]] [21 78]]] [3 93]] [6342 9.03 [5851 7.19 [658 7.78 [1322 5.94 [4768 1.1 [6406 0.504 [1239 60 [518 0.5 [429 82 [9 85] [9 100]] [9 100]] [9 100]] [9 100]] [9 100]] [9 85]] [9 57]] [9 75]] [9 66]]] [2800 1.55 [6091 4.21 [907 2.25 [7428 3.37 [6213 0.6 [5270 3.35 [2786 1.21 [7491 2.86 [5970 3.8 [5472 0.699 [7665 4.19 [3464 1.39 [2628 2 [4568 0.982 [642 1.25 [2913 9.11 [4781 1.48 [7343 1.37 [5655 2.06 [29 20] [23 72]] [12 50]] [11 75]] [15 70]] [22 90]] [28 90]] [12 58]] [37 88]] [899 2.33 [2 14] [32 75]]] [1239 1.4 [36 94] [36 100]]] [29 100]] [6342 0.328 [1065 0.911 [1628 0.852 [29 53] [29 100]] [12 50]] [29 41]]] [29 100]] [32 80]] [29 100]] [12 44]] [907 4.32 [21 42] [21 71]]] [32 51]] [29 100]]] [1026 3.14 [3 100] [3 87]]] [6871 0.531 [2624 1.95 [3742 3.38 [3 100] [3 85]] [3 100]] [3 100]]] [569 3.95 [127 0.587 [7410 0.14 [9 93] [9 100]] [9 77]] [9 100]]] [6892 1.55 [21 97] [21 100]]]] [7374 0.227 [4087 0.324 [7512 2.14 [4396 0.331 [6033 0.155 [2811 0.743 [6110 1.08 [4457 0.78 [7009 6.52 [857 0.818 [2259 15.2 [688 6.7 [1509 0.291 [163 12.8 [5482 1.13 [6611 6.07 [5283 2.88 [7176 3.34 [6514 0.414 [4870 1.55 [27 0.717 [1911 9.29 [1429 96.3 [1025 17.5 [1995 1.16 [4530 2.34 [5692 14.6 [973 6.37 [6732 0.303 [7149 1.66 [4611 3.41 [28 84] [28 44]] [28 100]] [5776 0.509 [6031 3.78 [5943 0.614 [5412 7.56 [7169 0.294 [1206 0.283 [28 97] [28 100]] [28 100]] [28 88]] [1086 0.939 [28 100] [28 80]]] [22 75]] [28 100]]] [28 66]] [28 42]] [28 58]] [28 100]] [28 42]] [28 52]] [28 62]] [28 100]] [28 66]] [36 87]] [22 88]] [22 63]] [28 100]] [22 100]] [28 50]] [28 98]] [28 50]] [6853 9.71 [28 60] [22 25]]] [22 100]] [36 38]] [36 83]] [22 85]] [22 66]] [22 100]] [6856 23.6 [1708 6.69 [6859 45.4 [5037 1.61 [2393 0.387 [5192 5.61 [404 0.412 [7067 0.582 [7413 0.642 [28 99] [28 100]] [28 100]] [28 100]] [28 75]] [28 100]] [28 90]] [28 90]] [28 60]] [28 77]]] [7741 1.2 [1 0.361 [1215 1.21 [1239 8.22 [1391 1.1 [6854 1.25 [7517 1.17 [7693 0.448 [5673 0.75 [4735 0.623 [5753 5.9 [7512 30.5 [6091 3.18 [1025 4.45 [5034 1.87 [4025 1.32 [7566 9.53 [7571 0.364 [144 0.626 [939 1.83 [663 5.31 [36 79] [36 100]] [36 100]] [36 62]] [36 100]] [36 70]] [36 100]] [28 58]] [13 66]] [36 66]] [13 29]] [36 100]] [36 100]] [36 41]] [3067 1.47 [3004 0.254 [6732 4.11 [429 13.9 [36 71] [36 100]] [36 73]] [36 100]] [36 100]]] [28 75]] [10 100]] [22 100]] [5472 1.38 [24 72] [36 84]]] [22 100]] [3012 0.296 [6036 0.347 [3004 0.603 [811 3.87 [5472 0.437 [36 63] [7149 1.95 [36 100] [36 85]]] [36 100]] [36 100]] [36 100]] [36 100]]] [631 3.33 [10 100] [10 77]]]] [36 100]] [811 2.8 [6404 0.211 [6859 1.08 [36 90] [4154 0.45 [36 98] [36 100]]] [36 100]] [36 77]]]] [791 5.66 [5801 0.972 [7421 0.544 [6346 0.631 [4573 2.21 [2955 0.851 [6809 10.2 [5972 4.83 [2944 12.1 [6982 1.62 [728 5.95 [2594 4.27 [7512 3.38 [5564 1.99 [2649 4.67 [2698 4.67 [1783 9.5 [1980 24.8 [6471 2.28 [301 5.62 [6157 0.659 [4655 1.85 [957 7.84 [730 1.16 [167 4.35 [2752 2.48 [2737 5.62 [5626 8.2 [7759 8.92 [5492 6.49 [96 17.3 [187 2.01 [2241 11 [7009 13.7 [2199 1.16 [1698 6.02 [165 17 [4235 5.16 [3935 2.49 [4279 39.1 [1078 30.9 [7623 14.5 [23 93.6 [7762 7.46 [6581 7.69 [5580 4.67 [3763 9.43 [5632 9.66 [5274 19.1 [2732 13.9 [1587 15.5 [1313 1.8 [4135 4.56 [5812 7.46 [7314 16.4 [5753 27.1 [88 4.5 [6159 18.9 [1435 19.8 [3576 8.47 [4684 7.37 [1772 8.36 [7449 7.05 [7472 0.609 [1895 28 [5435 23.3 [3238 2.82 [2951 9.72 [328 5.62 [4019 2.54 [1899 36.6 [7281 15.2 [2169 10.9 [6131 3.61 [45 10.7 [5412 26.2 [4218 17.2 [1913 13.6 [1 15] [15 33]] [3 33]] [31 33]] [22 37]] [33 33]] [1 71]] [26 40]] [29 19]] [11 25]] [14 10]] [7169 10.4 [5918 36.6 [1895 10.7 [2225 0.773 [2723 9.13 [38 39] [16 46]] [1 30]] [16 33]] [36 83]] [16 75]]] [38 100]] [16 85]] [38 56]] [38 61]] [5 26]] [33 37]] [38 33]] [15 100]] [1 35]] [29 27]] [37 42]] [33 44]] [3 38]] [12 41]] [37 55]] [33 70]] [33 27]] [16 90]] [32 35]] [16 76]] [15 100]] [6 50]] [17 40]] [7 87]] [15 56]] [33 34]] [4 16]] [15 29]] [31 81]] [2628 18.6 [33 20] [20 41]]] [38 81]] [25 84]] [7623 15.5 [29 16] [1 60]]] [7009 26.5 [22 30] [4 18]]] [15 44]] [7255 24.5 [1899 6.55 [7123 8.38 [2951 36.6 [2006 2.89 [2869 10.2 [83 13 [2866 11.4 [5918 9.47 [7474 2.13 [16 30] [38 90]] [17 50]] [37 34]] [2951 10.3 [16 64] [1 40]]] [5 37]] [38 31]] [38 59]] [16 54]] [38 39]] [38 92]]] [16 69]] [14 100]] [6199 5.49 [5211 8.2 [2939 48.2 [28 50] [28 40]] [13 100]] [18 72]]] [3027 9.71 [2862 7.21 [16 55] [16 72]] [16 36]]] [38 100]] [2634 6.54 [4066 3.12 [2701 2.24 [6207 2.56 [3936 7.61 [6409 8.44 [2259 11.4 [5673 18.9 [6015 5.03 [2081 10.2 [5 11] [1 24]] [16 50]] [38 50]] [2849 12.3 [30 14] [16 28]]] [16 44]] [8 83]] [35 32]] [29 92]] [19 44]] [29 100]]] [7343 12.5 [7726 1.42 [38 53] [17 20]] [17 17]]] [28 83]] [1233 6.67 [10 53] [27 100]]] [1 81]] [28 90]] [5673 4.28 [7281 6.21 [303 1.47 [4851 3.82 [2953 2.46 [6409 11.5 [301 27.5 [30 33] [30 76]] [30 80]] [30 90]] [30 87]] [30 100]] [30 100]] [30 57]]] [1696 16.3 [26 84] [26 57]]] [2948 28.4 [39 13.9 [1995 11.5 [29 30] [15 45]] [10 50]] [1980 77.7 [2939 85.6 [1 33] [38 83]] [23 30]]]] [3833 3.02 [1899 20 [4977 4.61 [5673 0.285 [2951 5.99 [16 13] [5137 3.76 [5597 1.07 [2628 30.7 [16 24] [63 3.4 [192 4.07 [6832 31.9 [16 38] [18 85]] [16 100]] [16 91]]] [2655 1.07 [94 13.9 [16 100] [16 50]] [16 66]]] [16 100]]] [16 35]] [6 54]] [29 18]] [26 81]]] [12 97]] [2939 88.9 [6257 6.67 [6749 3.03 [188 12.7 [2868 6.58 [5578 3.83 [2913 7.43 [6 31] [30 100]] [6 40]] [18 38]] [6 72]] [16 77]] [18 52]] [16 74]]] [14 97]] [7132 3.65 [1913 3.54 [7545 5.74 [1239 17.9 [4665 1.3 [3558 2.35 [2698 5.15 [6230 8.72 [2617 3.36 [5894 2.37 [2199 1.51 [7525 2.21 [3635 3.88 [1221 2.11 [6582 3.94 [4235 17.3 [2701 2.96 [6550 12.7 [5695 3.45 [4081 8.2 [6074 4.63 [6584 2.49 [1429 33.2 [7210 18.5 [328 1.9 [31 16] [1 15]] [4 33]] [2951 3.4 [429 4.66 [6 15] [18 21]] [18 66]]] [2628 20 [19 37] [5 46]]] [4 85]] [31 100]] [26 81]] [17 47]] [10 70]] [20 75]] [4 100]] [10 100]] [1 100]] [30 90]] [10 58]] [16 50]] [4 100]] [7512 25.5 [2939 14.7 [17 62] [5 23]] [5 78]]] [31 78]] [6732 13.5 [17 28] [5 33]]] [10 100]] [6 45]] [6 100]] [10 63]] [2617 3.53 [4 83] [4 100]]]] [5 75]] [5267 1.06 [10 58] [10 100]]] [2739 15.4 [4 90] [4 100]]] [21 54]] [5491 0.597 [12 61] [33 50]]] [32 100]] [2632 0.202 [2729 1.15 [4977 0.626 [1265 0.389 [4609 2.4 [2661 2.65 [6757 2.2 [2985 2.65 [3207 0.951 [2713 1.64 [7765 2.74 [6959 1.88 [7726 0.244 [6878 0.571 [6406 4.24 [1429 10 [2649 6.44 [5626 3.39 [5594 0.572 [2688 6.38 [7347 19.5 [3238 2.15 [2719 11.2 [96 1.25 [6370 27.8 [3948 1.25 [4716 5.62 [1980 0.202 [7763 4 [6879 1.51 [2711 4.25 [7104 10.4 [4851 6.89 [1239 48.9 [2707 18.3 [328 0.885 [38 55] [38 80]] [6523 19.2 [6148 2.42 [7231 18.4 [2209 2.38 [1769 6.72 [6721 7.88 [2466 9.8 [4478 4 [4909 9.35 [2628 74.7 [4496 0.824 [5368 12.2 [312 1.95 [2118 0.633 [2526 1.64 [7009 46.3 [2752 7.27 [7391 1.59 [4533 4.65 [5931 14.6 [1957 0.549 [3566 1.47 [3591 2.44 [5673 40.7 [38 80] [38 57]] [8 28]] [38 87]] [38 100]] [38 66]] [38 60]] [38 55]] [38 70]] [36 50]] [38 62]] [38 80]] [38 100]] [38 66]] [38 37]] [6199 31.3 [38 67] [38 90]]] [4909 17.5 [2850 0.741 [7482 78.3 [38 92] [38 85]] [38 76]] [38 100]]] [19 37]] [24 42]] [17 42]] [38 53]] [38 50]] [16 45]] [37 55]] [14 50]]] [7 38]] [17 25]] [16 39]] [37 44]] [5 47]] [7 100]] [1436 5.17 [2728 0.626 [4939 4.02 [3435 6.38 [3227 0.101 [2466 3.5 [2978 8.77 [5188 0.373 [1783 5.11 [6134 1.08 [4414 1.21 [38 80] [38 100]] [38 42]] [38 100]] [38 97]] [38 68]] [38 61]] [38 100]] [38 100]] [38 66]] [16 40]] [38 50]]] [16 34]] [16 88]] [16 52]] [16 50]] [5933 27.5 [22 40] [6 70]]] [16 50]] [78 6.54 [6370 14.5 [38 80] [6207 7.23 [16 77] [2853 4.13 [16 61] [18 50]]]] [16 30]]] [38 100]] [2717 0.286 [38 45] [5594 16.7 [5632 11.3 [16 100] [2654 7.2 [16 30] [16 92]]] [16 50]]]] [16 45]] [16 53]] [2469 0.153 [2654 0.441 [1380 1.92 [3882 1.73 [4097 2 [7167 5.18 [4851 5.2 [6230 2.21 [4103 0.358 [2259 63.6 [7132 16.8 [6148 2.55 [221 1.54 [3107 9.29 [4889 1.06 [5622 6.53 [2939 106 [2718 0.935 [2850 6.34 [6848 7.58 [2466 9.26 [5681 10.3 [307 5.12 [4535 12 [2955 17.2 [2849 8.5 [1429 11.1 [1 53] [328 0.956 [2849 4.77 [38 25] [14 33]] [38 71]]] [3675 13.7 [1895 5.46 [38 55] [1896 5.23 [38 29] [5 34]]] [8 60]]] [2951 35.5 [45 1.64 [2849 18.1 [14 21] [5 22]] [38 58]] [38 44]]] [2628 31.7 [2884 12.9 [7440 2.99 [38 73] [38 60]] [17 50]] [16 27]]] [30 66]] [18 34]] [38 65]] [7 21]] [2628 31.6 [5 66] [5 28]]] [2259 24.4 [38 96] [38 50]]] [38 64]] [5 50]] [38 80]] [5 63]] [16 23]] [1749 3.02 [5 100] [37 42]]] [7 87]] [7475 11.4 [5641 6.33 [38 81] [38 66]] [38 71]]] [5 50]] [14 61]] [17 55]] [30 63]] [1899 0.978 [37 60] [5 55]]] [5 81]] [17 54]] [16 48]] [1913 2.08 [6131 0.404 [3110 5.83 [1959 6.49 [38 73] [12 33]] [38 42]] [8 20]] [5641 9.28 [38 100] [38 90]]]]] [3238 1.85 [2849 19.1 [16 39] [2955 5.91 [38 80] [6406 38.1 [38 30] [38 90]]]] [16 80]]] [6878 7.52 [4074 15.6 [7391 0.15 [663 3.39 [37 73] [5 70]] [35 33]] [16 27]] [3675 3.11 [4011 4.13 [5 54] [37 50]] [6 66]]]] [5 35]] [2143 3.33 [5632 1.85 [1900 4.05 [16 46] [16 54]] [194 7.94 [5637 2.06 [94 7.27 [16 68] [16 100]] [16 94]] [5681 2.2 [4716 17.9 [18 55] [16 57]] [18 83]]]] [18 50]]] [6355 2.86 [2716 2.26 [7 59] [28 45]] [7 100]]] [5099 66.6 [6756 14.5 [7759 0.949 [5090 1.9 [5412 0.928 [305 7.15 [4762 13.8 [5799 1.77 [6959 15.2 [1239 48.5 [3424 1.16 [6877 15.6 [7241 4.08 [6830 11.4 [2897 37.3 [60 6.07 [1429 16.3 [2862 2.65 [6359 1.71 [5104 7.05 [16 42] [26 41]] [16 40]] [16 76]] [301 2.41 [6199 1.77 [2713 12.9 [16 29] [18 38]] [16 71]] [37 42]]] [16 84]] [16 37]] [18 83]] [16 90]] [37 72]] [6 66]] [7 78]] [16 89]] [23 24.4 [18 62] [6 37]]] [7 48]] [30 100]] [16 89]] [5099 28.6 [16 90] [16 62]]] [6256 0.949 [18 40] [7 57]]] [16 90]] [6 48]]] [2643 5.92 [4716 0.342 [3544 1.66 [5 25] [5 46]] [2682 2.13 [16 66] [16 29]]] [5 75]]] [3675 5.1 [187 10.6 [2628 25.4 [16 93] [16 61]] [26 66]] [16 50]]] [1396 2.36 [38 87] [38 100]]] [2954 1.82 [2628 54.3 [2707 47.1 [7619 10.8 [1896 1.78 [6959 2.41 [7260 0.522 [1355 7.14 [2661 27.2 [16 24] [6 56]] [18 88]] [18 45]] [5600 1.18 [16 44] [6 66]]] [16 54]] [18 66]] [4431 5.24 [6 33] [6 94]]] [6941 24.2 [16 36] [18 50]]] [30 100]]] [1592 2.04 [5565 0.776 [1980 11.9 [17 42] [32 41]] [14 100]] [19 87]]] [17 46]] [2690 0.745 [4977 13.4 [5637 4.51 [5409 0.327 [7331 0.241 [2671 6.77 [1239 5.14 [6 52] [16 56]] [18 90]] [16 29]] [6 66]] [6 50]] [6 61]] [6342 0.418 [5901 2.68 [2723 2.43 [1596 8.34 [5986 2.42 [2526 1 [6 33] [16 86]] [6 57]] [16 100]] [6 75]] [7331 1.75 [2951 27.8 [18 58] [16 42]] [16 60]]] [16 83]]]] [88 2.76 [2713 11.9 [5350 1.53 [5492 8.32 [2712 0.183 [7619 8.55 [2696 1.32 [4739 1.31 [7041 6.54 [4663 0.901 [1983 1.49 [2207 6.33 [2881 0.655 [2640 0.0842 [6406 5 [2006 8.33 [2983 1.12 [16 45] [16 57]] [16 83]] [7 42]] [16 20]] [6 37]] [16 85]] [16 50]] [16 90]] [16 90]] [16 87]] [30 66]] [7 28]] [2241 1.47 [16 84] [16 50]]] [14 100]] [33 55]] [26 44]] [5 50]]] [2201 6.08 [2862 10.1 [4103 8.12 [2178 0.173 [2849 38.7 [2632 6.85 [7457 7.6 [5 100] [5 87]] [5 84]] [1687 1.21 [3979 5.15 [5 82] [5 100]] [5 77]]] [5 57]] [1429 16.7 [5 28] [2955 7.87 [5 77] [5 86]]]] [5 33]] [5 66]]]] [187 3.51 [2526 3.93 [1661 4.21 [1783 6.4 [7 55] [16 35]] [2716 1.47 [7 88] [7 100]]] [7 44]] [2730 1.18 [2717 1.13 [4573 5.59 [16 57] [7 36]] [2951 25.8 [7 66] [7 100]]] [7 100]]]] [45 3.24 [38 95] [38 50]]] [2301 3.09 [5093 6.89 [195 1.42 [788 0.534 [7665 2.12 [4104 2.15 [2628 15.9 [18 30] [2667 9.47 [2728 1.09 [194 4.59 [1897 2.81 [6371 8.29 [4740 0.642 [7203 2.68 [6961 2 [4717 0.475 [16 62] [16 50]] [16 92]] [16 94]] [16 100]] [16 62]] [16 52]] [7 35]] [1899 9.45 [3435 0.36 [16 95] [16 76]] [6 57]]] [6 55]]] [16 50]] [221 3.56 [6 51] [16 57]]] [16 60]] [6 50]] [6 81]] [6 75]]] [196 3.63 [5435 1.89 [2891 8.57 [2753 2.41 [7354 2.13 [5673 3.33 [7149 4.32 [7260 1.15 [14 50] [2733 2.62 [16 55] [16 100]]] [16 33]] [2752 1.39 [2649 10.8 [16 69] [18 46]] [16 88]]] [18 85]] [16 85]] [7 50]] [4205 6.99 [2081 7.82 [2981 8.22 [4712 3.05 [1895 2.21 [1981 0.319 [7206 10.7 [6940 0.981 [3302 4.29 [7759 0.96 [1696 1.72 [1288 4.51 [7124 10.8 [3207 1.07 [16 65] [26 40]] [16 60]] [18 40]] [26 56]] [28 50]] [26 55]] [16 75]] [18 33]] [26 55]] [7260 2.13 [18 50] [2646 2.7 [5415 10.3 [1899 1.77 [16 76] [16 50]] [28 36]] [5931 16.1 [1429 4.39 [16 68] [26 71]] [6 28]]]]] [28 55]] [17 44]] [26 38]] [26 100]]] [1596 1.83 [7 83] [16 50]]]] [6560 4.85 [2639 1.04 [4865 3.89 [2103 0.666 [2701 1.42 [791 38.1 [4889 8.83 [906 10.2 [2671 0.168 [1052 2.79 [3099 1.59 [2699 2.15 [4959 0.955 [350 1.82 [5695 2.06 [2696 1.69 [7267 10.4 [2826 1.36 [4851 0.431 [3421 9.19 [7399 5.05 [5467 0.99 [3150 2.86 [5211 6.99 [3008 6.85 [6124 3.14 [1078 28.8 [2955 3.4 [5480 6.76 [3576 6.49 [896 5.47 [663 12.1 [2069 1.56 [3764 4.67 [7314 11.7 [2698 5.71 [2966 6.69 [4159 14.1 [2707 4.06 [7623 6.37 [5972 2.86 [3905 10.6 [2962 20.7 [2945 13.2 [3931 15.1 [6809 6.49 [4165 3.7 [740 4.27 [5851 7.42 [5007 13 [2202 3.68 [6155 11.7 [21 10] [28 55]] [22 37]] [29 77]] [29 21]] [35 85]] [22 100]] [3480 2.18 [32 93] [32 100]]] [36 90]] [33 100]] [31 85]] [32 68]] [12 48]] [2259 6.02 [1 28] [33 25]]] [38 30]] [29 82]] [32 54]] [12 80]] [3 86]] [15 100]] [29 90]] [29 43]] [6550 3.07 [7169 7.25 [695 3.18 [7734 9.32 [5 29] [7 66]] [14 21]] [29 26]] [5 62]]] [15 100]] [22 36]] [429 6.96 [1899 1.72 [38 31] [16 40]] [14 21]]] [1104 17.5 [2091 9.85 [29 15] [28 30]] [32 69]]] [12 95]] [10 23]] [6791 4.42 [2259 9.3 [22 43] [22 40]] [22 37]]] [21 100]] [10 46]] [24 100]] [5 48]] [7132 1 [7620 3.7 [3931 54.4 [4279 2.35 [3554 7.14 [7411 5.79 [7711 1.13 [17 15] [5 44]] [5 75]] [791 15.2 [19 40] [17 40]]] [32 33]] [7 44]] [36 54]] [4 80]]] [7586 6.54 [4851 4.59 [6732 2.88 [14 51] [7 29]] [7512 30 [5 47] [5 100]]] [19 83]]] [5797 7.22 [4 96] [4 100]]] [30 90]] [26 75]] [12 83]] [4 100]] [12 100]] [1 82]] [10 100]] [196 0.644 [2868 2.99 [2951 11.4 [7601 0.168 [5 27] [18 66]] [18 72]] [5692 3.46 [16 60] [16 45]]] [18 33]]] [2947 6.06 [21 49] [14 50]]] [6 92]] [1888 15.8 [2541 6.49 [2993 19.9 [21 28] [3 28]] [24 100]] [22 21]]] [4159 1.14 [6184 5.38 [7512 7.8 [29 83] [32 57]] [29 50]] [29 100]]] [5211 2.02 [10 64] [10 100]]] [3 100]] [2259 16.8 [12 100] [12 77]]] [21 100]]]] [221 4.48 [5110 1.46 [1843 1.36 [1600 1.15 [6612 3.71 [4754 0.0333 [1833 2.34 [7305 6.74 [233 0.4 [1813 6.36 [5524 1.68 [6767 0.791 [5258 0.222 [7729 2.18 [1 16.7 [1812 4.66 [917 1.88 [6772 0.478 [3929 3.64 [1634 2.23 [2701 2.59 [1717 0.478 [7305 0.421 [3099 2.15 [4682 4.8 [6063 5.73 [5892 0.283 [3602 0.27 [6484 1.43 [1696 1.15 [187 1.85 [968 12 [7081 2.36 [1062 16.8 [1261 2.88 [1391 43.9 [1 3.29 [4478 0.516 [4705 12.5 [1576 5.3 [6757 2.43 [3774 6.9 [5275 3.39 [7314 4.75 [6328 5.21 [1876 2.69 [2225 2.63 [6363 2.84 [1913 9.38 [1429 20.1 [33 15] [1451 6.09 [2939 2.16 [2628 1.69 [1783 35 [33 22] [1436 5.54 [11 20] [33 57]]] [1 42]] [19 18]] [8 28]]] [1783 21.9 [31 36] [3 47]]] [25 40]] [10 21]] [15 29]] [4 40]] [33 50]] [10 66]] [23 20.3 [7 33] [8 53]]] [33 36]] [2 64]] [11 55]] [9 55]] [30 42]] [31 63]] [11 25]] [29 40]] [10 80]] [28 50]] [1078 1.31 [2707 14.4 [16 88] [12 50]] [16 77]]] [26 83]] [25 93]] [4238 1.8 [1436 2.65 [5 40] [12 33]] [5 25]]] [5892 8.03 [17 52] [3 41]]] [22 100]] [33 88]] [1 88]] [23 22]] [32 100]] [29 100]] [13 100]] [12 66]] [1239 13.4 [30 81] [4704 2.46 [30 90] [30 100]]]] [3 66]] [1812 15.4 [33 100] [33 72]]] [18 76]] [1 100]] [10 100]] [31 93]] [11 100]] [2143 0.202 [5333 2.21 [7329 8.02 [5807 16.6 [33 43] [15 50]] [7512 17.6 [7255 13.9 [6774 2.15 [1812 1.14 [5845 4.67 [4655 5.49 [6082 9.96 [6897 1.36 [5244 9.09 [7139 4.27 [33 26] [33 81]] [33 56]] [9 70]] [25 69]] [1 83]] [10 100]] [33 86]] [30 100]] [25 81]] [1 71]]] [11 100]] [6294 3.25 [4768 3.09 [3635 1.92 [7210 0.788 [30 17] [31 23]] [1 100]] [2 87]] [33 60]]]] [291 2.44 [7528 2.06 [567 1.5 [6525 18.4 [1338 1.82 [1429 39.1 [4658 8.27 [5412 4.18 [250 16.2 [23 14.4 [233 83.9 [6928 5.88 [5322 6.97 [1783 103 [23 12.5 [1319 5.62 [6621 1.52 [5170 14.7 [33 93] [33 100]] [33 66]] [33 100]] [16 33]] [33 56]] [33 100]] [33 100]] [33 45]] [7664 11.4 [1867 20.9 [5641 2.49 [4799 3.43 [4655 8.99 [5491 8.29 [33 8.34 [4356 2.92 [233 3.54 [33 88] [7176 2.26 [1359 2.01 [695 3.23 [33 94] [33 100]] [33 88]] [33 97]]] [33 100]] [33 83]] [33 75]] [33 60]] [33 88]] [33 80]] [33 73]] [33 71]]] [33 76]] [1 54]] [1 85]] [33 97]] [33 66]] [1 55]] [1 57]] [1 100]] [33 81]]] [6460 1.9 [7210 9.19 [1813 9.69 [26 26] [25 62]] [22 50]] [25 100]]] [5495 1.96 [13 96] [13 100]]] [2259 37.1 [3323 0.543 [5170 2.42 [7149 0.419 [1830 4.14 [1259 1.77 [6040 1.33 [3135 1.59 [1684 2.11 [6032 3.71 [2259 19.2 [14 17] [32 25]] [25 44]] [11 76]] [13 57]] [30 36]] [30 55]] [11 54]] [15 33]] [33 63]] [2027 1.09 [24 38] [24 100]]] [13 71]]] [1078 1.59 [28 77] [28 100]]] [7 100]] [22 100]] [5693 1.31 [7207 13 [4154 22.5 [1293 5.43 [250 6.94 [1813 4.24 [1379 9.24 [2011 1.37 [23 3.68 [5175 4.67 [33 86] [33 100]] [6845 1.92 [1391 13.1 [6528 4.53 [7254 2.13 [1812 0.998 [7665 4.89 [33 94] [33 100]] [33 100]] [33 100]] [33 90]] [33 90]] [33 100]]] [33 100]] [33 60]] [1368 1.45 [33 81] [33 45]]] [248 33.5 [33 100] [1 50]]] [33 78]] [33 72]] [33 62]] [1 44]]] [4682 0.867 [5989 7.05 [4704 0.632 [791 3.57 [33 26] [29 40]] [5692 0.317 [1899 5.72 [5322 3.13 [4768 1.35 [6296 0.858 [6457 1.54 [429 6.33 [33 62] [22 27]] [25 100]] [7 50]] [33 50]] [11 52]] [328 8.88 [33 76] [33 63]]] [33 73]]] [30 30]] [4658 1.46 [7168 2.64 [5172 7.6 [1783 68.2 [221 50.1 [5376 3.99 [5360 1.17 [4898 7.93 [1319 1.47 [5999 1.55 [7207 0.982 [3027 1.2 [33 89] [33 100]] [33 100]] [33 100]] [33 71]] [33 85]] [4809 2.65 [33 100] [33 87]]] [33 84]] [33 71]] [33 72]] [33 76]] [33 55]] [1 85]]]]] [2826 1.25 [134 0.428 [6859 0.756 [2851 0.778 [5170 2.46 [6015 6.62 [1913 0.838 [312 32.2 [1 0.468 [6544 2.09 [3464 2.57 [5021 11.4 [731 6.9 [663 1.42 [2139 2.44 [5681 0.478 [1895 1.17 [831 1.39 [6616 5.35 [6312 1.83 [1089 17.1 [3103 0.907 [3438 3.9 [23 9.64 [7168 5.33 [2745 14.6 [3514 2.78 [2119 17.2 [1391 1.27 [4398 6.19 [740 4.07 [2023 1.63 [5680 2.88 [3008 42.9 [248 10.7 [1078 89.6 [3136 2.92 [2029 4.3 [7210 10.4 [1085 1.54 [35 85] [35 100]] [30 28]] [35 100]] [35 100]] [35 70]] [35 50]] [35 100]] [35 80]] [35 72]] [35 100]] [35 75]] [35 95]] [35 44]] [1776 7.91 [5673 25.2 [5680 2.13 [1995 0.961 [830 3.05 [35 93] [35 77]] [35 100]] [35 100]] [35 86]] [35 83]]] [35 77]] [13 37]] [35 52]] [35 100]] [7358 3.37 [433 1.46 [2745 3.99 [3435 26.2 [3445 0.36 [3008 36.7 [3862 1.12 [3041 29.4 [4279 0.87 [4465 0.911 [3668 0.554 [6353 10.8 [3273 11.7 [826 0.328 [5680 4.7 [4043 0.96 [392 9.34 [7411 0.552 [35 93] [35 100]] [35 81]] [35 100]] [35 89]] [35 100]] [35 85]] [35 80]] [35 100]] [35 100]] [35 91]] [35 72]] [35 98]] [35 57]] [35 100]] [35 50]] [35 87]] [35 62]] [35 62]]] [35 83]] [35 45]] [35 42]] [2083 0.589 [3155 6.53 [806 5.92 [2023 9.74 [3272 11.5 [1161 0.971 [3041 19.7 [1648 31 [1064 3.29 [4279 18.6 [3153 25.7 [1062 16 [366 1.14 [5812 14.9 [1078 46 [35 99] [35 93]] [35 72]] [35 100]] [35 83]] [35 81]] [831 6.1 [35 77] [35 66]]] [35 90]] [35 66]] [3389 4.49 [35 69] [35 100]]] [35 100]] [35 90]] [35 66]] [3849 12.7 [35 75] [35 100]]] [35 68]] [35 100]]] [35 36]] [38 38]] [1 46]] [3190 1.15 [35 30] [35 70]]] [26 50]] [13 55]] [37 40]] [3 40]] [36 28]] [28 2.62 [37 75] [37 90]]] [837 1.47 [30 58] [18 41]]] [22 46]] [33 52]] [16 25]] [28 43]] [26 50]] [1429 28.1 [5 33] [14 38]]]] [2629 5.47 [5007 0.0197 [5254 0.975 [774 2.82 [806 11.9 [5110 19.7 [3029 2.49 [5976 1.48 [2241 0.289 [5049 1.14 [6349 5.85 [2143 1.23 [957 1.17 [1913 0.876 [2774 1.66 [5413 1.58 [2048 6.38 [2259 20.7 [2086 1.36 [1062 10.3 [4159 1.89 [1106 1.59 [4768 41.7 [3095 2.11 [1995 9.81 [29 75] [29 100]] [29 100]] [3 28]] [29 100]] [29 100]] [29 43]] [29 100]] [29 43]] [11 37]] [29 100]] [5995 1.08 [29 91] [29 100]]] [2225 0.907 [29 100] [29 90]]] [10 60]] [7449 9.88 [23 0.726 [29 86] [7497 0.728 [29 100] [29 88]]] [29 100]]] [10 100]] [21 71]] [1101 0.321 [1089 0.289 [29 88] [29 100]] [2081 13.7 [2251 10.6 [29 100] [29 90]] [29 100]]]] [3 100]] [11 55]] [11 100]] [21 71]] [27 45]] [10 100]] [5942 1.56 [5753 8.88 [6732 1.64 [6397 1.49 [5073 18.2 [532 0.147 [429 79 [1166 0.621 [2167 0.174 [585 0.0274 [1913 0.418 [7139 14.4 [29 100] [29 87]] [29 100]] [29 100]] [2143 5.91 [29 100] [29 91]]] [29 90]] [29 55]] [29 100]] [2806 0.411 [2081 1.59 [29 85] [29 100]] [29 100]]] [29 90]] [5412 0.286 [29 100] [29 91]]] [1429 24.3 [29 100] [29 50]]] [29 75]]] [10 100]]] [6732 5.75 [2382 1.33 [6428 0.39 [791 1.74 [2320 1.74 [537 3.26 [4170 0.956 [2259 1.15 [5753 22.5 [6949 11.8 [736 2.65 [688 10.9 [957 11 [5692 3.25 [6230 7.92 [1913 26.3 [1899 9.84 [5316 1.87 [2913 16.4 [32 57] [32 94]] [32 100]] [32 30]] [23 45]] [7340 15.2 [32 64] [32 88]]] [32 25]] [1674 5.62 [32 50] [32 84]]] [32 100]] [18 71]] [32 50]] [22 55]] [2990 1.61 [7704 1.39 [5270 4.61 [915 2.99 [705 5.16 [392 3.1 [1998 0.577 [434 2.22 [7287 6.71 [32 44] [12 100]] [12 41]] [12 90]] [18 81]] [12 100]] [32 100]] [5447 3.31 [32 90] [32 100]]] [32 100]] [12 100]]] [32 97]] [3 100]] [32 96]] [5034 2.25 [4213 2.02 [7433 1.06 [2624 0.649 [2540 3.23 [221 0.319 [657 0.581 [1429 10 [4851 11.7 [5110 5.56 [4517 1.17 [826 6.75 [5647 17.5 [538 1.41 [6809 1.55 [7734 6.25 [5467 9.68 [2320 1.1 [5316 6.33 [5462 1.04 [6524 1.14 [7520 1.98 [1995 12.3 [915 2.19 [7340 6.34 [32 45] [5692 1.45 [889 5.03 [1899 3.31 [6106 2.24 [32 67] [32 100]] [32 30]] [32 95]] [3 36]]] [3 72]] [32 95]] [4 36]] [7 40]] [35 50]] [32 90]] [32 92]] [12 66]] [18 90]] [32 100]] [21 73]] [32 100]] [12 55]] [3 62]] [11 21]] [32 94]] [3905 0.736 [1401 1.42 [2929 1.03 [328 3.29 [6353 13.9 [7214 0.986 [6524 3.07 [3480 0.911 [685 1.36 [2526 8.15 [7520 1.61 [2752 3.5 [32 40] [5969 5.92 [660 24 [4288 0.732 [2426 3.03 [6550 7.72 [2752 23.3 [7463 2.39 [27 2.09 [7542 11.8 [5673 5.95 [6092 1.53 [2225 7.14 [896 0.924 [6294 2.56 [34 7.25 [5368 2.16 [7314 1.68 [1078 35.4 [695 2.3 [32 98] [32 100]] [32 84]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]] [32 85]] [32 100]] [32 96]] [32 90]] [32 88]] [32 100]] [4279 9.25 [567 0.982 [5013 1.54 [32 84] [32 50]] [11 55]] [32 100]]] [32 72]] [32 62]] [32 100]] [32 66]] [32 50]]] [32 100]] [32 25]] [32 35]] [32 100]] [32 40]] [32 100]] [18 42]] [1429 35 [32 26] [32 77]]] [32 100]] [12 100]] [2926 0.938 [4799 18.7 [5593 0.532 [3377 2.3 [2846 2.59 [23 32.9 [7428 0.682 [6230 10.5 [131 3.6 [3912 2.79 [4353 6.9 [6653 2.17 [7665 15.3 [32 100] [32 85]] [32 81]] [32 87]] [32 100]] [32 100]] [32 91]] [32 100]] [32 81]] [32 75]] [32 77]] [32 100]] [32 71]] [32 100]]]] [3 80]] [5412 5.07 [1913 1.55 [906 2.27 [32 22] [9 33]] [29 33]] [21 40]]] [12 100]] [12 60]] [12 100]] [12 100]] [1400 3.2 [867 8.99 [568 0.879 [685 5.92 [5211 7.43 [1888 0.442 [4716 7.7 [4369 4.59 [6548 3.91 [5047 1.52 [5205 3.15 [957 3.75 [7345 0.849 [5413 1.52 [6068 1.34 [4851 1.1 [7512 1.51 [32 64] [32 100]] [509 0.53 [1676 4 [32 100] [32 91]] [32 100]]] [32 100]] [32 100]] [32 100]] [695 1.89 [2913 13.6 [32 100] [32 87]] [32 80]]] [32 83]] [3 100]] [32 100]] [32 100]] [32 85]] [1769 1.31 [1980 0.351 [3907 0.849 [4684 0.829 [2846 1.07 [5730 5.03 [32 100] [32 94]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]]] [32 58]] [32 75]] [32 100]] [32 85]] [4799 0.543 [5730 6.64 [32 92] [32 85]] [32 100]]]]] [22 100]] [12 100]] [2331 3.5 [383 4.85 [7210 6.32 [5211 3.18 [896 12.1 [4288 3.85 [5693 2.82 [32 27] [32 33]] [32 91]] [4 27]] [22 80]] [3 40]] [18 55]] [32 100]]]] [7017 0.277 [5480 0.918 [5955 2.06 [1239 13.3 [4535 8.29 [4025 0.816 [7391 0.478 [6199 0.835 [4728 3.34 [2712 2.62 [4500 1.35 [4571 10.4 [1783 4.12 [7665 1.8 [6 31] [2577 1.32 [6342 0.918 [6920 5.92 [6732 0.963 [4891 5.49 [23 1.83 [6 92] [6 20]] [2259 34.2 [5 40] [2551 2.65 [6 89] [6 100]]]] [36 83]] [6 33]] [36 41]] [6 96]]] [663 1.46 [2728 0.252 [6422 1.9 [1980 2.51 [2752 9.83 [6 51] [22 33]] [16 25]] [6 85]] [16 85]] [22 45]]] [36 88]] [29 100]] [2275 1.74 [16 79] [16 53]]] [16 77]] [7169 0.719 [16 27] [18 42]]] [16 93]] [36 100]] [38 100]] [6961 1.05 [2396 8.35 [6148 4.85 [5627 0.586 [3208 0.451 [2733 1.17 [3435 2.71 [5623 1.01 [2558 2.1 [299 4.76 [7087 2.04 [6597 1.27 [1302 5.71 [5288 1.68 [6362 1.32 [2535 12.7 [2689 4.98 [1078 19.6 [2618 1.62 [1980 13.2 [5408 5.09 [4768 3.58 [5641 7.99 [6330 3.92 [1919 0.904 [4939 5.88 [6098 23.9 [190 5.04 [1268 4.53 [2370 4.37 [4716 27.1 [2585 8.28 [7041 15.6 [1783 45.5 [1268 2.5 [23 5.03 [6423 13.5 [4651 0.659 [5721 1.26 [2628 9.09 [663 5.88 [298 2.06 [7210 10.2 [4726 0.838 [2579 17.9 [6 89] [6 100]] [6 97]] [6 66]] [6 100]] [6 60]] [6 50]] [7540 17.8 [6 100] [6 92]]] [6 100]] [6 66]] [6 55]] [6 83]] [6 70]] [18 40]] [6 50]] [6 57]] [6 72]] [6 100]] [6 72]] [16 55]] [6 100]] [1239 15.6 [6 77] [7421 4.77 [2272 1.47 [6 100] [6 90]] [6 100]]]] [5898 1.62 [6 50] [6 90]]] [6 75]] [6 80]] [4712 2.38 [2620 0.861 [2584 12.8 [2628 11 [7667 4.04 [6 81] [6 42]] [16 57]] [16 57]] [16 62]] [6 100]]] [6 46]] [6 54]] [4513 2.9 [1382 0.496 [4725 2.43 [6 96] [6 100]] [6 100]] [6 87]]] [16 55]] [16 62]] [1239 34.7 [6 100] [7421 3.44 [18 63] [16 42]]]] [3 27]] [9 83]] [9 87]] [9 100]] [2143 2.81 [1899 4.25 [4892 6.36 [4651 9.47 [4716 7.5 [2351 9.12 [1320 4.95 [7665 26.1 [4673 48.6 [7149 2.07 [5598 13.6 [6 100] [6 93]] [6 100]] [6 88]] [6 90]] [2526 62.2 [6 66] [6 100]]] [6 80]] [6 62]] [6 66]] [6 50]] [2283 7.06 [1311 0.636 [5609 5.69 [6 100] [6 87]] [6 100]] [6 75]]] [6 57]]] [7038 3.94 [4674 2.39 [6 100] [1384 0.75 [2030 4.9 [6 92] [6 85]] [6 100]]] [6 84]]] [6801 4.02 [2549 4.47 [7675 11.1 [2283 0.272 [5723 1.13 [2412 11.2 [2079 3.66 [6277 1.03 [1364 2.96 [4414 8.56 [7404 1.19 [1078 10.2 [6 96] [6 85]] [6 100]] [6 89]] [6100 1.62 [6 85] [6 83]]] [6 100]] [6 100]] [6 71]] [6 100]] [6 100]] [6515 0.47 [7580 0.292 [6 78] [6 100]] [6 100]]] [5408 8.67 [6 100] [6 85]]] [6 83]]] [37 44]] [16 75]] [38 33]] [16 50]] [9 63]] [4674 7.65 [6 75] [2526 53.5 [16 80] [4727 4.57 [6 87] [6 50]]]]] [2707 14.7 [4431 0.654 [6 77] [16 100]] [2466 1.05 [7 42] [16 100]]]]] [2860 0.662 [6720 4.5 [7072 7.51 [38 87] [38 54]] [38 54]] [38 88]]] [1680 0.221 [6818 0.739 [7354 1.29 [5716 0.592 [4673 4.56 [29 38] [6 23]] [6 77]] [16 41]] [22 100]] [22 100]]] [61 60 [6824 0.319 [5682 8.08 [38 50] [38 44]] [97 0.486 [38 60] [2851 0.409 [2259 61.6 [38 87] [38 100]] [38 100]]]] [38 100]]]] [7549 0.0829 [1268 0.0846 [7405 0.557 [7222 2.12 [3008 2.36 [819 0.0905 [4373 0.402 [23 3.7 [5270 4.1 [6422 2.24 [1078 11.4 [27 53] [2178 16.3 [1913 4.84 [2752 25.8 [429 1.69 [27 83] [4279 16.8 [4139 0.526 [7635 1.56 [784 0.476 [1233 0.79 [6653 1.92 [429 43.2 [27 98] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 85]]] [27 66]] [27 80]] [27 75]]] [6 90]] [27 50]] [3 38]] [27 100]] [3566 16.7 [7512 13.1 [4331 0.0958 [5969 0.0814 [4369 43.2 [499 0.0905 [2752 0.325 [3269 7.11 [27 100] [27 97]] [27 100]] [27 100]] [1164 44.2 [819 14.9 [27 90] [27 100]] [27 100]]] [27 100]] [27 100]] [27 88]] [4137 1.69 [27 98] [27 100]]]] [32 38]] [6 66]] [6 68]] [2038 0.169 [2351 0.237 [6 100] [6 77]] [6 100]]] [6749 3.46 [6 96] [6 66]]]] [4315 0.821 [3008 14.3 [2849 3.6 [1119 3.18 [3561 4.59 [1078 74.5 [2466 2.18 [4799 1.44 [4312 4.19 [4017 13 [6279 1.33 [4840 0.0744 [3591 16.1 [7472 3.29 [3514 2.9 [3250 1.01 [7512 22.9 [1051 5.2 [7428 3.5 [377 3.45 [3279 3.36 [1932 9.12 [2257 5.97 [221 6.92 [3812 0.615 [5129 13.2 [6959 0.611 [328 41.8 [6937 9.38 [3498 0.27 [599 1.77 [3393 13.2 [1783 40.8 [3928 2.97 [2232 8.12 [4938 2.77 [3564 6.35 [479 0.493 [4065 40 [3332 15.4 [7369 3.09 [3676 12.1 [4044 2.99 [3907 22.9 [1986 3.35 [3351 6.21 [7461 12.5 [2787 17.6 [4789 4.82 [4071 12 [663 37.2 [3079 106 [5851 15.5 [7354 2.37 [7623 2.94 [3120 3.08 [3879 6.79 [312 71.6 [3080 0.211 [5655 3.08 [3045 6.76 [4533 0.296 [3086 15.8 [2143 16.3 [2628 47.7 [1923 15.7 [3492 10.6 [2526 0.431 [3587 42 [4939 0.645 [2752 30 [3221 7.38 [328 13.2 [3981 2.07 [1888 3.63 [695 0.55 [3086 0.516 [452 16.7 [434 1.59 [3158 1.31 [37 98] [37 100]] [37 100]] [37 91]] [37 100]] [37 100]] [37 87]] [37 94]] [6342 2.26 [37 95] [37 100]]] [37 85]] [37 100]] [37 77]] [37 80]] [37 100]] [1429 48.1 [37 97] [3262 5.7 [37 85] [37 100]]]] [37 85]] [37 75]] [37 71]] [4874 4.7 [429 49 [37 97] [37 90]] [37 100]]] [37 100]] [37 66]] [37 85]] [37 100]] [37 85]] [3771 0.276 [663 3 [37 95] [7349 1.98 [16 50] [37 100]]] [37 100]]] [37 89]] [37 55]] [37 37]] [37 77]] [37 71]] [37 92]] [37 92]] [37 62]] [37 81]] [37 77]] [37 71]] [1429 45.8 [37 89] [37 100]]] [37 87]] [37 75]] [37 81]] [37 81]] [35 62]] [37 66]] [3086 7.02 [37 100] [479 17.7 [37 100] [37 88]]]] [37 76]] [37 71]] [37 66]] [3127 0.42 [845 0.249 [145 0.309 [3777 1.12 [3413 0.569 [7301 1.94 [791 19.1 [5287 0.476 [3085 5.73 [37 100] [37 94]] [37 100]] [3079 28.3 [37 100] [37 82]]] [37 80]] [37 100]] [37 100]] [37 100]] [37 100]] [37 100]]] [37 40]] [37 92]] [37 66]] [3997 6.1 [37 100] [3297 0.459 [3687 11.8 [37 100] [37 92]] [37 100]]]] [37 75]] [37 75]] [37 60]] [16 41]] [37 75]] [37 58]] [37 54]] [37 50]] [35 62]] [35 28]] [1078 17.2 [5588 0.677 [3088 5.87 [37 80] [37 100]] [37 42]] [28 37]]] [37 66]] [37 33]] [3057 0.829 [37 70] [37 100]]] [35 43]] [37 65]] [37 66]] [33 50]] [37 54]] [37 43]] [37 45]] [37 57]] [4991 1.81 [1429 16.3 [37 54] [3921 0.622 [3338 1.79 [4533 0.808 [37 96] [37 100]] [37 83]] [957 0.657 [37 81] [16 60]]]] [37 100]]] [3095 7.27 [37 70] [27 100]]] [3884 2.51 [826 2.56 [37 74] [37 87]] [37 100]]] [27 100]] [3297 3.83 [2753 8.15 [1453 1.25 [3990 2.47 [3079 8.85 [37 53] [37 92]] [37 50]] [37 85]] [312 6.72 [16 57] [37 70]]] [37 100]]] [35 41]] [27 100]]] [1287 0.308 [2539 1.08 [5692 8.12 [4703 0.64 [4349 0.955 [4959 2.33 [7265 2.15 [3033 2.15 [3331 1.64 [2341 0.511 [2081 5.59 [5413 5.82 [2225 12.4 [4832 2.11 [4519 0.428 [4356 3.07 [4338 13 [4312 10.6 [4198 0.235 [2421 1.93 [4155 1.85 [24 37] [33 100]] [24 100]] [18 65]] [10 60]] [1738 4.35 [2259 6.23 [2548 3.27 [7535 2.2 [1899 43.6 [2617 5.75 [2011 4.66 [6920 0.496 [24 23] [4 37]] [2 22]] [4 60]] [23 64]] [4189 4.59 [4338 29.2 [24 92] [24 80]] [24 100]]] [24 93]] [2108 14.9 [4214 8.3 [4943 3.23 [2436 7.2 [7512 21.9 [5781 5.92 [1746 3.48 [3643 4.86 [4346 12.9 [5950 1.73 [5270 2.09 [3657 2.49 [655 1.61 [5267 1.06 [24 74] [2259 22.6 [24 100] [19 64]]] [4799 7.07 [791 10.4 [24 100] [24 87]] [24 100]]] [24 100]] [24 50]] [24 100]] [24 57]] [19 64]] [24 100]] [24 100]] [4 22]] [24 61]] [24 100]] [24 92]] [8 50]]] [2771 0.283 [2259 19 [24 83] [2752 17.9 [24 88] [24 100]]] [24 100]]]] [1927 4.31 [1390 1.19 [23 8.03 [5692 3.72 [7512 1.83 [24 95] [24 100]] [24 90]] [24 78]] [24 100]] [24 63]]] [4025 20.2 [3659 7.79 [5789 34.6 [7446 1.33 [213 3.07 [6708 0.144 [791 13.8 [6374 10.6 [5425 22.9 [3659 3.56 [6691 2.46 [4046 3.39 [2526 27 [2795 13.8 [7535 5.02 [23 1.68 [1089 1.4 [24 98] [24 100]] [24 100]] [24 83]] [24 100]] [24 96]] [3666 6.64 [24 55] [24 80]]] [24 100]] [24 100]] [24 80]] [24 85]] [24 100]] [3666 1.81 [4519 12.3 [24 100] [24 70]] [19 41]]] [24 92]] [24 71]] [24 75]] [24 66]] [24 50]]] [2 54]] [23 42]] [1668 2.96 [2576 1.47 [24 27] [2 70]] [17 55]]] [1980 22.3 [4356 1.73 [5819 2.44 [567 1.62 [2058 2.82 [7542 4.86 [5171 2.3 [5412 1.01 [2342 9.35 [7009 4.76 [4288 3.27 [24 25] [2 26]] [22 30]] [31 62]] [4 17]] [33 57]] [24 80]] [23 84]] [23 42]] [2 38]] [24 82]] [1986 1.9 [2091 17.3 [2149 16.1 [23 72] [27 50]] [27 42]] [23 82]]]] [5641 2.58 [7375 2.49 [5412 1.02 [7665 1.6 [7026 2.04 [3660 3.27 [6761 1.95 [2536 1.72 [24 98] [24 80]] [24 100]] [24 100]] [24 58]] [24 100]] [24 100]] [24 100]] [19 33]]] [1 100]] [23 96]] [2 90]] [7327 1.56 [4 94] [4 100]]] [4288 1.48 [7265 2.73 [4350 1.21 [4897 2.1 [2143 8.67 [6582 2.01 [7382 2.05 [2259 6.21 [1389 3.65 [24 28] [24 100]] [1429 21 [5753 11.3 [5793 1.24 [3653 4.88 [5698 5.16 [3637 5.28 [7428 0.316 [1035 3.68 [2520 2.42 [2436 1.41 [6374 7.05 [4342 6.05 [7693 0.861 [3430 1.54 [6335 11.7 [4492 5.06 [5061 0.907 [24 84] [24 91]] [19 50]] [24 100]] [24 100]] [24 100]] [4154 33 [24 100] [24 93]]] [24 80]] [24 71]] [24 88]] [24 77]] [36 41]] [19 57]] [24 66]] [6260 1.21 [24 64] [19 57]]] [24 100]] [24 50]] [4346 0.849 [2548 1.95 [1025 13 [1240 0.465 [2341 7.23 [2526 15.7 [24 59] [24 80]] [24 100]] [5693 5.54 [24 100] [24 83]]] [24 96]] [24 100]] [24 100]]]] [4217 10.4 [6374 4.61 [3694 0.23 [6335 11.2 [3016 3.1 [4214 15.1 [5641 2.45 [134 7.34 [5198 1.26 [4493 8.46 [7751 1 [1602 0.826 [7512 41.7 [3659 11.2 [2763 2.74 [24 100] [24 95]] [7156 0.879 [2259 33.7 [24 100] [24 71]] [19 71]]] [24 85]] [24 100]] [24 100]] [24 66]] [2458 0.742 [2902 1.24 [24 100] [7382 5.11 [24 100] [24 66]]] [24 100]]] [24 93]] [19 55]] [24 89]] [24 100]] [24 77]] [24 66]] [24 64]] [24 72]]] [4 87]] [2526 15.4 [14 50] [4 33]]] [19 45]] [2 35]] [2 69]] [2536 1.48 [7693 0.494 [7512 12.2 [2 41] [17 27]] [4 70]] [4 81]]]] [5851 1.41 [5926 1.86 [33 69] [33 100]] [1 37]]] [1240 0.419 [5140 0.998 [6265 0.888 [208 0.745 [2259 5.4 [774 4.76 [4158 2 [2628 0.909 [1025 2.65 [7512 8.78 [33 86] [24 31]] [24 44]] [429 15.1 [24 31] [5654 5.69 [4 34] [21 33]]]] [2 25]] [2517 4.76 [24 88] [24 87]]] [1738 7.19 [6374 9.26 [6861 1.28 [5779 4.35 [23 14.1 [24 86] [33 84]] [24 100]] [24 100]] [24 66]] [24 80]]] [6260 0.557 [24 70] [24 93]]] [24 89]] [1429 8.64 [33 100] [33 72]]] [203 5.4 [3024 2.85 [6910 2.72 [4299 2.8 [7067 9.09 [7512 22.5 [24 100] [24 94]] [24 95]] [24 85]] [24 83]] [24 100]] [24 50]]]] [23 80]] [5178 0.597 [33 87] [33 100]]]] [5034 1.42 [6297 2.35 [7139 0.187 [1164 5.86 [5308 6.16 [6124 0.145 [5509 4.14 [826 0.198 [5851 1.09 [731 6.44 [5466 3.62 [7561 18.5 [5299 0.782 [728 11.3 [2818 0.443 [1429 2.06 [12 95] [12 100]] [12 100]] [12 87]] [12 100]] [12 66]] [12 92]] [12 87]] [12 100]] [12 100]] [12 90]] [12 100]] [12 83]] [12 91]] [12 100]] [31 85]] [10 50]]] [5478 0.15 [5733 0.754 [1600 0.23 [4288 0.774 [1835 0.381 [730 0.044 [6811 0.221 [4031 0.253 [6584 0.378 [7571 0.327 [221 0.118 [6077 0.286 [1239 12.7 [4851 0.133 [3243 1.77 [248 14.7 [7542 0.72 [1564 4.29 [72 2.2 [5566 0.62 [4997 2.73 [6301 0.724 [4006 0.406 [5531 1.44 [5871 0.724 [899 0.225 [6544 2.5 [5753 5.56 [6524 1.81 [4896 1.15 [1552 1.58 [3928 0.234 [2951 1.19 [5314 3.94 [5734 9.33 [1084 1.49 [328 8.39 [1685 2.06 [2526 1.39 [6389 1.57 [685 4.42 [7082 0.574 [5464 1.99 [6382 2.26 [6614 2.92 [7413 1.68 [2787 2.11 [5267 1.56 [7340 13.2 [865 5.15 [3209 2.2 [3027 41.2 [28 46] [15 100]] [15 100]] [13 100]] [32 86]] [32 33]] [28 90]] [28 85]] [15 100]] [2752 2.03 [3 62] [14 75]]] [28 100]] [28 83]] [28 84]] [28 97]] [17 13]] [28 100]] [28 67]] [28 93]] [6 28]] [18 33]] [38 34]] [23 6.19 [15 50] [15 94]]] [32 99]] [14 51]] [7149 1.65 [6997 6.73 [5753 4.55 [2902 1.09 [1239 10.8 [28 79] [28 55]] [28 94]] [19 42]] [1 36]] [1630 2.33 [28 93] [28 100]]]] [1752 0.586 [1980 0.761 [7139 2.04 [28 76] [28 46]] [1017 1.36 [5851 0.956 [4414 3.98 [28 95] [28 90]] [28 100]] [28 100]]] [28 100]]] [14 61]] [7717 0.763 [957 1.06 [429 27.7 [32 40] [32 83]] [32 60]] [32 83]]] [1239 2.66 [14 71] [28 50]]] [13 90]] [28 100]] [5753 1.09 [2897 2.56 [1101 7.86 [28 93] [28 88]] [28 71]] [28 100]]] [7 100]] [14 100]] [13 100]] [889 0.452 [906 1.15 [32 59] [32 83]] [32 100]]] [124 2.86 [6333 0.901 [32 65] [32 90]] [32 100]]] [15 85]] [4154 4.92 [15 87] [15 97]]] [5555 0.392 [6230 1.43 [592 2.15 [975 0.539 [6486 1.74 [6333 1.81 [7520 0.568 [5744 2.33 [5034 0.595 [407 1.46 [3368 0.664 [1638 3.14 [5105 1.52 [4684 0.161 [695 0.949 [3480 4.53 [248 4.8 [2259 19.6 [14 46] [36 61]] [3 53]] [36 100]] [6260 0.949 [36 44] [36 100]]] [12 30]] [28 100]] [14 100]] [1 0.921 [36 97] [36 100]]] [7 27]] [7210 3.78 [2752 18.9 [5462 1.01 [4369 6.14 [14 70] [32 100]] [4565 0.503 [5462 14.2 [28 63] [28 100]] [28 100]]] [28 75]] [14 88]]] [1552 2.53 [112 7.13 [4895 1.52 [14 81] [14 90]] [14 60]] [32 100]]] [4768 0.568 [36 56] [36 100]]] [32 74]] [32 86]] [6857 10.8 [28 95] [28 80]]] [28 100]] [4309 0.784 [4590 0.163 [6155 2.17 [429 31.2 [7526 2 [2993 2.09 [7665 15.8 [2526 0.283 [377 1.48 [1580 0.935 [32 76] [14 100]] [14 90]] [14 70]] [5732 21.7 [6380 3.68 [695 4.68 [14 77] [14 100]] [14 57]] [32 42]]] [36 44]] [14 56]] [663 1.12 [32 50] [32 100]]] [14 100]] [32 100]] [32 100]]] [906 1.52 [4279 2.95 [6230 0.526 [14 94] [14 100]] [14 85]] [14 80]]]] [5972 0.542 [2259 5.62 [1062 9.28 [6160 0.388 [1664 0.0932 [2897 20 [1656 2.05 [28 35] [3 45]] [14 55]] [3 66]] [28 83]] [15 50]] [537 1.89 [1948 6.23 [429 16 [1854 1.17 [14 19] [28 100]] [1078 3.28 [3 66] [28 54]]] [28 100]] [3 100]]] [1078 2.87 [583 2.61 [3 85] [3 100]] [3 66]]]] [5401 0.286 [5632 1 [13 45] [7 83]] [13 100]]] [2781 0.0889 [7722 1 [6876 0.111 [3822 0.142 [5423 1.88 [5462 0.665 [5011 2.82 [4396 1.16 [6848 0.13 [5071 0.327 [3130 5.18 [7512 3.56 [4154 0.792 [28 81] [328 0.613 [1078 2.8 [28 50] [28 95]] [28 100]]] [30 27]] [15 37]] [10 45]] [28 44]] [28 100]] [28 37]] [906 2.34 [1580 1.79 [6732 11.7 [5732 7.4 [7149 1.34 [6199 0.252 [7169 0.366 [28 84] [7453 0.534 [28 96] [28 100]]] [28 100]] [392 7.46 [28 90] [20 40]]] [7149 0.832 [4205 8.85 [4781 0.942 [2899 0.489 [6732 2.7 [2259 1.22 [112 4.49 [28 97] [28 77]] [28 100]] [28 100]] [28 100]] [28 100]] [28 83]] [28 100]]] [28 80]] [28 80]] [328 6.14 [5732 6.65 [28 94] [28 82]] [28 57]]]] [28 44]] [14 42]] [20 55]] [14 47]] [28 100]]] [125 0.122 [328 4.58 [36 100] [36 87]] [36 100]]] [6449 1.03 [6977 9.37 [472 1.75 [4535 2.78 [7711 7.2 [1754 1.03 [1025 1.72 [695 12.2 [7590 4.14 [134 5.02 [6395 1.45 [7526 1.35 [429 13.3 [4895 1.65 [17 57] [17 100]] [14 30]] [17 83]] [17 87]] [17 94]] [19 35]] [14 71]] [19 54]] [17 40]] [7595 0.734 [3008 12.7 [2541 2.42 [17 88] [17 42]] [17 50]] [17 100]]] [19 75]] [19 50]] [14 60]] [14 71]]] [36 100]] [705 3.07 [32 100] [32 87]]] [7169 0.22 [1708 0.288 [4861 0.514 [132 0.96 [6300 7.21 [2081 14 [600 2.26 [883 5.86 [7665 4.77 [4279 0.313 [6727 1.88 [4568 1.46 [3027 1.24 [5007 2.59 [6761 2.56 [394 0.756 [28 96] [28 100]] [28 100]] [28 95]] [28 100]] [1429 35.7 [28 100] [28 90]]] [28 85]] [28 100]] [32 60]] [28 75]] [28 77]] [28 80]] [28 87]] [32 80]] [28 80]] [28 100]] [5812 1.69 [7324 0.215 [28 100] [28 71]] [28 92]]]] [429 6.73 [13 55] [13 97]]] [5746 0.174 [5194 0.431 [5969 3.24 [503 0.0904 [6333 1.71 [7354 0.981 [2846 2.75 [6727 0.986 [774 0.264 [28 55] [28 100]] [32 41]] [32 80]] [6524 0.411 [1429 44 [36 96] [36 66]] [36 100]]] [7722 1.24 [7665 10 [32 77] [32 100]] [32 96]]] [32 100]] [17 81]] [2628 1.05 [28 100] [28 90]]] [32 100]]] [7 100]] [2849 0.852 [6413 1.01 [13 29] [6413 23.1 [6508 0.754 [3769 2.37 [2752 24.1 [13 77] [13 100]] [13 100]] [7 100]] [23 47.6 [13 90] [13 100]]]] [6418 1.31 [2863 10.6 [7 59] [16 60]] [7 100]]]] [3480 1.93 [7068 11.6 [36 100] [5732 6.51 [36 90] [36 100]]] [5705 0.323 [36 100] [6839 1.36 [17 0.323 [2752 25.8 [36 100] [36 85]] [36 85]] [36 100]]]]]] [1197 0.219 [1405 0.125 [1116 0.451 [5731 0.236 [4420 0.37 [2472 1.58 [4929 0.566 [731 0.398 [6078 7.78 [3438 0.201 [5122 0.722 [5110 1.49 [1679 0.69 [6647 0.65 [1410 0.226 [6768 0.441 [1888 2.9 [6660 0.425 [5065 0.898 [2752 12.6 [232 3.07 [228 1.5 [7411 3.05 [2641 2.82 [6457 0.276 [3454 0.959 [5419 0.873 [7434 2.26 [5034 3.49 [1232 0.78 [3442 0.509 [4723 0.782 [1402 3.03 [2911 0.864 [7052 0.876 [190 2.71 [4449 0.161 [820 5.04 [4953 3.31 [6809 0.644 [392 6.25 [3576 9.07 [5235 6.49 [3931 14.4 [7742 5.43 [7077 4.16 [5995 1.39 [3608 1.75 [7032 3.26 [7007 0.53 [6013 0.149 [429 22.1 [3458 1.34 [6983 7.12 [163 1.9 [6166 2.43 [5312 1.26 [4959 0.914 [7381 1.16 [1783 0.256 [2004 12.9 [1391 14.9 [7449 19.1 [4663 13.4 [7305 9.28 [2969 0.555 [7419 1.45 [1059 1.03 [2538 4.18 [7009 2.28 [2476 9.39 [2138 0.688 [2616 12.3 [1459 3.5 [2232 3.3 [1452 2.2 [2913 51.6 [2143 2.4 [7512 9.8 [3309 14.8 [5267 14 [30 28] [4 50]] [26 33]] [25 20]] [25 27]] [11 50]] [30 44]] [21 21]] [30 91]] [6 42]] [9 33]] [15 90]] [15 30]] [14 50]] [26 69]] [2 44]] [21 66]] [25 72]] [15 64]] [15 59]] [15 81]] [1 66]] [5377 0.0854 [6260 1.12 [7117 1.38 [6471 0.515 [1764 1.75 [7298 1.45 [2067 3.58 [1951 0.527 [1795 0.6 [2204 1.42 [6031 1.83 [1913 0.299 [7169 8.15 [429 13.6 [6406 1.3 [4398 4.68 [2466 1.91 [791 17.5 [1899 2.06 [7330 7.32 [30 35] [25 54]] [30 14]] [30 58]] [25 33]] [4 90]] [30 50]] [16 18]] [25 62]] [1457 0.0664 [1239 16 [30 38] [32 30]] [14 75]]] [25 54]] [30 100]] [25 84]] [19 55]] [35 60]] [32 64]] [20 35]] [26 79]] [25 81]] [30 81]] [33 36]]] [5480 0.917 [655 0.682 [4 41] [24 72]] [4 90]]] [4 100]] [15 78]] [6 100]] [30 63]] [2479 5.38 [23 3.94 [4 82] [4 92]] [4 100]]] [15 63]] [1 4.29 [434 1.42 [1980 0.879 [1899 10.1 [7187 8.77 [4 22] [26 54]] [4 48]] [1400 2.59 [11 14] [6342 2.01 [2081 0.879 [10 83] [10 37]] [15 90]]]] [25 26]] [11 70]]] [21 100]] [25 100]] [31 84]] [15 100]] [29 100]] [23 10.7 [4 66] [4 100]]] [2628 2.92 [4 46] [4 94]]] [4 80]] [11 100]] [15 100]] [338 1.79 [2259 1.83 [26 53] [25 31]] [26 70]]] [5058 0.652 [32 86] [32 100]]] [31 92]] [4154 2.7 [7185 6.82 [11 87] [11 77]] [32 45]]] [4732 0.161 [6 90] [6 100]]] [1895 1.2 [38 65] [38 100]]] [11 95]] [3310 0.778 [5291 0.8 [2259 42.2 [10 90] [10 37]] [10 100]] [10 100]]] [15 100]] [4 100]] [3747 0.406 [759 2.42 [1078 41.3 [11 100] [11 75]] [11 100]] [11 100]]] [10 100]] [2993 2.62 [32 51] [30 68]]] [12 100]] [15 100]] [11 100]] [25 100]] [31 100]] [15 85]] [4 93]] [5989 5.52 [1429 2.79 [25 92] [25 100]] [25 87]]] [896 5.41 [1429 5.43 [2595 4.61 [6103 2.78 [1094 1.11 [429 31.9 [6077 3.65 [2764 1.23 [384 6.49 [6566 3.55 [2628 10.3 [1899 21.2 [7255 20 [1783 1.6 [2753 13 [2477 1.93 [4214 2.76 [1407 1.23 [5972 13.5 [4429 3.18 [2787 1.14 [2763 14.8 [2225 8.48 [7343 2.7 [2485 6.85 [7305 6.39 [2526 2.44 [5480 7.25 [7649 2.22 [15 88] [15 100]] [11 37]] [4 52]] [25 75]] [11 100]] [15 58]] [15 37]] [15 50]] [15 100]] [15 100]] [12 41]] [15 100]] [15 100]] [11 85]] [15 42]] [15 25]] [15 57]] [15 52]] [4 53]] [11 100]] [26 83]] [11 46]] [4 100]] [4838 6.44 [2475 1.58 [2225 1.05 [7457 2.2 [661 5.07 [2764 3.93 [1078 7.14 [4218 10.6 [7255 10.6 [2752 44 [906 4.01 [3905 6.33 [15 86] [15 100]] [15 100]] [11 60]] [11 50]] [15 69]] [826 10.6 [2259 7.22 [3455 4.24 [3273 3.82 [7255 20.8 [15 52] [11 88]] [11 100]] [11 100]] [11 62]] [15 100]]] [11 82]] [15 100]] [15 100]] [11 89]] [15 100]] [11 100]]] [11 77]] [12 88]] [4 100]] [820 0.42 [558 0.891 [3803 1.47 [3442 1.22 [874 1.99 [7434 1.43 [4288 1.11 [3243 0.821 [5980 2.07 [5482 1.01 [3693 2.97 [2466 3.13 [7314 6.06 [3537 1.74 [11 4.13 [811 2.13 [5732 4.68 [4920 13.2 [2474 1.55 [5143 1.34 [5211 5.52 [2849 2.47 [2913 10.2 [248 3.44 [3807 5.48 [6074 0.589 [7449 25.9 [15 21] [15 81]] [15 50]] [10 100]] [2752 24.5 [15 55] [15 82]]] [15 68]] [29 63]] [30 75]] [11 90]] [15 100]] [30 100]] [15 92]] [15 100]] [31 100]] [15 100]] [30 63]] [30 53]] [32 100]] [29 88]] [12 96]] [15 100]] [32 55]] [12 100]] [12 100]] [11 100]] [11 100]] [12 100]] [1913 1.26 [11 67] [11 100]]]] [6074 1.37 [4 74] [4 85]]]] [1402 0.528 [2760 1.41 [2475 15.7 [15 100] [429 16.8 [15 77] [15 100]]] [15 100]] [15 100]]] [791 20.5 [11 93] [2897 1.86 [906 2.61 [11 100] [11 94]] [11 100]]]] [4379 0.356 [1429 16.9 [5322 2.26 [435 3.26 [5776 3.77 [6199 3.54 [1253 1.22 [6582 2.15 [7381 1.11 [6977 4.38 [5239 2.54 [4 48] [4 100]] [4 91]] [4 83]] [4 100]] [12 40]] [26 38]] [26 50]] [4 35]] [12 61]] [7428 0.439 [2323 2.64 [7255 1.82 [7665 10.3 [12 32] [4 63]] [12 50]] [32 100]] [12 65]]] [32 100]]] [31 100]] [4418 1.54 [6393 0.387 [5480 7.77 [1239 3.3 [2149 0.29 [7623 16.7 [3703 0.309 [5410 1.21 [15 97] [15 84]] [15 100]] [7428 2.13 [15 94] [12 82]]] [15 100]] [15 77]] [12 83]] [15 100]] [15 100]]] [2298 0.557 [5267 3.29 [4968 0.503 [6134 0.268 [4564 0.104 [2394 1.04 [6647 21.4 [30 95] [30 40]] [30 100]] [30 100]] [30 100]] [30 100]] [30 85]] [30 75]]] [4154 9.86 [1997 0.894 [2259 9.68 [7085 0.803 [6708 5.72 [30 84] [13 50]] [30 100]] [30 100]] [30 100]] [30 80]]] [1062 0.418 [2765 1.78 [3616 2.76 [756 1.75 [248 0.798 [2083 2.43 [2473 0.81 [328 11.4 [5826 1.77 [860 2.42 [1400 3.12 [4938 1.54 [887 0.476 [4781 1.03 [1391 5.03 [30 36] [15 90]] [11 53]] [11 83]] [11 100]] [5410 6.33 [7434 1.22 [5972 16.6 [1391 0.206 [112 1.17 [15 96] [15 100]] [15 100]] [12 83]] [12 100]] [15 100]]] [11 100]] [11 100]] [30 67]] [15 100]] [11 92]] [1997 2.3 [6294 3.92 [337 3.06 [5110 7.46 [2808 0.684 [870 0.963 [6732 0.418 [15 55] [15 100]] [15 100]] [15 100]] [5154 1.5 [2526 7.38 [15 100] [15 80]] [15 100]]] [15 66]] [15 70]] [15 45]]] [30 100]] [11 63]] [11 90]] [429 31.1 [1078 36.7 [6733 0.537 [2808 0.759 [11 35] [15 100]] [15 100]] [11 76]] [5211 0.858 [15 47] [11 100]]]]] [4200 0.341 [30 95] [30 100]]] [792 0.347 [3802 0.232 [1094 0.929 [2178 0.291 [2752 9.34 [11 78] [1995 1.36 [11 92] [11 100]]] [11 100]] [11 100]] [11 100]] [11 100]]] [2698 1.01 [7213 0.763 [6982 7.21 [2296 2.82 [31 77] [31 100]] [31 62]] [31 100]] [31 94]]] [6173 1.25 [7722 8.33 [2259 28.8 [234 1.37 [17 1.48 [6585 0.693 [4781 0.338 [7623 7.1 [5812 0.448 [2616 7.69 [4398 4.15 [1696 4.85 [2470 37.3 [4968 1.39 [26 31] [26 81]] [4 39]] [26 90]] [31 42]] [6732 4.13 [4 78] [4 100]]] [1078 2.33 [4 90] [4 100]]] [31 100]] [4 41]] [26 75]] [7381 1.13 [4 85] [4 100]]] [25 100]] [31 88]] [26 69]] [31 100]]] [6582 0.159 [2048 0.855 [2595 7.04 [5154 8.55 [5972 2.34 [6791 0.124 [2081 12.3 [1069 3.87 [5240 1.63 [4 85] [4 100]] [4 100]] [31 62]] [4 60]] [31 83]] [4 66]] [4 63]] [2048 1.91 [24 53] [4 50]]] [23 6.01 [4 98] [4 94]]]] [6862 1.61 [5605 6.71 [2913 9.41 [4701 26.2 [5647 1.05 [7623 25.1 [1980 3.73 [2628 0.605 [30 90] [392 0.882 [3008 2.16 [4517 3.88 [30 98] [30 100]] [30 100]] [30 100]]] [30 90]] [30 75]] [30 100]] [30 100]] [30 96]] [30 85]] [30 100]]] [2628 3.36 [6795 0.335 [7480 21.6 [3993 1.1 [1068 2.45 [4663 86.6 [7623 12.9 [5110 0.305 [5851 1.06 [1025 21 [3703 0.77 [7173 2.3 [4669 3.43 [5065 0.649 [3244 1.33 [2476 0.967 [2752 2.13 [15 98] [15 100]] [15 100]] [15 100]] [15 100]] [15 93]] [15 100]] [15 100]] [15 86]] [15 100]] [15 100]] [1429 21.7 [15 100] [15 77]]] [15 90]] [6732 1.6 [5192 3.5 [15 95] [15 100]] [15 100]]] [15 66]] [4429 2.96 [15 76] [811 10.5 [15 100] [4218 5.88 [15 100] [15 66]]]]] [5851 2.05 [15 92] [15 100]]] [15 73]]] [11 100]] [7525 2.76 [2392 8.7 [6353 3.15 [6015 3.49 [6048 0.146 [6550 9.57 [5617 8.46 [4398 16.1 [1892 12.6 [4466 0.451 [899 1.38 [4851 23.8 [7169 3.72 [957 0.535 [3811 1.25 [4312 2.13 [2199 2.6 [7512 5.28 [30 100] [30 97]] [30 87]] [30 100]] [30 100]] [30 100]] [4851 0.596 [30 94] [30 100]]] [5590 30.9 [30 98] [30 84]]] [30 100]] [30 88]] [30 85]] [30 70]] [30 75]] [30 66]] [30 85]] [30 62]] [30 88]] [30 61]] [7665 5.38 [30 76] [30 100]]]] [4221 12.8 [3482 0.125 [4374 2.9 [3354 8.94 [15 100] [15 83]] [15 85]] [15 100]] [15 80]]] [2485 0.31 [5972 1.84 [5824 0.126 [6193 1.94 [6364 0.154 [2409 0.662 [11 50] [11 100]] [11 66]] [11 36]] [5082 0.318 [11 98] [11 100]]] [4398 1.4 [15 54] [15 100]]] [11 100]]]] [3460 0.147 [3564 3.41 [5158 0.577 [1906 0.893 [3555 0.288 [77 0.204 [3812 1.07 [3772 2.15 [7169 4.72 [3907 3.51 [663 23.6 [4071 0.71 [2775 5.03 [37 99] [37 71]] [37 90]] [37 60]] [37 80]] [4414 0.64 [37 38] [37 100]]] [37 75]] [16 42]] [16 36]] [3990 0.238 [37 91] [37 100]]] [3700 0.139 [3921 3.91 [37 100] [16 55]] [37 38]]] [3294 7.34 [3127 15.6 [3990 2.2 [37 100] [957 8.78 [4762 1.25 [37 100] [37 87]] [3220 2.07 [3087 4.53 [37 100] [37 94]] [37 83]]]] [695 9.09 [37 100] [37 85]]] [37 97]]] [37 61]] [37 100]]] [2793 2.06 [1429 18.6 [7381 0.533 [5239 0.529 [4602 0.466 [4448 0.433 [6491 0.196 [6167 0.933 [7508 0.293 [4601 0.708 [312 1.41 [2259 31.5 [3156 0.545 [6538 1.47 [2562 0.299 [6885 0.486 [731 0.412 [2574 0.347 [5845 0.287 [5812 1.53 [248 7.31 [7623 0.0973 [4067 0.715 [896 0.281 [4374 0.64 [6068 3.25 [3652 6.26 [2004 0.233 [665 1.93 [3708 0.204 [6230 1.12 [2701 1.52 [1993 0.326 [957 0.597 [7674 3.65 [6620 2.56 [429 15.1 [7419 0.808 [4414 9.89 [5413 1.78 [4390 4.08 [332 0.559 [5972 7.55 [2753 3.07 [112 15.6 [384 0.325 [4507 1.77 [1813 1.47 [5673 0.864 [328 26.6 [25 10] [25 59]] [16 25]] [1 53]] [18 69]] [23 38]] [19 80]] [19 31]] [31 100]] [25 87]] [26 84]] [18 50]] [31 20]] [6 45]] [6957 0.971 [828 9.1 [1036 1.98 [2470 3.07 [435 0.399 [7512 4.07 [5999 6.53 [2550 2.44 [286 4.44 [4832 12.6 [1761 2.92 [453 6.79 [5632 2.82 [4122 3.14 [5219 2.18 [3073 8.13 [4424 2.86 [3008 13.5 [4968 1.59 [4507 5.05 [791 11.7 [5366 2.82 [2752 5.72 [2 17] [392 4.36 [4630 6.33 [2759 6.49 [7494 3.4 [682 4.13 [5480 15.6 [5376 5.26 [7255 21.8 [1101 2.39 [4852 4.5 [1104 9.43 [4184 2.76 [23 46] [2 42]] [23 44]] [8 100]] [27 50]] [8 100]] [23 42]] [23 33]] [2 54]] [23 100]] [23 88]] [23 100]] [23 97]]] [23 100]] [1400 6.17 [6260 0.78 [2752 23.4 [35 24] [2752 39.6 [4279 2.09 [23 66] [23 66]] [23 96]]] [22 50]] [2 42]]] [18 62]] [35 72]] [35 55]] [23 77]] [26 91]] [6294 2.18 [5219 18.9 [8 100] [791 5.15 [8 87] [8 72]]] [8 100]]] [23 100]] [18 63]] [23 100]] [23 100]] [2 82]] [4288 1.59 [1980 9.98 [2752 3.14 [23 42] [7254 4.29 [798 2.53 [23 93] [23 100]] [23 100]]] [23 81]] [23 97]]] [8 81]] [584 3.7 [23 41] [23 95]]] [7742 17.6 [2 12] [4 52]]] [5803 1.62 [2081 1.42 [23 56] [929 0.971 [2259 0.635 [1899 0.53 [2145 0.399 [23 65] [23 100]] [1995 5.41 [23 100] [23 62]]] [23 50]] [23 94]]] [35 30]]] [4851 5.88 [23 16.6 [1011 2.46 [4 68] [4 90]] [25 54]] [4 77]]] [35 100]] [1078 5.75 [31 63] [31 100]]] [23 90]]] [25 100]] [10 100]] [1161 0.944 [475 4.65 [4140 0.595 [7578 1.08 [6740 1.45 [27 58] [18 80]] [10 100]] [27 100]] [10 100]] [10 100]]] [3794 9.82 [5411 0.326 [2089 0.832 [4279 0.476 [1899 36.7 [3531 11.7 [23 59] [22 100]] [8 55]] [23 73]] [23 100]] [23 81]] [23 50]]] [1078 9.2 [5972 2.24 [8 40] [12 66]] [29 58]]] [7009 12.5 [2470 20.1 [2993 2.44 [7512 8.71 [144 21.9 [4 25] [5 36]] [7 29]] [32 33]] [31 63]] [5 76]]] [35 100]] [292 3.11 [2 80] [2 66]]] [660 21.7 [7062 0.736 [4530 0.615 [5454 1.96 [3843 3.88 [392 1.4 [3095 2.95 [1919 0.888 [5751 0.928 [1013 1.92 [1078 53.7 [23 96] [4 50]] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [23 80]] [23 75]] [23 88]] [23 100]] [23 80]]] [24 93]] [392 0.664 [438 0.159 [7491 0.659 [23 66] [23 88]] [23 66]] [23 100]]] [10 100]] [653 2.85 [6927 1.35 [429 22.4 [7340 1.16 [2265 1.26 [1400 1.57 [5412 6.38 [4457 0.923 [2795 0.945 [248 1.27 [2470 1.36 [2939 9.58 [24 14] [5 33]] [4 57]] [1 42]] [24 100]] [18 33]] [1 40]] [4 75]] [24 100]] [16 42]] [6791 2.74 [415 2.16 [5161 2.22 [7009 3.67 [2251 0.787 [5034 3.84 [3669 2.24 [4507 3.44 [624 5.42 [3667 9.4 [6230 17.8 [6581 1.54 [7176 2.09 [1986 2.58 [2629 1.49 [913 1.66 [6977 0.668 [282 6.02 [532 5.65 [1101 1.23 [660 7.91 [957 9.45 [4 32] [18 100]] [29 40]] [29 57]] [19 33]] [19 55]] [2 36]] [4 50]] [29 57]] [2 47]] [7 100]] [5 28]] [7 52]] [4832 3.4 [2 60] [2 100]]] [5 60]] [1011 2.87 [2752 5.15 [19 66] [18 55]] [18 88]]] [4 44]] [7566 0.768 [32 50] [14 57]]] [18 54]] [5 62]] [18 66]] [2 100]] [5692 2.09 [2 51] [1980 11.8 [2 92] [1 42]]]]] [2902 1.69 [2 64] [2 100]]] [5666 1.05 [18 69] [18 57]]]] [4409 10.2 [35 95] [35 75]]] [5218 0.195 [1159 1.14 [811 6.01 [3940 0.294 [5381 0.373 [1993 4.31 [6791 5.66 [3531 0.613 [2470 14 [7623 14.3 [2178 1.15 [2902 0.78 [2259 2.96 [27 50] [10 28]] [1 50]] [1 16]] [4 16]] [31 55]] [27 87]] [1 62]] [18 37]] [12 38]] [27 100]] [10 92]] [27 100]] [10 100]]] [4682 0.849 [7737 2.65 [7044 1.31 [276 1.31 [4235 1.14 [5999 28.7 [232 2.59 [6364 1.93 [6585 0.818 [6073 1.17 [2752 9.55 [4658 3.07 [5170 2.69 [6619 3.32 [26 46] [25 100]] [7665 2.78 [2939 8.65 [5170 16.8 [19 33] [26 44]] [33 50]] [26 78]]] [1 69]] [1997 5.5 [6619 0.864 [2936 1.51 [673 1.29 [328 15 [435 9.43 [2748 4.5 [26 45] [26 73]] [25 77]] [26 46]] [7722 10.2 [418 24.8 [1081 8.28 [906 2.35 [5480 8.43 [6425 5.29 [6184 9.01 [7665 6.77 [260 6.85 [6034 2.01 [2081 6.85 [2143 0.967 [7101 3.81 [685 6.3 [6729 4.1 [6199 12.5 [2955 0.511 [6377 1.72 [2753 13.3 [1081 5.94 [26 65] [26 57]] [26 44]] [26 100]] [16 33]] [25 57]] [26 54]] [26 88]] [26 100]] [19 33]] [26 100]] [16 33]] [25 44]] [4279 5.57 [5673 13.8 [4205 8.62 [1429 8.45 [7681 0.322 [2526 19.3 [7665 13.2 [26 100] [26 83]] [26 64]] [26 92]] [26 73]] [23 1.03 [26 65] [26 100]]] [26 62]] [26 60]]] [26 64]] [19 57]] [1007 13 [26 100] [26 85]]] [5851 5.66 [6955 2.27 [999 2.11 [3332 1.83 [423 1.29 [26 95] [26 100]] [35 57]] [26 100]] [26 100]] [26 90]]] [673 51 [3404 2.07 [985 10.4 [7244 5.28 [2530 3.75 [2755 13.8 [1025 0.8 [26 94] [26 100]] [26 75]] [26 100]] [26 83]] [26 76]] [26 75]] [26 66]]] [19 50]] [26 56]]] [25 100]] [25 100]] [18 50]]] [26 100]] [6727 3.14 [5480 8.36 [2526 2.04 [26 94] [26 76]] [26 98]] [26 100]]] [25 95]] [25 62]] [25 91]] [384 2.13 [1072 1.31 [1899 5.03 [719 0.829 [6524 3.25 [6733 1.35 [5079 0.682 [995 0.666 [7185 4.59 [26 75] [26 100]] [26 100]] [25 75]] [26 93]] [896 0.813 [178 1.86 [1 55] [25 100]] [25 100]]] [26 100]] [25 62]] [25 72]] [727 5.1 [26 92] [26 80]]]] [33 55]] [25 100]] [25 79]] [2081 2.39 [33 72] [1 50]]]] [7684 0.811 [291 1.85 [4832 0.615 [7132 2.42 [7139 5.06 [573 11.6 [3905 1.52 [6103 0.347 [4690 1.89 [3527 17.9 [6537 0.931 [3669 6.1 [1400 16.2 [2739 6.07 [6982 1.47 [4312 1.16 [6230 2.55 [7185 2.57 [7241 2.72 [3667 7.12 [3652 2.27 [7101 2.66 [5851 1.33 [4 29] [2 40]] [35 73]] [24 100]] [2 75]] [4 46]] [7 27]] [4 30]] [4 80]] [4 92]] [5769 2.04 [4 87] [4 100]]] [6757 7.07 [2 50] [2 50]]] [2 75]] [5647 20.3 [6184 16.2 [2 72] [2 100]] [2 50]]] [978 19.7 [22 90] [22 100]]] [4 53]] [12 87]] [2526 14.5 [7 64] [17 50]]] [4 37]] [7 44]] [4 80]] [407 1.6 [4930 12 [5449 15 [1075 0.782 [1995 9.34 [1072 2.35 [1429 8.85 [6977 2.82 [7568 5.79 [5413 5.33 [7544 11.7 [429 29 [2 69] [6927 6.91 [2 85] [2 80]]] [2 100]] [2 57]] [2 75]] [2 100]] [4833 0.885 [4 61] [2 66]]] [5647 34.5 [4 61] [2 75]]] [2 44]] [4832 13.2 [2 84] [2 100]]] [2 57]] [22 35]] [2 95]]] [663 2.79 [2 76] [2 84]]] [5 78]]] [10 100]] [2943 2.06 [6983 1.07 [6320 4.26 [2820 0.574 [896 8.88 [6537 0.484 [23 11.5 [6581 0.967 [1068 4.12 [2081 4.39 [2 69] [4 55]] [4 62]] [5 38]] [4 62]] [1004 0.693 [5412 1.45 [2 55] [2 100]] [2 100]]] [4 41]] [2 100]] [17 30]] [4 100]] [4 100]]] [5869 0.233 [1899 7.9 [6983 5.84 [5480 1.46 [1400 2.68 [7552 0.761 [6588 0.816 [7008 0.69 [424 1.17 [1001 2.93 [6524 1.75 [4017 4.95 [2470 6.89 [6537 2.46 [673 2.79 [5994 1.33 [7188 6.67 [5716 0.713 [6732 7.58 [4 14] [978 17.2 [5 33] [19 70]]] [23 60]] [17 81]] [7 88]] [26 96]] [2 100]] [31 38]] [19 72]] [695 3.51 [25 42] [7 100]]] [31 90]] [26 100]] [25 100]] [5 45]] [26 100]] [7317 1.79 [673 2.18 [4 50] [435 0.673 [1420 0.629 [5198 5.51 [999 0.463 [4611 5.94 [896 9.18 [424 0.864 [906 1.1 [26 87] [26 100]] [26 100]] [26 70]] [26 84]] [26 100]] [26 58]] [25 83]] [26 50]]] [26 100]]] [5160 0.395 [6585 0.705 [1432 0.209 [2628 4.29 [4507 0.811 [1062 2.71 [384 15.4 [6184 1.7 [26 64] [26 33]] [26 100]] [18 70]] [18 81]] [7693 0.363 [18 50] [16 88]]] [26 82]] [4684 2.82 [1888 0.705 [429 3.76 [4968 1.86 [26 74] [26 60]] [2752 13.6 [26 100] [695 6.27 [26 100] [26 50]]]] [26 100]] [26 75]]] [18 42]]] [2470 30.7 [4 72] [429 19.1 [4 100] [4 87]]]] [7363 1.18 [2987 2.51 [5883 22.8 [7149 6.04 [3207 1.11 [3006 1.1 [2752 33.6 [5918 2.46 [3667 6.16 [5451 1.39 [392 6.81 [5412 5.57 [1047 0.879 [719 7.22 [4 36] [2 61]] [4 66]] [4 28]] [16 30]] [2 40]] [2 75]] [7 37]] [5413 5.07 [2 29] [5 50]]] [26 100]] [26 87]] [18 57]] [2 90]] [4 90]] [4 83]]] [978 2.75 [26 70] [6708 2.06 [6199 5.64 [736 1.56 [26 100] [5692 6.47 [26 100] [26 85]]] [26 83]] [26 83]]]]] [1011 0.945 [1913 7.11 [23 94] [23 70]] [26 83]]] [5225 0.189 [5647 1.01 [2604 1.52 [5412 2.52 [2766 1.42 [996 7.94 [2902 1.22 [7449 5.08 [1980 2.39 [8 71] [1980 16.1 [23 27] [23 88]]] [23 73]] [23 100]] [429 38.6 [8 71] [8 62]]] [23 100]] [23 75]] [8 65]] [4768 0.672 [5914 0.852 [1913 6.41 [6322 0.991 [23 80] [23 100]] [23 66]] [23 100]] [23 93]]] [6920 0.331 [981 0.688 [2029 3.09 [2225 0.509 [6031 2.37 [23 98] [22 72]] [23 100]] [23 83]] [23 100]] [1980 9 [23 83] [23 100]]]]] [23 1.93 [7707 5.72 [4832 1.85 [6537 11.8 [6342 0.882 [4235 9.15 [2 91] [2 36]] [2 60]] [6539 4.26 [435 3.3 [2 95] [2 87]] [2 77]]] [1004 0.545 [2 98] [2 100]]] [2 50]] [1239 4.14 [2 78] [2 33]]]] [35 82]] [2133 0.795 [3495 1.1 [5211 2.3 [6362 1.38 [4929 3.68 [7222 0.844 [4822 0.949 [2611 1.17 [2641 8.11 [6701 9.56 [5007 3.24 [5454 1.86 [284 3.03 [7512 7.74 [6074 4.07 [2043 3.4 [3659 4.67 [6560 5.37 [673 0.417 [4279 2.7 [23 17] [2259 41 [23 77] [24 66]]] [26 50]] [8 78]] [24 100]] [32 44]] [31 88]] [328 19.2 [2846 6.07 [6 44] [32 81]] [18 68]]] [18 54]] [24 100]] [1186 1.67 [1980 6.36 [6724 6.73 [19 53] [18 66]] [29 30]] [19 71]]] [5717 8.65 [6 100] [6 92]]] [31 100]] [6 78]] [1314 4.37 [2584 1.95 [6 70] [6 100]] [6 100]]] [4653 10.4 [429 11.5 [2199 0.472 [2370 2.37 [2419 0.5 [6 52] [2396 1.32 [6 100] [6 80]]] [6 75]] [16 33]] [6 90]] [6 100]]] [8 75]] [4674 0.763 [6289 0.203 [978 11.4 [6 83] [6 100]] [6 70]] [6 100]]] [2583 0.763 [2399 4.13 [4414 3.97 [6560 2.37 [4799 1.08 [1239 10.1 [2764 9.81 [2426 8.77 [23 40] [8 100]] [23 100]] [23 42]] [10 90]] [2604 1.55 [5219 1.21 [0 90] [8 100]] [8 83]]] [8 50]] [8 100]] [0 100]]] [8 100]] [5963 4 [6422 0.386 [6 92] [6 100]] [6 90]]]] [5812 3.52 [6187 1.76 [709 1.83 [5978 1.08 [4253 1.34 [322 2.45 [5482 0.914 [5695 0.609 [248 0.873 [1984 1.83 [19 0.945 [639 2.9 [4764 0.412 [398 1.7 [7292 2.86 [1083 10 [2610 2.94 [6538 2.22 [4114 8.27 [665 3.4 [144 10.4 [7133 1.11 [1888 1.37 [1007 1.96 [695 2.69 [312 28.1 [7009 1.42 [1906 0.995 [2760 2.53 [5267 1.58 [4 18] [31 83]] [2 33]] [4 40]] [4 81]] [312 43.1 [4 92] [4 70]]] [4 70]] [4 65]] [7677 2.84 [1078 33.1 [4 41] [4 89]] [4 57]]] [4 100]] [2 75]] [2 80]] [23 33]] [2 71]] [24 50]] [2 46]] [2 75]] [23 100]] [2 41]] [4 100]] [2 81]] [23 69]] [26 41]] [26 70]] [19 58]] [4 100]] [2529 0.353 [4154 0.994 [896 4.7 [2 54] [2 75]] [24 50]] [25 100]]] [31 100]] [4 100]] [2764 0.375 [665 10.4 [147 1.17 [2763 2.71 [2752 8.34 [2 62] [2 91]] [2 66]] [2 90]] [2 75]] [2 70]]] [2826 1.13 [7766 3.24 [2179 1.05 [7268 1.65 [664 1.12 [4154 8.13 [4929 2.78 [4718 4.18 [4154 7.14 [1141 0.719 [2939 2.93 [1004 0.707 [4586 2.37 [1239 2.23 [7568 0.38 [4235 2.59 [929 1.09 [6077 2.26 [2 68] [2 50]] [2 77]] [2 90]] [896 7.53 [2 66] [2 100]]] [2 30]] [2 100]] [1429 7.91 [2 89] [2 85]]] [1899 6.73 [4 100] [4 77]]] [6537 1.72 [2 92] [2 100]]] [4 44]] [4 100]] [4 73]] [2 75]] [2 100]] [4 100]] [22 55]] [4 90]] [978 11.1 [4 100] [4 85]]]]] [5219 0.655 [429 15.2 [2570 0.511 [1108 4.74 [6525 0.577 [2361 0.864 [7414 0.461 [4205 22.8 [5851 6.95 [23 38.7 [362 3.47 [7516 0.434 [1062 4.85 [254 0.982 [2916 16 [6955 5.21 [4201 12.3 [4159 0.472 [1081 4.46 [26 77] [26 100]] [25 40]] [26 50]] [26 66]] [18 40]] [26 100]] [17 30]] [736 6.93 [1899 0.381 [1081 5.82 [2764 5.02 [2915 8.84 [6727 12.2 [7590 0.756 [6761 7.56 [423 3.75 [7373 1.04 [7711 0.808 [4478 1.72 [791 0.901 [23 0.805 [4603 1.36 [26 92] [26 90]] [26 100]] [26 100]] [26 100]] [26 100]] [26 100]] [26 77]] [26 71]] [26 100]] [26 71]] [26 77]] [26 71]] [7665 9.33 [19 33] [26 100]]] [6517 0.306 [6472 1.82 [724 0.0952 [2913 4.79 [7722 1.69 [685 0.372 [978 8.86 [26 83] [26 100]] [26 100]] [26 100]] [26 72]] [26 100]] [26 66]] [26 100]]] [26 71]]] [26 58]] [26 44]] [26 62]] [26 66]] [1429 4.36 [25 35] [26 77]]] [8 83]] [25 58]] [4 37]] [2 25]] [286 10.1 [1023 0.34 [5999 11.5 [2011 2.77 [5211 5.17 [791 19.7 [7561 2.37 [2361 4.49 [2 23] [8 66]] [17 62]] [26 66]] [23 75]] [8 62]] [23 87]] [5692 8.15 [5693 1.3 [2 38] [2 77]] [26 45]]] [6920 0.949 [1899 0.805 [23 81] [23 92]] [23 100]]]] [6572 0.406 [8 89] [8 100]]]] [2161 1.88 [599 0.173 [1986 0.379 [435 0.376 [1062 0.634 [1993 0.833 [23 98] [23 100]] [23 100]] [23 100]] [23 100]] [23 100]] [2081 3.17 [23 100] [23 87]]]] [1316 6 [978 2.95 [2599 0.941 [7603 0.907 [5597 1.88 [6 91] [6 80]] [6 100]] [6 64]] [5381 0.308 [7560 0.901 [5093 1.87 [2262 6.97 [6398 1.1 [1980 15.1 [7038 0.991 [6 95] [6 83]] [6 80]] [6 81]] [6 77]] [6 100]] [6 62]] [6 100]]] [6 62]]] [2132 0.785 [5480 8.67 [5007 12.9 [23 100] [23 66]] [23 92]] [23 71]]] [5393 2.9 [2531 0.137 [1986 2.3 [2571 2.26 [392 0.931 [1025 5.04 [6114 0.371 [4279 2.3 [23 97] [23 100]] [23 100]] [23 95]] [23 100]] [23 83]] [2763 1.16 [23 100] [23 90]]] [23 100]] [23 57]]] [7359 1.25 [2361 2.75 [4393 2.22 [269 6.04 [4135 1.61 [429 19.1 [1445 0.711 [2259 18 [2616 0.71 [2913 42.4 [5509 4.51 [4939 4.85 [4312 0.158 [4200 0.557 [978 2.56 [26 88] [7665 12.8 [4602 1.87 [26 87] [26 100]] [4851 1.34 [26 88] [26 100]]]] [26 100]] [26 100]] [26 83]] [26 85]] [4603 1.74 [26 92] [26 100]]] [2927 1.98 [26 94] [26 72]]] [26 77]] [26 77]] [996 3.02 [4235 1.54 [1059 1.95 [2526 12.1 [4602 21.6 [2749 1.54 [248 11.3 [26 57] [2755 1.21 [26 82] [26 100]]] [19 37]] [394 19.4 [26 90] [26 100]]] [0 55]] [26 50]] [26 91]] [0 100]]] [26 71]] [6027 3.16 [6152 1.11 [6732 0.319 [380 5.2 [26 65] [33 33]] [26 95]] [19 50]] [393 1.39 [26 100] [26 83]]]] [19 50]] [0 77]] [26 70]]] [2199 7.18 [407 3.88 [1141 0.876 [186 10.3 [4 100] [4 90]] [4 71]] [4 88]] [4 88]]] [6582 0.147 [4959 0.486 [665 0.398 [655 0.536 [6591 0.157 [5692 1.43 [6089 2.29 [1429 10.3 [2470 0.416 [4218 4.1 [4418 17.4 [520 1.38 [1033 0.655 [1429 6.33 [2453 5.22 [7382 10.8 [1190 26.3 [1899 5.58 [1078 20.7 [736 5.99 [2 25] [7 50]] [5396 0.941 [985 2.06 [312 1.85 [7512 21.7 [2 53] [5 21]] [2 33]] [2 81]] [2 50]]] [5812 13.4 [2 86] [2 55]]] [4 60]] [24 100]] [24 100]] [7449 11.2 [7 25] [4 42]]] [2 75]] [2 87]] [4 88]] [17 42]] [4851 22.6 [1400 26.9 [4 92] [6230 0.68 [4 70] [4 58]]] [4 71]]] [328 1.36 [1390 2.79 [434 0.502 [6529 2.7 [6581 3.47 [7363 1.33 [2259 3.85 [5 29] [7 38]] [4 100]] [5 39]] [7 93]] [4 63]] [24 100]] [4154 2.14 [7520 1.86 [7381 9.27 [2259 6.28 [7 90] [7 100]] [7 85]] [7 80]] [7 50]]]] [2526 1.15 [2 71] [1078 4.63 [2 73] [5413 1.31 [2 95] [2 100]]]]] [134 1.6 [4719 2.34 [144 3.77 [5461 0.945 [7665 26.8 [7512 8.35 [2 46] [5812 19.5 [5154 0.31 [1911 0.752 [5851 8.7 [4312 4.05 [5198 4.34 [1980 2.4 [7381 9.74 [2739 0.99 [1025 0.575 [4 52] [5662 1.98 [4 90] [4 50]]] [4 100]] [896 10.3 [24 44] [4 58]]] [1253 2.14 [2 55] [4 83]]] [2 46]] [24 36]] [7 40]] [2081 0.752 [2 37] [2 62]]] [7 57]] [7413 1.28 [4279 3.92 [2 63] [2 28]] [17 72]]]] [5 43]] [7665 17.6 [429 39.9 [2 90] [2 80]] [2 70]]] [1190 2.49 [2470 3.86 [1083 0.743 [695 1.18 [2 85] [2 44]] [2 100]] [4 100]] [2 90]]] [17 100]] [6395 0.917 [3667 0.554 [5753 0.322 [2902 4.34 [2 52] [2 81]] [4 61]] [6230 1.39 [2 92] [2 50]]] [2 30]]]] [6554 0.471 [1201 0.56 [5662 2.07 [7512 9.03 [5 33] [17 50]] [17 74]] [5803 0.531 [35 40] [35 100]]] [17 77]]] [3667 4.81 [7382 3.36 [6186 0.351 [286 2.57 [2029 1.22 [5198 1.14 [1888 5.34 [978 30.6 [328 2.49 [1078 18.3 [2 44] [2 80]] [2 38]] [4 37]] [1888 19.7 [4 58] [2 45]]] [2 66]] [2 85]] [4 60]] [2 100]] [3644 1.19 [24 53] [4338 6.3 [24 100] [24 55]]]] [2 61]]] [6088 0.664 [2939 11.5 [144 18.5 [4533 1 [1778 0.393 [6537 1.65 [2 77] [2 100]] [2 100]] [2 95]] [2 76]] [4 36]] [2 100]]] [1429 10.1 [978 17.9 [4 98] [4 70]] [4 100]]] [1023 9.25 [723 0.517 [6575 4.47 [4651 1.86 [5198 0.224 [791 17.1 [6217 0.268 [224 0.549 [2742 2.95 [7335 6.91 [4 100] [4 87]] [4 83]] [4 100]] [4 100]] [791 19.3 [4 71] [4 100]]] [4 100]] [4 76]] [6439 5.33 [4 100] [4 87]]] [4 87]] [4 88]]]] [3204 0.225 [5952 0.0664 [7588 0.102 [3905 0.436 [7405 0.698 [3057 0.458 [4690 1.55 [6853 0.364 [386 0.139 [5732 0.656 [5904 1.09 [788 0.115 [573 0.394 [286 2.53 [7356 1.2 [685 0.0468 [5632 1.34 [5270 1.28 [3313 1.03 [6550 1.43 [673 2.8 [1671 0.935 [4675 0.292 [2259 8.21 [1706 2.22 [5972 1.31 [1557 0.967 [5132 1.25 [1429 37.5 [642 1.96 [7009 2.37 [7187 1.12 [6982 0.652 [733 1.94 [4044 0.69 [7192 2.35 [5480 1.69 [3311 1.98 [6926 2.5 [6591 1.13 [7253 1.24 [5692 3.97 [134 9.09 [5412 4.69 [4611 2.65 [7665 3.29 [4092 0.754 [985 4.09 [7305 0.595 [978 10.9 [1452 0.437 [1899 18.8 [5007 1.82 [248 2.79 [1980 5.44 [978 9.81 [5 29] [23 57]] [23 54]] [33 50]] [29 44]] [23 50]] [24 33]] [663 3.41 [438 3.39 [23 16] [18 63]] [2752 31.3 [4 25] [7 17]]]] [25 47]] [4 35]] [35 84]] [2470 3.59 [4851 5.06 [1986 2.44 [1062 12.2 [5 21] [2 50]] [4 50]] [791 8.65 [7 32] [7 73]]] [4 92]]] [7 33]] [2 18]] [19 29]] [896 2.94 [1783 2.82 [2536 1.42 [6230 3.03 [1899 10.3 [4 52] [17 25]] [17 28]] [4 71]] [4 53]] [1253 1.62 [939 0.736 [6311 5.01 [17 3.84 [5 23] [17 44]] [5 33]] [7 54]] [2 33]]]] [7520 4.79 [17 48] [5 45]]] [17 56]] [23 2.48 [978 12.3 [4 62] [2 54]] [2 54]]] [23 100]] [7168 1.07 [735 1.85 [5482 6.08 [5491 3.55 [4338 0.994 [2753 0.763 [7461 0.873 [18 25] [18 44]] [22 100]] [23 88]] [13 50]] [18 78]] [18 100]] [18 62]]] [17 77]] [35 60]] [5154 3.61 [978 6.89 [5 76] [17 36]] [17 88]]] [6735 0.907 [6982 5.19 [4 77] [4 100]] [4 87]]] [4 77]] [5 41]] [722 0.873 [5 63] [5 85]]] [3858 0.901 [7253 4.9 [6529 3.38 [5480 2.88 [653 0.456 [1240 0.764 [3054 8.77 [649 1.56 [1690 1.53 [6983 4.87 [642 0.657 [3041 1.18 [1101 2.92 [1475 0.6 [3969 2.02 [5753 2.71 [4870 0.797 [4508 13.2 [429 30.2 [328 11.9 [6024 2.73 [3889 1.56 [2628 3.91 [3365 3.18 [7354 1.04 [6581 2.72 [7185 3.62 [3849 11.1 [985 11.6 [682 0.808 [1919 6.11 [3561 1.68 [6537 5.88 [1580 21.7 [1505 2.92 [1077 7.39 [2739 2.28 [731 2.25 [434 1.09 [1913 16.7 [7241 3.08 [1788 3.88 [728 8.15 [5154 2.01 [5 13] [19 57]] [5 75]] [5 33]] [134 10.8 [5 70] [5 57]]] [23 90]] [4 29]] [3252 2.38 [2784 2.35 [2752 24.2 [17 33] [2466 1.82 [23 6.95 [5 27] [5 38]] [5 75]]] [5 50]] [5 100]]] [4 83]] [5 100]] [5 84]] [19 76]] [2 100]] [5 63]] [4 50]] [4 52]] [17 35]] [35 100]] [5 44]] [5 40]] [7169 2.38 [7449 29.1 [1783 12.7 [1888 3.47 [6581 7.55 [6230 20 [2607 1.04 [5 55] [1429 58.9 [5 50] [5 88]]] [5 71]] [12 33]] [16 50]] [18 66]] [35 33]] [5 71]]] [5 100]] [5154 11.5 [957 9.38 [2928 2.51 [6584 0.402 [5 46] [5 85]] [5 100]] [5 87]] [17 33]]] [5 93]] [7 100]] [23 24]] [4517 0.921 [791 2.53 [6581 1.37 [2902 13 [7665 34.6 [929 19 [3752 2.37 [1078 22.7 [2178 7.94 [17 32] [38 37]] [6230 4.44 [1888 2.78 [1094 6.99 [8 16] [4 50]] [17 40]] [17 45]]] [5 53]] [2 21]] [7 38]] [5 64]] [17 52]] [7373 5.79 [7009 1.39 [7188 26.9 [4061 4.25 [485 9.2 [7270 13.2 [1007 11.6 [736 2.25 [695 3.28 [2470 2.35 [1630 1.57 [1899 26.1 [3014 1.67 [7463 9.66 [724 4.23 [2826 5 [5 32] [5 50]] [17 72]] [5 100]] [17 71]] [4 30]] [17 41]] [4 44]] [7188 4.04 [17 39] [17 37]]] [17 40]] [17 50]] [5 100]] [38 47]] [5 77]] [5 80]] [5 61]] [38 87]]] [38 58]]] [18 87]] [17 28]] [4832 2.04 [791 0.852 [2826 10.1 [5 21] [5 60]] [7343 1.48 [1919 1.4 [733 0.792 [5019 1.41 [5 60] [5 85]] [5 55]] [17 40]] [5 50]]] [4 53]]] [5 83]] [2826 9.61 [3929 3.99 [5 74] [5 46]] [3724 1.31 [5 82] [5 100]]]] [4 25]] [35 93]] [1210 4.43 [7021 0.952 [5 68] [5 100]] [19 54]]] [4 83]] [1899 6.53 [17 75] [17 100]]] [7512 24 [17 44] [5 66]]] [0 100]] [1429 55.3 [655 1.14 [24 60] [24 100]] [24 50]]] [5007 1.29 [957 0.632 [731 2.13 [5 55] [5 75]] [5 57]] [5 100]]] [5090 1.39 [2726 0.752 [7449 17.3 [155 2.35 [18 48] [13 28]] [18 37]] [6 40]] [22 85]]] [7 66]] [141 3.56 [17 51] [5 33]]] [35 100]]] [731 7.69 [4509 0.657 [18 39] [18 88]] [7665 10.6 [16 41] [429 21.3 [16 81] [16 60]]]]] [3879 2.72 [2752 12.9 [736 1.8 [17 57] [17 41]] [7 41]] [19 55]]] [814 0.975 [31 70] [12 90]]] [4 100]] [7472 1.87 [1701 2.28 [3929 0.508 [2406 1.52 [2453 3.46 [2807 1.32 [2470 4.77 [1974 1.94 [688 5.41 [4027 1.55 [6581 0.474 [2385 2.07 [6413 6.84 [2204 8.01 [1025 4.57 [6959 9.81 [5132 1.61 [5717 4.06 [7009 13.3 [5647 19.9 [4040 4.59 [1239 21.2 [2428 2.26 [6997 0.917 [719 0.406 [3055 2.67 [3308 9.09 [811 1.84 [4154 31.1 [4158 6.94 [112 1.84 [1913 15.4 [5491 3.76 [6375 3.46 [722 0.292 [2752 8.6 [5480 0.924 [1011 5.07 [8 17] [6 33]] [18 57]] [17 10]] [17 30]] [35 37]] [18 33]] [23 35]] [22 28]] [19 54]] [24 54]] [10 50]] [23 80]] [0 100]] [695 6.12 [2 33] [16 33]]] [31 45]] [7 100]] [4712 0.967 [6 41] [6 77]]] [24 100]] [23 68]] [19 66]] [6 90]] [5132 6.92 [16 54] [6 38]]] [6 50]] [1888 6.15 [1899 20.7 [24 48] [23 53]] [6 33]]] [23 58]] [0 63]] [18 77]] [724 1.55 [5 47] [17 62]]] [24 100]] [791 14.9 [7 100] [7 80]]] [429 4.99 [16 57] [6 75]]] [4 38]] [22 100]] [24 95]] [6 100]] [17 48]] [5484 1.99 [663 1.63 [1783 3.83 [24 70] [7512 7.39 [6 55] [6 100]]] [22 100]] [18 50]]] [2811 0.813 [38 80] [38 100]]]] [1364 0.424 [5776 0.0659 [6 82] [6 66]] [6 100]]] [2568 1.26 [6363 0.87 [7566 4.3 [132 1.63 [1783 13.5 [5130 2.26 [791 19.8 [2526 10.6 [1078 25.2 [738 1.08 [6042 0.935 [5482 2.92 [18 42] [18 88]] [18 84]] [18 50]] [18 50]] [18 92]] [18 42]] [18 80]] [18 33]] [18 37]] [18 60]] [18 50]] [18 100]]] [384 5.56 [4980 6.78 [7009 1.33 [1223 3.59 [7241 7.59 [429 21.6 [392 0.967 [5353 0.387 [1081 12.3 [1239 5.02 [695 6.15 [408 6.45 [2963 0.761 [1696 1.86 [5673 1.15 [5480 2.15 [26 82] [26 87]] [26 66]] [26 100]] [26 100]] [26 50]] [18 33]] [26 45]] [26 47]] [26 100]] [26 90]] [6 28]] [19 50]] [26 55]] [4 40]] [26 100]] [26 44]]] [728 1.78 [3008 2.53 [2526 33.1 [726 0.362 [736 5.52 [1023 1.08 [1505 2.96 [7665 3.9 [5 29] [929 7.11 [6865 1.01 [5480 4.24 [31 3.59 [6980 1.47 [4654 2.16 [642 0.391 [5 69] [7354 0.803 [5 86] [5 66]]] [5 100]] [5 94]] [5 40]] [16 33]] [6557 10.1 [5 100] [5 66]]] [5 45]]] [5 100]] [17 62]] [5155 1.46 [6550 10.4 [5 57] [5 45]] [719 3.77 [5 40] [17 75]]]] [5 50]] [695 4.51 [0 29] [17 53]]] [7192 1.41 [1011 2.73 [17 44] [719 10 [2591 4.88 [896 7.13 [17 100] [17 58]] [17 100]] [17 50]]] [17 100]]] [5693 8.57 [2628 6.8 [5692 5.8 [17 56] [17 83]] [19 66]] [5 42]]]] [7188 4.95 [3885 2.93 [458 0.634 [2676 2.24 [5693 0.963 [647 1.35 [5 83] [5 91]] [5 98]] [5 66]] [5 100]] [5 87]] [5 84]]] [4904 0.203 [429 14.8 [7169 2.7 [6078 20.7 [2281 2.13 [31 88] [31 100]] [31 72]] [31 100]] [31 34]] [31 100]]] [2749 0.536 [181 3.53 [5132 4.65 [719 5.02 [7169 0.963 [1452 1.39 [2707 10.7 [7332 0.715 [7566 0.809 [485 1.37 [16 25] [16 100]] [18 62]] [16 55]] [1078 4.43 [16 93] [16 50]]] [18 22]] [5 20]] [18 73]] [5673 1.13 [7512 5.6 [16 85] [16 50]] [16 88]]] [26 100]] [26 81]]] [5482 1.12 [7512 0.198 [5366 0.935 [6529 2.89 [7472 1.15 [7449 0.222 [429 14.5 [26 39] [7354 5.57 [5647 21.1 [5751 3.6 [23 48] [23 100]] [23 100]] [18 38]]] [16 27]] [38 93]] [7 100]] [23 100]] [5174 0.581 [673 3.28 [2717 0.611 [4870 0.661 [1669 1.33 [4970 0.8 [5641 6.9 [5873 4.32 [6776 9.89 [1899 2.05 [3554 2.78 [1213 0.73 [6363 1.79 [7384 2.15 [1601 1.55 [7427 9.25 [7537 7.14 [5155 2.07 [5160 1.69 [6349 2.04 [7176 2.91 [5090 0.967 [4611 0.569 [1646 2.15 [6833 1.47 [5484 1.47 [7699 0.448 [2628 0.956 [6732 0.661 [384 5.21 [18 34] [5693 4 [18 51] [16 57]]] [18 75]] [26 37]] [18 85]] [18 82]] [18 100]] [18 44]] [16 37]] [18 37]] [7 70]] [7 83]] [14 100]] [16 50]] [16 66]] [16 50]] [18 100]] [7 100]] [23 29]] [26 50]] [7 81]] [5753 1.43 [1078 23.6 [2809 1.99 [144 1.17 [18 34] [16 47]] [16 65]] [18 68]] [13 23]]] [7 100]] [7 90]] [26 44]] [7 100]] [7381 1.82 [2752 10.5 [7 87] [7 100]] [7 100]]] [7 56]] [7665 8.07 [16 69] [16 30]]] [1429 34.9 [1400 39.3 [26 91] [26 77]] [18 76]]] [429 5.72 [5170 5.35 [26 100] [26 66]] [26 100]]]] [791 8.03 [6091 1.46 [18 55] [16 45]] [5154 18.3 [7546 15.6 [6230 7.54 [6708 6.5 [392 10.9 [18 78] [18 95]] [18 77]] [7 41]] [18 50]] [5 46]]]]] [5154 5.06 [6592 7.94 [185 1.57 [7154 1.39 [6040 0.931 [5482 4.02 [1023 1.43 [5971 5.14 [4288 2.57 [5883 0.669 [1025 1.42 [18 56] [16 75]] [18 66]] [16 33]] [18 85]] [18 80]] [18 100]] [18 93]] [18 75]] [18 100]] [19 50]] [16 50]]] [7413 1.83 [663 0.849 [1919 6.9 [2282 1.81 [248 2.2 [7734 0.305 [4517 1.33 [384 0.96 [7255 1.04 [2752 5.95 [24 23] [435 1.87 [685 2.42 [23 38] [23 100]] [429 45 [23 100] [23 66]]]] [12 35]] [23 100]] [23 100]] [23 90]] [1 35]] [6 77]] [6 90]] [7085 0.582 [2 45] [2 57]]] [2 51]]] [4806 2.02 [731 2.89 [2740 0.227 [3220 0.325 [5971 0.393 [312 3.15 [6395 1.41 [7711 4.06 [2902 1.27 [5429 1.65 [3008 2.79 [2143 8.85 [1062 2.44 [1190 7.6 [2760 2.48 [929 3.06 [5 29] [2 42]] [5 64]] [17 46]] [4 27]] [4 72]] [35 41]] [5 100]] [929 1.47 [2571 1.49 [1078 28.5 [5 75] [4 71]] [5 90]] [5 37]]] [17 70]] [1888 7.12 [17 81] [17 66]]] [4 66]] [5662 3.92 [17 84] [17 50]]] [5819 1.84 [5 100] [5 75]]] [4 89]] [312 0.765 [1517 0.631 [1690 0.546 [5509 0.686 [2595 0.711 [7365 4.05 [722 0.456 [5267 0.244 [6977 4.19 [567 3.09 [2081 5.89 [144 0.917 [2470 0.945 [1023 0.602 [663 3.96 [6791 0.811 [6333 0.846 [5812 3.52 [17 88] [5 45]] [5 90]] [4 28]] [19 43]] [17 60]] [4 87]] [3220 0.453 [5413 1.49 [5 91] [19 62]] [5 100]]] [4 50]] [19 55]] [5 72]] [19 50]] [7665 12 [17 63] [17 55]]] [4 100]] [4 100]] [723 0.894 [2628 6.86 [19 41] [17 88]] [17 75]]] [17 82]] [1429 66.4 [5 87] [5 62]]] [23 0.382 [4 66] [4 100]]]] [7682 1.09 [5819 4.53 [2752 18.3 [573 4.26 [19 68] [17 55]] [2628 1.21 [5 80] [19 44]]] [17 72]] [17 100]]]] [2939 6.18 [6929 0.145 [6471 0.219 [680 1.69 [5314 7.92 [2259 42.4 [4645 3.88 [1911 1.41 [1601 1.07 [178 2.13 [7210 6.98 [7491 3.22 [1557 2.99 [2268 7.28 [2342 0.956 [2752 27.6 [7139 3.14 [1011 1.96 [6732 0.208 [2259 31.6 [144 9.72 [18 98] [18 33]] [18 53]] [18 100]] [18 73]] [18 30]] [18 50]] [18 70]] [18 60]] [7 27]] [18 50]] [18 57]] [16 30]] [18 30]] [16 53]] [16 33]] [1078 8.21 [7 33] [16 22]]] [19 50]] [18 100]] [18 39]] [16 60]] [4895 1.2 [18 48] [5484 0.433 [16 43] [16 100]]]]] [2752 14.3 [663 0.736 [23 1.4 [1888 4.92 [18 52] [19 45]] [5596 1.46 [2707 1.99 [7722 3.41 [7259 3.85 [2526 0.864 [19 58] [18 54]] [2260 13.9 [19 83] [18 42]]] [19 71]] [19 88]] [19 37]]] [7546 1.56 [23 15.6 [7253 1.12 [5198 1.2 [19 84] [19 60]] [19 71]] [19 50]] [18 50]]] [5521 1.53 [688 1.95 [6380 2.25 [2763 0.498 [1009 5.93 [458 2.97 [2755 1.68 [6711 0.805 [2760 2.45 [7006 3.37 [5482 5.31 [1429 39.2 [19 66] [19 90]] [19 81]] [5 42]] [19 45]] [18 54]] [26 66]] [19 60]] [19 33]] [19 96]] [18 50]] [7 80]] [19 100]]]] [7708 0.433 [2591 0.105 [6024 0.74 [1745 0.606 [7734 0.844 [5920 1.18 [72 0.994 [6531 1.02 [6880 5.01 [7731 0.75 [2939 2.86 [1600 0.36 [7118 1.11 [6802 0.406 [4896 1.29 [14 26] [14 80]] [7 42]] [38 70]] [7 100]] [7185 1.87 [7 25] [19 40]]] [16 33]] [17 100]] [2913 1.19 [7 91] [7 100]]] [13 100]] [18 55]] [6529 1.29 [5480 0.726 [7 75] [18 62]] [7 94]]] [14 59]] [7 100]] [3734 5.38 [7085 0.315 [2760 0.268 [1239 0.931 [17 100] [17 88]] [17 100]] [17 60]] [17 53]]] [17 86]]] [23 100]] [5211 4.62 [7419 3.51 [4790 1.22 [7185 1.9 [429 20.8 [5192 3.33 [4342 0.711 [2752 18.1 [4851 0.407 [24 62] [36 72]] [24 89]] [24 86]] [24 100]] [2259 21.8 [1641 0.443 [24 49] [24 85]] [36 88]]] [1239 8.02 [1888 2.6 [18 25] [18 43]] [36 33]]] [31 100]] [24 87]] [30 0.155 [1068 0.946 [22 65] [22 62]] [22 100]]]] [2752 5.55 [6050 1.39 [7363 0.967 [7255 5.4 [6260 0.816 [726 4.5 [2536 2.28 [695 3.65 [3956 1.59 [3784 0.829 [2259 16.3 [8 88] [8 100]] [0 71]] [8 100]] [4 28]] [8 100]] [4 100]] [8 100]] [0 50]] [4 100]] [0 63]] [719 0.539 [1466 0.545 [4338 0.37 [6560 1.92 [4 44] [8 91]] [4 88]] [8 100]] [4 34]]]] [3362 1.95 [3553 2.96 [2334 3.11 [6591 7.2 [7325 4.69 [906 3.31 [1838 0.606 [3694 0.836 [1201 0.329 [7324 2.22 [3929 8.68 [5129 8.5 [142 1.78 [2760 10.5 [7586 3.26 [5429 13.2 [4304 2.46 [4218 1.64 [1025 1.51 [6068 1.78 [1503 0.79 [2081 6.83 [978 35.8 [5660 0.639 [2023 4.62 [3435 3.02 [5462 2.11 [725 3.23 [1007 5.19 [602 6.35 [5019 1.84 [929 7.68 [6230 26.4 [5692 0.882 [3998 7.95 [1128 1.74 [5 93] [5 100]] [5 75]] [5 100]] [5 75]] [5 71]] [2826 5.59 [5 90] [5 83]]] [7009 1.35 [1429 67.1 [5 100] [5 87]] [5 90]]] [5 66]] [5 85]] [5 70]] [5 83]] [5 66]] [5 100]] [5 58]] [5 75]] [5 97]] [5 55]] [5 81]] [5 100]] [5 28]] [5 78]] [5 81]] [5 50]] [5 58]] [35 33]] [5 50]] [5 74]] [5753 2.01 [5 70] [5 62]]] [5 71]] [19 68]] [7020 0.635 [7722 0.532 [5 37] [5 84]] [5 100]]] [429 33.3 [1011 2.89 [35 63] [5 60]] [5 100]]] [5 55]] [8 100]] [8 83]] [8 60]]] [5033 1.76 [1273 2.4 [6750 0.712 [429 8.01 [1374 0.31 [2585 1.18 [6 50] [6 100]] [6 87]] [1909 6.68 [5778 0.139 [6 98] [6 85]] [6 50]]] [6701 1.61 [6 100] [6 87]]] [6 75]] [6 60]]] [5297 0.751 [6550 0.239 [4588 0.204 [5523 0.805 [6414 0.256 [6549 0.183 [3012 0.864 [5157 1.18 [896 8.36 [6524 0.884 [1704 0.365 [4573 2.39 [7185 11.3 [5812 2.47 [5632 1.47 [1226 2.49 [6584 5.11 [1626 3.76 [1754 0.217 [7009 1.56 [3985 1.17 [1063 4.51 [7259 2.43 [6251 2.04 [494 3.58 [4288 2.17 [6173 1.8 [112 8.8 [2241 3.83 [2913 0.864 [5904 1.22 [4017 0.469 [1084 2.84 [6260 0.656 [6544 3.03 [6599 14.9 [3732 2.73 [1740 3.03 [7520 3.48 [184 1.49 [1463 5.25 [407 3.38 [145 11.1 [988 2.66 [5851 10.8 [7601 0.671 [3515 1.79 [695 11.3 [3182 1.92 [7381 4.99 [1993 7.12 [429 16.9 [17 37] [3905 35.5 [3558 0.747 [6134 0.664 [728 5.8 [17 51] [19 42]] [17 33]] [17 77]] [17 100]]] [5 33]] [7 35]] [17 100]] [14 41]] [19 100]] [16 25]] [4 50]] [19 22]] [35 36]] [7 60]] [5 40]] [17 80]] [731 8.95 [17 37] [35 60]]] [35 48]] [23 3.47 [17 93] [19 45]]] [19 62]] [14 80]] [36 100]] [23 83]] [19 80]] [1078 1.96 [19 80] [19 95]]] [7 38]] [17 73]] [19 53]] [31 100]] [32 56]] [3377 1.31 [7 27] [7 100]]] [19 60]] [18 100]] [791 2.88 [17 35] [35 76]]] [0 100]] [4200 2.02 [5 24] [2628 1.55 [5 66] [5 50]]]] [2628 0.217 [38 73] [38 62]]] [17 84]] [17 100]] [6883 0.945 [23 88] [23 100]]] [16 42]] [3492 0.516 [7354 1.33 [1068 2.75 [728 0.719 [5519 0.949 [731 5.95 [17 39] [1062 7.02 [1429 25.3 [17 100] [17 70]] [35 50]]] [19 100]] [5969 1.17 [2628 1.95 [3014 0.77 [7512 2.48 [35 50] [19 50]] [16 66]] [38 40]] [17 85]]] [17 80]] [7214 1.66 [7 85] [7 88]]] [1980 0.949 [17 72] [17 88]]]] [978 6.37 [19 44] [3917 5.21 [5316 5.99 [7 59] [7 100]] [7 100]]]] [731 10 [19 83] [19 33]]] [1630 2.35 [931 1.12 [6708 4.35 [6548 7.82 [1783 3.37 [688 1.25 [17 73] [17 100]] [17 38]] [17 94]] [16 63]] [17 55]] [19 66]]] [6581 0.96 [2993 1.32 [3905 15.4 [7 80] [7 64]] [36 53]] [17 80]]] [6725 3.75 [6449 3.35 [7534 1.36 [1253 2.87 [7735 0.675 [429 29.9 [6199 18.8 [7 26] [7 57]] [5345 0.761 [17 50] [7 40]]] [5383 3.13 [7 96] [7 88]]] [19 50]] [17 85]] [7 87]] [7 87]]] [5345 1.37 [6436 0.659 [1023 6.31 [3517 1.97 [1011 8.42 [1723 1.93 [141 1.63 [17 3.12 [1598 0.734 [1584 3.03 [17 31] [17 78]] [17 33]] [19 76]] [19 64]] [35 80]] [17 90]] [19 100]] [7 50]] [19 100]] [736 4.86 [5 23] [17 54]]]] [36 100]] [1707 3.78 [3317 2.1 [178 3.78 [6382 1.71 [7352 1.42 [7682 0.914 [723 2.45 [2143 0.183 [3014 1.13 [1073 3.27 [3929 1.68 [19 36] [17 69]] [17 57]] [19 36]] [17 88]] [7722 2.4 [17 66] [17 100]]] [19 58]] [17 40]] [14 33]] [17 100]] [494 1.09 [17 85] [17 100]]] [16 20]]] [7 100]] [722 1.69 [7723 1.73 [999 0.655 [3798 5.86 [7203 4.13 [736 0.526 [144 0.337 [19 97] [19 100]] [5205 2.26 [5654 0.552 [3519 5.35 [19 77] [19 100]] [19 100]] [19 66]]] [19 71]] [19 57]] [19 100]] [19 70]] [1633 6.46 [19 90] [17 62]]]] [7301 0.669 [7255 0.561 [3913 0.659 [6548 0.204 [1429 58 [6395 0.73 [434 0.765 [17 75] [17 66]] [791 5.38 [5891 0.244 [17 92] [17 100]] [17 100]]] [17 55]] [7665 24.3 [17 100] [17 87]]] [7 45]] [17 54]] [19 53]]] [5522 0.464 [4568 2.69 [6310 2.52 [1475 0.605 [6776 0.584 [2259 12.8 [7301 1.33 [6980 0.122 [647 3.87 [5904 1.67 [1239 1.16 [6131 0.759 [1151 9.67 [4851 1.98 [6557 1.46 [6732 1.58 [3794 1.33 [7512 8.11 [17 72] [17 30]] [38 62]] [6413 0.808 [5345 0.329 [6230 7.74 [17 83] [17 30]] [17 85]] [17 66]]] [610 0.797 [17 62] [5 100]]] [3929 0.456 [7590 3.28 [1884 1.38 [929 0.994 [3732 1.58 [17 78] [17 50]] [17 71]] [17 62]] [17 42]] [17 96]]] [38 80]] [14 33]] [6535 0.879 [17 87] [17 50]]] [4806 0.717 [19 66] [19 100]]] [16 30]] [17 0.96 [719 5.47 [2571 0.563 [896 0.53 [17 69] [17 100]] [17 66]] [19 70]] [17 70]]] [957 2.88 [3905 9.89 [17 60] [19 50]] [19 100]]] [38 57]] [5812 0.456 [17 91] [17 100]]] [5 100]] [7605 1.35 [4324 0.351 [6310 5.5 [695 3.09 [4222 0.244 [3905 6.74 [178 0.253 [2826 4.09 [17 77] [17 70]] [17 50]] [2259 0.44 [19 81] [17 44]]] [17 90]] [19 30]] [6396 0.738 [4414 0.894 [17 58] [17 75]] [896 8.78 [17 100] [17 85]]]] [17 72]] [35 40]]] [2526 3.75 [16 37] [19 64]]] [1888 12.7 [6584 0.996 [19 62] [19 75]] [35 54]]]] [4861 8.82 [2849 1.67 [3822 2.36 [1072 2.45 [5462 0.875 [1584 0.401 [1078 3.21 [19 100] [3558 0.448 [929 2.88 [7169 0.484 [2526 7.19 [23 2.14 [16 42] [19 80]] [19 92]] [17 37]] [7 37]] [1239 1.76 [19 90] [19 100]]]] [7722 3.97 [19 100] [19 60]]] [19 50]] [19 63]] [19 66]] [19 42]] [14 38]]]] [4304 0.793 [6589 0.162 [3266 0.136 [1529 0.21 [7064 2.91 [312 1.29 [2573 0.724 [4478 2.3 [610 1.1 [5413 0.842 [4718 1.19 [6443 1.52 [7333 0.294 [3014 0.315 [2628 0.757 [6585 1.04 [1087 0.254 [2610 1.98 [2259 6.4 [2526 8.98 [7722 10.3 [7722 1.11 [6395 2.19 [17 65] [17 100]] [5383 7.9 [736 7.23 [5812 1.46 [731 5.15 [17 42] [17 71]] [5154 1.49 [17 91] [17 100]]] [3929 4.84 [5 37] [3 33]]] [3 33]]] [4222 1.25 [17 80] [17 90]]] [17 50]] [5680 2.89 [5 42] [5 75]]] [19 55]] [5 70]] [26 85]] [7588 7.26 [1783 1.89 [728 3.25 [3558 5.72 [5 50] [5 100]] [17 57]] [791 4.85 [5 55] [19 60]]] [17 36]]] [6891 2.59 [3518 0.414 [2752 12 [7381 4.76 [17 100] [17 50]] [17 57]] [19 100]] [19 71]]] [5192 0.588 [2591 0.627 [17 85] [17 100]] [17 100]]] [5 95]] [7588 7.31 [3928 1.22 [5 82] [5 100]] [5 55]]] [2199 1.27 [3928 1.35 [1899 4.63 [429 29.1 [19 58] [17 50]] [17 56]] [4587 6.3 [5154 2.29 [1063 3.68 [602 0.428 [5812 2.96 [17 66] [17 100]] [17 100]] [17 80]] [17 77]] [17 50]]] [17 100]]] [5 97]] [1078 2.23 [573 1.05 [17 60] [17 50]] [7214 0.918 [5157 2.54 [3554 3.23 [1899 6.97 [791 6.15 [17 100] [17 96]] [17 85]] [17 66]] [17 80]] [19 55]]]] [4218 0.186 [7381 6.09 [2591 4.51 [602 1.39 [1239 0.551 [17 91] [17 70]] [17 56]] [38 40]] [7185 1.5 [17 66] [19 63]]] [5288 0.111 [2939 7.45 [6597 0.792 [4572 0.648 [5637 2.51 [7588 5.04 [896 1.85 [6310 0.764 [17 100] [17 75]] [17 100]] [17 62]] [17 42]] [17 85]] [14 42]] [17 40]] [17 50]]]] [978 5.86 [4 100] [4 46]]] [3313 0.22 [5 91] [5 100]]] [5 94]] [1463 0.127 [5154 4.74 [791 6.02 [5 90] [5 100]] [5 83]] [5 100]]] [7009 4.86 [2616 2.52 [5 42] [5 100]] [3554 0.494 [7324 9.57 [2591 1.01 [7185 0.312 [5 72] [5 62]] [5 100]] [19 50]] [5 56]]]] [7241 0.907 [5 50] [5 85]]]] [131 0.403 [7359 0.202 [2466 0.137 [7241 8 [4478 0.492 [5660 2.36 [429 46.3 [394 0.505 [7742 2.13 [5953 3.21 [5878 0.14 [1648 1.24 [5742 0.157 [7067 1.12 [1239 1.4 [19 29] [4 54]] [3503 6.16 [7712 0.172 [6804 3.6 [17 80] [17 60]] [17 100]] [17 50]]] [17 54]] [141 1.37 [7708 2.2 [2753 1.97 [5904 1.46 [3794 15.8 [2763 2.06 [2840 0.792 [1980 2.55 [1703 1.54 [3908 1.63 [7085 0.691 [144 1.03 [19 33] [7241 0.462 [5741 3.3 [17 75] [17 50]] [38 50]]] [17 44]] [19 60]] [19 77]] [38 75]] [19 90]] [17 83]] [17 100]] [19 75]] [19 86]] [17 76]] [7373 0.515 [17 50] [17 100]]]] [1721 2.4 [7241 1.57 [38 53] [6584 1.77 [17 100] [17 62]]] [16 50]]] [985 5.77 [155 1.74 [738 0.945 [7665 9.01 [6358 4.21 [3794 23.1 [17 55] [19 35]] [38 69]] [141 2.09 [4564 4.35 [17 50] [38 62]] [16 80]]] [14 22]] [17 62]] [38 81]]] [862 1.01 [35 41] [38 75]]] [18 66]] [3734 0.609 [5673 14 [896 8.79 [38 60] [3733 6.22 [38 100] [38 42]]] [16 33]] [7335 1.98 [5812 2.03 [19 64] [38 50]] [38 71]]]] [19 84]] [567 0.214 [3913 0.774 [4661 0.135 [4479 1.66 [4742 0.397 [7526 0.827 [38 57] [19 75]] [17 100]] [5390 2.08 [6074 0.296 [17 76] [17 87]] [17 80]]] [17 100]] [7169 0.596 [695 0.413 [17 38] [19 77]] [38 41]]] [7424 0.0664 [4851 2.31 [6534 0.13 [1190 0.727 [6581 2.31 [19 75] [19 50]] [38 54]] [1183 0.697 [19 93] [17 25]]] [17 31]] [17 66]]]] [16 70]] [5389 7.28 [5904 0.741 [3120 0.744 [2628 1.26 [4478 0.221 [5007 0.321 [7185 2.2 [16 58] [38 57]] [17 66]] [17 84]] [6230 9.79 [5892 0.976 [6555 0.799 [6727 0.538 [19 80] [17 80]] [19 100]] [19 100]] [35 54]]] [1072 0.294 [5693 0.36 [38 30] [17 77]] [38 87]]] [5519 0.42 [7711 1.86 [733 0.411 [7210 2.23 [19 100] [19 83]] [494 0.922 [19 55] [19 80]]] [19 57]] [4565 0.634 [19 100] [1633 0.711 [19 66] [19 100]]]]] [38 38]]] [1633 0.977 [19 87] [19 100]]] [3014 3.21 [144 0.954 [19 85] [19 100]] [7301 0.754 [19 57] [19 75]]]]] [1008 1.61 [723 4.56 [1400 6.7 [17 1.62 [3205 0.225 [17 50] [1539 5.01 [3602 0.301 [1483 3.2 [2199 3.45 [2657 5.42 [1545 9.8 [3685 0.342 [1995 4.62 [7535 0.75 [2526 13.2 [6724 1.44 [458 3.5 [4235 0.686 [7185 3.76 [3205 22.6 [1078 5.39 [5 72] [4112 4.83 [6230 8.01 [5 96] [5 62]] [5 100]]] [5 100]] [5 100]] [5 100]] [5 71]] [5 42]] [3676 2.15 [1546 0.225 [5 90] [5 100]] [5 87]]] [5 71]] [5 72]] [5 42]] [5 70]] [5 58]] [5 42]] [38 50]] [12 69]] [5 28]]] [1429 52.2 [7512 19.9 [5 100] [5 92]] [5 77]]] [12 62]] [7722 7.82 [723 7.93 [5 66] [5 66]] [19 66]]] [19 60]]]] [4145 0.173 [4954 0.382 [1995 0.288 [1986 1.17 [4339 0.242 [435 0.692 [4189 1.97 [3659 0.863 [576 2.31 [655 0.492 [5457 1.73 [6853 3.46 [1980 5.41 [772 1.08 [7354 2.97 [407 4.28 [6230 8.71 [4342 1.72 [2913 5.88 [1400 0.864 [23 43] [10 26]] [26 70]] [24 95]] [7 32]] [7 81]] [7512 6.25 [18 25] [16 37]]] [4356 3.37 [5413 3.93 [2411 0.914 [24 82] [19 66]] [24 100]] [19 55]]] [1226 1.14 [6342 0.986 [2199 18.8 [2000 2.39 [23 76] [23 100]] [23 55]] [23 93]] [23 100]]] [24 86]] [24 100]] [24 100]] [23 100]] [2451 3.26 [1751 0.924 [4519 8.96 [7512 8.42 [24 76] [2466 0.713 [2517 9.79 [655 0.87 [2517 1.6 [24 78] [24 100]] [24 100]] [24 73]] [24 100]]] [3659 13.5 [19 76] [24 57]]] [24 100]] [4154 14.7 [24 50] [6708 11.9 [19 53] [19 71]]]]] [7665 5.43 [4046 2.39 [4495 0.747 [24 93] [24 100]] [24 85]] [5647 10.1 [4495 0.705 [2536 0.754 [1047 18.6 [5866 1.19 [4492 2.7 [3652 2.96 [24 100] [978 4.41 [4340 0.821 [19 85] [24 92]] [24 90]]] [19 62]] [24 75]] [19 50]] [24 100]] [24 100]] [24 62]]]] [7512 2.12 [23 96] [23 66]]] [2525 6.94 [1899 2.92 [6230 0.792 [24 67] [24 77]] [434 0.534 [3637 2.18 [4339 4.15 [24 66] [1240 0.885 [24 92] [24 100]]] [24 100]] [24 100]]] [19 57]]] [7508 0.821 [441 0.367 [1913 2.83 [7381 0.62 [23 80] [24 100]] [23 95]] [23 100]] [23 100]]] [4833 0.692 [2275 1.8 [6386 0.289 [5345 0.948 [1239 0.855 [435 0.846 [23 52] [23 86]] [7665 3.33 [1995 1.37 [23 85] [23 100]] [24 50]]] [10 45]] [24 60]] [24 42]] [24 47]]] [1913 3.06 [23 100] [23 80]]] [1429 3.91 [1888 5.53 [7693 1.76 [24 72] [19 50]] [24 93]] [6374 0.241 [1035 1.14 [5427 3.53 [7693 2.04 [5597 0.307 [5819 0.833 [1239 1.65 [24 93] [24 100]] [24 85]] [24 100]] [5192 2.72 [24 80] [7520 1.58 [24 100] [24 88]]]] [24 66]] [3653 8.28 [2341 2.13 [24 76] [24 100]] [24 60]]] [4147 0.465 [791 12.1 [24 100] [24 75]] [24 51]]]]]]] [145 0.199 [5733 0.78 [430 0.242 [312 1.17 [2902 0.578 [2399 0.154 [7009 9.52 [2804 0.127 [1391 1.23 [4929 0.121 [3821 0.664 [6643 1.5 [5812 1.64 [5472 1.01 [7558 1.61 [6382 3.13 [7665 6.26 [558 0.982 [429 2.89 [1955 3.32 [4690 3.51 [2262 2.78 [6853 1.54 [23 2.61 [4103 6.62 [3008 1.59 [5322 1.87 [2701 22 [221 6.7 [2526 15.2 [34 34] [8 92]] [29 44]] [13 76]] [11 42]] [34 29]] [8 100]] [32 27]] [34 92]] [4851 2.26 [34 90] [34 100]]] [1078 16.2 [7176 2.2 [978 2.99 [2488 34.2 [2607 2.16 [2562 15.2 [8 96] [8 68]] [8 100]] [8 97]] [8 100]] [8 100]] [8 100]]] [1 41]] [7176 0.527 [2268 5.92 [5264 1.6 [3054 1.5 [1735 1.27 [1483 0.406 [6313 1.85 [3273 0.914 [1888 0.559 [5859 3.11 [1513 4.35 [6235 1.93 [3085 0.848 [2466 2.61 [6569 2.21 [2342 3.39 [3849 5.7 [4324 1.21 [2550 0.717 [4765 19 [1429 39.1 [2259 52.3 [7623 2.7 [7491 0.457 [1025 11.6 [394 1.25 [4285 4.12 [7449 14.1 [3779 7.38 [3106 2.95 [7354 1.59 [5322 3.31 [5219 1.67 [2259 1.01 [8 59] [328 11.4 [0 36] [0 70]]] [8 96]] [23 50]] [8 86]] [8 92]] [37 94]] [23 66]] [8 100]] [8 75]] [0 22]] [29 77]] [34 42]] [7623 24.1 [34 87] [34 100]]] [1094 1.71 [1521 2.73 [7413 2.09 [8 70] [8 93]] [13 100]] [8 94]]] [13 100]] [2259 1.43 [8 62] [7428 8.41 [3124 0.717 [4690 33.3 [4338 1.68 [7251 1.19 [3830 1.81 [8 97] [8 100]] [8 100]] [8 100]] [8 90]] [8 100]] [8 70]]]] [8 100]] [35 63]] [34 100]] [32 100]] [2628 1.39 [1587 2.2 [35 50] [32 42]] [37 71]]] [37 91]] [34 86]] [13 100]] [0 100]] [2993 7.65 [6048 0.606 [985 0.559 [4693 13.3 [8 80] [8 66]] [978 30.8 [8 100] [8 93]]] [0 50]] [8 50]]] [35 75]] [0 87]] [3597 2.59 [1742 6.7 [2494 0.911 [1899 0.734 [1483 4.94 [2536 1.51 [8 81] [8 100]] [8 100]] [8 100]] [8 100]] [8 80]] [8 90]]] [29 100]] [0 100]] [13 100]] [377 1.36 [3715 1.2 [2268 11.3 [34 93] [791 5.57 [34 53] [34 75]]] [34 100]] [34 100]]] [330 0.701 [5757 1.28 [2897 1.14 [5227 0.81 [1 6.23 [999 13.9 [3997 0.759 [2321 0.336 [2589 3.23 [2143 6.59 [5918 0.511 [4154 0.456 [1980 0.711 [7512 1.19 [3291 0.606 [1429 51.5 [8 100] [8 98]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 80]] [2259 25.3 [8 100] [8 95]]] [8 100]] [8 85]] [8 90]] [12 54]] [328 2.56 [0 87] [0 100]]] [8 82]] [0 80]] [4690 4.34 [0 40] [8 100]]]]] [12 100]] [3069 4.13 [20 1.78 [7176 2.42 [4799 5.26 [1180 5.15 [5692 5.15 [1239 13.2 [8 42] [8 52]] [13 93]] [13 100]] [13 80]] [7176 3.88 [8 83] [8 100]]] [13 100]] [8 100]]] [32 100]] [13 100]] [1429 78.1 [791 5.73 [13 94] [519 5.3 [4533 3.25 [13 100] [4533 5.33 [13 77] [13 100]]] [13 96]]] [13 85]]] [5264 1.19 [665 2.06 [3027 3.46 [1062 2.56 [3134 6.53 [5692 3.56 [7169 6.85 [13 92] [13 90]] [13 83]] [13 66]] [1429 14.7 [13 85] [13 60]]] [13 31]] [13 100]] [13 100]]] [4601 0.528 [2494 4.82 [957 7.49 [7665 2.09 [1888 2.96 [13 53] [8 80]] [6040 0.785 [6082 1.15 [1078 14.4 [13 92] [13 100]] [13 100]] [13 100]]] [13 72]] [0 57]] [0 69]]] [13 100]] [7179 0.164 [2550 0.31 [7169 0.328 [8 81] [8 53]] [8 100]] [8 100]]] [134 0.234 [2939 0.262 [5229 2.46 [3497 2.54 [4690 0.294 [0 35] [0 78]] [0 100]] [0 89]] [35 27]] [0 100]]] [8 100]] [7287 0.246 [867 1.02 [5385 1.99 [4406 2.28 [2334 2.35 [7022 1.59 [7019 1.38 [663 1.42 [2526 21.5 [5753 10.2 [2081 3.95 [2426 2.13 [896 0.975 [1980 2.51 [13 88] [13 100]] [13 100]] [12 57]] [12 55]] [13 50]] [8 97]] [13 100]] [8 97]] [6643 1.98 [13 97] [13 100]]] [8 100]] [13 100]] [8 100]] [13 100]] [8 100]]] [4456 1.49 [2143 8.62 [2897 2.42 [5913 3.59 [6970 3.31 [2426 0.154 [5229 2.13 [2015 0.184 [2488 39.9 [5828 0.238 [2488 8.29 [8 100] [2526 48.2 [8 93] [8 77]]] [3829 0.439 [2494 4.59 [1062 0.238 [3363 0.845 [4279 0.684 [1463 0.928 [2628 1.89 [2259 37.2 [1980 9.74 [8 100] [8 85]] [8 84]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [7210 4.2 [8 88] [8 100]]] [8 100]]] [8 78]] [8 100]] [0 100]] [8 100]] [8 71]] [8 75]] [8 88]] [8 72]] [8 85]]] [2505 0.491 [6643 0.465 [7009 1.01 [5851 0.64 [5968 0.963 [547 1.81 [5692 3.61 [2488 19 [13 46] [34 73]] [3820 1.42 [4235 1.63 [899 0.858 [7566 6.72 [13 89] [13 83]] [13 100]] [13 100]] [13 100]]] [13 100]] [13 100]] [13 50]] [13 100]] [13 100]] [13 100]]] [2062 1.42 [3829 0.68 [2763 0.288 [462 1.76 [2505 0.671 [1025 3.04 [7520 0.645 [2499 0.644 [2081 2.83 [1483 0.379 [2489 0.632 [1071 1.15 [5264 0.713 [7428 1.55 [13 83] [0 62]] [13 100]] [13 100]] [13 53]] [8 61]] [0 55]] [8 53]] [13 100]] [13 100]] [13 100]] [0 66]] [13 45]] [8 78]] [0 57]]] [7512 1.15 [5753 1.48 [0 60] [32 71]] [5138 1.31 [3766 0.355 [728 0.37 [2029 0.297 [3391 0.559 [3480 7.78 [1079 0.478 [6091 7.57 [429 18.7 [20 0.695 [7558 0.583 [1025 1.31 [13 95] [13 100]] [13 100]] [13 100]] [13 100]] [13 88]] [13 100]] [13 85]] [13 100]] [13 100]] [13 100]] [13 100]] [13 66]]]] [13 100]] [1458 0.426 [2081 3.68 [3929 1.12 [5211 5.2 [5692 0.589 [532 3.07 [5402 0.734 [1980 6.73 [957 6.59 [13 83] [13 54]] [13 60]] [13 100]] [13 50]] [4190 0.529 [5260 1.17 [13 97] [13 100]] [13 100]]] [8 38]] [37 73]] [1981 0.858 [13 57] [32 100]]] [7241 0.291 [32 90] [32 100]]]]] [538 0.32 [2605 0.463 [4870 0.125 [202 0.336 [7210 7.98 [2834 0.154 [6833 1.03 [2836 0.644 [221 2.23 [978 1.84 [7381 1.08 [5954 3.94 [915 2.26 [1282 4.67 [7520 1.73 [6180 1.78 [6528 0.48 [616 1.53 [5472 7.22 [5047 1.59 [5994 1.5 [5316 0.994 [3079 4.07 [1592 0.949 [263 3.03 [2929 2.89 [4233 3.55 [5692 1.71 [896 5.08 [181 2.89 [673 1.48 [2662 6.88 [4154 12.5 [2526 8.87 [5099 4.44 [2628 17.7 [7514 2.51 [1429 8.05 [7665 3.18 [4279 2.44 [6199 39 [4533 0.513 [907 3.94 [384 3.88 [635 4.07 [534 3.65 [248 21.6 [3 18] [7742 6.17 [25 88] [25 100]]] [3 100]] [9 92]] [25 90]] [3 83]] [11 38]] [22 21]] [3 54]] [25 44]] [7615 2.09 [429 3.08 [5294 2.86 [1078 30.5 [286 4.59 [2260 2.54 [25 16] [14 42]] [16 33]] [1 40]] [8 37]] [6524 7.73 [5732 1.7 [5891 1.98 [906 13.5 [7665 4.83 [5647 2.96 [2093 1.25 [29 15] [29 37]] [23 37]] [14 39]] [3 44]] [3 55]] [14 25]] [22 57]]] [3 100]]] [19 52]] [1769 6.1 [7 22] [14 50]]] [18 57]] [6457 8.89 [1881 1.77 [2259 19.9 [25 67] [6181 7.58 [6 31] [7 52]]] [25 100]] [25 100]]] [3 33]] [7 100]] [1899 9.71 [25 93] [25 75]]] [25 80]] [184 2.04 [7305 2.65 [392 2.73 [286 3.88 [1239 5.38 [25 53] [18 57]] [25 100]] [14 50]] [25 100]] [25 100]]] [899 1.72 [5695 2.61 [2936 2.46 [2199 1.16 [25 35] [22 42]] [25 100]] [7722 1.53 [25 97] [25 100]]] [14 50]]] [3 100]] [25 86]] [25 91]] [3 100]] [37 92]] [32 36]] [29 47]] [3 100]] [13 60]] [3 100]] [6177 7.74 [25 87] [4704 0.12 [25 97] [25 100]]]] [25 100]] [7 20]] [7 100]] [3 68]] [38 100]] [5692 2.13 [7 41] [7 45]]] [4851 0.787 [731 4.3 [145 12.2 [567 2.35 [248 5.77 [5480 6.7 [25 33] [18 39]] [5969 5.16 [4601 8.02 [7693 0.745 [7185 3.92 [4898 3.27 [7576 0.671 [685 13.2 [25 100] [2913 9.01 [25 93] [25 100]]] [25 100]] [25 77]] [25 85]] [25 100]] [25 56]] [25 71]]] [23 62]] [25 52]] [6524 1.68 [248 11.1 [18 18] [25 86]] [6178 4.76 [25 77] [25 100]]]] [978 16.4 [7 42] [19 54]]]] [2938 0.295 [2939 11.9 [6592 1.18 [25 76] [25 100]] [16 27]] [25 100]]] [2586 1.83 [4159 6.2 [25 100] [6177 15.8 [25 80] [25 100]]] [25 100]]] [2713 1.44 [7 97] [7 100]]] [5753 0.252 [25 97] [25 100]]] [6907 3.11 [534 1.39 [6031 11.4 [1081 2.46 [2616 2.3 [6711 1.67 [695 9.43 [25 12] [36 20]] [3 66]] [25 88]] [25 100]] [22 70]] [3 85]] [25 93]]] [765 2.22 [7343 3.74 [731 5.35 [5432 0.672 [7665 2.78 [144 2.64 [25 92] [25 100]] [25 100]] [25 100]] [25 77]] [25 90]] [25 90]]] [6230 6.44 [6363 0.54 [7428 0.422 [25 85] [21 27]] [7667 0.416 [3424 1.11 [7512 21 [4369 0.655 [5043 1.63 [178 0.821 [25 96] [25 100]] [25 100]] [25 100]] [7512 22.3 [22 62] [25 100]]] [25 87]] [25 100]]] [25 50]]] [432 0.277 [407 10.2 [2752 1.2 [221 3.45 [25 96] [25 100]] [25 100]] [6363 2.16 [25 96] [25 100]]] [25 100]]] [1239 76.4 [7449 13.1 [4768 1.77 [538 14.5 [802 9.44 [9 85] [9 60]] [21 66]] [9 100]] [21 70]] [823 0.135 [791 40.5 [358 10.4 [5480 4.07 [7085 4.73 [9 94] [9 90]] [9 100]] [9 84]] [9 66]] [9 83]]]]] [1726 1.27 [1913 0.551 [7007 0.763 [7287 3.28 [6850 0.172 [2852 3.62 [4478 0.655 [134 1.37 [4539 2.78 [1325 0.58 [37 2.31 [2862 3.91 [2939 4.22 [4154 2.48 [2707 2.03 [38 68] [38 28]] [17 33]] [2875 15.4 [1888 1.18 [7118 2.43 [5784 8.18 [3017 0.861 [7020 13 [1338 7.64 [4663 26.3 [6708 1.23 [7390 0.764 [1429 49 [1253 2.06 [2859 2.13 [2132 1.16 [4956 5.39 [7149 14 [2952 5.54 [1563 2.27 [1981 1.75 [3243 0.344 [2983 8.84 [2870 6.58 [2870 2.82 [429 2.8 [2849 24.1 [2665 15.4 [2955 37.4 [6276 4.05 [1900 4.62 [2259 13.1 [38 100] [38 96]] [2081 2.37 [38 95] [38 100]]] [38 83]] [38 80]] [38 71]] [1860 0.487 [2955 15.6 [7260 14.5 [38 95] [38 83]] [2259 5.7 [38 82] [38 88]]] [38 100]]] [38 77]] [38 100]] [38 86]] [38 73]] [38 100]] [38 80]] [38 71]] [38 70]] [38 60]] [38 55]] [7369 1.54 [38 50] [38 100]]] [38 62]] [2849 10.2 [2939 120 [24 30] [38 75]] [38 88]]] [38 59]] [3027 1.85 [2850 4.91 [4577 7.66 [4009 0.421 [1687 3.64 [38 100] [38 71]] [38 100]] [38 87]] [38 83]] [38 94]]] [28 33]] [38 75]] [38 33]] [1900 4.62 [38 57] [25 40]]] [24 44]] [38 50]] [17 47]] [38 48]] [38 62]]] [1899 0.571 [1789 3.03 [28 30] [17 50]] [4573 2.19 [24 2.37 [1897 3.89 [69 4.95 [1239 25.7 [6879 0.969 [7332 4.57 [6875 11.6 [7134 0.695 [5209 4.59 [2242 3.47 [2862 13.3 [2143 2.01 [2081 8.26 [2686 5.87 [1899 10.3 [7446 4.6 [7260 1.33 [7370 2.11 [38 94] [38 73]] [38 37]] [1997 7.4 [2242 2.65 [2469 5.72 [38 83] [38 100]] [38 90]] [38 83]]] [38 63]] [38 100]] [14 33]] [38 100]] [2241 1.23 [38 50] [2707 11.7 [38 77] [38 100]]]] [2112 3.85 [38 45] [38 81]]] [25 36]] [38 100]] [33 42]] [8 28]] [17 40]] [2851 2.91 [38 69] [8 33]]] [2870 6.55 [2076 7.17 [38 91] [38 57]] [38 60]]] [1895 4.79 [37 38] [1789 1.2 [38 71] [38 45]]]] [16 57]] [14 40]]]] [2686 8.4 [6107 0.278 [3007 2.74 [3551 0.354 [2427 1.79 [1900 9.18 [3905 0.503 [5545 2.15 [7203 0.301 [5600 1.47 [37 3.27 [12 72] [4897 2 [2081 2.17 [1897 3.32 [38 77] [1899 4.79 [38 69] [7472 4.5 [16 40] [5 17]]]] [17 41]] [7017 5.38 [2468 2.09 [38 36] [6824 2.49 [17 66] [5210 2.56 [26 28] [17 57]]]] [38 87]]]] [16 87]] [5673 0.314 [38 76] [19 45]]] [17 46]] [38 100]] [1896 6.85 [17 46] [14 25]]] [69 3.36 [1896 3.11 [38 100] [38 85]] [38 60]]] [2386 3.03 [1563 1.8 [38 100] [38 58]] [6 33]]] [5 53]] [2023 1.61 [2430 2.09 [38 72] [6384 3.43 [4889 0.417 [5673 20 [38 100] [38 75]] [38 100]] [38 80]]] [17 26]]] [2111 0.998 [38 62] [38 100]]]] [16 36]] [4537 9.18 [2887 11.3 [2405 11.2 [2406 5.1 [38 94] [38 77]] [1239 5.29 [38 91] [38 45]]] [38 63]] [5954 6.33 [2939 13.8 [38 100] [38 75]] [187 2.62 [17 81] [38 84]]]]] [2081 0.141 [5 25] [26 75]]] [7084 1.8 [2952 0.773 [3006 2.55 [5 38] [37 44]] [38 66]] [7369 3.93 [5 91] [5 42]]]] [16 60]] [167 1.64 [7474 0.532 [38 62] [7500 1.06 [2732 1.11 [1078 6 [1341 3.8 [23 17.2 [38 100] [38 50]] [1078 2.39 [187 3.2 [38 90] [38 100]] [38 92]]] [38 83]] [38 85]] [7136 5.24 [38 100] [38 90]]]] [1253 2.51 [2748 0.321 [38 97] [38 100]] [38 85]]]] [1262 1.85 [14 66] [17 70]]] [6383 2.92 [16 30] [16 78]]] [4105 1.84 [24 0.518 [2404 1.15 [5673 0.238 [5569 8.47 [7343 1.97 [4920 3.61 [5641 2.16 [23 22.3 [38 60] [2851 3.06 [199 0.601 [8 62] [38 75]] [12 60]]] [7474 7.8 [38 78] [4131 4.71 [38 30] [38 87]]]] [26 57]] [4478 2.93 [7390 1.65 [38 33] [38 55]] [37 66]]] [14 33]] [7390 2.69 [5058 0.173 [5809 0.831 [7419 1.61 [1895 10.1 [38 53] [12 29]] [18 33]] [17 45]] [14 57]] [16 46]]] [4538 65 [38 100] [38 66]]] [24 47]] [8 76]]] [5673 0.877 [2748 1.1 [2691 0.782 [17 25] [17 71]] [7486 3.95 [17 53] [17 87]]] [17 100]]]] [7425 1.89 [6199 3.26 [1373 0.548 [5055 5.48 [5619 3.78 [6684 7.03 [6091 3.56 [5864 1.34 [7428 5.93 [635 1.61 [5278 34.1 [2058 5.05 [660 30.2 [4534 19.3 [6068 9.11 [1757 0.323 [6148 4.95 [506 0.116 [688 34.8 [4898 7.88 [7101 6.8 [688 0.191 [4663 31.2 [524 0.448 [5692 16.9 [6082 1.73 [5937 1.04 [4794 13.2 [21 100] [21 98]] [21 100]] [21 100]] [5692 17 [21 86] [21 100]]] [21 100]] [1899 5.85 [21 100] [7449 8.55 [21 100] [21 75]]]] [21 100]] [906 8.31 [21 83] [21 100]]] [21 62]] [21 96]] [21 100]] [9 64]] [21 66]] [21 98]] [21 80]] [21 88]] [21 90]] [21 81]] [9 50]] [21 91]] [21 94]] [907 14.1 [7343 4.1 [4533 8.93 [5831 1.98 [112 6.16 [919 0.805 [6320 3.18 [517 2.37 [688 8.62 [21 90] [21 100]] [21 100]] [21 100]] [21 100]] [9 82]] [9 100]] [9 83]] [21 100]] [526 2.41 [535 15.8 [21 100] [21 61]] [21 100]]]] [21 62]] [9 94]] [9 54]] [6149 0.115 [6093 0.797 [918 0.843 [4917 1.49 [21 68] [21 100]] [21 92]] [9 100]] [9 66]]] [6320 0.669 [5412 1.51 [4691 0.492 [21 84] [21 100]] [9 70]] [21 100]]] [791 15.9 [9 85] [9 53]]]] [4131 0.31 [2713 16.9 [338 1.15 [2749 0.241 [7038 0.58 [1821 0.573 [1429 27.2 [2628 36.7 [6701 1.22 [2849 22.6 [1079 0.416 [23 11.3 [2585 0.766 [7619 4.2 [685 2.47 [7124 3.32 [7301 5.89 [995 0.485 [6942 7.72 [7731 1.91 [2445 0.803 [5363 1.72 [6959 3.59 [5211 3.49 [5605 0.562 [5597 2.48 [312 6.44 [5753 12.5 [5753 2.62 [1783 4.66 [6 56] [4897 1.17 [16 23] [16 83]]] [5412 3.47 [16 46] [16 22]]] [6 100]] [6 36]] [6098 1.42 [5962 4 [6 71] [6 83]] [6 100]]] [38 28]] [187 10.4 [30 91] [30 66]]] [5626 5.53 [6 80] [6 92]]] [30 75]] [30 66]] [16 55]] [16 40]] [26 100]] [25 53]] [16 62]] [18 41]] [26 42]] [6 100]] [2410 0.522 [685 0.273 [7512 4.76 [30 34] [5100 2.61 [5 36] [6 46]]] [18 33]] [30 100]]] [30 90]] [4882 4.47 [6877 0.863 [301 3.76 [7359 0.58 [429 1.93 [6130 21.9 [6848 3.43 [5724 6.17 [5492 2.54 [2951 0.204 [2661 1.25 [4854 24.5 [5609 2.22 [4897 3.09 [5435 32 [2667 4.35 [4427 3.79 [75 5.44 [90 4.69 [7419 7.19 [37 5.6 [6471 7.8 [5627 4 [4426 8.5 [62 0.436 [7347 6.85 [16 44] [16 37]] [18 28]] [16 62]] [26 28]] [16 91]] [16 76]] [16 77]] [26 55]] [16 100]] [16 81]] [16 90]] [28 45]] [16 95]] [2714 4.17 [16 33] [26 60]]] [6 30]] [16 30]] [6517 0.564 [2259 0.811 [3675 2.71 [1263 1.39 [2656 2.68 [6383 4.48 [5595 11.1 [85 0.186 [5986 14.9 [4414 23.1 [6937 5.28 [5627 1.63 [2752 3.43 [4465 1.53 [64 2.76 [6761 3.87 [5600 1.29 [6 31] [6 60]] [16 69]] [4851 24.8 [18 46] [16 63]]] [5983 12.6 [16 83] [6 50]]] [16 76]] [1783 14.6 [16 78] [16 46]]] [16 87]] [1696 5.36 [6 42] [6 41]]] [6 65]] [18 58]] [18 66]] [16 90]] [4457 2.1 [2727 3.51 [16 46] [18 76]] [2868 1.51 [18 62] [26 38]]]] [6 88]] [7149 5.03 [6 60] [26 57]]] [1997 0.136 [5609 2.27 [2660 2.08 [6199 10.3 [2628 34.7 [16 53] [17 50]] [19 36]] [7150 3.83 [16 100] [16 50]]] [6 45]] [5 30]]] [5192 0.319 [6717 3.31 [2649 2.26 [16 64] [26 31]] [16 80]] [26 63]]]] [14 81]] [4851 12.5 [16 58] [5099 46.2 [6 63] [16 62]]]] [16 23]] [6 100]] [5983 7.54 [4611 0.252 [6920 1.93 [1198 2.92 [2644 1.1 [6121 0.657 [6131 1.21 [5597 1.65 [1981 0.757 [5103 3.89 [18 46] [16 50]] [18 100]] [6 25]] [14 61]] [6 40]] [16 36]] [16 55]] [16 55]] [29 44]] [2709 1.43 [16 66] [16 75]]]] [38 91]] [2259 1.06 [16 57] [30 95]]] [23 64.9 [6406 1.86 [2734 0.582 [4622 19.3 [16 41] [2649 3.7 [187 11.4 [5 75] [5 50]] [6 44]]] [37 55]] [5 53]] [37 83]]] [187 24.5 [6 60] [16 50]]]] [5099 0.83 [6941 2.22 [7 34] [18 75]] [7762 4.72 [7512 1.11 [4414 0.978 [18 92] [4859 2.29 [18 42] [18 87]]] [6 50]] [18 60]]]] [5210 1.05 [6574 3.36 [6007 5.47 [2723 19.8 [6207 2.19 [7123 0.132 [2683 2.24 [2940 2.79 [5753 0.742 [2881 13.5 [2667 4.98 [2653 5.35 [7765 2.51 [4763 9.5 [1769 4.59 [2006 4.63 [76 10.9 [6 52] [16 69]] [5102 0.99 [2143 2.77 [6 55] [6 37]] [6 80]]] [2628 46.7 [16 59] [30 37]]] [6 75]] [7 87]] [16 66]] [16 32]] [16 72]] [6256 8.63 [2709 1.44 [16 54] [6 44]] [18 66]]] [6 82]] [16 51]] [6831 0.262 [3435 3.95 [16 33] [37 55]] [3 45]]] [4763 4.35 [5933 1.39 [2685 2.4 [5799 12.1 [2654 2.62 [16 40] [6 33]] [32 33]] [18 66]] [1429 3.83 [5673 8.39 [16 64] [187 23.5 [16 42] [6 56]]] [18 30]]] [18 90]]] [16 44]] [3239 1.25 [5099 5.52 [16 61] [16 77]] [6 60]]] [17 50]] [7370 2.58 [38 66] [38 55]]]] [1611 0.271 [4896 1.96 [2201 1.45 [5643 1.32 [5723 4.51 [1662 2.4 [2849 37.4 [4889 0.137 [5962 1.6 [7623 2.84 [5931 1.98 [1906 0.595 [5034 0.555 [2752 0.605 [1900 0.62 [663 1.42 [4717 1.18 [6701 1.78 [5099 31.6 [16 11] [26 40]] [18 60]] [16 66]] [16 50]] [3 27]] [18 26]] [28 83]] [16 66]] [6121 3.53 [2884 3.24 [28 22] [5 62]] [5 53]]] [144 4.56 [6406 5.2 [30 77] [30 85]] [30 40]]] [6 75]] [6 81]] [5607 0.879 [2469 1.31 [2656 1.86 [1726 1.45 [17 18] [17 82]] [16 54]] [6 31]] [17 88]]] [19 88]] [60 7.28 [1895 5.91 [6 57] [16 53]] [6 44]]] [6257 1.96 [5435 0.483 [16 27] [16 100]] [18 100]]] [6 100]] [1895 10.1 [2750 1.64 [17 57] [17 50]] [7402 4 [17 82] [17 100]]]] [307 5.63 [30 100] [5214 5.72 [30 100] [30 53]]]]] [7 100]] [1852 0.854 [85 3.11 [4133 0.165 [5624 0.68 [2030 1.78 [5170 0.248 [2695 0.736 [4716 4.42 [7301 5.87 [5681 0.764 [2654 1.54 [2951 9.5 [6380 0.192 [6129 0.209 [791 1.76 [4622 1.93 [6287 0.0968 [2262 0.118 [1783 20.5 [4426 0.502 [6422 4.17 [4673 1.34 [5673 0.516 [7419 8.17 [5851 0.478 [1239 27.8 [16 80] [19 28]] [6 37]] [6 60]] [16 71]] [16 62]] [16 75]] [16 68]] [7041 6.09 [16 33] [6 81]]] [6933 2.33 [16 90] [16 60]]] [16 75]] [37 50]] [1899 3.78 [663 3.85 [2849 22.6 [6 60] [26 37]] [6 42]] [18 57]]] [6 75]] [6 68]] [4426 5.22 [6515 0.773 [2733 2.96 [2275 0.536 [2753 1.3 [1374 1.35 [2716 0.362 [2678 0.286 [16 39] [6 44]] [6 72]] [16 72]] [6 66]] [6 100]] [7101 1.41 [37 30] [4821 1.37 [16 77] [37 57]]]] [6 100]] [2979 2.8 [6 45] [6 100]]]] [7665 1.96 [16 90] [7 40]]] [5396 3.58 [7734 1.06 [5188 0.277 [5797 6.25 [2866 6.69 [1900 2.06 [1320 4.84 [2178 0.278 [1646 4.81 [2569 1.27 [7104 3.07 [7419 5.92 [193 6.78 [4427 5.25 [5568 4.1 [3061 0.176 [2940 17.2 [2279 2 [6517 1.46 [429 11.1 [5593 2.24 [1383 0.633 [4889 0.443 [2709 3.19 [6371 0.489 [2259 34.6 [91 6.34 [5007 0.701 [6940 14.6 [5898 0.154 [685 0.971 [194 1.49 [6 55] [6 42]] [18 60]] [6 33]] [16 57]] [16 62]] [16 50]] [16 35]] [16 88]] [16 67]] [5412 0.0493 [2939 30.7 [16 100] [16 71]] [16 77]]] [18 57]] [6 60]] [6 50]] [18 50]] [18 60]] [6 50]] [16 100]] [6 54]] [6 66]] [18 34]] [2729 0.62 [1078 0.402 [16 73] [6 33]] [16 33]]] [18 52]] [4514 1.49 [6514 1.94 [6 45] [16 50]] [6 80]]] [4889 0.33 [16 88] [16 83]]] [2681 0.538 [7445 0.247 [1239 46.2 [6371 6.32 [3238 0.287 [7260 1.7 [16 90] [16 77]] [16 70]] [16 37]] [6 57]] [7206 0.401 [16 33] [26 42]]] [16 100]]] [16 100]] [5007 0.575 [2412 1.83 [16 72] [14 42]] [16 80]]] [2939 38.8 [2869 0.65 [16 63] [5 50]] [37 62]]] [30 75]] [7 83]] [5408 0.246 [18 66] [19 53]]] [18 66]]] [6 73]] [1268 0.894 [1783 14.9 [5102 6.58 [2764 3.18 [7203 6.55 [6 77] [6 77]] [6 50]] [6 53]] [6 47]] [16 81]]] [30 68]] [2713 1.54 [6 50] [5099 21 [26 85] [26 71]]]] [6687 1.34 [91 4.44 [5643 0.213 [4717 6.49 [1888 0.425 [7149 0.549 [6 88] [190 2.77 [6 100] [6 85]]] [6 66]] [16 63]] [6 50]] [1429 3.87 [6 50] [16 63]]] [16 76]]] [1429 13.3 [6 72] [6 100]]] [38 100]] [18 92]] [7 73]]] [7445 3.71 [1899 0.581 [5721 0.129 [6848 6.77 [5673 6.7 [7512 2.7 [26 57] [5192 1.78 [4205 10.9 [6199 0.555 [26 90] [26 100]] [26 71]] [26 75]]] [2707 3.71 [6 66] [26 76]]] [16 35]] [5723 2.86 [6 56] [16 77]]] [1837 0.317 [94 0.738 [5438 0.109 [673 7.32 [26 83] [26 100]] [26 100]] [26 57]] [26 57]]] [6 58]]] [429 5.39 [5931 0.423 [1078 2.87 [26 71] [26 93]] [26 100]] [6199 1.45 [2951 3.07 [896 0.684 [23 1.74 [26 66] [38 37]] [26 100]] [16 53]] [26 100]]]] [23 1.66 [6129 1.48 [2984 18.4 [2628 23.4 [6 32] [1783 3.21 [5626 11.5 [5101 8.4 [2713 18 [6 74] [5090 6.75 [2178 6.6 [6 57] [2713 22.8 [6 62] [5102 33.5 [6 100] [6 85]]]] [16 50]]] [5100 9.11 [6 77] [6 100]]] [5626 19.2 [6 92] [6 66]]] [6 32]]] [16 55]] [16 45]] [190 17.6 [4879 7.98 [2006 4.12 [1259 1.22 [7169 2.13 [4739 3.75 [301 18.5 [7153 1.37 [6 37] [16 55]] [30 100]] [6 57]] [16 43]] [19 42]] [18 54]] [1256 11.6 [1261 1.08 [4854 26.5 [6 86] [16 55]] [16 50]] [16 80]]] [94 0.766 [6 50] [26 70]]]]] [6953 3.98 [38 50] [1897 2.01 [4896 1.45 [1687 13.6 [17 100] [17 58]] [17 100]] [2242 0.942 [17 100] [17 85]]]]]] [5904 0.809 [4717 0.867 [1218 0.868 [2470 4.32 [6826 0.186 [119 0.855 [809 0.392 [435 1.27 [4769 0.381 [5040 6.04 [7176 1.62 [169 8.17 [580 1.1 [5103 0.293 [5131 0.59 [6397 4.27 [4694 1.76 [5987 7.9 [7623 10.7 [6524 0.506 [896 3.23 [957 8.03 [802 2.72 [4507 26.5 [685 30 [6911 3.52 [6199 20.7 [397 0.167 [788 7.22 [4663 2.01 [6134 0.079 [7168 4.37 [1089 5.79 [4541 0.852 [168 2.27 [324 3.79 [7245 1.86 [2983 5.05 [7281 6.96 [7085 1.39 [4977 6.57 [2005 1.84 [1601 1.13 [5157 3.59 [2081 10.9 [4517 3.75 [3251 0.329 [6883 1.03 [5154 0.448 [560 45.5 [2259 11.2 [152 1.71 [1919 0.393 [4647 2.46 [389 3.76 [1025 1.37 [6732 1.36 [5099 13.9 [18 74] [18 55]] [1078 14.6 [18 88] [18 71]]] [18 33]] [18 66]] [18 100]] [18 94]] [18 100]] [18 54]] [18 100]] [18 62]] [18 42]] [18 33]] [18 44]] [26 42]] [18 57]] [18 100]] [18 37]] [384 1.95 [18 41] [6 42]]] [16 25]] [6 37]] [16 57]] [383 2.43 [19 45] [17 33]]] [16 70]] [18 38]] [18 100]] [22 38]] [3 70]] [5 30]] [3 20]] [7354 2.2 [2259 22.2 [18 100] [18 75]] [18 100]]] [2526 3.24 [5484 1.99 [18 100] [18 84]] [18 100]]] [9 62]] [16 47]] [1429 6.99 [16 50] [6 44]]] [16 47]] [21 35]] [1899 14.6 [18 76] [18 40]]] [6042 10.3 [2062 0.641 [1186 0.338 [4601 5.15 [6766 1.57 [6696 0.44 [281 2.53 [407 8.23 [5516 1.99 [724 6.89 [4860 12.5 [279 7.68 [7491 5.44 [429 74.4 [429 29.9 [2849 7.05 [7737 5.74 [7185 19.3 [2617 0.411 [5160 1.73 [791 13.8 [5482 5.85 [695 4.05 [18 100] [7520 0.986 [18 72] [18 100]]] [2813 1.67 [18 78] [18 60]]] [18 61]] [18 61]] [18 66]] [18 42]] [5480 5.43 [18 80] [1078 1.95 [18 90] [18 100]]]] [18 60]] [328 6.54 [18 88] [18 60]]] [18 42]] [6 57]] [18 58]] [16 36]] [18 50]] [18 57]] [18 44]] [5692 5.25 [1888 1.67 [18 52] [16 71]] [18 63]]] [18 100]] [19 64]] [26 61]] [7425 1.41 [5413 0.155 [2978 1.27 [896 16.4 [5140 0.169 [7737 0.383 [1888 1.51 [18 60] [18 92]] [18 100]] [18 100]] [18 100]] [18 83]] [18 100]] [18 62]]] [18 41]] [18 46]]] [5480 11.8 [6 37] [22 75]]] [12 88]] [6 71]] [8 100]] [145 0.77 [29 66] [29 83]]] [6123 1.88 [5013 0.705 [7255 4.95 [281 17.3 [1675 2.22 [5007 16.7 [7731 6.57 [788 17.7 [4568 7.22 [1626 2.69 [1696 3.82 [5516 10.8 [6373 2.93 [328 19 [5597 1.78 [132 21.4 [6332 0.894 [5723 0.618 [1899 3.71 [560 38.9 [384 4.35 [106 1.36 [5612 7.6 [5873 2.42 [282 8.52 [7260 1.13 [2445 0.937 [1011 4.17 [324 1.33 [18 90] [18 88]] [18 81]] [18 100]] [18 100]] [6658 10.6 [18 61] [18 89]]] [18 100]] [18 70]] [18 100]] [791 7.32 [6353 1.25 [18 70] [18 81]] [6659 4.46 [18 100] [18 88]]]] [18 50]] [5894 0.766 [2526 11.8 [18 58] [18 88]] [18 50]]] [18 100]] [6 57]] [279 13.5 [896 1.77 [18 83] [18 66]] [16 60]]] [18 55]] [18 55]] [18 50]] [16 75]] [16 50]] [16 71]] [38 57]] [6 60]] [5480 22.4 [18 77] [18 100]]] [19 42]] [16 63]] [16 50]] [560 3.09 [19 31] [788 6.71 [5484 1.21 [18 47] [7512 19.2 [132 1.06 [18 68] [2707 4.58 [18 70] [18 80]]] [18 50]]] [2707 7.78 [16 68] [26 57]]]]] [19 54]] [16 80]]] [929 0.295 [1661 2.43 [2841 0.996 [896 0.423 [4977 0.98 [2671 3.18 [195 1.1 [5103 7.54 [18 45] [16 87]] [18 77]] [16 76]] [16 62]] [2752 2.68 [19 40] [731 2.33 [2707 5.67 [18 66] [26 63]] [18 84]]]] [30 37]] [663 0.469 [18 55] [18 100]]] [16 70]]] [9 60]] [6659 0.435 [19 70] [18 50]]] [7241 3.76 [896 0.873 [18 51] [1062 12.6 [6230 0.924 [728 2.18 [429 23.1 [2259 7.29 [18 100] [18 71]] [429 46.4 [18 100] [791 22.9 [18 100] [18 83]]]] [18 100]] [18 100]] [18 87]]] [560 8.33 [22 69] [18 100]]]] [21 61]] [29 100]] [1104 0.677 [7699 0.654 [18 30] [18 50]] [29 66]]] [22 100]] [22 100]] [18 90]] [1078 8.72 [248 14.7 [4 33] [26 100]] [26 69]]] [2526 5.4 [2705 0.423 [4500 0.494 [29 66] [29 100]] [29 100]] [18 44]]] [6940 5.1 [5155 1.36 [2152 1.02 [194 0.869 [5131 0.834 [6832 0.622 [18 100] [18 57]] [16 33]] [6923 0.368 [190 8.07 [7260 6.53 [4926 0.888 [5484 2.6 [6658 1.47 [5901 2.19 [5130 1.43 [13 36] [16 88]] [16 50]] [16 93]] [18 64]] [276 0.38 [16 100] [16 57]]] [328 1.44 [4762 1.95 [16 50] [18 40]] [22 42]]] [18 88]] [6 57]]] [18 50]] [18 71]] [18 91]]] [5888 2.14 [939 0.451 [4568 3.62 [90 0.505 [7516 0.56 [5288 0.441 [6724 13.4 [6659 2.62 [1177 1.06 [6230 1.49 [5931 0.699 [5904 11.9 [1888 11.7 [18 57] [18 89]] [19 64]] [16 57]] [7185 1.19 [19 83] [19 62]]] [18 80]] [132 5.94 [1062 5.88 [685 3.96 [276 6.92 [19 100] [19 66]] [18 62]] [19 83]] [18 50]]] [19 75]] [19 80]] [18 80]] [19 100]] [19 100]] [2707 3.08 [1429 14.7 [19 77] [19 40]] [19 100]]] [19 85]]]] [3016 0.0956 [3018 0.532 [4959 0.218 [1011 0.0445 [6816 1.63 [5732 0.5 [5117 0.247 [5211 1.44 [6988 0.545 [4755 1.86 [1710 0.469 [5848 0.365 [4964 2.09 [5770 0.259 [4929 4.55 [2253 0.773 [5771 0.12 [3454 1.14 [1239 13.1 [791 17.2 [1389 2.09 [2081 8.93 [1841 0.176 [3130 2.2 [978 2.62 [6342 1.5 [4 21] [24 37]] [2 42]] [4 53]] [10 25]] [1 50]] [24 100]] [11 29]] [6378 2.2 [2232 2.61 [2761 0.539 [2 20] [2 83]] [15 62]] [22 36]]] [11 100]] [134 5.73 [3695 4.24 [4279 4.51 [6088 0.217 [1995 0.571 [228 2.69 [2 45] [23 1.38 [312 6.99 [6342 0.441 [2 47] [4 50]] [2 33]] [4 68]]] [2 75]] [2 100]] [7665 5.35 [2 40] [2 66]]] [13 77]] [2 94]]] [1453 0.492 [8 30] [22 60]]] [527 12.5 [4929 16.7 [4 65] [4 37]] [4 91]]] [978 6.17 [7620 1.18 [1436 0.519 [6582 0.191 [4288 2.17 [5771 16.3 [1576 0.726 [5576 5.32 [6538 2.82 [1025 30.9 [791 28.4 [5575 20.8 [4 78] [4 44]] [2 83]] [2 62]] [2 33]] [2 62]] [2 52]] [2 66]] [2 75]] [4 100]] [4 37]] [4 100]] [144 4.94 [5238 7.69 [4 89] [4 71]] [2 55]]]] [4964 5.11 [4851 4.78 [2268 0.545 [1594 3.63 [4 88] [4 62]] [4 66]] [4 71]] [7285 0.482 [4 88] [4 100]]]] [7520 0.605 [5819 3.07 [7449 1.29 [731 1.82 [4 96] [4 100]] [4 100]] [4 55]] [4 100]]] [7210 5.63 [30 100] [30 71]]] [6960 4.96 [4154 1.62 [15 58] [22 50]] [2 58]]] [7327 0.464 [1078 7.04 [4601 0.657 [361 0.633 [2939 28.3 [4324 6.76 [291 11.8 [5040 1 [1919 0.502 [6990 0.621 [2 70] [7032 6.19 [2 100] [2 87]]] [573 5.19 [5660 6.11 [2752 1.54 [429 2.79 [2 94] [2 100]] [6732 6.77 [2 100] [3667 2.73 [2 98] [2 100]]]] [2 90]] [4235 4.99 [2 92] [2 77]]]] [2 68]] [4 55]] [4832 6.32 [2 100] [2 70]]] [5771 28.9 [2 50] [2 74]]] [2 100]] [2 100]] [3571 4.68 [2674 16.4 [4345 2.52 [2760 6.6 [1095 4.8 [1040 2.09 [145 8.44 [2108 5.73 [1110 0.403 [514 7.54 [2939 19.2 [4225 0.288 [5238 0.826 [25 5.75 [2178 0.51 [2675 3.91 [5574 12.9 [7009 0.511 [328 0.745 [6989 2.17 [2 92] [6926 5.11 [2 100] [2 85]]] [2 100]] [2 100]] [2616 2.87 [2 80] [1025 3.18 [2 100] [2 88]]]] [1429 19.2 [2 100] [2 85]]] [2 100]] [2 81]] [2 80]] [2 100]] [2 93]] [2 77]] [2 100]] [2 83]] [2 78]] [2 58]] [2 85]] [2 70]] [6989 3.45 [2 55] [2 100]]] [20 57]] [2 77]]] [4 94]]] [7385 1.72 [2675 0.56 [11 57] [2 91]] [6054 2.85 [22 68] [22 100]]]] [11 100]] [4585 1.64 [3130 4.5 [5753 0.215 [24 65] [24 41]] [13 91]] [24 100]]] [665 20.1 [6199 9.67 [1000 0.251 [6791 9.65 [4585 3.17 [6192 0.593 [4414 1 [6816 4.47 [4324 4.23 [2 100] [2 83]] [2 100]] [2 100]] [2 100]] [2 75]] [6732 4.35 [2 100] [2 81]]] [2 100]] [2 54]] [2 62]]] [5240 0.568 [3660 1.78 [649 0.609 [2553 0.299 [1089 1.59 [6989 0.183 [4228 1.33 [643 1.17 [4748 0.318 [25 1.87 [4684 1.38 [7590 2.4 [5770 0.756 [4533 0.428 [7677 1.55 [1429 12.8 [731 0.279 [2 88] [2 45]] [1011 2.1 [4 66] [24 24]]] [2 30]] [2 30]] [4414 1.64 [7381 4.29 [4 72] [4 50]] [4 62]]] [4 85]] [6347 0.334 [2 64] [2 85]]] [7185 5.81 [4 68] [4 100]]] [2 77]] [2 83]] [23 88]] [7494 2.5 [5848 0.287 [7413 0.307 [2033 0.276 [1429 30.7 [5913 1.86 [7305 0.875 [2939 0.136 [2 75] [5320 1.72 [1910 4.53 [6977 2.86 [5659 0.0648 [1108 2.85 [2902 9.33 [1011 4.99 [2 100] [7712 1.42 [1640 3.81 [2 66] [7568 0.743 [791 1.36 [6816 11.2 [4991 3.36 [2 93] [2 100]] [2 83]] [6538 14 [2 100] [2 90]]] [2 100]]] [2 100]]] [2 92]] [2 85]] [2 100]] [2 75]] [2 88]] [2 75]]] [2 88]] [2 75]] [2 70]] [4991 1.64 [4 37] [2 100]]] [736 3.25 [23 14 [5769 1.12 [6537 5.07 [2 100] [2 88]] [2 100]] [2 66]] [2 75]]] [4 92]] [2 54]]] [7032 0.34 [2902 5.34 [4832 6.57 [5918 0.333 [2674 0.0445 [978 19.5 [719 0.121 [4 68] [4 87]] [2 70]] [1911 2.78 [2 89] [2943 1.93 [2 85] [4 62]]]] [4 88]] [2 100]] [2 100]] [7032 1.53 [2 85] [2 100]]]] [4325 0.975 [719 6.87 [4158 3.91 [6999 0.658 [4992 4.7 [6310 0.138 [1025 18.1 [4414 0.147 [5411 4.08 [2 100] [144 8.1 [2 100] [2 85]]] [2 100]] [1899 7.39 [2 85] [2 100]]] [2 75]] [2 71]] [2 80]] [2 83]] [2 81]] [5819 1.09 [2 75] [2 100]]]] [1919 0.6 [4 83] [2 57]]] [24 100]] [4 100]]] [728 3.47 [7020 4.74 [1584 2.42 [1225 0.982 [6375 1.35 [4 100] [4 90]] [4 60]] [4 70]] [4 66]] [4 66]]] [2771 0.661 [7722 0.87 [1980 1.08 [2526 12.1 [24 100] [24 89]] [24 100]] [24 100]] [24 81]]] [23 24.9 [3337 0.769 [6337 4.33 [7301 4.56 [7535 1.4 [3650 4.04 [208 3.1 [1205 6.85 [3368 25.6 [5733 8.55 [1062 6.41 [4041 16.7 [5574 9.73 [24 100] [24 94]] [24 80]] [5728 0.164 [24 77] [5789 0.221 [24 87] [24 100]]]] [24 79]] [3659 6.49 [24 100] [24 70]]] [1888 1.86 [5736 2 [24 55] [5574 17.7 [605 17 [38 58] [24 100]] [24 85]]] [24 100]]] [19 57]] [24 55]] [20 0.338 [1047 15.5 [2324 1.32 [2958 4.22 [978 0.236 [3008 8.37 [2421 3.76 [24 100] [24 62]] [24 100]] [24 100]] [24 87]] [24 87]] [24 55]] [24 84]]] [24 70]] [19 50]] [19 57]] [2958 2.44 [24 99] [24 100]]]]] [906 2.54 [4219 0.469 [7390 1.23 [2993 5.49 [4210 0.477 [916 0.722 [7314 0.14 [590 3.6 [695 1.08 [2624 3.82 [802 0.537 [4282 1.99 [2962 0.666 [4895 0.0511 [1592 1.33 [5673 14.3 [1400 0.69 [4684 3.6 [1011 2.42 [6447 0.276 [2700 2.62 [4418 1.61 [2266 1.29 [5034 2.46 [328 0.79 [6579 0.907 [7701 3.94 [1870 2.49 [31 37] [7 100]] [31 100]] [31 100]] [2526 4.03 [18 22] [23 31]]] [32 55]] [31 100]] [12 38]] [31 100]] [7 100]] [7561 3.07 [5368 4.08 [1899 1.39 [7169 2.59 [31 95] [31 70]] [31 78]] [31 55]] [31 100]]] [3 33]] [5222 1.57 [6406 0.818 [5480 4.11 [4326 4.44 [2752 29.5 [3829 2.44 [1239 14.9 [7585 7.07 [7169 1.68 [6174 1.02 [328 13.3 [5270 1.81 [6390 2.11 [1025 1.31 [2939 2.89 [429 45 [2752 23.8 [31 99] [31 88]] [31 83]] [31 100]] [31 100]] [31 100]] [31 100]] [31 90]] [31 100]] [31 100]] [31 83]] [31 50]] [3931 5.88 [31 88] [31 100]]] [31 60]] [31 91]] [31 88]] [31 92]] [10 100]]] [16 36]] [3 100]] [7 23]] [3727 0.709 [2482 1.1 [1980 4.91 [31 100] [31 96]] [31 100]] [31 100]]] [3 100]] [3 63]] [3 100]] [6173 0.403 [4288 1.58 [6077 0.452 [5482 0.366 [6342 4.9 [1400 3.51 [1062 7.61 [5368 2.87 [7308 1.59 [7559 0.617 [7585 2.04 [685 1.57 [31 55] [12 22]] [31 100]] [31 58]] [31 100]] [13 44]] [31 53]] [4308 1.98 [5267 0.956 [325 0.675 [2962 1.31 [6855 2.65 [660 2.39 [31 92] [31 77]] [31 100]] [31 100]] [31 100]] [31 100]] [31 100]]] [31 50]] [1078 7.78 [18 100] [2526 4.14 [18 75] [16 57]]]] [6735 4.43 [5879 1.66 [5476 1.14 [734 0.467 [5320 17.6 [5670 0.949 [4587 1.22 [5412 7.77 [31 100] [5753 1.64 [6853 3.94 [31 95] [31 100]] [31 100]]] [31 100]] [31 100]] [31 90]] [31 100]] [13 100]] [31 100]] [31 55]]] [7697 2.59 [6074 4.14 [5403 6.06 [31 62] [31 71]] [31 100]] [31 100]]] [160 0.589 [144 13.5 [31 100] [31 88]] [31 100]]]] [802 3.36 [4282 5.38 [3 50] [3 100]] [3 100]]] [5978 0.938 [1592 1.34 [7512 7.99 [3 85] [31 59]] [3 100]] [31 100]]] [3 92]] [5753 0.79 [3 91] [3 70]]] [4154 1.95 [31 80] [5976 1.56 [3 81] [3 100]]]] [38 92]] [3 100]] [6103 1.05 [6853 2.54 [7623 3.28 [518 0.88 [6579 2.49 [7571 2.79 [3768 1.28 [906 44 [7512 8.78 [4925 8.93 [906 6.49 [1239 3.83 [3 41] [1987 0.876 [1986 3.07 [1062 2.95 [2081 12 [5047 0.732 [5368 1.56 [5976 0.967 [3 66] [3 100]] [9 62]] [3 100]] [3 60]] [3 57]] [3 100]] [3 55]]] [7140 1.36 [5937 2.01 [312 1.27 [4454 4.45 [429 40.4 [3 85] [5404 0.642 [2624 1.86 [7452 3.07 [3 92] [3 70]] [3 62]] [3 100]]] [3 100]] [3 77]] [21 100]] [3 100]]] [21 62]] [1888 10.2 [31 44] [31 80]]] [21 66]] [13 100]] [31 100]] [31 100]] [21 92]] [31 96]] [31 88]] [429 32.1 [31 100] [31 43]]]]] [2470 1.8 [6187 0.239 [695 0.693 [4865 0.137 [5093 0.385 [4145 0.329 [2426 0.258 [2826 0.103 [6178 0.271 [491 0.124 [537 0.259 [4114 13 [1240 0.72 [3262 1.81 [2752 5.99 [2955 0.0618 [4690 1.17 [803 0.406 [5110 1.49 [6098 1.1 [939 5.32 [802 5.79 [5891 0.169 [2549 0.169 [5482 0.688 [144 11.8 [2468 0.209 [3019 0.161 [190 0.319 [1645 0.0984 [5170 2.3 [6581 2.03 [7623 76.2 [2917 6.33 [5598 0.336 [3622 0.0287 [5703 0.77 [7034 1.64 [7540 1.27 [4891 2.18 [616 1.65 [5403 0.911 [5976 0.531 [7032 1.08 [6648 0.531 [4315 0.0958 [6809 1.18 [1600 0.84 [3768 1.31 [4159 0.808 [248 4.6 [168 6.14 [4778 0.192 [5682 2.51 [3155 0.135 [3088 1.19 [6484 0.0479 [1696 1.64 [2707 1.22 [7665 2.2 [957 2.48 [6064 1.27 [5255 0.445 [4682 1.96 [2143 3.03 [534 0.618 [6772 0.446 [1638 0.478 [1713 0.202 [429 0.362 [6899 2.27 [4154 2.74 [3667 13.9 [6506 4.67 [5965 1.2 [2849 0.0773 [2628 0.12 [1737 1.42 [6331 0.475 [4444 4.62 [287 4.76 [4092 1.77 [7095 6.46 [1634 1.98 [7615 5.51 [2499 3.14 [5590 8.2 [5732 5.82 [4655 0.684 [1617 1.64 [4851 1.44 [2488 5.24 [1708 0.265 [752 15.6 [1116 10.1 [2359 5.75 [788 1 [1913 38.6 [357 4.42 [232 2.89 [1 17] [25 52]] [30 100]] [1996 11.2 [1248 1.04 [1 25] [29 66]] [1 92]]] [18 37]] [1239 10.2 [7 83] [7 100]]] [30 95]] [30 100]] [4395 9.09 [1445 3.35 [3130 4.27 [28 70] [33 42]] [13 55]] [28 100]]] [4414 22.4 [6068 1.85 [383 11.5 [5769 4.18 [663 5.88 [8 52] [13 62]] [2 50]] [8 100]] [2 83]] [34 64]]] [7139 4.85 [5034 2.54 [23 32.5 [4684 23.5 [4895 1.43 [2939 0.73 [30 15] [17 42]] [14 53]] [23 40]] [4 50]] [30 100]] [32 45]]] [10 100]] [7729 0.684 [6524 21.9 [1 100] [1 75]] [1 100]]] [1567 7.25 [227 12.8 [28 31] [5732 42.1 [24 100] [24 93]]] [28 83]]] [30 100]] [8 100]] [216 2.89 [3 80] [3 91]]] [4895 6.74 [13 97] [13 95]]] [15 100]] [1025 30.4 [35 77] [35 52]]] [4559 3.23 [32 96] [32 100]]] [4680 13.8 [4235 12.2 [2130 9.96 [2048 7.55 [1 42] [1 69]] [1 83]] [1 50]] [33 50]]] [7469 3.53 [6082 0.6 [11 47] [11 66]] [15 54]]] [20 92]] [2526 14.3 [221 47.8 [5723 5.26 [7765 15.6 [5539 6.94 [7512 2.76 [2656 8.2 [6155 26.5 [328 4.21 [1436 31.8 [30 9] [7 54]] [7 12]] [30 80]] [18 50]] [10 50]] [13 95]] [13 56]] [16 66]] [4 41]] [4 37]]] [301 13.5 [6031 6.73 [1268 3.4 [6779 6.07 [95 2.58 [7017 3.18 [2251 3.45 [5641 8.85 [1783 25.5 [5632 10.7 [5368 13.4 [38 21] [38 38]] [16 77]] [1997 4.44 [166 13 [6449 4.13 [1841 0.517 [6688 8.53 [1837 3.15 [5894 14.7 [187 2.62 [1660 3.18 [33 20] [16 33]] [16 78]] [18 57]] [18 66]] [6 54]] [13 60]] [17 33]] [6 57]] [18 44]]] [16 42]] [16 72]] [38 93]] [4739 2.39 [78 3.94 [16 26] [18 64]] [18 50]]] [37 58]] [6 70]] [13 55]] [37 47]]] [3 100]] [7 100]] [1429 31 [35 85] [35 70]]] [3849 4.14 [3576 5.02 [5762 1.18 [1170 3.06 [2525 5.88 [4342 2.02 [217 1.96 [2118 14.6 [2342 10.2 [4332 43.7 [1623 2.59 [1301 6.71 [2916 5.31 [7225 9.09 [3559 2.86 [1634 0.686 [1672 1.12 [4326 11.1 [1934 4.27 [1783 1.63 [2421 5.88 [5809 3.14 [2526 25.5 [1899 66 [2268 21 [5679 12.2 [4183 13 [2122 20.1 [33 6] [24 87]] [32 95]] [14 62]] [19 57]] [23 33]] [8 30]] [24 38]] [24 100]] [3308 0.0861 [1436 1.63 [4703 10.6 [5851 4.23 [2628 4.76 [5898 2.56 [1459 1.14 [2216 1.05 [33 32] [25 33]] [3 33]] [6 33]] [4279 2.99 [2 20] [24 37]]] [1239 0.849 [20 27] [21 33]]] [33 50]] [32 24]] [2199 0.234 [11 23] [10 57]]]] [2 85]] [27 25]] [22 100]] [13 100]] [32 85]] [22 100]] [26 76]] [33 87]] [11 100]] [27 88]] [34 27]] [24 58]] [10 74]] [24 96]] [24 100]] [4768 35 [27 71] [10 50]]] [5267 4.74 [22 100] [22 81]]] [15 72]] [35 82]]] [2232 3.27 [3279 11.9 [2241 5.52 [221 3.37 [1980 28.6 [33 73] [29 50]] [33 79]] [33 90]] [33 55]] [33 100]]] [5943 0.169 [5158 1.42 [5034 4.66 [3223 1.29 [4092 0.174 [906 4.42 [5202 0.226 [6266 4.13 [3073 3.99 [2461 1.81 [811 2.37 [791 0.25 [3222 3.54 [134 4.36 [976 1.46 [1285 1.58 [5860 1.46 [6344 3.46 [635 3.82 [7512 7.76 [4282 2.9 [338 4.52 [756 1.95 [3151 4.59 [3462 1.08 [4761 11.5 [6181 3.4 [1429 21.9 [4154 13.1 [2684 7.25 [8 8] [4 100]] [3 21]] [7247 6.67 [3972 16.5 [8 18] [8 100]] [27 88]]] [3 56]] [12 79]] [0 73]] [21 100]] [3 76]] [26 78]] [4282 17.3 [3 75] [3 90]]] [10 35]] [9 80]] [15 100]] [0 100]] [9 85]] [27 100]] [2081 4.69 [0 20] [22 71]]] [8 94]] [5467 1.87 [5862 0.508 [4631 3.82 [831 1.64 [6063 0.258 [5735 3.5 [2523 0.948 [7031 17.3 [4627 0.197 [3849 0.518 [5225 2.15 [3151 0.16 [4799 9.17 [1623 0.29 [5419 1.84 [915 0.296 [5462 16.6 [223 9.31 [35 5] [2 80]] [35 46]] [4282 4.85 [21 48] [3 100]]] [15 96]] [11 100]] [32 70]] [21 100]] [112 2.76 [22 68] [1078 18 [22 100] [22 87]]]] [35 89]] [1899 1.88 [10 51] [10 100]]] [3022 46.3 [24 100] [24 91]]] [5851 1.58 [7428 1.59 [24 72] [36 80]] [36 71]]] [13 93]] [22 98]] [3008 7.85 [35 93] [35 55]]] [2008 2.51 [2081 5.84 [11 85] [11 100]] [11 100]]] [0 100]] [6621 3.88 [12 81] [12 100]]]] [504 5.26 [10 65] [10 28]]] [27 84]] [26 80]] [24 82]] [9 76]] [163 10.3 [517 6.17 [5037 3.74 [1239 9.07 [6524 23.9 [1400 3.22 [5322 11.1 [7335 11.1 [6131 8.32 [2701 5.26 [3292 7.12 [7449 50.6 [907 1.54 [3849 2.92 [3310 10 [3 18] [23 80]] [906 11.6 [35 60] [35 100]]] [21 78]] [21 83]] [37 100]] [29 83]] [9 71]] [21 63]] [21 78]] [12 39]] [22 64]] [614 1.26 [607 7.87 [6997 2.37 [620 18.1 [6897 2.47 [915 4.55 [5756 7.99 [793 1.43 [1907 11.6 [5046 19.9 [569 9.74 [5322 1.39 [21 53] [21 78]] [9 50]] [3 85]] [3 40]] [9 78]] [21 100]] [739 5.26 [21 74] [21 62]]] [9 56]] [3 100]] [3 80]] [3 100]] [9 100]]] [9 65]] [21 90]] [3 85]]] [3438 13.8 [3099 1.6 [1899 11.1 [4154 2.73 [4956 12.7 [630 0.645 [35 84] [35 100]] [35 83]] [35 69]] [35 100]] [30 37]] [35 71]]] [2536 2.15 [4014 1.29 [1483 4.56 [0 53] [8 100]] [8 100]] [8 100]]] [968 2.37 [112 1.77 [4210 7.04 [1116 8.4 [30 55] [30 100]] [30 100]] [30 92]] [2259 44.1 [4414 31.7 [28 80] [9 57]] [15 28]]]] [4098 2.86 [37 95] [37 100]]] [28 95]]] [4611 0.202 [31 97] [31 100]]] [14 100]] [2253 0.298 [6638 1.37 [30 86] [30 66]] [5989 2.82 [30 93] [30 100]]]] [5673 3.4 [5575 1.89 [1899 2.18 [1869 1.63 [5799 5.62 [4626 2.67 [7438 9.52 [6306 1.54 [42 4.67 [3 99] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 100]]] [1189 2.04 [5529 1.03 [3003 0.349 [1831 0.5 [1628 0.313 [4154 0.397 [2944 3.64 [5499 2.56 [1244 3.25 [5040 1.55 [6199 9.62 [1980 1.81 [5412 0.425 [978 3.2 [3576 25 [5972 6.49 [2225 8.07 [6287 5.16 [2151 1.55 [5762 2.2 [2029 15.1 [6091 4.19 [7169 34.4 [2180 3.72 [429 0.759 [2167 11.7 [6342 1.4 [7078 9.36 [1 22] [1 88]] [25 21]] [35 50]] [2145 40.3 [11 8] [21 53]]] [1 57]] [1 54]] [1 60]] [35 61]] [10 100]] [1963 0.874 [1813 10.6 [2056 7.29 [2069 4.35 [2039 12.6 [3794 5.98 [1 23] [29 100]] [30 44]] [1 33]] [29 37]] [28 42]] [29 42]]] [12 66]] [1 38]] [9 38]] [15 66]] [4 17]] [5692 1.05 [23 10.1 [28 13] [21 42]] [3 44]]] [2002 13.2 [2178 2.15 [3667 11.8 [3873 1.07 [1249 4.67 [5642 5.65 [5911 12.7 [7428 0.495 [2939 0.522 [4557 5.96 [2167 4.38 [2148 4.5 [2138 20.3 [4205 10.8 [6976 2.49 [3474 3.24 [915 2.76 [7254 19.1 [2227 3.79 [5151 2.9 [3463 11.9 [2701 1.4 [1987 5.9 [1 19] [21 56]] [29 57]] [35 87]] [31 88]] [1 33]] [33 90]] [21 43]] [4 33]] [11 100]] [28 72]] [29 100]] [23 77]] [2081 5.17 [1 66] [1 25]]] [7 70]] [1454 1.02 [2939 20.9 [29 12] [10 27]] [15 25]]] [10 17]] [29 87]] [18 52]] [29 43]] [32 100]] [35 86]] [4948 0.226 [5491 10.4 [4414 32.2 [6638 0.28 [1094 31.2 [1106 20.3 [2248 14.7 [2156 26.5 [3931 1.09 [5270 2.85 [4338 2.73 [2054 0.071 [3032 2.13 [2064 1.41 [1997 1.64 [2130 1.59 [2299 4.83 [1957 3.27 [3450 1.67 [5368 0.722 [5692 1.35 [29 19] [9 30]] [33 36]] [35 100]] [35 62]] [4 22]] [29 50]] [2113 1.46 [4587 0.325 [1239 57.8 [2212 2.16 [3435 5.97 [2178 60.1 [1 15] [11 75]] [29 66]] [13 33]] [29 39]] [7 100]] [18 40]]] [2276 3.31 [1106 8.24 [2064 13.9 [2108 8.32 [29 30] [29 76]] [23 23]] [15 55]] [29 57]]] [24 71]] [22 35]] [23 100]] [429 6.76 [11 60] [23 37]]] [1 41]] [23 25]] [35 64]] [1 29]] [2180 6.71 [1 41] [1 34]]] [30 100]] [29 51]] [2143 11.3 [1 90] [1 55]]] [1447 0.161 [1239 11.9 [11 88] [6 37]] [30 94]]]] [4414 40.4 [791 10.5 [1 15] [21 60]] [2081 69.7 [1 31] [29 64]]]]] [35 38]] [21 73]] [2253 5.35 [2091 2.33 [2178 3.65 [35 47] [29 36]] [35 80]] [11 53]]] [30 100]] [4663 2.79 [2146 3.65 [7210 4.79 [21 75] [21 50]] [21 95]] [21 88]]] [907 7.29 [5504 0.197 [418 5.81 [5564 1.14 [4290 3.07 [2149 6.5 [392 4.85 [4832 4.44 [7185 1.56 [743 7.81 [1672 1.38 [2254 3.74 [2259 27.2 [1917 0.606 [3130 1.13 [906 4.9 [5368 1.72 [7255 2.36 [7329 6.44 [7512 13 [978 0.93 [1099 0.949 [6294 0.0494 [1943 1.39 [1458 0.267 [2042 3.85 [2062 0.381 [3 13] [23 33]] [2 28]] [23 27]] [1 33]] [25 36]] [28 63]] [23 53]] [10 71]] [2 42]] [32 62]] [38 36]] [3 43]] [29 28]] [3 38]] [6276 0.935 [1445 7.32 [3281 4.26 [2028 1.83 [10 9] [25 33]] [14 42]] [31 42]] [10 42]]] [19 57]] [22 100]] [21 92]] [2297 1.19 [5 22] [31 87]]] [2 70]] [2225 0.164 [18 50] [25 40]]] [2072 0.674 [4331 19.3 [7241 0.639 [7449 2.34 [15 27] [28 55]] [27 44]] [15 58]] [19 25]]] [26 84]] [14 100]] [28 88]] [10 100]] [3 100]]] [29 100]] [7210 4.71 [30 100] [30 75]]] [27 100]] [15 100]] [3790 1.01 [28 100] [28 75]]]] [233 9.8 [33 74] [33 90]]] [10 99]] [5762 0.59 [22 92] [22 100]]] [6659 2.62 [6156 0.861 [429 38.2 [2461 0.952 [7737 3.65 [3282 4.21 [1171 2.2 [4627 1.42 [1913 0.14 [7078 4.55 [5612 4.88 [6482 1.02 [3008 4.06 [775 1.31 [560 10.6 [6562 3.12 [5480 1.06 [5211 13.8 [1400 31.5 [4323 2.06 [2007 1.04 [7634 5.49 [2091 4.16 [6653 3 [3530 1.77 [4630 17.2 [7255 12.2 [4478 2.18 [1908 9.97 [2434 2.18 [5541 6.46 [398 10.4 [978 13.3 [6349 1.36 [3474 1.29 [1992 4.92 [5753 17.3 [286 6.29 [3675 2.58 [27 23] [5 61]] [27 58]] [1 42]] [27 50]] [37 50]] [10 91]] [8 66]] [27 100]] [13 100]] [18 60]] [16 31]] [34 50]] [16 36]] [34 71]] [27 100]] [28 42]] [27 72]] [27 100]] [10 100]] [27 100]] [10 100]] [30 96]] [10 31]] [21 53]] [278 6.49 [18 87] [18 87]]] [27 100]] [28 30]] [13 100]] [18 100]] [10 100]] [7169 2.65 [34 24] [38 30]]] [10 100]] [27 88]] [2143 2.26 [27 91] [27 100]]] [10 96]] [27 100]] [7169 15.8 [4323 1.01 [631 4.35 [5267 2.73 [2180 2.78 [4375 2.65 [6791 35.8 [928 0.864 [3319 1.63 [6087 4.35 [2913 8.47 [2108 1.73 [1182 3.23 [7314 9.8 [4665 20.8 [7061 4.67 [1995 20.4 [2461 1.08 [6406 30.7 [3282 1.92 [791 10.4 [6466 8.4 [5288 1.38 [27 79] [27 100]] [27 100]] [1429 12.7 [10 32] [957 27.4 [37 24] [32 50]]]] [27 100]] [27 100]] [27 100]] [27 91]] [12 83]] [27 100]] [32 44]] [27 100]] [27 95]] [5 62]] [27 100]] [27 100]] [27 92]] [7 33]] [32 50]] [27 100]] [10 60]] [28 100]] [27 100]] [27 50]]] [10 94]] [328 5.24 [18 66] [18 66]]]] [1366 1.14 [1356 5.11 [6186 0.0445 [2616 0.425 [2913 2.21 [1389 1.14 [3067 0.797 [2701 4.99 [1426 2.58 [1025 3.09 [6643 1.44 [7405 1.13 [2331 5.31 [1239 23.6 [6333 3.18 [7133 1.83 [5034 1.87 [1078 4.39 [1400 9.04 [7583 1.87 [2488 8.71 [4663 7.25 [5316 6.3 [7514 12.2 [7533 20.1 [2081 5.56 [3432 15.7 [4154 21.2 [7585 2.26 [3905 3.65 [4446 0.69 [7525 2.76 [2526 7.73 [6524 3.46 [2259 23.9 [6006 28.7 [5485 1.51 [3130 3.22 [5430 5.91 [7142 11.6 [14 15] [20 100]] [5 90]] [4 33]] [4859 0.754 [18 84] [18 57]]] [1 90]] [5769 2.73 [2268 2.67 [36 26] [7687 4.56 [19 21] [19 75]]] [17 42]]] [7 30]] [7 15]] [3 100]] [31 100]] [3917 35.8 [14 31] [14 81]]] [7722 9.5 [2259 30.9 [14 70] [36 83]] [36 54]]] [5753 5.38 [791 3.11 [5410 12.4 [24 17] [20 57]] [24 60]] [5 25]]] [36 100]] [7722 16.4 [1980 41.5 [2259 25.5 [20 17] [2241 1.11 [2081 22.7 [1980 2.89 [16 27] [3 82]] [26 20]] [3 23]]] [20 42]] [20 54]]] [14 82]] [144 4.01 [19 66] [22 40]]] [32 42]] [3 43]] [13 66]] [23 42.9 [429 6.02 [1 36] [36 47]] [1 75]]] [6732 7.04 [7512 52 [14 52] [14 81]] [36 85]]] [4781 0.868 [1083 12.5 [731 5.13 [404 12 [7012 2.44 [4270 2.2 [7698 2.22 [4243 0.99 [6732 9.47 [7109 1.54 [6666 0.816 [7554 3.08 [6544 5.63 [4851 8.29 [328 9.98 [2629 0.846 [7323 2.3 [4765 4.89 [6529 5.33 [6350 1.56 [7685 9.51 [6261 6.37 [10 9] [36 100]] [20 88]] [10 100]] [36 60]] [13 100]] [8 90]] [791 6.07 [10 100] [10 57]]] [14 21]] [7 40]] [14 60]] [10 92]] [10 92]] [36 100]] [646 5.75 [36 29] [36 100]]] [20 100]] [36 91]] [36 100]] [13 100]] [19 50]] [1062 5.35 [5 27] [6 40]]] [2 100]] [5254 1.32 [10 41] [10 100]]]] [4242 1.52 [861 2.04 [3113 2.51 [4279 13.5 [663 22.8 [4154 14.1 [14 59] [32 90]] [32 71]] [32 78]] [32 88]] [32 100]] [20 100]]] [4 100]] [5 36]] [1253 4.02 [5350 5.08 [7675 3.94 [221 16.5 [6776 1.89 [802 2.37 [1997 3.62 [5435 4.61 [534 1.55 [1023 9.16 [756 3.11 [2259 5.81 [33 21] [4233 3.5 [6 38] [3 100]]] [3 100]] [6 69]] [3 100]] [3 90]] [14 37]] [10 100]] [3 88]] [6 70]] [6 100]] [7512 13.1 [6 90] [6 100]]] [13 21]]] [1651 3.31 [4801 3.94 [5034 9.43 [36 85] [32 100]] [32 100]] [36 100]]] [7405 20.3 [6 100] [6 60]]] [13 79]] [1525 1.69 [7381 6.97 [7520 15.6 [3653 3.55 [5999 1.52 [4594 1.96 [527 15 [5413 5.56 [221 11.6 [4338 5.38 [1011 2.28 [6230 9.22 [5480 6.47 [4611 9.27 [5833 3.7 [13 41] [13 100]] [7 42]] [2 36]] [14 50]] [4 26]] [2 33]] [4 45]] [24 100]] [4 100]] [4 54]] [10 50]] [24 84]] [1025 19.9 [13 87] [13 36]]] [931 3.7 [2 63] [2 87]]] [13 100]]] [1980 1.59 [10 85] [10 100]]] [1253 0.931 [5883 3.61 [221 3.51 [1986 5.67 [7664 2.61 [1101 1.27 [13 35] [29 91]] [10 100]] [29 100]] [29 100]] [29 94]] [29 100]]] [36 100]] [1047 9.69 [7566 5.05 [791 11.3 [24 70] [6859 6.32 [24 98] [24 93]]] [24 66]] [3642 1.17 [24 100] [24 80]]]] [4309 1.44 [203 1.83 [4851 14.5 [731 2.37 [3113 0.792 [44 30.2 [1239 19.8 [2251 0.45 [6131 9.21 [2628 7.97 [7724 0.975 [7463 1.44 [2916 10.1 [3931 2.38 [32 58] [32 100]] [25 76]] [32 100]] [25 83]] [32 36]] [19 72]] [25 42]] [3 45]] [3 77]] [32 100]] [5 71]] [7 66]] [19 66]] [32 100]]] [4214 4.97 [4832 0.711 [5851 0.481 [4513 7.25 [6063 0.726 [7449 1.43 [7421 3.83 [2388 0.395 [6743 2.62 [791 9.28 [221 0.792 [1454 2.59 [6166 2.73 [2259 32.7 [7413 1.34 [7381 8.47 [1007 4.44 [978 4.26 [1023 10.4 [6 13] [2 50]] [4 60]] [13 38]] [2 83]] [4 47]] [6422 3.07 [7505 10.2 [1303 24.9 [5609 11.6 [1899 25.8 [1338 1.34 [6 80] [6 100]] [6 61]] [6 100]] [6 64]] [6 100]] [6 92]]] [6 94]] [6 100]] [6 67]] [2 17]] [18 41]] [6 100]] [5610 2.24 [5396 28.5 [2616 62.7 [6829 5.25 [6424 4.27 [1429 53.9 [791 2.39 [6 97] [6 100]] [6 82]] [6 75]] [6 85]] [6 70]] [6 80]] [6 66]]] [1062 4.67 [7451 15.5 [7 26] [25 40]] [2 50]]] [22 100]] [6 88]] [4 24]] [2556 1.58 [2 48] [4 100]]] [24 100]]] [731 11.1 [7381 22.3 [2 88] [2 61]] [2 70]]] [6 95]] [6 95]]] [2611 3.18 [4743 1.23 [7149 0.884 [311 0.905 [2951 0.92 [301 10.1 [1675 1.54 [1899 0.252 [2722 6.12 [2707 37.4 [1868 5.28 [7475 4.5 [4851 13.7 [4725 8.11 [1341 12.9 [61 2.89 [7255 6.75 [3677 0.551 [5491 3.76 [2688 7.46 [6877 4.42 [2023 0.986 [1701 2.95 [6256 8.55 [2691 15.2 [2081 13.9 [16 31] [25 26]] [1395 23.7 [7 50] [16 37]]] [18 53]] [6 60]] [38 40]] [37 42]] [38 86]] [2707 19.2 [14 100] [14 91]]] [5 75]] [16 56]] [38 100]] [38 100]] [6 75]] [1587 2.36 [6 45] [6 60]]] [38 73]] [22 100]] [1078 3.13 [7260 1.78 [5578 1.02 [2691 10.2 [5099 0.942 [16 40] [2939 91.1 [0 2.59 [6 66] [6 94]] [16 72]]] [16 62]] [6 90]] [6 38]] [6 33]]] [16 81]] [7491 1.39 [5007 2.39 [1436 0.355 [2729 5.02 [16 29] [16 100]] [328 2.19 [2111 0.991 [38 58] [38 45]] [28 35]]] [16 36]] [16 83]]] [1445 1.79 [5099 7.38 [6 66] [6 88]] [18 78]]] [6409 13.4 [30 79] [30 100]]] [5103 10.9 [7369 2.56 [2849 3.23 [4768 3.6 [4939 5.26 [38 35] [38 44]] [38 56]] [191 4.35 [7372 13.5 [7419 1.2 [5724 0.283 [2649 2.87 [3929 6.33 [6342 13 [5480 1.54 [6574 6.85 [5438 1.67 [4684 0.644 [2006 2.6 [2662 14.4 [1896 5.24 [6942 7.53 [4414 18.2 [4017 10.5 [6779 5.35 [38 32] [5 57]] [38 80]] [16 58]] [6942 22.7 [14 23] [6 33]]] [6199 18.7 [38 46] [38 80]]] [16 60]] [25 33]] [38 66]] [16 68]] [17 88]] [18 57]] [38 83]] [37 80]] [16 32]] [16 82]] [16 68]] [16 86]] [30 100]]] [38 57]] [2849 31.3 [16 80] [18 54]]]] [7203 2.37 [7763 1.51 [28 83] [16 37]] [28 64]]] [5626 6.15 [7048 7.05 [3008 4.91 [5007 1.91 [2081 2.82 [6717 5.96 [6445 3.82 [6136 4.06 [16 34] [6 42]] [14 30]] [16 50]] [7260 6.45 [18 23] [18 66]]] [18 48]] [1 23]] [16 62]] [2707 18.4 [6 75] [16 36]]]] [16 100]] [6 68]]] [2868 9.66 [1062 7.59 [4854 6.33 [2466 3.79 [3008 1.07 [3835 8.96 [26 74] [2939 6.04 [26 89] [26 100]]] [26 50]] [26 28]] [6 42]] [18 31]] [16 66]]] [2100 2.22 [6459 0.0479 [7445 2.81 [4398 1.55 [25 65] [27 85]] [25 72]] [25 95]] [27 71]]] [3554 3.27 [3905 8.85 [37 93] [3374 31.9 [37 100] [37 92]]] [37 100]]] [2208 5.47 [437 6.58 [35 75] [14 30]] [35 64]]] [3983 4.94 [5147 4.93 [38 90] [4889 2.89 [38 97] [38 100]]] [38 67]]] [5989 0.64 [2181 0.429 [6353 1.58 [15 99] [15 100]] [15 100]] [15 87]]] [168 52.8 [216 1.3 [6131 9.9 [682 1.68 [2143 22.6 [5386 6.39 [6294 12.7 [6575 5.49 [1587 13.2 [177 1.65 [5462 2.33 [2342 12.2 [4308 6 [4571 5.26 [1391 4.2 [1079 6.64 [4326 7.77 [1997 4.21 [168 9.78 [20 33] [1783 0.949 [19 25] [18 20]]] [14 63]] [19 37]] [2081 3.27 [19 81] [14 25]]] [13 45]] [19 91]] [19 60]] [17 36]] [28 66]] [7512 21.7 [429 9.64 [19 66] [19 57]] [19 93]]] [33 50]] [26 75]] [28 40]] [13 81]] [14 50]] [13 100]] [26 40]] [19 73]] [19 63]]] [251 4.88 [4946 1.7 [4704 8.93 [6899 4.14 [426 0.669 [5011 0.322 [6483 1.47 [2701 2.21 [5491 5.3 [4377 2.01 [6063 3.76 [1400 7.77 [673 0.543 [6524 2.41 [1698 5.38 [1638 2.81 [5345 1.35 [6862 6.27 [2124 3.6 [5701 0.678 [3100 2.33 [6472 1.79 [1708 3.03 [5531 2.38 [6784 1.97 [1078 1.69 [2894 4.27 [3714 4.2 [1783 25.3 [7665 2.37 [5360 3.94 [1742 17 [4655 6.02 [4778 0.785 [4682 1.17 [3929 3.82 [2081 17.2 [7009 4.76 [7305 2.79 [392 5.1 [2081 0.994 [4781 5.95 [2892 5.26 [6074 4.78 [5019 4.42 [2280 22.3 [7255 28.8 [7314 12.1 [23 79 [33 21] [33 56]] [3 20]] [33 69]] [1 80]] [3 71]] [13 66]] [33 68]] [8 57]] [1451 5.38 [791 12.9 [1 14] [2 45]] [2 27]]] [26 41]] [24 37]] [25 43]] [1 23]] [12 87]] [33 69]] [15 100]] [1 100]] [33 42]] [33 100]] [25 19]] [1445 6.18 [4897 3.11 [2259 11.8 [5769 4.97 [33 33] [28 37]] [2023 7.25 [4768 9.74 [6791 2.96 [1886 1.43 [13 36] [15 50]] [33 50]] [2 66]] [13 50]]] [13 29]] [30 23]]] [26 100]] [33 88]] [3834 2.26 [2488 10.7 [2215 0.414 [5593 1.56 [4478 3.35 [4768 2.07 [7446 4.73 [1 17.9 [1995 20.3 [6353 13.4 [7207 6.38 [2263 10.9 [5270 2.71 [1079 6.79 [6776 1.24 [250 3.88 [2225 8.63 [1429 22.5 [25 23] [2055 2.07 [33 16] [15 42]]] [1 61]] [35 33]] [15 42]] [8 33]] [32 36]] [14 23]] [10 55]] [18 33]] [15 63]] [11 33]] [12 57]] [2 22]] [1062 0.956 [2 53] [25 28]]] [1 83]] [2 70]] [13 92]] [26 71]]] [31 100]] [13 66]] [28 71]] [5632 0.367 [26 71] [26 100]]] [1 100]] [4338 0.678 [33 81] [33 100]]] [31 72]] [33 67]] [10 50]] [14 100]] [25 84]] [2526 21.6 [7583 7.83 [4658 1.71 [25 47] [1 88]] [1 74]] [25 79]]] [2259 5.63 [2259 0.543 [5695 6.58 [4200 7.94 [4611 0.578 [5692 11.4 [26 35] [26 66]] [26 100]] [26 91]] [5695 8.07 [1 80] [25 52]]] [26 80]] [6 23]]] [338 6.75 [1078 35.7 [4611 6.44 [26 49] [26 100]] [25 63]] [26 92]]] [1445 1.99 [22 93] [22 100]]] [791 2.01 [25 94] [25 100]]] [6328 1.79 [25 51] [11 50]]] [4611 2.54 [567 1.15 [29 86] [29 94]] [29 100]]] [13 100]] [2003 0.778 [2143 0.709 [1239 3.62 [800 0.322 [29 65] [29 100]] [29 53]] [29 100]] [29 100]]] [1 71]] [248 35.2 [33 92] [33 77]]] [6406 6.87 [1453 2.15 [7084 11.7 [233 7.41 [23 12 [33 44] [7329 2.89 [33 50] [248 13.8 [33 83] [33 57]]]] [1722 5.75 [33 83] [33 100]]] [33 66]] [26 30]] [33 100]]] [18 90]] [4655 12 [7254 8.5 [248 11.1 [33 75] [1 42]] [33 62]] [1 87]]]] [806 0.774 [2201 2.97 [2526 0.247 [1340 0.469 [3073 0.949 [2701 0.229 [4313 7.69 [1237 0.832 [2002 11.1 [3308 1.42 [4214 36.7 [444 0.482 [4200 21 [3931 4.09 [5462 1.33 [1998 3.94 [4852 0.48 [23 85.1 [731 1.69 [5412 13.7 [3794 1.99 [1166 3.7 [2081 5.1 [1995 1.01 [2001 8.13 [1980 34.2 [1925 4.88 [5211 0.108 [112 10.8 [29 32] [29 71]] [22 36]] [26 25]] [29 53]] [23 78]] [15 25]] [23 1.02 [2009 13 [2297 1.15 [7210 3.02 [440 0.763 [4292 11.1 [29 15] [4154 67.8 [15 57] [4292 58.4 [1 64] [23 44]]]] [15 40]] [23 33]] [2 71]] [26 35]] [2259 29.8 [29 19] [29 88]]]] [1 91]] [29 100]] [28 86]] [4 100]] [29 88]] [29 100]] [12 44]] [25 12]] [23 69]] [26 100]] [4601 0.933 [27 55] [26 100]]] [29 100]] [5412 7.04 [4768 0.974 [4337 15 [4154 20.7 [6082 2.13 [2 18] [10 72]] [4 37]] [22 55]] [2 28]] [4 36]]] [3 57]] [29 97]] [3 100]] [4768 23.2 [2298 0.705 [1104 2.99 [29 97] [29 85]] [29 100]] [29 62]]] [26 95]] [6960 1.07 [33 0.907 [11 31] [4 54]] [11 70]]] [5693 1.74 [2199 14.6 [4704 0.222 [4428 5.35 [2628 5.66 [8 25] [4 46]] [1 66]] [10 38]] [12 52]] [1078 1.19 [18 42] [2 70]]]] [5753 1.33 [4279 2.51 [1114 6.53 [4320 2.47 [27 37] [27 100]] [27 90]] [4161 8.61 [2245 8.52 [29 21] [15 44]] [15 44]]] [10 36]]] [26 96]]] [13 100]] [7 100]] [32 100]] [27 100]] [2274 0.226 [2071 0.212 [4517 1.02 [1899 24.9 [7330 16.2 [30 100] [30 85]] [1239 8.08 [30 80] [30 100]]] [30 88]] [6717 0.39 [30 100] [30 84]]] [30 83]]] [7594 1.05 [2973 4.27 [3936 4.27 [2178 9.26 [7457 2.16 [2700 5.75 [7265 0.337 [245 4.07 [4081 2.13 [3115 3.86 [6732 0.559 [5007 32.4 [6997 10.5 [1253 6.52 [643 3.34 [1986 2.91 [7428 4.74 [2939 1.16 [7512 3.2 [5267 0.736 [13 25] [2 50]] [7745 3.18 [2560 29.7 [2 37] [2 85]] [4 50]]] [978 12.1 [4 48] [4 100]]] [23 71]] [21 77]] [2 66]] [2 50]] [31 100]] [2 80]] [2 65]] [31 100]] [31 100]] [31 100]] [2 77]] [31 100]] [31 90]] [2 100]] [2330 7.94 [31 85] [31 100]]] [31 98]] [2 84]]] [3 100]] [3931 2.28 [2178 7.83 [1980 0.512 [1239 0.756 [6521 0.59 [7464 5.59 [6999 14.6 [7381 5.15 [5034 2.46 [4663 14.8 [2267 2.39 [7255 3.44 [7587 1.08 [682 1.42 [6174 2.03 [31 75] [31 100]] [31 100]] [31 100]] [31 63]] [31 100]] [31 64]] [3 63]] [2 45]] [31 100]] [3 100]] [31 100]] [3 78]] [3 37]] [3 78]] [31 100]]] [791 16.4 [6199 2.35 [3 98] [3 100]] [3 84]]] [6205 2.38 [2268 11.2 [6 78] [16 66]] [19 44]]] [7121 6.83 [4673 27.6 [2275 10.9 [6167 0.826 [1911 8.2 [896 3.55 [663 5.75 [2526 4.85 [6 60] [1059 13.2 [6 86] [6 62]]] [6 100]] [6 90]] [6 100]] [6 100]] [6 71]] [4674 43 [6 95] [6 73]]] [6 100]]] [7594 3.7 [7255 0.891 [1051 2.65 [2574 11.1 [7544 6.66 [2939 12.1 [7009 4.68 [2 70] [13 100]] [4 42]] [2 91]] [2 83]] [2 100]] [4369 1.37 [1239 3.35 [7210 15 [13 98] [13 71]] [13 66]] [13 100]]] [2 76]]] [6429 0.986 [791 17.2 [13 100] [1083 1.09 [2488 8.34 [13 50] [13 100]] [13 100]]] [13 100]]] [4154 8.91 [7343 2.37 [7665 0.717 [1451 8.79 [5007 0.0287 [7449 1.65 [2189 0.281 [2218 0.583 [2002 1.43 [4279 1.65 [2241 24 [23 7.89 [29 75] [29 62]] [29 57]] [29 87]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 50]] [29 33]] [20 50]] [29 96]]] [1783 24.8 [2081 3.28 [5637 1.42 [2618 2.04 [1335 4.83 [4 4.72 [2611 10.4 [4414 20.9 [1429 18.6 [7149 13.7 [6138 0.971 [685 1.91 [6959 2.35 [6114 19.3 [1078 21.5 [2713 4 [7153 2.16 [2005 0.982 [1382 4.62 [4716 8.16 [6 74] [6 62]] [6 100]] [6 85]] [6 100]] [6 57]] [6 56]] [6 100]] [16 77]] [16 33]] [6 100]] [34 33]] [6423 7.59 [6 85] [6 71]]] [6 38]] [4675 5.26 [6 86] [6 100]]] [6 100]] [6 96]] [16 100]] [6 57]] [7512 3.94 [16 31] [6 82]]] [16 57]]] [372 20.1 [3 73] [3 50]]] [3667 0.962 [4071 1.08 [2207 4.48 [7626 11 [3843 7.52 [5799 3.55 [7343 1.85 [4444 14.3 [2106 3.37 [1956 3.31 [7641 19.6 [2628 25 [2123 27.2 [3323 4.61 [2913 5.45 [328 2.32 [7665 4.53 [4663 17.9 [3993 2.73 [2020 29.1 [2219 0.924 [1445 1.63 [1239 92.9 [35 28] [35 89]] [1 66]] [1 72]] [7623 168 [35 47] [35 80]]] [1 53]] [1 51]] [0 13]] [35 46]] [26 40]] [35 40]] [35 100]] [38 41]] [1 53]] [35 84]] [4414 25.7 [7630 19.1 [3694 7.52 [2033 3.14 [35 67] [35 50]] [25 33]] [35 48]] [37 44]]] [9 36]] [35 67]] [5799 20.1 [23 28] [16 42]]] [35 75]] [1783 1.83 [7626 41.7 [5673 2.26 [7628 13.7 [2241 2.02 [35 63] [35 77]] [35 81]] [2225 2.26 [35 80] [35 66]]] [35 33]] [35 54]]] [7629 3.55 [2023 1.15 [35 75] [35 88]] [35 63]]] [35 64]] [2023 5.03 [429 23.9 [35 90] [35 50]] [35 77]]]] [2658 1.14 [6757 0.986 [2417 3.6 [980 3.1 [2616 7.52 [1400 2.56 [7665 3.22 [1646 3.34 [6959 4.8 [6964 3.12 [6984 2.35 [7267 2.56 [7139 0.802 [3917 3.14 [25 3.88 [5637 5.45 [5692 6.78 [7380 2.13 [4 31] [4 100]] [17 45]] [26 44]] [4 100]] [19 92]] [32 33]] [4 100]] [4 100]] [26 90]] [13 36]] [3 66]] [3315 3.31 [7404 0.894 [7384 8.41 [738 8.93 [5410 14.1 [7381 5.88 [2950 2.62 [485 2.61 [7014 4.51 [1769 46.9 [3835 7.9 [5732 10.6 [4718 10.1 [4851 38.3 [3734 7.55 [1023 2.54 [647 1.47 [2588 29.4 [5833 16.1 [6581 43 [5753 1.47 [141 6.24 [6588 3.37 [7620 2.11 [6552 2.09 [1210 8.15 [978 1.47 [19 20] [19 31]] [5 75]] [4 90]] [5 87]] [5 41]] [19 70]] [5 57]] [5 46]] [17 44]] [19 81]] [5 66]] [17 36]] [17 87]] [5 44]] [1429 13.9 [5 70] [5 100]]] [17 50]] [26 87]] [17 56]] [5 64]] [2591 2.14 [16 37] [38 80]]] [5 85]] [7253 2.39 [5316 0.756 [1546 2.09 [736 9.45 [17 39] [5 41]] [5 100]] [1429 35.2 [17 70] [6388 0.756 [17 47] [38 66]]]] [5 63]]] [4 50]] [17 63]] [17 69]] [16 85]] [5 90]]] [1888 2.54 [26 69] [36 52]]] [7588 3.65 [5 45] [6587 8.85 [1769 2.18 [2616 22.6 [4851 10.1 [978 5.68 [5 85] [5 70]] [5 20]] [5 61]] [5 80]] [5 53]]]] [26 100]] [7185 4.9 [3027 13.4 [4 88] [4 100]] [4 63]]] [30 36]] [4 100]]] [3635 0.637 [144 3.14 [896 0.73 [178 9.35 [685 2.04 [6959 6.69 [6528 16.5 [285 0.724 [7124 0.787 [4682 0.219 [7729 6.01 [2526 12.5 [1429 6.51 [5360 1.49 [5462 1.19 [251 2.54 [5801 6.62 [5176 23.7 [7640 2.2 [4684 1.57 [5617 5.88 [6458 7.04 [33 70] [25 80]] [30 50]] [33 85]] [1 66]] [7665 6.02 [33 83] [26 70]]] [26 66]] [33 66]] [33 57]] [214 1.72 [5702 0.428 [33 98] [33 100]] [33 83]]] [5989 0.253 [7642 1.24 [2939 8.93 [4154 5.29 [4851 2.51 [1757 1.61 [5178 2.64 [7623 1.45 [1722 5.49 [33 41] [33 100]] [33 77]] [33 93]] [248 9.96 [33 66] [33 100]]] [18 40]] [71 4.28 [7623 10.2 [6791 1.71 [33 80] [33 100]] [33 62]] [33 100]]] [33 46]] [33 100]] [1841 3.66 [14 33] [14 37]]]] [1867 3.45 [33 44] [33 88]]] [6524 12.6 [1 75] [1 100]]] [6058 3.74 [5244 4.55 [7208 16.6 [5302 0.392 [6844 16.3 [248 1.16 [2259 12.6 [4338 2.07 [33 91] [33 100]] [33 100]] [5573 0.635 [4802 1.74 [1980 0.355 [33 97] [33 100]] [33 100]] [33 80]]] [33 66]] [33 100]] [33 85]] [33 76]] [33 75]]] [16 58]] [4353 1.9 [33 87] [33 60]]] [1 83]] [13 31]] [377 6.86 [5435 7.03 [396 9.92 [187 1.42 [1239 2.24 [26 55] [6 20]] [26 66]] [26 81]] [26 90]] [38 55]]] [5196 3.11 [6189 13.7 [26 58] [26 71]] [33 100]]] [2983 2.75 [2526 17.1 [26 86] [26 70]] [26 70]]] [26 58]] [1 68]]] [2226 0.328 [1886 1.08 [23 0.588 [1980 0.911 [15 98] [15 100]] [15 100]] [15 72]] [15 92]]] [6959 4.19 [2403 1.5 [89 2.92 [5170 1.19 [5099 1.9 [4663 11.8 [23 14 [2862 7.42 [2469 4.42 [2951 18.1 [38 54] [190 9.27 [38 77] [16 23]]] [38 81]] [38 30]] [4622 3.82 [2241 1.98 [5189 3.03 [7343 3.98 [24 4.76 [1395 8.95 [4851 2.18 [2112 5.53 [5593 2.65 [2714 6.91 [2852 11.3 [5716 5.51 [2656 2.96 [6074 0.975 [1897 2.02 [38 34] [5637 2.04 [38 38] [17 55]]] [5 33]] [190 16.4 [16 25] [16 60]]] [16 69]] [6 66]] [16 48]] [16 75]] [38 75]] [16 19]] [6 44]] [16 100]] [5931 22.3 [2656 1.93 [167 5.45 [16 32] [6574 11.1 [165 17.4 [14 50] [16 50]] [14 62]]] [5801 26 [62 7.41 [16 58] [16 75]] [6517 3.36 [16 30] [26 69]]]] [6 31]]] [38 86]] [5210 1.14 [23 28.1 [7 40] [16 44]] [7484 3.7 [38 72] [38 62]]]] [88 4.29 [16 72] [37 42]]]] [38 100]] [7169 6.36 [2707 17.6 [6422 1.11 [16 47] [16 50]] [1395 4.83 [1897 16.8 [6 38] [14 42]] [6 55]]] [6 57]]] [26 60]] [38 85]] [5957 0.944 [38 95] [38 81]]] [7279 2.58 [1837 2.22 [5642 8.43 [5368 0.278 [5724 12.2 [1239 33.3 [6499 2.51 [16 77] [4527 9.3 [16 48] [16 88]]] [6 38]] [4854 13.3 [16 45] [6 72]]] [16 58]] [16 100]] [6 60]] [26 36]]]] [1783 19.2 [6573 35.2 [24 90] [2259 10.8 [6573 39.2 [24 83] [24 62]] [24 53]]] [24 98]]] [2403 8.36 [4538 4.26 [38 51] [2887 11.1 [7241 9.99 [7369 5.75 [38 94] [38 85]] [38 84]] [2869 9.52 [1808 1.97 [38 100] [38 75]] [38 55]]]] [2403 8.59 [17 41] [7475 7.55 [38 77] [2884 2.42 [2405 9.55 [17 37] [5678 5.35 [38 100] [2872 7.1 [38 60] [19 60]]]] [38 75]]]]]] [6607 7.94 [1221 4.78 [5402 1.4 [978 1.84 [4770 0.0823 [4326 0.156 [4745 3.98 [7739 1.44 [1684 6.8 [6009 4.13 [430 0.637 [7722 1.49 [83 6.67 [5260 4.42 [1885 5.32 [2930 18.7 [859 6.46 [534 1.64 [44 0.5 [169 15.6 [3429 6.02 [155 0.459 [7615 5.48 [6524 5.41 [4784 1.63 [5989 9.5 [145 16.6 [2566 3.6 [5900 2.96 [4663 22.3 [6865 4.9 [5472 3.5 [6159 3.4 [4680 4.95 [5368 16.7 [4338 10.7 [7734 1.01 [7385 9.22 [4231 2.04 [7185 14.4 [1463 4.42 [4279 12.2 [301 4.42 [6199 10.9 [1995 14.3 [150 10.4 [1116 3.82 [1445 10.2 [5637 26.7 [7009 11 [2466 1.54 [2081 14.4 [899 19.1 [6569 2.02 [112 9.81 [2411 5.26 [1646 11.5 [7665 7.94 [1786 1.98 [5509 2.49 [2251 2.56 [1769 2.2 [1982 2.15 [30 7] [19 50]] [1 50]] [11 33]] [30 71]] [14 50]] [13 22]] [18 57]] [30 66]] [29 32]] [14 62]] [14 77]] [1429 8.64 [29 40] [36 50]]] [10 34]] [22 44]] [13 100]] [32 58]] [30 64]] [10 85]] [32 37]] [18 18]] [30 80]] [14 15]] [6 54]] [19 60]] [10 80]] [13 58]] [18 31]] [24 75]] [29 48]] [10 46]] [28 91]] [13 100]] [36 43]] [15 54]] [18 52]] [6 88]] [145 57.6 [100 9.53 [2207 1.17 [1079 26.3 [2117 2.22 [1783 54.6 [5637 10.2 [6310 3.4 [5642 0.88 [6230 21.4 [5480 0.265 [19 23] [10 25]] [32 54]] [22 44]] [32 33]] [13 46]] [10 63]] [30 63]] [19 61]] [14 66]] [19 85]] [177 91.5 [30 22] [13 41]]]] [10 60]] [28 100]] [7583 1.77 [22 39] [1 60]]] [3 87]] [429 5.08 [19 55] [36 30]]] [36 100]] [4198 0.592 [2069 1.02 [19 62] [13 50]] [19 87]]] [30 88]] [3 95]] [22 100]] [4946 22.2 [30 75] [30 100]]] [26 100]] [13 100]] [19 71]] [5692 2.28 [1587 4.06 [1961 4.02 [19 60] [19 100]] [7139 3.19 [3008 5.57 [19 94] [19 88]] [19 71]]] [36 36]]] [32 39]] [30 100]] [11 40]] [7514 0.914 [4920 1.36 [7739 8.15 [19 52] [19 25]] [10 100]] [2138 0.684 [2251 0.631 [1062 2.11 [2149 5.33 [64 12.2 [2124 1.49 [2119 7.91 [1900 1.89 [1997 2.79 [312 0.319 [168 77.4 [2118 4.14 [7169 4.22 [19 81] [19 66]] [19 50]] [19 64]] [19 100]] [19 64]] [19 57]] [19 60]] [19 40]] [19 66]] [19 42]] [19 52]] [19 64]] [19 100]]]] [13 100]] [2225 3.54 [175 12.4 [1661 3.44 [2939 3.83 [1250 0.334 [4327 0.156 [19 50] [7314 3.7 [2064 0.463 [7724 7.8 [1955 3.43 [2093 1.49 [83 23.8 [7739 0.914 [19 68] [19 88]] [19 45]] [26 50]] [14 50]] [7 33]] [2165 0.232 [19 86] [19 100]]] [19 50]]] [19 100]] [13 33]] [1899 4.72 [18 78] [18 42]]] [26 45]] [19 35]]] [29 100]] [429 32.8 [112 0.971 [2587 0.768 [6537 2.2 [4 10] [286 6.67 [2 84] [2 70]]] [2 87]] [18 28]] [2 51]]] [13 100]] [10 28]] [28 94]]] [906 0.758 [660 1.29 [4540 1.41 [7332 3.6 [867 3.29 [5281 10.2 [5211 20.3 [6353 12.4 [6524 2.15 [2452 15.6 [3515 7.49 [5130 4.23 [791 29.2 [5155 0.531 [1023 0.486 [7566 5 [5596 1.48 [5693 2.84 [4895 3.09 [2705 0.568 [144 4.41 [2385 5.75 [1980 0.363 [5412 5.24 [377 1.89 [383 1.59 [18 33] [18 80]] [18 66]] [18 30]] [18 78]] [2259 38.9 [18 60] [1783 5.9 [19 45] [16 45]]]] [132 1.3 [19 43] [18 63]]] [29 100]] [19 66]] [788 3.83 [7722 1.22 [18 83] [19 50]] [18 44]]] [18 100]] [392 3.07 [429 30.3 [7 50] [18 75]] [18 80]]] [7210 3.29 [6517 1.9 [728 0.545 [663 10.6 [899 6.4 [4504 8.93 [7354 3.33 [7301 3.55 [2628 1.34 [328 7.1 [18 68] [18 81]] [19 57]] [18 52]] [18 92]] [18 37]] [29 66]] [18 100]] [18 100]] [18 30]] [18 71]]] [18 64]] [284 13.1 [29 46] [19 100]]] [18 58]] [19 81]] [19 50]] [29 75]] [18 92]] [22 100]] [7723 5.9 [7665 2.79 [18 79] [18 60]] [18 92]]] [22 66]] [19 100]] [18 94]] [4154 18.9 [29 82] [29 71]]] [2029 1.82 [7734 2.01 [29 71] [18 40]] [29 100]]]] [4533 2.9 [2030 24.6 [5577 0.467 [4731 4.5 [299 5.95 [5776 1.93 [2526 81.8 [1355 23.7 [6747 3.69 [4673 45.5 [5673 1.12 [4675 19.2 [2566 11.6 [23 2.28 [294 1.86 [5962 0.328 [6005 1.74 [2584 0.599 [4674 36.5 [6 100] [6 80]] [6 100]] [6 100]] [6 100]] [6 100]] [6 83]] [6 88]] [6 61]] [6 44]] [6 80]] [1899 15 [6 57] [6 85]]] [6 75]] [2526 86.7 [6 62] [6 81]]] [6 68]] [1239 39.5 [6422 1.07 [299 22.7 [6 88] [6 100]] [6 100]] [6 100]]] [6 100]] [6 62]] [6 57]] [6 54]]] [1715 0.243 [4885 0.0785 [4863 1.99 [4537 0.271 [4682 2.94 [5893 14.2 [4643 0.476 [5892 8.87 [6666 0.8 [7118 6.57 [6382 3.57 [1759 0.165 [4398 3.37 [5893 6.2 [4564 2.52 [5368 1.01 [6148 9.01 [5271 0.647 [250 1.7 [1259 4.32 [3008 12.4 [4587 3.28 [6113 0.404 [3905 6.58 [791 35.4 [5034 5.35 [5784 1.06 [6149 5.72 [2112 0.508 [7255 1.27 [5618 2.06 [4764 2.31 [4017 2.08 [2275 0.533 [1913 5.12 [7169 1.52 [2402 1.55 [3130 4.11 [17 28] [14 66]] [14 42]] [17 53]] [25 28]] [17 60]] [17 72]] [32 58]] [32 37]] [17 21]] [17 57]] [17 76]] [14 50]] [3 91]] [32 71]] [32 52]] [17 100]] [17 100]] [17 76]] [14 60]] [6809 14.4 [33 55] [32 100]]] [6809 4.33 [32 66] [32 100]]] [3 46]] [2081 0.483 [32 26] [32 41]]] [14 64]] [2402 0.504 [17 33] [19 33]]] [30 50]] [4630 19.5 [32 71] [32 100]]] [5566 0.066 [7073 1.94 [6879 0.0543 [2055 2.43 [1642 3.52 [4764 5.09 [6382 5.98 [14 77] [5837 2.14 [284 0.855 [32 32] [32 100]] [14 90]]] [17 77]] [17 80]] [19 30]] [17 77]] [17 100]] [14 100]]] [3 68]] [32 100]] [6581 7.75 [2004 9.55 [1606 1.65 [126 4 [7512 4.92 [7074 2.92 [5555 0.216 [5034 7.65 [187 1.72 [6382 1.57 [3 36] [4279 4.37 [14 47] [32 66]]] [12 30]] [3 100]] [14 100]] [17 100]] [4279 2.28 [17 47] [32 66]]] [3 100]] [14 100]] [3 95]] [17 62]]] [1656 6.55 [5891 11 [2259 20.9 [32 80] [32 100]] [1456 1.41 [5941 1.21 [32 88] [17 46]] [17 88]]] [17 88]]] [1714 4.24 [4687 0.187 [1608 0.121 [1638 0.136 [1783 16.8 [5789 4.51 [1673 0.386 [2131 0.855 [2229 0.101 [1717 0.588 [6294 2.94 [2402 1.24 [2218 0.191 [252 0.803 [1078 1.4 [6441 1.09 [5637 6.64 [5892 28.3 [5297 1.2 [6228 0.886 [17 71] [6776 1.28 [17 38] [14 66]]] [17 75]] [32 62]] [19 50]] [17 44]] [17 30]] [17 81]] [19 66]] [17 40]] [14 33]] [32 100]] [17 85]] [32 57]] [3255 0.879 [7169 0.199 [1630 0.546 [17 86] [17 100]] [4896 0.201 [17 88] [17 100]]] [1654 2.06 [19 50] [4639 5.65 [17 80] [14 40]]]]] [1656 0.808 [17 83] [17 100]]] [1664 0.406 [17 90] [17 100]]] [14 97]] [17 80]] [7065 1.52 [17 100] [17 78]]] [17 36]]] [33 92]] [2055 0.865 [1637 0.649 [177 0.241 [2232 0.71 [4783 0.275 [7058 0.403 [5789 0.0916 [4089 0.91 [2215 0.304 [4564 5.73 [2164 0.36 [6353 0.0863 [1746 13.9 [19 46] [17 88]] [19 57]] [17 62]] [2168 0.309 [1659 12.2 [5891 14.9 [17 92] [17 42]] [5840 1.03 [16 37] [17 50]]] [17 66]]] [35 62]] [19 76]] [7428 0.174 [1714 0.676 [17 55] [35 60]] [38 55]]] [35 80]] [19 100]] [17 50]] [19 88]] [17 53]] [2966 0.899 [19 80] [19 66]]]] [3 100]] [4473 0.229 [6076 3.36 [6812 7.07 [32 72] [32 100]] [32 77]] [32 63]]] [6777 2.47 [6938 0.141 [6382 1.31 [5893 0.904 [32 75] [32 70]] [5893 25.7 [1754 4.97 [6682 0.498 [4787 1.26 [3317 0.143 [851 14.7 [14 100] [5891 22.3 [14 83] [14 60]]] [14 75]] [14 100]] [3161 4.36 [14 100] [14 87]]] [14 50]] [14 72]]] [32 100]] [3683 2.34 [4851 1.56 [14 37] [14 85]] [14 90]]]]] [7318 3.18 [5202 0.668 [1285 0.135 [5268 6.94 [5938 1.35 [4218 0.13 [739 0.223 [916 4.27 [7369 6.05 [4918 0.717 [609 1.64 [5692 11.2 [4182 0.465 [554 3.7 [7088 0.309 [5041 0.99 [574 1.41 [6937 1.82 [634 1.15 [4154 6.58 [7438 5.71 [906 2.82 [23 7.27 [4805 5.84 [2149 5.26 [7343 6.04 [1783 24 [6260 15.5 [5812 23.3 [4415 1.47 [4794 16.8 [6015 3.76 [5007 20.7 [2083 11.7 [6150 9.8 [434 7.46 [660 11.4 [3027 44.3 [6294 14.4 [221 1.9 [5972 5.38 [2939 3.61 [2199 1.96 [6036 18.2 [21 37] [21 100]] [21 31]] [21 68]] [21 90]] [2 20]] [3 45]] [11 50]] [29 37]] [25 29]] [9 80]] [21 59]] [3 77]] [21 80]] [21 100]] [21 84]] [13 88]] [9 42]] [3 48]] [25 30]] [23 22]] [3 100]] [5042 0.491 [607 8.77 [9 34] [3 100]] [9 96]]] [6261 6.28 [657 2.97 [5211 8.15 [6177 8 [5410 39.6 [4983 1.62 [6131 1.96 [5873 1.46 [373 8.75 [6413 0.883 [4794 1.98 [6347 0.998 [1332 3.65 [504 3 [5918 17.6 [620 3.4 [2143 5.44 [7451 8.55 [6564 3.45 [127 7.52 [1253 0.471 [1025 16 [21 64] [21 100]] [25 30]] [21 81]] [9 55]] [21 77]] [2001 1.27 [1906 12 [21 87] [21 77]] [21 100]]] [3 100]] [21 100]] [21 95]] [9 75]] [9 66]] [21 97]] [21 100]] [4664 5.15 [21 92] [21 100]]] [3 57]] [9 70]] [9 76]] [9 75]] [112 4.07 [9 42] [9 50]]] [9 71]] [9 81]] [3 41]]] [3 100]] [7512 13.5 [7085 1.98 [4414 11.8 [2259 2.62 [2179 1.52 [802 26.9 [3 68] [3 100]] [3 70]] [429 35.5 [4154 12.8 [29 44] [7 37]] [3 60]]] [3 93]] [14 36]] [13 33]]] [21 98]] [10 50]] [9 100]] [6406 5.49 [921 1.5 [919 0.75 [907 1.09 [221 3.5 [5206 4.5 [21 96] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 87]]] [6897 0.463 [9 44] [9 85]]] [2081 1.87 [3 73] [3 100]]] [21 100]] [569 3.58 [4917 3.76 [21 46] [21 100]] [2993 11.4 [21 92] [7451 8.7 [5040 3.45 [3 68] [21 100]] [21 85]]]]] [112 1.77 [6260 14.8 [806 2.42 [6190 3.39 [21 96] [21 100]] [21 100]] [21 80]] [21 83]]] [7169 3.26 [691 8.69 [21 95] [21 100]] [5851 11 [802 20.3 [21 100] [21 87]] [21 75]]]] [1451 3.23 [31 32] [2 25]]] [6060 11.6 [5393 4.67 [1373 2.2 [5041 1.07 [6320 2.27 [5509 7.15 [548 3.7 [21 76] [21 88]] [9 50]] [21 55]] [21 100]] [5972 1.5 [21 75] [9 90]]] [21 92]] [21 100]]] [1980 56.9 [6184 46.1 [23 2.74 [2526 10.3 [802 9.35 [21 69] [538 2.86 [4206 4.2 [2146 1.64 [746 1.9 [1907 2.52 [2199 1.98 [754 1.25 [747 1.39 [1429 9.28 [21 90] [21 50]] [21 100]] [21 100]] [21 100]] [21 90]] [21 100]] [21 100]] [21 100]] [21 100]]] [21 57]] [1899 0.223 [21 88] [21 100]]] [21 100]] [21 66]]] [3 75]] [4748 1.72 [505 1.07 [517 10.8 [1338 14.8 [1078 7.87 [804 20.4 [816 0.175 [6676 1.22 [580 13 [535 1.04 [5972 10 [21 78] [9 58]] [21 100]] [661 33.1 [7009 4.07 [1341 9.8 [585 1.75 [915 31.6 [6092 2.82 [746 15.6 [739 1.71 [688 3.88 [1 3.23 [587 5.26 [7493 3.55 [21 93] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 80]] [21 100]] [21 63]] [21 100]] [21 72]] [21 100]] [21 80]]] [21 78]] [21 98]] [9 57]] [21 82]] [9 77]] [21 99]] [21 57]] [9 100]]] [7512 10.6 [13 91] [13 100]]] [9 88]] [6919 2.49 [6413 1.85 [1325 2.5 [1783 0.876 [9 92] [9 100]] [9 91]] [9 50]] [9 55]]] [3 100]]] [4568 0.134 [6271 0.0453 [957 0.22 [2004 0.6 [2799 3.38 [3633 2.07 [451 1.21 [6264 5.16 [7575 1.86 [6092 0.797 [7404 3.81 [2703 1.29 [3744 1.56 [3332 2.83 [1025 3.6 [3480 0.945 [3449 2.44 [2488 1.42 [7032 1.42 [1219 2.02 [7665 0.523 [4769 1.32 [1207 13.9 [1769 0.372 [432 3.04 [4154 10.9 [6125 1.5 [3235 0.538 [3452 2.96 [3779 6.33 [3931 2.14 [5018 5.47 [7623 11.7 [976 3.18 [940 9.38 [4611 9.91 [4968 1.01 [1138 3.03 [771 7.28 [4876 0.931 [6328 4.15 [3072 1.48 [5480 15.4 [1121 2.62 [5940 6.82 [504 3.4 [7085 0.664 [3156 4.27 [2282 3.58 [2149 11.4 [2232 11.4 [978 12.2 [915 5.47 [5647 7.29 [663 7.62 [1078 50.7 [27 13] [2225 4.21 [434 2.74 [441 1.94 [1062 14.9 [27 50] [4 22]] [1 25]] [28 40]] [1 42]]] [29 23]] [11 50]] [32 62]] [8 32]] [15 35]] [27 47]] [33 60]] [35 66]] [28 41]] [2 60]] [14 41]] [27 100]] [22 76]] [32 53]] [11 72]] [11 33]] [8 35]] [27 100]] [35 75]] [29 46]] [2 48]] [27 100]] [27 51]] [35 66]] [774 6.51 [27 45] [27 100]]] [37 100]] [11 88]] [11 100]] [27 100]] [27 36]] [26 82]] [10 21]] [2 75]] [23 2.05 [2178 2.88 [29 100] [29 62]] [29 92]]] [6791 6.07 [7514 7.95 [2091 0.281 [2628 27.8 [939 35.3 [284 2.67 [2616 3.91 [811 5.56 [7085 5.7 [6199 6.24 [5673 6.34 [791 17.1 [6 17] [36 34]] [32 50]] [2 28]] [29 83]] [10 61]] [6 44]] [19 62]] [31 80]] [31 85]] [4 28]] [13 27]] [2 42]]] [10 100]] [31 54]] [13 50]] [35 97]] [32 55]] [1986 6.72 [3273 0.49 [6732 2.4 [2089 2.46 [27 18] [2 41]] [2 45]] [11 100]] [11 76]]] [3273 1.49 [35 85] [35 100]]] [35 84]] [29 100]] [6 100]] [1980 2.76 [32 42] [32 100]]] [31 100]] [1899 12.5 [8 57] [8 100]]] [3130 6.39 [27 88] [27 50]]] [842 6.25 [3155 7.25 [35 69] [4070 2.2 [35 33] [35 62]]] [436 1.84 [35 77] [35 100]]]] [26 80]] [29 65]] [7512 6.51 [2207 6.51 [6091 5.54 [2993 4.34 [929 0.217 [6320 17.3 [7335 1.71 [2202 1.13 [4761 1.32 [5345 6.28 [453 12.2 [5267 2.34 [5439 10.4 [4320 12.4 [2902 5.47 [3132 0.644 [5154 9.92 [4382 6.75 [3534 0.901 [1788 4.5 [811 7.25 [2130 0.5 [4154 0.407 [435 0.307 [7634 1.15 [16 1.18 [392 1.92 [470 2.02 [3736 0.898 [4371 1.58 [448 2.43 [1908 3.45 [6450 0.891 [1429 24.9 [2526 0.726 [5391 1.43 [3843 1.04 [927 6.31 [1239 0.535 [27 97] [27 100]] [27 57]] [27 100]] [27 100]] [27 100]] [27 72]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 80]] [27 70]] [27 85]] [27 100]] [27 93]] [27 88]] [27 100]] [27 93]] [27 84]] [27 80]] [27 81]] [27 88]] [27 53]] [27 75]] [27 87]] [27 57]] [27 80]] [27 81]] [27 60]] [27 38]] [27 50]] [4312 7.26 [5309 0.48 [1429 22.6 [10 61] [32 57]] [10 100]] [27 100]]]] [27 100]] [27 95]]] [4279 0.605 [2876 0.0659 [78 6.14 [1364 11.4 [194 5.76 [221 6.54 [2029 0.18 [1025 0.975 [4762 1.72 [5641 0.938 [7255 2.04 [1997 13.5 [2283 23 [5673 3.57 [2616 0.942 [6690 6.3 [6933 0.766 [2611 3.23 [7404 3.22 [6287 1.98 [6406 2.13 [6 63] [16 62]] [6 71]] [6 50]] [6 57]] [6 90]] [16 60]] [5408 7.86 [4434 0.938 [6 93] [6 100]] [2406 2.8 [6 76] [6 66]]]] [16 60]] [6 50]] [16 44]] [2616 5.23 [6 46] [6 100]]] [16 50]] [6 58]] [16 54]] [1335 0.586 [1374 12.2 [7574 11.1 [2611 9.78 [2143 0.301 [7512 8.68 [6 80] [5396 0.566 [1899 22.8 [6 90] [6 100]] [6 100]]] [6 80]] [6 100]] [6 50]] [6 62]] [6 100]]] [3020 1.31 [4674 4.43 [4726 8.21 [2295 12.4 [2030 10.4 [2763 0.861 [2412 2.03 [6136 5.01 [2079 5.9 [4820 2.17 [7582 18.5 [7675 0.644 [2295 0.975 [6801 1.17 [6 100] [6 91]] [6 100]] [6 100]] [6 90]] [6923 4.6 [6 100] [6 77]]] [2275 3.8 [6 92] [6 50]]] [6 85]] [5409 5.25 [6 100] [16 53]]] [6 100]] [6 62]] [6 60]] [6 73]] [1366 4.51 [4986 1.2 [5408 1.12 [4939 5.05 [5598 16.1 [5963 1.12 [6098 15.3 [2579 11.2 [6 100] [6 91]] [6 80]] [6099 1.12 [6 88] [6 100]]] [6 100]] [6 87]] [6 100]] [6 80]] [6 80]]] [6 100]]] [16 75]] [6 96]] [18 90]] [16 100]] [6 36]]] [248 1.6 [2434 0.846 [7176 2.18 [688 2.09 [233 1.16 [301 0.677 [5911 1.55 [1482 3.66 [2913 0.564 [1215 19.1 [1239 7.9 [7722 0.659 [4712 2.01 [2461 3.37 [7341 0.516 [5122 2 [1391 2.07 [5110 24.6 [2488 2.75 [6844 1.37 [5508 5.46 [5482 1.75 [859 13 [377 2.25 [6517 2.49 [4924 3.07 [429 72.2 [5851 1 [328 36.8 [5632 5.11 [5140 0.994 [6883 18.9 [957 3.99 [2091 2.04 [7441 1 [2199 5.42 [221 8.4 [5160 2.06 [663 18.6 [791 31.7 [4799 2.82 [12 6] [10 83]] [3 29]] [36 54]] [30 54]] [2 26]] [3 35]] [11 50]] [11 50]] [30 62]] [33 66]] [5420 2.62 [33 94] [33 100]]] [30 50]] [30 51]] [4789 1.22 [27 11] [8 36]]] [3 58]] [21 81]] [30 69]] [685 5.5 [15 40] [30 47]]] [22 80]] [29 68]] [12 100]] [28 43]] [6342 1.24 [5669 2.15 [7428 2.28 [7665 4.22 [2343 5.49 [8 64] [34 100]] [13 100]] [34 66]] [34 100]] [8 50]]] [2939 7.04 [429 19.2 [5412 18.1 [30 53] [107 10.2 [33 33] [33 100]]] [22 10]] [33 50]]] [328 3.67 [22 47] [22 40]]] [7085 2.59 [6299 1.33 [30 89] [30 100]] [30 100]]] [30 100]] [27 100]] [6732 4.76 [15 81] [15 100]]] [17 15]] [5141 4.45 [5499 13.1 [5278 0.835 [907 1.01 [1239 118 [2342 4.36 [5753 4.96 [6413 15.2 [7766 5.02 [3027 0.994 [2526 23.3 [1986 6.87 [4279 10.8 [569 7.7 [6199 6.44 [2081 3.71 [5807 3.83 [4611 0.552 [65 3.64 [7413 4.39 [6015 0.858 [3 19] [21 66]] [33 90]] [33 100]] [29 37]] [22 42]] [11 25]] [9 42]] [3 71]] [3 93]] [3 62]] [8 54]] [33 41]] [3 91]] [13 50]] [33 57]] [34 100]] [9 75]] [747 1.56 [3 51] [21 92]]] [3 77]] [30 100]] [33 100]]] [22 100]] [7542 1.4 [30 81] [32 100]]] [8 100]] [5121 0.743 [22 25] [22 100]]] [7162 0.741 [2713 14 [7049 5.83 [5099 15.1 [5330 16.7 [2916 2.21 [1429 63.7 [144 1.68 [30 99] [30 100]] [30 93]] [30 100]] [30 95]] [30 97]] [304 18.2 [30 85] [30 100]]] [30 80]] [30 100]]] [5668 10.6 [221 5.66 [6653 1.86 [33 97] [33 100]] [33 85]] [33 80]]] [906 2.78 [21 30] [6018 1.28 [371 0.508 [688 12.5 [1899 2.51 [2259 5.01 [1078 2.42 [21 70] [21 55]] [21 50]] [21 93]] [21 90]] [21 92]] [21 100]]]] [6524 1.31 [4663 4.63 [233 0.652 [1253 6.33 [7424 0.99 [33 42] [10 20]] [8 71]] [33 100]] [11 42]] [22 42]]] [2707 7.96 [7245 8.16 [328 12.1 [328 1.64 [2697 6.99 [30 97] [30 100]] [30 100]] [30 88]] [30 40]] [30 85]]] [4592 4.93 [5170 3.1 [5111 4 [4214 14.5 [5753 3.2 [144 1.01 [6524 2.89 [2232 0.311 [7168 3.55 [4369 2.65 [1899 3.43 [7623 13.8 [1783 9.99 [429 1.69 [33 49] [15 47]] [5999 4.02 [33 68] [33 100]]] [33 75]] [33 68]] [25 46]] [29 46]] [33 57]] [1 50]] [1 28]] [328 14.9 [6964 7.4 [5753 13.5 [33 77] [33 89]] [33 85]] [33 58]]] [1 54]] [15 42]] [1932 3.77 [232 0.827 [2232 4.41 [7583 1.63 [6528 16.6 [427 0.39 [7491 0.931 [7642 4.79 [7169 1.54 [7139 2.36 [7207 6.17 [5851 5.73 [7180 13.6 [1338 5.78 [1293 2 [178 5.07 [5647 5.49 [33 92] [33 98]] [33 88]] [33 100]] [33 83]] [33 80]] [33 100]] [33 70]] [33 100]] [33 100]] [33 72]] [33 100]] [33 78]] [1 63]] [7512 10.2 [1 100] [33 66]]] [33 57]] [1263 1.44 [6899 21.6 [5211 1.65 [7210 0.437 [1757 2.47 [426 7.99 [33 97] [33 83]] [33 75]] [33 100]] [33 66]] [33 76]] [33 100]]] [33 66]]] [15 77]]]] [4924 0.305 [507 0.89 [906 7.18 [4918 1.03 [2526 1.03 [917 0.115 [21 70] [21 70]] [21 85]] [21 97]] [7465 3.18 [2526 8.11 [5154 0.835 [21 96] [21 100]] [21 88]] [21 100]]] [21 100]] [21 100]]] [4810 1.54 [3689 0.527 [7685 0.772 [1998 0.649 [7597 2.25 [1079 0.832 [569 1.72 [791 30.5 [5236 0.775 [513 2.51 [4456 2.5 [1534 2.57 [6082 3.93 [3054 1.89 [3309 0.935 [1493 0.219 [4684 8.71 [4455 2.3 [4235 26.2 [5812 0.864 [4691 1.05 [1562 2.04 [5764 3.11 [4764 6.76 [1913 4.4 [7409 9.4 [5838 2.72 [4690 46.3 [1574 2.77 [2849 8.72 [6310 1.55 [7352 4.27 [1764 8.27 [3339 0.229 [663 1.3 [7197 9.35 [5114 0.146 [6727 12.9 [3410 1.18 [2913 2.9 [4991 4.43 [2161 5.69 [221 10.9 [6969 1.68 [2562 4.61 [2331 1.56 [2752 4.5 [6397 3.39 [7241 1.97 [3548 0.946 [5605 14.5 [4312 1.29 [2939 2.76 [2628 1.01 [3868 1.08 [1058 0.747 [7343 1.16 [3113 14.1 [7512 14.4 [6230 1.1 [7179 0.403 [7168 0.659 [2081 6.9 [8 94] [8 88]] [8 100]] [8 100]] [8 83]] [8 90]] [2259 25.9 [8 81] [8 100]]] [8 61]] [8 100]] [8 100]] [8 100]] [8 84]] [8 83]] [8 83]] [8 100]] [6560 1.6 [8 53] [8 100]]] [8 60]] [8 78]] [8 100]] [7413 3.07 [4167 2.67 [1239 0.695 [3609 5.15 [1769 2.44 [5605 6.61 [8 97] [8 87]] [8 100]] [8 100]] [8 100]] [8 100]] [0 40]]] [8 71]] [8 69]] [8 62]] [8 54]] [0 60]] [8 100]] [8 77]] [8 100]] [8 57]] [0 54]] [8 100]] [5647 3.94 [4279 3.82 [8 62] [8 100]] [8 62]]] [8 70]] [0 50]] [7 54]] [4 37]] [2550 43.8 [8 56] [8 100]]] [35 76]] [0 81]] [1783 2.22 [8 44] [25 30]]] [35 66]] [0 100]] [0 90]] [21 44]] [2939 2.59 [27 28] [4 85]]] [20 61]] [0 100]] [0 30]] [8 100]] [20 25]] [0 100]] [8 50]] [0 100]] [0 77]] [7139 6.17 [21 87] [9 50]]] [4663 5.62 [7210 2.02 [20 95] [20 100]] [20 100]]] [21 55]] [4690 21.4 [2526 5.2 [21 98] [21 62]] [21 54]]] [0 80]] [20 100]] [429 3.95 [0 50] [2550 10.1 [7056 0.75 [1764 2.99 [0 85] [2081 4.99 [4692 3.38 [0 100] [0 85]] [0 85]]] [0 100]] [0 66]]]] [7749 1.78 [328 0.205 [4876 1.5 [3545 1.96 [6410 3.59 [4608 22.4 [2251 3.2 [4768 0.669 [4607 0.64 [2093 0.876 [2199 6.7 [5134 14.4 [20 100] [20 88]] [20 66]] [20 100]] [20 100]] [20 100]] [20 94]] [20 62]] [20 95]] [20 100]] [20 71]] [20 100]] [20 100]]] [0 100]] [21 100]]] [6509 0.404 [1239 25.4 [6824 0.186 [2653 0.0508 [6371 3.37 [2688 1.51 [6758 0.265 [302 1.7 [4051 0.0539 [2683 0.543 [199 0.199 [2889 2.07 [4613 1.54 [4854 0.32 [7369 7.01 [2734 0.461 [7421 0.227 [7084 0.754 [4535 4.35 [6940 3.67 [2949 0.19 [221 0.792 [7482 0.659 [4104 0.222 [1980 1.61 [2628 56.2 [6208 1.43 [2707 26.1 [2640 0.659 [2856 1.67 [23 19.8 [6471 4.36 [2628 29.4 [4897 2.91 [38 27] [16 28]] [16 17]] [26 60]] [2951 4.65 [16 42] [7150 4.39 [3199 1.75 [2712 5.5 [4622 14.7 [5415 2.79 [2849 58.8 [7445 2.92 [38 23] [38 62]] [7260 6.59 [1936 0.322 [2849 63.5 [38 61] [38 84]] [2955 5.85 [38 44] [5 91]]] [16 22]]] [16 60]] [6877 16.5 [192 0.686 [37 55] [37 100]] [5 47]]] [16 84]] [3980 4.85 [37 87] [37 50]]] [2644 1.47 [2867 4.09 [6 29] [6207 9.66 [13 50] [16 66]]] [16 70]]]]] [2869 2.45 [6833 2.92 [16 66] [7 100]] [16 88]]] [16 53]] [2877 10.3 [2712 0.858 [3037 2.62 [2259 63.8 [5873 5.18 [7390 3.53 [5801 6.66 [328 14.3 [2276 1.25 [190 20.3 [1646 9.6 [7101 7.3 [2660 6.97 [2711 3.15 [5673 13 [2853 0.938 [38 42] [38 100]] [6 26]] [37 37]] [16 57]] [6 33]] [16 72]] [16 29]] [38 72]] [14 42]] [23 28 [18 50] [16 62]]] [2862 10.6 [38 72] [38 85]]] [38 91]] [7390 0.327 [2687 14.5 [38 68] [38 100]] [38 100]]] [38 100]] [187 25 [4426 8.5 [187 2.59 [16 40] [16 56]] [19 33]] [6 46]]] [16 83]]] [38 55]] [2654 2.7 [1955 0.353 [5580 6.29 [5103 3.11 [7446 2.68 [4610 4.52 [3677 16.9 [7348 2.65 [1244 1.33 [2110 11 [2628 65.9 [2713 5.08 [37 24.1 [2983 1.54 [38 57] [38 78]] [38 100]] [16 33]] [5578 4.35 [6959 3.45 [7255 2.24 [2955 50.5 [5983 30.4 [38 73] [16 45]] [38 41]] [38 91]] [6 28]] [16 66]]] [38 57]] [38 100]] [6208 12.3 [38 90] [38 100]]] [5 30]] [17 66]] [38 66]] [6 63]] [16 44]] [38 90]] [16 45]]] [6409 5.07 [429 1.3 [5627 1.52 [5597 4.11 [2122 1.3 [2643 8.29 [2712 2.36 [2650 1.42 [5632 5.21 [7354 1.82 [7369 4.07 [2168 1.25 [5100 2.59 [1437 0.956 [1983 0.644 [4017 4.05 [2948 6.34 [1981 9.52 [1395 8.72 [3994 0.745 [167 5.25 [4011 0.734 [38 64] [38 50]] [38 45]] [38 100]] [38 100]] [38 29]] [38 80]] [38 46]] [38 83]] [38 95]] [16 100]] [1 33]] [38 31]] [10 40]] [16 40]] [18 35]] [16 57]] [37 63]] [38 100]] [16 80]] [18 44]] [6353 0.673 [38 28] [17 37]]] [16 60]]] [3120 0.367 [37 55] [5 75]]] [38 87]] [7665 5.27 [7260 0.766 [16 29] [16 100]] [6 63]]] [2207 0.245 [2851 0.471 [2232 1.02 [5683 3.17 [1895 0.38 [2225 1.19 [1997 4.16 [38 83] [38 66]] [38 83]] [38 100]] [38 58]] [2006 2.95 [38 100] [38 85]]] [38 93]] [38 93]]] [1899 1.95 [2469 1.33 [16 40] [16 70]] [16 62]]] [5931 6.1 [3984 4.47 [7439 17.2 [187 5.95 [38 82] [38 92]] [17 54]] [38 45]] [23 34.6 [17 57] [38 75]]]] [2849 36.3 [37 22] [2276 0.843 [7260 2.85 [167 5.78 [5 60] [19 57]] [5 66]] [5 62]]]] [299 12.4 [6690 4.35 [7169 0.901 [1429 8.1 [1239 9.5 [88 3.56 [16 56] [16 71]] [6 38]] [1268 0.565 [5632 1.77 [16 80] [16 57]] [16 53]]] [6 50]] [6 66]] [6 66]]] [2656 3.09 [5986 28.3 [5103 4.24 [1980 8.33 [16 42] [2628 49.8 [6 62] [6 27]]] [6 80]] [5985 30.4 [6 41] [6 66]]] [18 53]]] [17 31]] [7281 10.9 [6257 2.24 [7343 1.13 [4997 1.37 [2877 0.641 [3435 1.55 [304 3.37 [4854 35.6 [2680 6.29 [6749 7.92 [6961 1.95 [165 4.49 [194 7.85 [5334 5.91 [2661 14.8 [5633 2.37 [2720 10.6 [311 18.5 [2178 2.16 [6473 9.22 [83 10.7 [2868 14.8 [5100 5.41 [2983 9.33 [16 41] [4427 9.82 [6 41] [18 60]]] [1701 2.17 [4763 3.17 [2709 23.8 [5647 2.37 [2526 7.35 [6342 5.34 [5898 4.56 [7031 3.62 [791 11.9 [2667 25.2 [2712 6.3 [4851 30.3 [4716 2.84 [6942 0.956 [6406 30.8 [6 46] [16 60]] [16 57]] [16 60]] [16 41]] [6 33]] [6 83]] [32 50]] [16 54]] [18 54]] [6 75]] [5102 8.89 [6 100] [190 11.8 [2713 15.7 [6 75] [16 37]] [6 44]]]] [6 30]] [6 75]] [16 68]] [6 71]]] [13 50]] [18 66]] [26 72]] [4854 7.35 [38 44] [16 66]]] [28 85]] [5983 25.5 [26 28] [26 57]]] [16 85]] [6 50]] [6 72]] [6 62]] [38 25]] [5103 7.26 [1661 4.57 [4746 0.401 [5898 14.3 [6959 8.08 [5628 3.93 [2713 7.08 [16 58] [2707 24.4 [6 90] [6 57]]] [6 77]] [192 6.27 [2655 9.65 [2939 19.9 [16 75] [5681 0.55 [16 86] [16 62]]] [4527 12.4 [6 70] [6 50]]] [16 100]]] [6 63]] [6 80]] [18 70]] [6 85]]] [6 94]] [7 57]] [193 10.4 [6 57] [6 70]]] [30 100]] [16 28]] [16 51]] [7 100]] [2752 1.7 [7446 10.1 [83 0.25 [2983 0.612 [1429 36.3 [16 27] [2849 39.2 [17 63] [17 100]]] [16 39]] [4414 10.3 [2849 56.1 [2868 1.54 [16 45] [5681 1.58 [26 63] [6 26]]] [2714 3.97 [5799 6.85 [6 22] [2660 7.84 [5205 1.76 [7343 12.9 [16 75] [16 40]] [16 66]] [2650 2.13 [16 60] [18 37]]]] [5438 4.8 [26 72] [26 50]]]] [5 50]]] [17 90]] [2752 4.06 [2628 26.6 [26 62] [6 36]] [16 35]]]] [18 76]] [6 58]]] [1239 10.5 [26 62] [26 100]]] [7149 0.173 [2983 1.08 [429 0.465 [2327 12.7 [3582 8.15 [3675 13.7 [3675 4.94 [5 70] [1899 18.7 [2199 2.51 [2849 33.3 [5 66] [5 95]] [5 76]] [5 66]]] [5 42]] [3581 11 [5 58] [5 77]]] [37 46]] [5 40]] [5 50]] [38 30]]] [5028 0.597 [7446 3.24 [7371 1.71 [1897 9.28 [7486 0.365 [1783 4.74 [2665 10.2 [200 9.9 [38 89] [38 76]] [38 64]] [7474 4.23 [38 68] [38 100]]] [38 100]] [27 37]] [38 71]] [38 94]] [5 50]]] [5160 0.668 [5635 0.321 [2187 0.329 [88 6.32 [5100 22.1 [7419 4.62 [3006 0.855 [1983 7.47 [7611 2.56 [7665 5.43 [5681 1.48 [4851 1.77 [7765 4.1 [16 54] [6257 0.838 [7 42] [18 87]]] [16 31]] [7049 2.92 [7231 8.73 [5102 0.524 [1895 0.894 [18 50] [18 60]] [6 42]] [4851 18.2 [7343 1.3 [7122 10.3 [7 33] [7232 17.8 [16 60] [18 37]]] [16 72]] [6 70]]] [16 63]]] [4854 5.33 [16 61] [6 63]]] [28 60]] [16 86]] [26 100]] [187 3.11 [2081 0.367 [16 94] [16 100]] [4895 3.05 [62 2.83 [2683 4.71 [16 29] [5681 8.91 [16 53] [6 33]]] [16 63]] [16 100]]]] [6 66]] [45 0.555 [7167 7.13 [5962 0.516 [37 53] [16 42]] [16 75]] [16 37]]] [1783 0.657 [6 50] [6 76]]] [2681 11.8 [16 93] [16 71]]] [286 0.917 [14 33] [14 88]]]] [7401 0.251 [6705 0.506 [5918 4.23 [7473 0.0539 [1564 0.971 [16 27] [17 53]] [4571 1.27 [6383 16.1 [6677 0.795 [2947 0.229 [4764 0.528 [2628 38.2 [6574 1.65 [1429 36.6 [2628 17 [38 75] [7484 0.699 [165 6.32 [199 0.0539 [38 69] [1981 3.02 [2628 33.9 [38 90] [38 76]] [38 42]]] [38 81]] [38 100]]] [38 60]] [199 2.02 [17 90] [17 45]]] [2949 3.78 [2849 6.92 [23 2.23 [38 95] [38 100]] [4050 1.36 [38 61] [2628 65.1 [3238 0.703 [38 84] [38 100]] [38 66]]]] [38 100]]] [14 50]] [38 63]] [190 11.4 [38 58] [17 62]]] [17 60]] [19 33]]] [24 29]] [14 50]] [7374 0.778 [7391 0.0908 [17 60] [17 100]] [17 40]]]] [7232 22.7 [685 0.901 [2978 3.19 [7232 2.01 [6406 1.07 [3008 0.864 [301 8.45 [5 33] [2628 30.2 [30 81] [30 75]]] [30 94]] [30 100]] [2731 2.55 [30 68] [30 100]]] [30 66]] [6 57]] [6 62]]] [4991 2.54 [5874 1.32 [6279 7.35 [5368 0.538 [2199 2.24 [167 1.04 [1436 13.5 [2939 158 [7474 15.6 [2955 5.42 [38 85] [38 97]] [38 81]] [38 50]] [38 85]] [38 83]] [38 100]] [38 70]] [38 62]] [38 53]] [17 53]]] [4663 9.21 [7136 14.9 [2081 0.857 [2750 5.38 [2383 14.1 [2075 0.321 [7122 1.69 [7488 60.1 [38 100] [38 97]] [38 100]] [38 100]] [38 81]] [38 70]] [2879 1.14 [2241 1.65 [7488 21.5 [16 57] [2429 5.44 [38 80] [38 100]]] [38 100]] [38 83]]] [38 83]] [38 62]]] [2178 7.19 [5007 1.66 [7101 4.93 [6701 2.36 [6134 0.109 [78 11.5 [4738 8.28 [5673 10.6 [2871 0.529 [1783 4.6 [1981 4.93 [5799 7.57 [2081 10.6 [83 3.31 [16 70] [16 93]] [16 45]] [16 60]] [17 25]] [6 50]] [16 87]] [16 34]] [16 100]] [16 28]] [2006 1.48 [16 45] [26 52]]] [7 100]] [16 76]] [6371 13.1 [18 100] [16 50]]] [6 33]]] [6981 0.267 [6007 2.98 [5900 2.97 [7512 2.04 [52 0.236 [4009 0.331 [4716 15.6 [4820 1.1 [2716 4.39 [2654 3.95 [7314 2.9 [5626 12.4 [6778 4.4 [1696 1.97 [4573 1.24 [5692 0.157 [2690 3.64 [6422 0.196 [2259 4.35 [4854 0.713 [7476 2.59 [1895 2.93 [16 78] [16 94]] [16 66]] [16 47]] [190 4.2 [6 37] [5635 1.77 [26 33] [16 94]]]] [16 100]] [16 35]] [7260 0.943 [16 50] [16 60]]] [7 54]] [26 55]] [5 50]] [6 80]] [17 42]] [16 78]] [4716 14.3 [2867 2.28 [16 48] [7 18]] [16 83]]] [2733 6.53 [2939 46.7 [4977 1.14 [1239 17.4 [16 100] [16 66]] [16 72]] [16 37]] [16 100]]] [16 42]] [2654 2.27 [6383 1.61 [38 71] [38 100]] [38 66]]] [2849 46.8 [16 60] [37 62]]] [23 5.76 [6 59] [2656 3.6 [2713 5.93 [5130 0.312 [190 10.1 [4820 0.424 [5681 2.33 [6 46] [16 28]] [16 80]] [16 77]] [16 50]] [16 100]] [6 46]]]] [6833 0.28 [4717 4.45 [16 56] [18 63]] [2671 9.43 [4716 1.9 [19 58] [1980 1.49 [7 38] [16 60]]] [5635 10.6 [18 62] [7 62]]]]] [2241 2.89 [1783 13.1 [5901 0.915 [16 45] [22 42]] [1899 2.87 [2712 1.67 [18 52] [6961 3.42 [4716 9.58 [6 66] [16 44]] [2717 2.19 [16 50] [7 81]]]] [1661 3.94 [6 100] [6 45]]]] [2849 38.5 [6833 1.6 [2649 2.82 [30 45] [6 37]] [7 100]] [7 39]]]] [38 70]]] [7157 0.93 [7476 0.358 [4895 0.262 [200 1.99 [38 44] [38 100]] [6931 1.79 [7347 0.552 [7038 0.666 [1895 4.91 [4132 0.585 [7017 1.22 [38 77] [2864 9.05 [38 100] [38 42]]] [38 100]] [3550 7.94 [6199 9.04 [38 95] [38 88]] [38 80]]] [4539 1.18 [38 48] [6720 2.53 [38 92] [38 62]]]] [38 42]] [1899 2.07 [97 3.83 [38 44] [38 90]] [38 83]]]] [7446 1.07 [2039 0.214 [2081 1.04 [7449 0.567 [38 33] [1783 37.5 [5 63] [2707 14.7 [3418 3.12 [12 50] [5 77]] [37 83]]]] [5 65]] [12 62]] [3243 0.476 [38 57] [38 90]]]] [5955 7.55 [38 57] [4562 3.56 [38 88] [38 63]]]]] [2439 0.873 [7402 1.45 [6257 3.29 [7473 0.0585 [6103 1.99 [5102 0.24 [4427 9.79 [2616 2.34 [6380 3.32 [4716 2.34 [5962 1.84 [5639 3.72 [7765 1.46 [5595 1.85 [78 2.3 [7041 5.7 [6833 0.84 [2659 0.329 [2725 2.22 [2680 6.86 [5904 1.87 [2683 3.39 [6208 10.1 [6432 17.8 [2187 0.232 [5681 3.37 [6177 4.93 [7623 2.61 [6380 0.631 [6523 1.66 [38 39] [38 90]] [17 42]] [6 87]] [7 50]] [2081 3.43 [16 29] [18 50]]] [6 75]] [7 78]] [6015 1.03 [17 40] [17 50]]] [2849 12.7 [16 66] [2683 6.07 [19 50] [16 28]]]] [19 69]] [2628 42.3 [7 100] [7 82]]] [7 100]] [38 83]] [7 97]] [2951 17.2 [2707 21.7 [16 46] [6 46]] [16 85]]] [16 45]] [2619 1.71 [16 50] [6 62]]] [6199 5.54 [4851 6.41 [6353 2.56 [7 30] [7 100]] [7 50]] [7 95]]] [16 84]] [6701 0.861 [16 65] [7 28]]] [4998 0.666 [2849 7.52 [6 30] [194 8.46 [16 80] [16 44]]] [7 100]]] [1445 1.66 [2849 9.6 [14 42] [4895 1.73 [38 32] [17 62]]] [6842 0.231 [32 44] [17 83]]]] [5103 0.452 [7132 2.57 [6 100] [7 100]] [6 100]]] [6 45]] [685 1.79 [2861 3.42 [302 0.511 [6830 7.32 [1900 0.636 [2644 0.736 [4712 2.69 [6941 7.56 [1919 1.05 [2143 3.38 [37 6.8 [7421 5.62 [194 9.26 [6342 2.87 [5580 1.96 [6159 1.79 [6207 4.13 [5983 11.2 [2661 3.73 [5099 41 [6 44] [6 65]] [16 53]] [2707 21.7 [5099 13.9 [6 100] [6 85]] [5985 9.37 [16 40] [6 80]]]] [5010 2.09 [16 40] [16 35]]] [6 40]] [7149 2 [16 44] [16 83]]] [16 61]] [6 43]] [6 80]] [6 90]] [6 75]] [6 100]] [2628 36.1 [23 8.9 [6 57] [2951 12.8 [16 91] [16 83]]] [6 47]]] [2723 0.343 [1429 5.95 [18 41] [6 37]] [16 100]]] [2667 1.03 [2466 1.29 [16 42] [6 60]] [16 77]]] [1895 2.21 [5010 10.5 [16 88] [18 50]] [6 100]]] [6688 0.412 [7 42] [7 40]]] [4880 1.66 [30 60] [30 100]]] [6134 3.55 [91 0.238 [6409 0.62 [16 38] [16 50]] [6 50]] [6 28]]] [26 46]]] [38 94]] [6199 4.51 [2689 0.583 [1255 0.468 [2164 0.34 [2881 1.23 [6207 0.824 [2691 0.62 [1787 0.582 [38 75] [38 100]] [38 66]] [38 53]] [38 85]] [38 57]] [14 33]] [20 26]] [7486 0.392 [2850 0.0585 [38 51] [38 71]] [187 3.22 [17 28] [17 81]]]]] [6701 10.2 [5436 1.83 [6406 2.98 [2241 2.56 [5643 0.344 [2849 22.7 [7 48] [2709 2.78 [18 84] [18 63]]] [18 100]] [7 55]] [18 64]] [2048 1.26 [18 100] [18 90]]] [18 69]]] [1239 49 [17 63] [6208 12.1 [17 75] [17 97]]]] [6346 2.54 [38 63] [4820 1.17 [5774 0.734 [7132 11.5 [4133 2.03 [38 100] [38 92]] [4781 1.94 [38 90] [38 80]]] [38 100]] [38 50]]]]] [1429 21.3 [2713 0.645 [5789 0.404 [1596 1.25 [4571 1.49 [7 88] [7 100]] [7 100]] [7 100]] [7 100]] [4716 3.75 [7 88] [7 85]]]]] [2331 0.752 [3003 1.43 [798 0.297 [6859 1.75 [5454 0.223 [2526 0.772 [4170 0.909 [248 6.05 [6226 0.551 [3514 1.42 [877 0.204 [6106 1.03 [3004 0.971 [7657 0.21 [613 0.469 [7665 3.7 [839 0.412 [6524 0.51 [7620 1.64 [5122 0.328 [3921 0.807 [1391 2.75 [5420 1.57 [1400 3.21 [5789 6.8 [1226 3.5 [685 2.82 [4555 2.3 [5995 0.665 [2259 7.18 [5809 7.13 [3237 0.255 [5972 3.53 [2793 1.74 [6153 16.7 [5013 0.4 [784 0.808 [3045 0.391 [5117 0.349 [3990 3.16 [3310 7.09 [731 2.93 [3444 6.93 [3944 1.56 [663 0.27 [6363 0.141 [3849 0.911 [5627 0.123 [2802 3.59 [1735 1.29 [6353 2.77 [2628 10.2 [328 6.8 [1429 8.71 [1164 2.15 [5812 18.4 [2081 4.72 [2808 4.76 [7649 1.61 [1812 1.18 [5766 12.2 [418 37.4 [4417 17.9 [3439 3.03 [3794 31.7 [6639 7.69 [2241 3.91 [5066 1.54 [3273 4.41 [2846 8.65 [5223 2.73 [5732 8.85 [5730 0.566 [5396 22.4 [1025 1.57 [819 2.37 [306 18.9 [1233 1.31 [6544 9.09 [957 1.99 [5360 5.83 [430 5.05 [4956 7.55 [2804 16.1 [5007 23.6 [23 13] [15 87]] [4851 71.8 [8 71] [8 81]]] [35 45]] [25 81]] [33 92]] [27 66]] [14 84]] [23 55]] [29 100]] [27 100]] [23 18]] [12 100]] [11 81]] [28 60]] [11 100]] [2 43]] [11 64]] [15 100]] [11 39]] [23 100]] [27 57]] [11 100]] [15 88]] [28 90]] [28 100]] [33 91]] [15 100]] [15 100]] [5211 1.19 [764 3.26 [2760 11.9 [5527 3.36 [802 21.6 [2849 0.952 [2201 1.68 [435 3.76 [312 3.94 [221 4.89 [7411 1.75 [1917 6.44 [2081 36.7 [2002 8.93 [2132 8.12 [3931 7.75 [4601 5.49 [4364 6.19 [4991 8.72 [2143 22.1 [2241 14.9 [7512 27.5 [2023 27.8 [23 13] [29 26]] [22 60]] [2 31]] [23 31]] [25 31]] [23 52]] [28 81]] [27 57]] [23 87]] [23 44]] [23 43]] [1917 28 [23 63] [23 83]]] [15 50]] [29 28]] [11 43]] [23 34]] [2143 32.5 [27 19] [4 23]]] [29 70]] [21 81]] [29 100]] [1025 11.6 [25 43] [15 42]]] [23 100]] [5110 1.71 [5692 3.4 [7085 3.7 [23 45] [23 100]] [23 37]] [11 71]]]] [12 30]] [27 67]] [3959 0.529 [7340 2.54 [5211 8.91 [7460 1.26 [1913 13.6 [6471 5.78 [1939 5.05 [791 3.04 [929 12.5 [5732 2.09 [5904 7.73 [4205 10.7 [1753 3.88 [6729 4.59 [7188 26.8 [1834 9.32 [6230 9.36 [6063 1.06 [4135 3.84 [2753 4.59 [429 5.43 [4559 8.46 [1742 4.97 [2091 23.3 [7139 1.57 [6199 32 [6791 3.3 [4564 1.05 [2707 1.87 [4517 4.55 [1812 1.79 [23 7] [33 83]] [30 46]] [5 30]] [18 36]] [17 22]] [14 62]] [14 38]] [23 45]] [33 50]] [17 55]] [4324 2.54 [3136 1.39 [978 1.56 [28 17] [2081 11.7 [23 15] [5 41]]] [5 42]] [23 44]]] [2466 24.1 [14 8] [19 33]]] [29 52]] [22 100]] [30 41]] [33 100]] [12 88]] [5 66]] [22 57]] [28 100]] [5904 22.1 [19 54] [19 76]]] [28 42]] [17 61]] [844 1.08 [5480 9.8 [968 3.31 [5246 0.494 [6660 4.22 [6849 0.911 [5677 4.12 [2179 0.303 [3997 3.18 [3709 6.17 [2701 7.65 [939 0.995 [460 6.17 [6328 1.81 [3079 6.67 [5092 6.45 [730 4.59 [668 11.9 [855 3.82 [4533 5.21 [7149 9.52 [7354 3.9 [4417 11 [28 16] [15 75]] [13 34]] [28 52]] [35 36]] [14 100]] [38 66]] [28 100]] [22 100]] [37 100]] [11 53]] [37 100]] [1906 5.49 [1913 3.63 [27 28] [27 50]] [11 66]]] [1062 4.67 [29 73] [29 100]]] [11 100]] [37 91]] [11 56]] [38 80]] [35 90]] [11 87]] [11 100]] [28 91]] [18 40]] [11 100]]] [23 83]] [26 68]] [5057 2.51 [1436 1.33 [23 42] [1436 19.1 [31 67] [2178 1.91 [31 14] [11 33]]]] [31 100]]] [29 100]] [30 47]] [5381 3.07 [7491 2.42 [3555 3.31 [7340 8.53 [12 37] [32 89]] [32 100]] [32 85]] [32 100]]] [29 87]]] [3292 7.47 [5288 0.369 [221 0.577 [7411 2.71 [350 33.4 [2701 6.02 [384 0.388 [5732 1.1 [7009 12.9 [2987 5.26 [4832 12.7 [7255 5.22 [7317 10.3 [2759 8.27 [4781 9.06 [2916 8.05 [3404 3.55 [1783 4.98 [2108 1.63 [361 0.639 [1429 33 [3027 24.2 [906 3.5 [1888 5.49 [23 15] [18 37]] [21 57]] [27 60]] [28 32]] [33 36]] [28 36]] [30 20]] [11 60]] [25 100]] [11 62]] [23 25]] [30 80]] [12 62]] [2 100]] [23 100]] [7009 33.2 [4602 2.02 [26 41] [26 100]] [26 50]]] [28 83]] [23 87]] [15 58]] [12 87]] [2764 4.44 [4533 1.98 [35 65] [35 87]] [35 45]]] [23 12.8 [28 40] [30 53]]] [28 90]] [37 100]]] [2890 2.99 [5102 0.861 [1821 2.46 [1783 1.35 [978 13.1 [83 2.31 [5345 9.17 [4851 8.87 [2766 9.7 [2728 1.24 [7409 4.71 [7255 21.9 [6394 6.02 [6621 6.17 [2722 4.76 [2955 15.9 [5681 3.18 [1769 15.6 [7422 3.81 [7123 2.56 [94 3.77 [7623 6.98 [4332 3.11 [5 12] [38 50]] [3 36]] [37 50]] [16 40]] [16 68]] [11 62]] [16 55]] [38 39]] [16 87]] [28 75]] [15 100]] [12 51]] [38 57]] [16 45]] [38 60]] [2752 17.6 [8 19] [30 48]]] [30 40]] [16 64]] [791 7.04 [5 40] [4 30]]] [192 4.53 [2764 13.5 [5643 5.18 [1913 6.82 [2717 0.64 [7354 5.76 [7472 3.47 [16 45] [38 77]] [16 44]] [16 78]] [10 62]] [18 45]] [6 25]] [16 85]]] [7 100]] [16 43]] [5 67]]] [35 46]] [3325 4.67 [29 90] [29 100]]] [2786 1.51 [29 62] [29 100]]] [5594 1.22 [16 61] [5902 3.16 [2716 4.2 [7 72] [6 62]] [7 33]]]] [3103 4.42 [3095 2.86 [3852 3.36 [3042 7.82 [35 79] [37 50]] [35 100]] [35 100]] [1899 2.96 [4956 3.76 [35 98] [35 100]] [35 100]]]] [859 0.202 [7255 5.69 [2764 1.72 [11 46] [11 100]] [12 100]] [11 100]]] [906 1.83 [5521 6.27 [6490 1.47 [3554 10.5 [5378 2.26 [144 15.6 [5090 1.59 [5626 0.652 [5130 11.7 [4927 3.55 [3959 1.4 [155 1.41 [1646 3.76 [1567 1.51 [5260 5.62 [112 1.49 [7354 1.16 [2671 5.62 [6395 11.9 [2897 2.22 [5 9] [28 62]] [17 50]] [18 77]] [7512 2.79 [5 34] [12 33]]] [7340 5.15 [6015 2.2 [7354 19.3 [4897 1.99 [3056 2.33 [791 22.9 [37 20] [37 43]] [37 100]] [16 66]] [32 38]] [29 57]] [32 91]]] [13 100]] [28 66]] [16 80]] [29 35]] [29 100]] [18 52]] [16 71]] [16 62]] [5804 1.38 [22 87] [22 100]]] [144 32.7 [4159 1.1 [2849 2.64 [29 20] [29 47]] [29 53]] [7449 3.5 [29 40] [29 90]]]] [29 64]] [32 82]] [29 88]] [19 100]] [434 9.2 [29 43] [32 62]]]] [3233 23.7 [7357 1.36 [35 72] [35 100]] [35 62]]] [35 84]] [1671 3.34 [5 21] [18 87]]] [23 100]] [6375 1.77 [1528 1.46 [3079 1.01 [101 0.982 [37 86] [37 75]] [37 100]] [37 100]] [37 66]]] [5911 0.613 [2897 0.343 [1138 1.4 [1104 1.3 [7442 1.16 [11 98] [11 100]] [11 100]] [11 100]] [11 100]] [11 100]]] [3234 5.34 [1062 2.24 [1253 4.04 [377 10.8 [23 17.8 [35 89] [35 87]] [35 60]] [14 57]] [35 100]] [35 70]]] [27 100]] [5851 1.73 [3515 3.76 [957 2.96 [7453 2.42 [1911 5.66 [7354 8.93 [2752 22.3 [29 40] [4769 1.28 [4501 2.02 [6184 2.15 [29 72] [23 50]] [29 100]] [29 100]]] [19 41]] [2 25]] [29 90]] [5 28]] [19 100]] [29 50]]] [28 95]] [3033 1.71 [4897 3.11 [2517 11.2 [4288 6.85 [429 29.1 [4158 5.68 [2098 6.49 [4418 18.3 [5154 6.49 [3533 6.67 [4601 5.05 [23 13.4 [4135 6.76 [3527 0.613 [957 0.302 [7301 13.7 [1108 17.9 [1099 9.74 [2251 8.34 [7449 14.7 [4680 6.17 [2178 6.89 [1025 2.16 [2628 0.457 [978 2.06 [2759 6.45 [1094 19.2 [23 32] [23 55]] [8 37]] [23 83]] [13 22]] [24 51]] [14 39]] [28 70]] [23 68]] [23 80]] [27 44]] [28 23]] [28 100]] [2251 0.573 [27 100] [27 80]]] [27 58]] [27 100]] [2091 6.67 [14 64] [36 57]]] [36 44]] [27 75]] [14 63]] [27 85]] [23 100]] [23 53]] [976 0.557 [7623 3.6 [1164 6.67 [429 47.1 [2201 1.04 [23 26] [27 42]] [23 64]] [27 100]] [27 88]] [27 100]]] [2752 50.4 [35 50] [22 40]]] [24 82]] [31 35]] [23 79]]] [512 5.39 [434 11.9 [3763 9.17 [2083 7.83 [12 73] [12 63]] [15 70]] [31 50]] [12 50]]] [3130 0.139 [3274 0.457 [1436 1.06 [2752 23.9 [11 94] [11 100]] [11 100]] [11 100]] [11 100]]] [15 94]] [70 5.92 [5524 0.545 [4279 8.49 [6173 0.826 [4612 1.22 [6124 3.62 [6031 4.96 [4218 16.5 [5692 2.67 [1980 16.7 [112 8.33 [2775 0.846 [2429 1.67 [5312 6.2 [3308 5.78 [7354 4.12 [826 3.35 [3652 2.89 [2384 2.76 [7320 1.52 [2957 4.45 [6813 2.44 [7489 10.8 [4369 3.33 [6333 20.3 [2750 0.996 [429 7.73 [2914 0.371 [7449 2.14 [2195 0.48 [5270 2.94 [3677 3.53 [2913 1.64 [1089 0.743 [5532 9.17 [2955 0.924 [2160 0.982 [209 3.03 [5972 2.88 [2771 4.07 [3008 6.93 [6199 43.7 [1965 2.02 [1701 7.27 [6331 2.73 [2849 8.95 [3351 1.17 [3660 2.24 [5642 5.87 [2237 3.82 [6643 12.5 [3332 8.48 [5889 6.12 [2993 8.01 [5564 1.83 [24 9] [14 100]] [38 17]] [17 46]] [8 53]] [1 87]] [4846 61.5 [1 71] [1 100]]] [19 40]] [24 58]] [25 66]] [16 23]] [11 46]] [24 50]] [37 44]] [14 93]] [30 42]] [24 92]] [2259 45.9 [12 60] [31 40]]] [24 70]] [1 78]] [2753 14.3 [6778 1.71 [38 29] [5 50]] [16 75]]] [13 58]] [10 70]] [30 92]] [37 58]] [31 37]] [1 38]] [3675 0.717 [12 14] [2327 1.95 [5 54] [5 75]]]] [30 94]] [3555 3.45 [4769 0.424 [1189 3.45 [7322 11.8 [4338 9.54 [2818 4.85 [5323 2.7 [906 4.07 [2764 11.1 [5940 1.05 [3332 2.98 [1078 20.5 [1429 34.9 [4583 6.68 [5011 1.53 [6152 27.4 [6853 11.5 [5211 11.7 [6294 9.43 [2199 7.43 [4205 12.3 [6544 6.49 [4790 1.15 [5972 11.5 [4414 40.8 [6581 7.13 [28 11] [4 85]] [21 27]] [36 50]] [31 41]] [14 40]] [28 77]] [2259 11.3 [23 70] [22 26]]] [12 80]] [30 61]] [28 62]] [28 100]] [29 45]] [29 44]] [957 16.9 [392 7.14 [28 16] [14 53]] [30 40]]] [4929 6.85 [4781 7.04 [968 1.17 [4601 1.89 [7491 2.35 [2701 2.73 [5812 2.82 [2180 3.04 [36 16] [27 44]] [12 62]] [29 80]] [22 33]] [31 44]] [28 38]] [36 40]] [18 42]]] [35 57]] [17 48]] [23 50]] [429 59.6 [32 30] [21 47]]] [11 75]] [12 100]] [24 80]] [30 90]] [28 100]] [29 96]] [3555 13 [32 88] [32 100]]]] [7242 1.33 [38 72] [38 83]]] [8 68]] [32 47]] [38 93]] [791 7.41 [32 95] [32 100]]] [12 57]] [30 72]] [10 100]] [24 75]] [12 36]] [36 42]] [818 5.49 [5892 3.17 [29 38] [23 66]] [29 100]]] [15 66]] [4132 0.551 [38 69] [38 100]]] [8 83]] [36 30]] [6699 3.64 [3027 17 [1917 8.15 [5969 7.72 [2806 2.82 [2093 5.68 [5007 6.75 [5647 9.85 [6015 9.44 [4369 2.59 [475 4.11 [1622 2.35 [5211 6.14 [816 10.4 [429 3.3 [5412 10.8 [2103 6.33 [7491 18.1 [2073 3.69 [33 11] [28 44]] [15 28]] [10 100]] [23 33]] [7169 6.06 [7287 3.82 [2260 5.99 [11 15] [30 75]] [11 68]] [15 28]]] [11 100]] [23 85]] [11 100]] [11 50]] [32 47]] [21 40]] [5884 0.694 [4684 2.65 [11 44] [11 100]] [11 87]]] [29 57]] [32 43]] [29 83]] [23 55]] [28 75]] [1986 10.2 [23 57] [23 90]]] [29 100]]] [6389 0.178 [1679 1.6 [7149 2.76 [2420 3.6 [3483 2.9 [4210 0.701 [7411 3.91 [2262 1.55 [2268 4.2 [5034 1.32 [4414 1.6 [2004 7.12 [6294 8.42 [7457 1.87 [6015 1.87 [28 23] [21 40]] [12 71]] [3 50]] [23 39]] [5883 2.82 [33 19] [22 33]]] [28 75]] [12 57]] [28 88]] [29 50]] [30 100]] [32 100]] [28 71]] [38 35]] [2259 23.8 [30 100] [30 60]]] [28 70]]] [15 73]] [2354 1.73 [4279 0.971 [2178 0.637 [2752 11.8 [22 20] [22 74]] [25 33]] [28 58]] [22 100]]] [4533 4 [6342 3.18 [12 87] [32 50]] [12 100]]] [36 100]] [31 100]] [6337 8.07 [660 4.09 [2323 1.92 [1452 6.44 [6853 2.18 [2004 9.35 [3851 2.88 [6260 15.2 [6812 1.75 [208 8.33 [7314 1.16 [6643 1.06 [6436 3.79 [2444 2.96 [4292 18.4 [1586 3.94 [4163 2.92 [4158 1.42 [145 18.3 [3875 2.42 [1776 6.85 [6809 5.05 [392 24 [4611 12.2 [3640 2.26 [5034 9.66 [4611 9.32 [4519 1.47 [2795 2.11 [6294 6.66 [2793 2.3 [5972 12.2 [7742 19 [7169 9.35 [6914 4.42 [4160 3.45 [2123 4.26 [286 12.6 [4564 1.71 [968 5.15 [1436 9.2 [2068 3.06 [2011 5.92 [2342 30.8 [32 14] [23 100]] [29 42]] [29 50]] [33 28]] [28 66]] [24 54]] [24 50]] [36 37]] [23 33]] [13 100]] [10 25]] [18 70]] [36 87]] [1429 31.5 [15 14] [24 26]]] [11 22]] [24 100]] [24 80]] [4 27]] [32 45]] [24 59]] [36 56]] [14 71]] [32 88]] [12 100]] [32 100]] [36 58]] [28 37]] [32 100]] [32 100]] [10 73]] [15 100]] [1078 4.5 [30 93] [30 100]]] [14 42]] [30 52]] [3666 8.48 [24 84] [16 42]]] [32 100]] [24 84]] [35 100]] [23 50]] [24 75]] [29 84]] [32 100]] [15 59]] [24 86]]] [11 100]] [30 100]]] [1764 0.879 [5007 0.849 [6653 0.642 [6017 0.364 [29 92] [29 100]] [29 100]] [29 100]] [27 93]]] [1242 7.69 [23 92] [23 100]]] [1648 3.61 [1216 0.281 [2703 0.832 [7411 1.13 [791 1.62 [5900 0.917 [5130 1.52 [5732 1.63 [788 0.675 [7343 2.7 [388 2.16 [1429 27.3 [2939 3.6 [23 61] [16 47]] [4324 9.55 [23 31] [18 83]]] [18 100]] [18 38]] [18 46]] [4154 3.31 [1429 55.2 [28 94] [28 42]] [28 100]]] [5480 0.21 [1239 8.26 [16 50] [18 41]] [18 78]]] [18 61]] [2081 4.54 [1025 3.84 [6354 5.17 [5480 3.19 [5017 3.67 [5749 4.38 [6310 3.27 [3179 1.93 [3931 1.63 [5381 1.62 [6708 12.7 [6877 0.785 [145 4.81 [5106 0.264 [883 1.02 [1980 5.47 [3342 3.7 [4326 2.11 [5462 1.25 [392 17.1 [1078 27 [4154 4.87 [28 37] [28 56]] [23 40]] [5753 7.23 [377 13.1 [4851 6.67 [28 53] [28 100]] [28 42]] [28 100]]] [1783 4.31 [28 84] [28 81]]] [27 57]] [28 50]] [1084 1.37 [2764 4.3 [23 39] [29 58]] [23 85]]] [28 90]] [28 100]] [28 36]] [21 33]] [28 100]] [28 100]] [23 33]] [28 100]] [28 64]] [23 92]] [28 29]] [1062 2.39 [18 43] [18 61]]] [18 100]] [23 38]] [435 6.85 [6040 3.11 [23 36] [18 66]] [23 80]]]] [30 40]] [29 100]] [27 100]] [28 75]]] [5911 11.4 [4324 0.782 [3332 0.98 [7149 2.04 [978 1.77 [23 59] [7453 1.53 [996 1.28 [23 97] [23 100]] [23 100]]] [23 100]] [35 90]] [23 100]] [11 50]]] [2518 10.8 [24 70] [2518 16.7 [24 85] [24 66]]]] [939 5.95 [2818 0.499 [7638 1.22 [328 5.23 [6665 7.06 [731 15.1 [1586 3.88 [7578 1.62 [3554 7.75 [5972 1.62 [5467 1.69 [286 2.89 [957 8.81 [4414 20.8 [5322 10.3 [811 2.84 [7455 1.16 [1079 6.95 [15 21] [32 68]] [15 100]] [10 35]] [4218 3.4 [15 85] [15 100]]] [15 73]] [10 72]] [2259 5.62 [10 33] [10 83]]] [12 53]] [2752 15.4 [12 100] [5972 15.7 [5972 11 [5972 8.53 [12 90] [12 83]] [12 68]] [2844 21.7 [7452 3.4 [1776 2.89 [811 2.92 [7449 5.88 [12 92] [12 100]] [12 100]] [12 100]] [12 88]] [12 75]]]]] [12 68]] [10 100]] [32 100]] [4 100]] [1239 4.42 [12 95] [12 100]]] [6124 2.65 [1084 1.86 [4530 2.99 [2763 2.33 [377 2.35 [12 49] [15 70]] [12 57]] [3475 11.5 [15 36] [15 100]]] [12 55]] [12 100]]] [12 100]] [12 100]] [7428 1.2 [3573 1.17 [5218 1.68 [10 64] [10 100]] [10 100]] [12 72]]]] [5804 3.03 [4154 10.9 [1567 1.75 [2701 1.37 [5668 1.2 [2143 26 [2931 2.38 [5648 22.8 [934 11.9 [5851 2.33 [2752 9.66 [12 33] [23 5.75 [6791 2.86 [4154 1.29 [23 85] [1899 5.66 [23 100] [23 57]]] [23 100]] [12 50]]] [6342 3.79 [23 100] [23 85]]] [23 57]] [23 53]] [23 100]] [23 55]] [28 58]] [12 100]] [28 84]] [5662 1.72 [2011 0.938 [581 10.9 [5972 6.49 [28 79] [12 100]] [28 100]] [28 91]] [22 47]]] [22 100]]] [5281 1.56 [7329 0.617 [5647 0.698 [4092 1 [2701 4.98 [4704 2.96 [6784 1.55 [3851 1.66 [4956 1.42 [144 2.78 [5809 5.5 [7241 3.89 [6449 1.83 [4895 2.01 [3884 7.86 [2091 3.08 [7142 3.8 [4799 1.6 [5225 1.89 [1239 1.5 [1025 17 [22 39] [22 57]] [4398 1.08 [33 19] [25 33]]] [22 100]] [15 53]] [20 100]] [22 58]] [15 100]] [1783 23 [3 20] [13 42]]] [20 37]] [22 90]] [15 96]] [22 80]] [35 42]] [35 76]] [31 100]] [1899 2.14 [33 55] [33 80]]] [15 90]] [35 87]] [22 71]] [11 22]] [22 100]]] [37 85]] [6363 6.88 [435 6.25 [1679 0.639 [1783 5.81 [5873 19.6 [1562 1.05 [2260 1.12 [4326 2.82 [5110 33.6 [30 97] [30 62]] [30 100]] [30 100]] [30 100]] [30 90]] [1980 1.75 [30 85] [30 100]]] [30 100]] [30 77]] [30 94]]] [22 66]] [4522 0.734 [5462 0.244 [7413 2.64 [5753 1.74 [2786 0.978 [5883 13 [6660 0.565 [6080 0.747 [5730 0.301 [7583 1.72 [6063 0.962 [5662 3.14 [1391 0.515 [968 0.262 [660 0.945 [162 3.76 [549 2.2 [2064 0.645 [859 1.67 [2200 8.82 [2029 9.64 [5110 2.08 [394 24.4 [628 6.76 [5972 5.75 [2178 2.97 [6711 1.57 [2091 3.21 [3027 7.61 [426 4.47 [641 7.94 [144 11 [28 35] [22 50]] [22 83]] [1 75]] [21 33]] [28 68]] [22 100]] [28 37]] [36 66]] [22 100]] [28 100]] [30 30]] [12 33]] [22 55]] [7176 4.26 [22 92] [22 100]]] [11 33]] [22 100]] [22 100]] [29 29]] [1104 0.325 [5851 0.525 [28 94] [28 100]] [28 88]]] [22 98]] [22 82]] [22 100]] [1 45]] [11 100]] [15 100]] [11 100]] [1055 0.353 [22 90] [11 100]]] [29 100]] [7156 1.79 [5011 0.873 [4663 21.3 [5911 3.42 [6031 6.98 [7335 3.64 [145 10.3 [4569 0.31 [2259 2.03 [221 7.35 [28 47] [28 92]] [4768 6.81 [2260 4.13 [2793 0.322 [6529 8.96 [5753 3.36 [28 75] [2023 0.785 [28 89] [28 100]]] [28 66]] [28 97]] [22 40]] [28 46]]] [2143 0.826 [28 97] [28 100]]] [28 42]] [22 50]] [22 100]] [5121 2.49 [28 47] [22 100]]] [28 86]] [28 100]] [22 93]]] [28 70]] [6524 1.51 [28 37] [3008 1.89 [5753 4.84 [2760 1.02 [6791 2.22 [28 66] [22 38]] [28 77]] [4611 0.654 [28 83] [28 100]]] [28 62]]]] [11 100]]] [37 100]] [503 1.13 [124 1.08 [3652 0.879 [5668 1.05 [7747 0.446 [1 1.2 [5972 0.831 [2705 1.05 [7340 1.06 [6349 3.32 [4690 0.816 [2320 1.78 [7695 2.03 [5482 2.43 [7009 1.29 [5163 1.34 [4519 1.78 [4851 0.734 [2913 3.63 [6604 2.33 [811 2.09 [7354 0.858 [7737 9.09 [978 4.88 [899 1.96 [6544 5.5 [377 16.7 [5804 1.05 [1389 2.24 [2763 2.4 [2009 4.15 [7512 6.86 [131 1.82 [7609 16.9 [4895 2.06 [1391 6.28 [4205 2.54 [184 7.04 [132 4 [1696 3.63 [5472 2.11 [14 11] [13 82]] [26 60]] [18 45]] [16 31]] [28 100]] [22 56]] [28 42]] [8 100]] [29 37]] [125 0.597 [6524 5.16 [404 11.1 [4288 20.7 [3655 2.86 [7255 21.9 [7514 5.78 [204 5.53 [4349 7.96 [2846 5.31 [1533 6.33 [7313 5.75 [883 6.26 [549 2.33 [5473 2.3 [1521 1.85 [5281 2.39 [328 20.9 [1646 4.85 [4235 3.03 [7233 4 [652 3.82 [4210 4.59 [2793 14.1 [4505 4.97 [144 35.4 [6382 11.3 [4154 52 [5662 2.35 [7515 4.05 [7665 15.5 [392 1.32 [7149 3.88 [6333 7.77 [2752 13 [13 28] [6406 4.02 [23 11.6 [10 15] [19 20]] [19 50]]] [32 72]] [18 28]] [14 40]] [1416 3.91 [1025 32.7 [1888 6.66 [144 3.4 [5611 12.7 [1023 15.3 [14 24] [14 71]] [36 100]] [14 30]] [14 44]] [13 80]] [14 100]]] [4 30]] [23 71]] [14 80]] [14 71]] [20 57]] [32 100]] [24 36]] [30 80]] [19 64]] [7233 16.1 [32 100] [32 83]]] [20 56]] [32 88]] [14 62]] [32 77]] [13 100]] [13 86]] [22 69]] [13 64]] [20 88]] [5 94]] [6375 3.6 [1104 9.51 [14 28] [22 61]] [22 66]]] [24 68]] [22 92]] [22 43]] [12 61]] [24 70]] [22 66]] [28 84]] [2752 35.5 [7522 4.95 [22 29] [22 100]] [22 95]]] [14 68]]] [1145 3.14 [26 61] [26 100]]] [144 0.645 [22 21] [7722 1.29 [22 86] [22 100]]]] [1390 13.9 [24 94] [24 70]]] [22 100]] [392 6.03 [14 79] [14 100]]] [14 80]] [2488 1.87 [5673 1.74 [14 56] [429 25.2 [14 100] [14 62]]] [13 100]]] [7534 2.99 [7253 1.93 [5261 3.6 [286 1.93 [1980 12.4 [3667 3.4 [6591 9.81 [610 2.09 [17 18] [5 95]] [494 5.88 [17 100] [17 87]]] [1025 3.7 [2 100] [2 53]]] [23 44]] [23 52]] [13 81]] [17 50]] [17 76]]] [2753 3.03 [99 5.55 [4279 22.7 [1911 4.76 [22 28] [2081 2.51 [22 80] [22 71]]] [22 100]] [19 42]] [7419 3.03 [22 96] [22 100]]]] [2764 4.14 [221 2.02 [1078 16.5 [6040 4.63 [23 44.2 [125 3.22 [5430 2.04 [6205 4.27 [653 9.75 [18 28] [5 45]] [18 55]] [2752 19.3 [5 100] [5 50]]] [36 100]] [19 48]] [18 77]] [3820 1.1 [1079 9.38 [6643 1.84 [791 11.7 [18 31] [1906 0.858 [13 44] [13 91]]] [13 60]] [19 50]] [13 82]]] [20 37]] [36 50]]] [10 60]] [1899 8.78 [30 100] [30 66]]] [2259 5.42 [2902 4.9 [429 14 [23 29.2 [25 48] [30 54]] [1429 59.1 [32 36] [32 71]]] [5 50]] [2021 2.92 [32 59] [5 50]]]] [3732 1.45 [7255 8.74 [4288 4.54 [5165 1.65 [3931 2.89 [6666 3.27 [6791 5.09 [6581 5.27 [4801 1.73 [7354 6.05 [5211 7.4 [4851 9.59 [3558 3.18 [14 49] [14 50]] [4854 3.11 [1239 8.45 [7548 10.8 [4061 4.85 [1899 10.1 [4414 11.5 [7665 27.7 [3251 2.82 [5034 12.2 [14 82] [32 56]] [14 88]] [14 91]] [14 76]] [14 40]] [14 100]] [14 50]] [6 20]] [16 41]]] [30 85]] [2259 17.3 [32 33] [36 90]]] [32 100]] [17 38]] [17 50]] [32 100]] [32 51]] [14 100]] [32 83]] [32 69]] [2760 4.8 [17 47] [19 55]]]] [24 100]] [30 100]] [6866 1.49 [4279 0.652 [5641 2.92 [5472 1.23 [7255 1.44 [5198 7.76 [6588 1.25 [144 22.3 [2488 2.88 [5430 7.31 [5211 0.639 [5 33] [30 60]] [5 91]] [13 100]] [20 45]] [5 86]] [13 60]] [13 60]] [13 92]] [22 54]] [13 52]] [5154 14 [5 100] [5 75]]]] [435 1.41 [2143 6.65 [2628 7.05 [6592 2.11 [4279 3.5 [388 1.43 [5641 1.71 [1911 1.22 [7203 1.5 [7057 6.25 [7665 32 [896 1.9 [18 50] [2434 2.96 [18 61] [18 50]]] [29 38]] [19 50]] [18 46]] [16 33]] [19 76]] [18 88]] [18 35]] [18 70]] [18 30]] [22 72]] [29 57]]] [2914 1.73 [5904 1.93 [30 70] [30 91]] [30 87]]] [7233 2.56 [1429 30.7 [1101 5.55 [1400 2.56 [4288 1.85 [32 73] [32 100]] [36 100]] [32 55]] [36 75]] [2320 9.39 [32 80] [32 100]]]] [7311 19.7 [2241 2.4 [20 91] [20 100]] [20 70]]] [5345 4.59 [1213 1.41 [10 92] [10 100]] [10 55]]] [5270 5.74 [5154 7.31 [899 0.894 [4154 12.3 [1552 1.79 [328 9.99 [6230 17.9 [1769 3.07 [6732 6.06 [2628 5.72 [7717 0.928 [5509 15.1 [663 29 [2913 20.7 [32 86] [32 57]] [32 77]] [32 75]] [32 100]] [32 50]] [22 36]] [32 100]] [32 62]] [32 41]] [32 100]] [2323 14.6 [914 1.55 [4354 2.44 [905 2.24 [3075 4.13 [32 95] [32 100]] [32 100]] [32 94]] [32 75]] [32 87]]] [1078 5.81 [32 94] [1436 2.16 [5693 1.83 [32 99] [32 100]] [32 100]]]] [32 68]] [32 66]]] [685 4.2 [29 100] [29 88]]] [7742 1.39 [4815 3.23 [11 1.26 [7677 8.38 [7665 39 [2698 6.9 [5879 6.78 [826 3.36 [328 9.88 [6373 2.82 [2833 2.62 [321 3.18 [6260 1.69 [6173 3.4 [6353 6.51 [2266 4.08 [125 1.98 [23 40.5 [4307 1.77 [144 1.89 [7571 0.277 [5007 4.13 [36 52] [36 100]] [1025 0.998 [36 87] [36 100]]] [36 85]] [36 100]] [36 100]] [36 100]] [31 100]] [36 60]] [31 100]] [2628 5.26 [36 100] [36 71]]] [31 100]] [12 100]] [36 100]] [12 31]] [12 75]] [31 88]] [31 91]] [12 64]] [12 75]] [31 100]] [36 100]] [31 100]]] [2846 0.366 [3012 1.38 [2789 1.1 [5270 1.01 [2381 1.04 [23 7.96 [429 5.19 [12 28] [5472 1.83 [811 1.22 [7185 1.46 [36 35] [18 42]] [10 81]] [850 2.86 [36 96] [36 100]]]] [5780 0.623 [36 61] [36 100]]] [36 55]] [36 100]] [36 100]] [36 100]] [32 55]]] [4608 0.446 [20 97] [20 100]]] [4187 1.36 [5007 4.78 [429 32.1 [12 24] [896 1.54 [7665 7.48 [29 66] [29 92]] [29 100]]] [29 100]] [29 81]]] [24 73]] [32 100]] [4370 10.2 [4288 1.29 [1429 20.3 [32 41] [32 93]] [32 96]] [32 60]]]] [7722 0.0817 [1078 27 [5183 0.593 [4533 8.83 [6436 27.2 [791 16.2 [4458 1.63 [5386 6.8 [5904 19.8 [5900 0.835 [4312 0.756 [30 80] [30 100]] [30 100]] [30 50]] [5386 9.5 [7623 4.12 [30 93] [30 100]] [30 100]]] [30 100]] [30 79]] [5684 2.01 [30 66] [30 100]]] [30 60]] [30 100]] [30 57]] [6436 12.4 [19 38] [14 93]]]] [2225 3.65 [3874 1.24 [1068 0.982 [811 1.15 [7660 0.894 [12 97] [12 100]] [12 100]] [12 100]] [12 100]] [12 92]]] [5345 11.4 [7571 0.971 [5972 2.04 [36 50] [36 100]] [36 100]] [36 63]]] [32 100]] [22 100]] [915 0.475 [645 5.33 [4044 3.33 [6621 27 [1176 4.46 [837 11.1 [1119 1.33 [3735 0.813 [3153 11.7 [2259 22.3 [4807 10.6 [3711 5.49 [4154 3.21 [4667 0.984 [2939 4.31 [740 0.648 [3042 9.01 [1084 4.58 [2199 0.441 [429 1.55 [35 85] [2187 1.05 [2764 1.18 [392 0.95 [328 1.6 [3445 1.18 [35 92] [35 100]] [35 100]] [35 100]] [35 100]] [35 100]]] [35 100]] [35 84]] [35 85]] [35 100]] [35 81]] [35 100]] [4611 2.66 [906 0.876 [831 1.99 [3462 0.659 [35 96] [35 100]] [35 100]] [35 100]] [35 100]]] [3103 7.85 [35 66] [35 92]]] [35 85]] [30 44]] [35 87]] [35 62]] [35 77]] [35 66]] [35 50]] [35 83]] [35 100]] [35 80]] [35 57]]] [3027 4.1 [4500 1.81 [2752 53.9 [2025 0.792 [29 100] [29 75]] [29 66]] [29 100]] [29 80]]] [6528 1.81 [978 0.358 [4202 2.11 [2916 2.54 [7411 0.671 [1867 0.292 [906 2.07 [732 19.7 [2936 6.33 [5073 7.41 [2748 0.436 [7734 1.17 [3207 5.68 [2934 2.69 [4658 1.59 [4769 1.15 [6653 2.16 [4703 3.11 [5482 0.699 [4092 0.754 [6457 6.17 [5561 8.26 [7665 1.81 [5737 3.5 [4874 8.26 [6910 5.71 [5911 8.76 [3523 2.35 [2846 2.33 [2802 1 [2786 0.77 [5110 4.06 [5174 2.45 [7461 3.34 [2166 1 [4897 10.4 [419 7.46 [4338 3.22 [429 5.99 [5480 3.03 [2011 10.4 [5322 10.4 [5617 8.85 [2939 12.4 [248 44.2 [4603 8.2 [685 3.18 [6206 1.95 [1429 15.7 [26 23] [33 17]] [25 50]] [26 58]] [26 100]] [26 29]] [32 20]] [33 66]] [11 36]] [25 87]] [18 75]] [4424 6.41 [2799 4.67 [957 3.7 [567 4.64 [2701 3.03 [2259 8.87 [29 25] [7480 1.57 [4398 3.7 [32 18] [15 60]] [15 85]]] [221 1.53 [29 95] [29 100]]] [8 33]] [248 14.3 [32 50] [32 42]]] [26 85]] [15 60]]] [25 28]] [26 83]] [26 66]] [32 70]] [29 70]] [33 63]] [5170 4.43 [1414 6.85 [15 78] [15 100]] [33 94]]] [29 100]] [29 88]] [25 70]] [15 100]] [15 87]] [15 92]] [1 43]] [15 100]] [6826 3.5 [2251 3.81 [4655 3.5 [3834 4.95 [4245 3.14 [17 4.76 [107 7.1 [4200 6.94 [328 46.8 [1025 2.54 [7340 2.35 [251 1.68 [2755 10.5 [567 1.92 [429 12.5 [1024 2.26 [2755 5.63 [4235 4.72 [25 25] [15 23]] [33 66]] [16 28]] [26 45]] [29 83]] [26 59]] [1 71]] [32 100]] [26 90]] [25 100]] [26 41]] [14 39]] [36 75]] [20 100]] [26 68]] [1 100]] [26 44]] [18 96]]] [33 93]] [25 100]] [35 47]] [3325 0.699 [29 64] [29 100]]] [33 70]] [2199 5.3 [1735 1.42 [552 2.09 [33 71] [29 83]] [29 100]] [29 71]]] [29 97]] [1 100]] [6184 3.07 [33 74] [33 85]]] [38 48]] [18 91]] [26 87]] [29 100]] [25 85]] [2755 32.9 [26 100] [26 88]]] [4662 1.33 [7413 0.938 [5206 4.08 [7460 1.59 [2764 7.8 [6115 0.527 [2004 0.761 [429 24.8 [26 49] [6732 3.25 [5526 1.41 [2705 2.09 [4768 1.42 [29 75] [29 97]] [29 100]] [29 100]] [29 62]]] [4184 1.99 [7512 1.22 [29 92] [29 100]] [29 100]]] [29 100]] [33 83]] [29 81]] [26 66]] [33 55]] [29 100]]] [248 10.9 [33 66] [2763 3.27 [4398 0.292 [33 90] [33 100]] [33 100]]]] [7480 3.03 [2993 1.21 [1510 0.797 [7461 2.24 [6732 5.63 [15 72] [2808 2.96 [15 70] [15 100]]] [15 100]] [15 100]] [15 40]] [15 100]]] [1239 5.68 [25 70] [25 41]]] [1 95]] [6826 3.03 [5999 2.48 [771 2.37 [7340 3.82 [2764 8.49 [1911 7.46 [4703 2.97 [2760 10.2 [7449 8.49 [4602 0.932 [1400 25.5 [5907 1.54 [5170 1.01 [4977 3.42 [107 7.79 [6724 5.06 [5099 16.9 [144 8.69 [2897 6.26 [2755 37.9 [4613 1.05 [6791 6.1 [5110 12.5 [4391 6.79 [5509 7.27 [5673 16.6 [7413 7.47 [5851 10.7 [2916 4.67 [1223 3.07 [4159 10.5 [384 23.5 [999 1.17 [5694 2.54 [431 1.53 [1213 7.26 [26 83] [26 66]] [26 54]] [26 100]] [26 100]] [26 61]] [29 42]] [26 96]] [26 60]] [18 50]] [19 42]] [26 60]] [10 28]] [26 72]] [7 33]] [26 72]] [248 32.5 [26 88] [26 100]]] [26 50]] [26 44]] [26 85]] [18 50]] [26 50]] [14 33]] [18 75]] [5799 2.05 [4385 12.1 [6473 1.89 [2897 5.18 [23 12 [1223 1.06 [2259 1.02 [394 2.42 [26 96] [26 85]] [26 100]] [26 71]] [4601 2.07 [26 81] [26 87]]] [4738 0.717 [26 37] [26 83]]] [26 50]] [26 66]] [26 100]]] [26 52]] [6199 10.4 [1415 3.5 [5692 3.11 [26 61] [26 93]] [26 100]] [25 60]]] [5170 1.54 [4611 7.39 [26 93] [26 77]] [2755 3.2 [26 77] [26 100]]]] [26 40]] [25 40]] [25 70]] [26 37]] [31 33]] [26 52]] [25 100]] [679 0.583 [25 36] [25 60]]] [18 93]]] [3099 1.22 [1062 1.77 [2755 7.41 [1813 1.39 [5110 7.84 [1 52] [15 68]] [1 50]] [25 46]] [15 56]] [23 18.8 [248 28.9 [1 100] [1 80]] [1 78]]]]] [3905 55.1 [4235 10.6 [6524 7.36 [4369 0.303 [5316 1.6 [7354 1.56 [7449 1.57 [3075 1.51 [32 88] [32 100]] [32 100]] [36 66]] [32 100]] [660 0.775 [3908 4.24 [32 94] [32 92]] [32 100]]] [36 90]] [32 50]] [15 55]]] [5615 0.467 [685 0.563 [3660 0.682 [2793 0.778 [7507 0.376 [2531 0.16 [6926 0.155 [7176 3.17 [5420 1.02 [1919 0.0835 [7713 1.06 [6528 1.01 [4519 0.81 [3851 0.262 [5828 1.01 [2526 51.9 [3313 0.701 [7381 0.47 [248 15.7 [6809 0.243 [929 1.84 [3333 0.693 [4997 0.213 [6182 2.13 [3155 0.99 [4832 1.52 [5403 3.93 [7512 1.55 [2955 0.573 [3332 1.16 [7453 4.41 [1226 3.6 [2849 6.41 [957 0.455 [2957 2.11 [6653 3.63 [660 1.82 [791 9.27 [4858 1.36 [1786 3.18 [2752 26.9 [5267 5.72 [1059 9.64 [5632 4.24 [5833 2.02 [6550 1.39 [4960 7.53 [4968 5.71 [7472 7.93 [435 7.83 [5211 2.1 [5692 12 [5574 3.74 [4840 3.31 [5110 1.53 [4338 5.56 [6848 2.23 [3849 0.537 [4312 3.1 [407 11.7 [5851 4.7 [1239 0.331 [5812 14.3 [3928 1.83 [4205 7.86 [4663 14.5 [221 4.67 [1888 17.8 [12 10] [4 26]] [4 50]] [25 60]] [7 57]] [12 53]] [4 85]] [1980 18.6 [2251 0.152 [3136 3.65 [5642 1.02 [1913 0.668 [663 19.8 [33 9] [33 44]] [17 27]] [19 42]] [30 44]] [17 33]] [1 24]]] [429 3.41 [2536 7.99 [2 25] [2 69]] [5 30]]] [8 57]] [12 50]] [35 100]] [35 60]] [23 28]] [33 52]] [19 29]] [16 50]] [18 33]] [5110 7.38 [2550 1.51 [8 36] [8 81]] [8 40]]] [23 66]] [38 71]] [35 100]] [4 100]] [978 6.8 [8 36] [8 66]]] [8 100]] [16 37]] [2 84]] [6078 5.38 [5871 2.44 [4 24] [31 85]] [31 100]]] [3928 11.2 [3027 29.2 [1943 2.92 [5480 4.95 [7354 2.96 [7321 1.52 [774 3.68 [1668 3.23 [7497 0.678 [312 3.85 [978 5.21 [6310 16.7 [4991 3.49 [5 10] [12 45]] [17 85]] [434 4.67 [23 22] [19 26]]] [4 38]] [2089 2.79 [23 41] [23 100]]] [4 44]] [23 83]] [14 33]] [18 25]] [5480 8.2 [18 37] [6732 5.88 [18 60] [18 80]]]] [23 75]] [23 78]] [17 81]]] [16 19]] [23 92]] [144 1.19 [4852 5.49 [7638 1.2 [5812 0.634 [4956 11.9 [5328 6.61 [4968 3.36 [2048 2.65 [1487 4.2 [1993 5.06 [5225 5.74 [5568 2.28 [630 2.62 [2753 13 [221 2.18 [1995 1.86 [6917 2.89 [4533 0.998 [1769 9.56 [1036 6.33 [7340 5.05 [4418 1.98 [7451 9.01 [5219 7.63 [663 9.49 [6310 6.37 [2241 0.392 [4235 5.73 [4776 2.73 [312 4.18 [23 29] [2 72]] [2 42]] [1 50]] [4 21]] [5 35]] [5 54]] [22 50]] [23 66]] [23 75]] [32 80]] [12 28]] [27 37]] [21 42]] [23 100]] [826 4.85 [11 44] [23 64]]] [2 19]] [17 53]] [35 75]] [35 100]] [23 85]] [23 83]] [23 100]] [11 41]] [35 63]] [23 94]] [2526 13.2 [35 100] [35 71]]] [4 26]] [12 100]] [8 100]] [17 23]]] [688 1.19 [23 70] [23 42]]] [1899 2.04 [8 47] [33 76]]] [8 84]] [3933 0.559 [5588 0.455 [3095 7.1 [6791 2.09 [27 36] [23 66]] [27 100]] [27 50]] [27 85]]] [3244 1.97 [2709 6.85 [6831 4.46 [75 1.07 [4051 3 [2075 2.38 [16 26] [16 100]] [16 71]] [16 91]] [18 64]] [16 87]] [37 36]]] [23 79]] [1089 2.35 [23 78] [23 100]]] [35 81]] [5632 0.756 [3929 1.47 [1897 2.17 [5723 3.25 [2469 0.233 [4851 0.186 [16 27] [16 61]] [38 50]] [16 92]] [3897 1.2 [1078 2.98 [37 26] [16 33]] [5 57]]] [37 47]] [5626 7.36 [16 64] [6 42]]]] [7354 3.57 [3667 1.06 [7309 2.49 [5310 0.184 [5219 1.64 [2753 4.18 [7566 3.73 [2739 6.78 [6949 3.92 [3008 1.85 [7523 1.36 [7332 2.93 [5627 2.09 [5647 22.8 [21 3.26 [3273 1.69 [1704 2.82 [5260 2.24 [7449 6.84 [4931 4.95 [5467 1.46 [4805 4.08 [7529 2.79 [2398 1.85 [7188 7.81 [5170 1.65 [5034 1.1 [6582 2.28 [6173 3.07 [6920 4.33 [1429 14.1 [7664 4.54 [134 4.68 [7512 28.4 [6732 17.2 [7734 3.17 [7680 2.46 [5383 4.11 [187 6.03 [2178 8.24 [328 7.94 [7248 2.46 [6349 1.24 [2 18] [10 100]] [17 50]] [5753 1.24 [1 21] [1 57]]] [23 40]] [1 20]] [17 58]] [10 76]] [18 42]] [4 25]] [6584 3.6 [5 18] [5 80]]] [2 47]] [2 60]] [328 0.403 [1533 1.35 [5972 0.975 [5482 0.634 [5429 0.754 [6347 2.33 [2752 49 [1400 6.06 [2241 1.67 [2752 38 [791 1.56 [978 7.58 [5574 2.96 [2259 22.7 [5 18] [6 75]] [2 33]] [19 33]] [736 6.99 [7712 2.55 [6724 3.75 [3905 13.5 [7711 1.87 [5 32] [5 62]] [5 42]] [5 25]] [5 54]] [5 50]]] [17 19]] [18 33]] [4 75]] [17 33]] [5 71]] [5 61]] [18 57]] [12 52]] [5 100]] [1899 2.42 [2902 0.976 [7 17] [7 45]] [6 35]]]] [2 41]] [31 100]] [4 100]] [32 41]] [26 60]] [5 30]] [12 85]] [24 100]] [5851 0.739 [7512 18.8 [17 88] [17 33]] [17 50]]] [12 86]] [4 81]] [12 27]] [13 82]] [723 0.626 [1011 1.2 [17 66] [17 50]] [17 100]]] [1 93]] [663 1.39 [17 40] [5 57]]] [1073 10.6 [7512 26.3 [4414 1.21 [1 66] [1 90]] [1 30]] [2 28]]] [7419 2.67 [16 71] [16 85]]] [19 53]] [23 91]] [5851 0.839 [791 9.71 [19 19] [17 44]] [17 50]]] [4428 1.07 [2745 2.06 [17 23] [1 100]] [1 100]]] [4 72]] [1011 1.18 [2628 14.5 [1783 3.88 [5 18] [1 42]] [4 45]] [7253 3.34 [5 72] [5 75]]]] [7722 3.69 [4154 9.99 [6206 9.69 [2119 0.503 [6131 12.4 [5037 0.471 [2591 2.11 [5851 4.47 [4741 3.02 [24 19] [14 40]] [19 55]] [19 60]] [32 60]] [17 50]] [19 70]] [600 2.92 [19 55] [17 69]]] [1017 4.51 [19 56] [5 22]]] [7722 9.98 [6589 6.57 [5 35] [19 30]] [14 38]]]] [10 59]] [10 100]] [25 93]] [7512 15.2 [2 43] [2 92]]] [16 1.49 [1838 1.65 [7287 3.03 [2385 4.29 [642 1.63 [7456 2.35 [4601 5.39 [2717 2.26 [1429 11.3 [7149 2.27 [7693 0.644 [5482 2.62 [32 22] [18 47]] [18 50]] [16 40]] [4851 4.51 [2259 1.27 [7255 1.92 [5692 13.8 [7340 2.02 [647 1.81 [284 2.28 [2913 5.88 [2005 6.9 [5154 3.78 [18 36] [18 50]] [15 30]] [5 66]] [18 50]] [5 57]] [18 100]] [18 72]] [18 52]] [1025 2.74 [18 69] [16 41]]] [5 43]]] [16 50]] [36 54]] [5 63]] [5 63]] [392 2.48 [5693 3.28 [5482 11.3 [144 3.44 [18 80] [18 100]] [16 42]] [18 100]] [18 63]]] [8 100]] [19 88]] [36 100]]]] [31 80]] [7210 8.29 [4338 4.55 [3279 3.01 [1068 1.74 [4414 6.85 [429 6.33 [2 91] [4253 3.46 [5211 1.15 [2 60] [2 40]] [2 100]]] [2 50]] [2 93]] [4 45]] [2 87]] [2 43]]] [439 3.58 [2526 7.34 [35 97] [35 82]] [35 87]]] [25 100]] [7 96]] [4658 0.849 [1 97] [1 100]]] [2939 1.26 [4832 1.66 [1761 1.86 [494 3.84 [896 1.53 [934 1.03 [4991 11.7 [6491 2.46 [23 53] [23 100]] [2 60]] [23 100]] [1899 6.43 [5 50] [5 30]]] [17 66]] [23 100]] [2 64]] [5 22]]] [32 100]] [4682 3.64 [7623 5.21 [6457 0.657 [2570 3.24 [6581 1.37 [7449 7.53 [6471 1.15 [286 3.86 [5170 1.23 [6180 1.31 [1239 25.2 [5918 4.37 [6791 4.58 [6524 5.29 [5480 1.27 [2526 19.5 [7354 2.59 [185 0.541 [1024 0.573 [5647 10.4 [1429 22.8 [673 6.27 [26 46] [4158 1.11 [26 94] [26 100]]] [26 56]] [26 57]] [19 75]] [26 62]] [26 45]] [5647 2.88 [2101 6.98 [731 6.17 [178 16.2 [25 39] [25 85]] [26 75]] [25 70]] [1 50]]] [26 65]] [2769 3.82 [25 82] [25 100]]] [5692 2.76 [25 59] [6791 11.6 [25 100] [25 85]]]] [7343 4.71 [26 65] [26 100]]] [2752 13.2 [3 27] [1980 3.13 [33 46] [25 72]]]] [25 100]] [270 5.04 [5412 7.42 [4851 1.61 [791 19.5 [1429 7.04 [913 3.65 [2259 12 [26 89] [26 60]] [19 50]] [978 2.2 [26 76] [26 100]]] [26 60]] [26 100]] [26 55]] [19 62]]] [25 88]] [160 1.24 [2199 3.81 [939 0.568 [6616 6.01 [2849 14.9 [2913 5.35 [5412 2.66 [26 95] [26 80]] [26 88]] [5170 6.65 [26 100] [26 60]]] [26 77]] [26 77]] [26 75]] [26 40]]] [25 60]] [26 97]] [33 53]] [25 95]] [33 55]] [33 94]]] [7032 0.707 [4929 4.08 [7021 2.1 [2610 0.588 [7384 0.785 [7533 4.7 [5157 6.41 [5812 4.51 [739 0.77 [5952 0.367 [7497 1.23 [1025 3.09 [6544 2.64 [4851 7.16 [6581 1.01 [5 34] [17 38]] [17 45]] [17 46]] [520 5.32 [4288 3.14 [1239 3.1 [4 31] [5 50]] [2 40]] [2 81]]] [2 50]] [4564 1.4 [19 40] [17 40]]] [2 100]] [1640 3.75 [494 2.35 [7718 0.47 [7711 3.4 [6550 1.66 [2 42] [1429 9.56 [4 92] [35 50]]] [17 100]] [2 62]] [7 50]] [2 77]]] [6575 5.35 [5 72] [5 94]]] [17 75]] [17 51]] [2 79]] [5 86]] [4 54]] [2939 16.5 [1011 2.71 [7413 0.707 [2 95] [2 71]] [2 73]] [4 85]]]] [5 85]] [7665 9.03 [881 1.82 [5833 0.81 [6560 3.11 [8 26] [8 100]] [8 100]] [8 97]] [1783 19.1 [7665 34 [2804 3.18 [2764 3.88 [7588 1.29 [2 21] [5 68]] [7665 20.1 [4 35] [2 31]]] [8 100]] [3675 3.07 [5 24] [5 72]]] [25 54]]]] [5480 1.87 [4606 1.95 [8 80] [8 100]] [8 100]]] [5605 0.575 [5018 1.83 [5192 1.01 [787 4.85 [7665 1.56 [3849 0.349 [2259 3.86 [35 85] [35 33]] [1078 15.2 [771 0.196 [35 87] [35 100]] [35 76]]] [35 33]] [35 61]] [26 73]] [35 100]] [35 42]]] [5793 1.39 [3657 2.35 [2518 11.3 [24 96] [24 66]] [24 100]] [24 100]]] [5693 3.62 [7043 1.72 [1081 6.34 [896 6.81 [5007 2.76 [4655 1.01 [7413 5.36 [25 53] [25 93]] [4414 1.01 [1 77] [1 100]]] [1 85]] [25 88]] [25 91]] [1 80]] [1 90]]] [1891 3.18 [4304 12.2 [6310 1.51 [2841 2.8 [5 87] [5 61]] [5 100]] [5 57]] [5 62]]] [4491 1.66 [978 3.36 [3635 0.717 [3851 0.833 [6524 1.46 [7381 1.24 [5170 1.4 [2795 1.44 [1996 3.47 [2674 2.91 [2562 2.12 [2961 0.121 [5413 1.49 [2833 2.96 [7292 2.59 [2164 0.626 [187 3.41 [2537 2.4 [2530 0.934 [4718 6.56 [4832 1.71 [7354 1.75 [2739 6.4 [5680 0.766 [1068 6.74 [2050 0.779 [6888 1.47 [3409 1.95 [2128 2.79 [7693 6.95 [3207 6.36 [5403 7.75 [2 11] [31 100]] [36 70]] [4 28]] [24 45]] [5 55]] [5 100]] [2 55]] [2 37]] [36 30]] [4 72]] [18 31]] [4279 2.7 [4833 7.47 [2 57] [4 71]] [2 83]]] [4 69]] [26 58]] [12 78]] [7512 0.629 [16 92] [16 50]]] [1 66]] [2 100]] [12 100]] [6396 3.44 [2905 0.291 [573 1.59 [4187 3.66 [2241 7.56 [688 0.701 [18 29] [2 55]] [2 100]] [576 5.92 [2 45] [2 73]]] [4154 18.8 [2259 7.74 [5 21] [19 23]] [4 48]]] [2 75]] [17 81]]] [4 100]] [23 90]] [2 100]] [23 90]] [24 92]] [5140 3.81 [7516 0.448 [26 50] [5170 10.9 [26 83] [26 100]]] [33 95]]] [5155 1.86 [3989 1.28 [6538 0.761 [7461 2.25 [228 0.413 [4851 1.45 [2 59] [4 35]] [6076 3.26 [429 16.4 [4 100] [2 53]] [2 69]]] [4 71]] [2 100]] [4 90]] [5 90]]] [3929 2.79 [1 53] [17 100]]] [35 89]] [1 100]] [140 0.303 [1007 1.65 [1033 1.21 [6040 1.66 [429 7.06 [5299 0.654 [980 0.418 [26 32] [266 0.418 [26 72] [26 72]]] [25 66]] [5848 0.291 [1075 2.84 [5225 0.236 [7354 2.87 [1640 2.55 [1633 5.17 [4959 0.994 [1078 10.8 [1723 0.501 [3915 0.975 [1883 0.671 [5695 0.699 [5211 2.96 [5198 1.69 [1078 4.33 [3905 1.45 [7009 2.93 [2 21] [4 37]] [17 84]] [2 33]] [1073 3.93 [2536 0.945 [2 33] [2 83]] [5 50]]] [2562 7.18 [23 40] [23 100]]] [5692 8.26 [25 62] [1 50]]] [2 56]] [5819 4.39 [17 100] [17 87]]] [2939 7.73 [6395 3.5 [5883 8.06 [17 62] [17 87]] [17 87]] [17 33]]] [4663 13.1 [6921 3.28 [7449 3.4 [7665 4.55 [1995 7.55 [1993 0.963 [2628 4.41 [4414 1.71 [2 26] [2 57]] [4 92]] [4 50]] [23 41]] [2 55]] [2 23]] [23 88]] [23 80]]] [4 95]] [19 100]] [6920 0.579 [6076 0.363 [791 12.6 [2 85] [2 57]] [682 2.25 [2 100] [2 66]]] [2 100]]] [7354 25 [18 40] [4 45]]] [23 95]] [2 62]] [4 100]]] [1705 0.763 [18 74] [18 85]]] [5693 1.03 [2 76] [1899 15.3 [17 0.89 [2 94] [2 100]] [2 71]]]] [1051 2.94 [7722 6.11 [2939 4.88 [2 63] [2 88]] [5 60]] [2 100]]] [2 91]]] [24 91]]] [5970 1.14 [4184 1.11 [2570 3.89 [7185 2.09 [1253 9.92 [435 1.87 [2081 16.6 [5110 0.846 [2023 12.4 [6196 1.44 [2562 1.16 [23 86] [23 100]] [23 66]] [23 85]] [5420 8.48 [22 42] [23 27]]] [23 60]] [23 100]] [23 63]] [23 62]] [13 76]] [2143 0.44 [2259 4.9 [2570 7.96 [13 57] [13 100]] [8 45]] [8 62]]] [23 100]]] [5171 1.72 [7646 1.44 [663 0.467 [2628 9.53 [4693 0.397 [5140 0.821 [1888 15.8 [3874 3.53 [883 0.96 [6560 4.09 [7101 1.98 [8 57] [22 42]] [4852 1.03 [8 95] [8 100]]] [4414 1.81 [0 83] [2 50]]] [12 100]] [8 24]] [1239 3.27 [33 84] [7413 1.68 [33 100] [33 91]]]] [8 100]] [7 13]] [4154 1.4 [6732 2.1 [4533 0.467 [791 15.4 [0 36] [22 76]] [22 42]] [7 37]] [22 90]]] [33 90]] [7415 1.72 [5412 7.45 [33 92] [33 100]] [33 100]]]] [3670 2.98 [5368 7.85 [2907 0.448 [6170 1.65 [5799 0.207 [1888 24.7 [6926 6.1 [5192 3.76 [1925 4.06 [23 0.411 [1888 7.59 [5662 2.14 [6089 4.82 [7381 1.95 [2 100] [2 89]] [2 55]] [1040 0.454 [2 93] [2 100]]] [4832 2.35 [2 60] [2 100]]] [7032 1.27 [1993 0.452 [2 75] [2 50]] [2 100]]] [2 72]] [2 100]] [6925 0.885 [7381 7.36 [1051 1.01 [4669 1.47 [1083 3.27 [4158 10.1 [514 3 [4991 0.52 [2 75] [2 100]] [2 53]] [2 60]] [4 44]] [2 25]] [2 100]] [7665 3.76 [2 62] [2 100]]] [2 57]]] [4 66]] [2 54]] [2 37]] [6817 0.679 [2576 0.944 [5197 0.568 [2 100] [2 77]] [2 83]] [2 100]]] [896 3.92 [2 60] [2 81]]] [1919 5.02 [2 47] [2 80]]]] [996 0.299 [5420 0.501 [6639 1.18 [2081 3.33 [23 80] [23 100]] [23 100]] [23 100]] [23 100]]] [7665 1.04 [23 100] [23 55]]] [4519 0.428 [3652 1.74 [3905 13.8 [2517 0.445 [1094 2.35 [5467 1.67 [819 1.81 [429 25.5 [7520 2.73 [1888 2.54 [4286 20 [4344 1.9 [2531 2.33 [4169 1.19 [2570 10.2 [2299 4.05 [4349 0.785 [1913 6.5 [2518 2.44 [2099 3.11 [5972 4.82 [5211 2.38 [23 56] [23 68]] [178 2.39 [2398 5.08 [12 68] [12 100]] [12 100]]] [23 88]] [24 85]] [23 92]] [24 46]] [23 42]] [24 69]] [24 85]] [23 86]] [2752 25.7 [24 75] [24 90]]] [27 82]] [24 30]] [24 88]] [791 30 [5692 10.4 [7169 1.11 [4768 1.95 [2764 1.08 [2939 2.42 [23 63] [18 38]] [23 100]] [23 100]] [23 94]] [24 66]] [12 47]]] [27 100]] [12 86]] [1094 20.9 [6397 0.654 [23 95] [23 85]] [2081 40.7 [1919 5.75 [2526 13.8 [23 50] [23 90]] [23 100]] [27 41]]]] [2764 1.15 [24 89] [24 100]]] [14 100]] [2517 13.8 [5192 0.956 [23 1.22 [6732 2.15 [24 76] [19 50]] [24 100]] [24 100]] [24 62]]] [6373 2.78 [2029 1.44 [1919 4.95 [3652 4.17 [4357 0.428 [24 94] [24 100]] [1025 13.4 [24 100] [896 4.73 [24 70] [24 80]]]] [24 87]] [24 100]] [24 71]]]] [3548 0.56 [5660 4.86 [1436 1.53 [7445 0.855 [7351 3.53 [2616 4.85 [1980 6.37 [2451 2.89 [2143 0.431 [3643 5.94 [2763 2.8 [4814 4.85 [2265 0.838 [6373 2.31 [6997 5.08 [2777 1.46 [24 92] [24 77]] [24 66]] [24 83]] [24 100]] [24 66]] [1888 1.55 [24 50] [24 91]]] [24 57]] [24 100]] [24 62]] [24 57]] [24 95]] [19 46]] [24 56]] [7301 3.43 [19 56] [24 85]]] [24 62]] [19 70]]] [6921 0.137 [1400 2.41 [5089 0.713 [5225 0.561 [5114 0.336 [7734 0.643 [1078 11.1 [1223 0.564 [5695 0.556 [3370 0.612 [3207 5.49 [6042 1.05 [4603 1.01 [5969 0.547 [2259 19.6 [2628 4.27 [3332 12.5 [6732 3.08 [3006 0.756 [3273 2.82 [5914 1.09 [1011 1.04 [2081 3.24 [1068 7.43 [23 5.62 [1533 3.69 [7693 1.57 [398 1.3 [4533 7.12 [7210 8.78 [377 2.89 [2178 9.59 [896 7.95 [2589 1.92 [429 35.9 [663 4.59 [2759 10.6 [7665 6.8 [8 34] [7 41]] [23 66]] [16 28]] [2259 3.65 [23 62] [23 100]]] [8 100]] [18 47]] [23 71]] [7 42]] [8 61]] [8 50]] [23 74]] [18 33]] [8 100]] [18 44]] [23 90]] [1068 0.928 [23 84] [23 92]]] [7 47]] [23 100]] [35 100]] [26 100]] [328 16.7 [18 37] [26 75]]] [35 100]] [1011 3.91 [4279 0.711 [6830 0.473 [8 25] [1631 0.852 [16 60] [2671 4.03 [18 57] [16 60]]]] [4 25]] [7 62]]] [8 48]] [1980 5.57 [7354 5.36 [19 33] [18 70]] [1668 2.49 [23 100] [18 66]]]] [4205 6.56 [978 6.53 [26 85] [26 100]] [26 85]]] [5662 1.65 [18 100] [18 75]]] [26 88]] [8 100]] [791 6.12 [4205 2.46 [26 71] [178 0.627 [26 83] [26 100]]] [26 63]]] [26 80]] [6732 0.164 [5366 0.24 [3438 3.47 [5450 0.924 [1011 1.01 [5079 0.956 [7354 2.73 [980 0.982 [1980 8.06 [7472 1.15 [4205 1.14 [685 7.86 [23 25] [23 45]] [16 33]] [38 75]] [2081 0.684 [23 75] [2088 1.23 [23 97] [23 100]]]] [26 81]] [5211 1.49 [2752 18.4 [18 58] [16 64]] [8 92]]] [26 72]] [26 70]] [23 100]] [35 87]] [23 100]] [2799 1.21 [5693 1.21 [5753 0.536 [26 44] [26 33]] [5662 0.258 [18 57] [22 44]]] [26 88]]]] [2259 37.2 [6524 1.56 [7734 8.33 [1239 23.2 [913 1.55 [5516 0.652 [5692 4.39 [5904 1.23 [5281 1.79 [2005 1.15 [7722 0.11 [4517 2.07 [1919 3.38 [4540 0.282 [738 0.393 [6877 0.479 [18 50] [18 77]] [2983 1 [18 71] [18 87]]] [18 100]] [18 100]] [18 28]] [18 81]] [18 66]] [18 38]] [5480 8.25 [7 50] [19 66]]] [7601 0.824 [4926 3.88 [957 2.62 [18 73] [18 60]] [18 100]] [18 100]]] [18 63]] [18 57]] [19 36]] [383 9.09 [1429 7.31 [18 50] [6827 21.8 [4154 2.97 [429 24.9 [4540 1.48 [7512 12.3 [18 95] [18 61]] [18 100]] [18 100]] [18 70]] [18 66]]] [18 78]]] [7 75]] [19 55]]] [8 100]] [929 3.46 [4768 1.14 [5411 0.657 [2409 0.743 [5692 8.38 [23 90] [23 55]] [23 100]] [23 100]] [23 100]] [23 100]]] [23 98]] [1888 0.345 [5386 2.89 [4288 1.58 [3208 2.3 [7321 0.934 [510 3.91 [6585 1.04 [2143 0.715 [7516 0.855 [26 52] [26 80]] [26 41]] [26 95]] [26 100]] [26 42]] [10 40]] [26 100]] [33 37]] [733 1.03 [980 2.07 [423 0.565 [2616 1.96 [26 63] [7516 3.67 [26 100] [26 66]]] [26 100]] [26 100]] [26 88]]]] [5322 3.3 [2081 0.855 [23 96] [23 100]] [23 85]]]] [4832 0.754 [1078 0.607 [23 71] [23 97]] [2 45]]]] [5972 1.21 [1078 6.27 [4159 1.46 [5211 1.02 [663 2.6 [6920 2.42 [2955 2.83 [4611 1.59 [24 35] [29 44]] [16 83]] [24 50]] [1087 1.14 [29 86] [29 100]]] [20 47]] [29 100]] [978 3.16 [1888 2.23 [2259 34.4 [1980 0.142 [4235 4.23 [5412 6.71 [3308 2.35 [943 0.349 [221 1.13 [145 0.605 [1628 1.05 [36 41] [7491 1.93 [29 87] [29 100]]] [29 100]] [29 96]] [29 100]] [29 100]] [22 50]] [20 93]] [5931 1.2 [7168 3.42 [6184 13.1 [4851 0.848 [7210 1.86 [4235 6.73 [1452 0.206 [1025 4.4 [1094 19.7 [2023 2.67 [2048 0.462 [2149 0.65 [6122 0.654 [6213 0.785 [7497 0.697 [2001 1.17 [515 1.15 [6524 1.06 [29 100] [29 87]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [2786 1.61 [5073 17.9 [2252 1.46 [1911 2.48 [29 100] [939 2.42 [29 88] [29 100]]] [29 100]] [29 91]] [29 100]]] [29 94]] [29 88]] [29 95]] [20 100]] [29 85]] [29 100]] [29 75]] [29 83]] [29 72]]] [64 0.428 [29 50] [29 100]]] [5 33]] [7520 1.56 [906 2.62 [2151 1.4 [1226 1.72 [24 48] [23 100]] [23 81]] [29 88]] [4 71]]]] [5950 0.982 [7374 0.833 [2939 0.982 [6210 0.948 [557 2.06 [36 61] [36 100]] [36 100]] [12 62]] [36 80]] [36 100]]]] [6173 0.709 [2326 0.596 [2787 0.298 [5090 0.735 [874 0.534 [5462 3.94 [4569 0.921 [4300 0.317 [2795 0.485 [5036 1.38 [7571 1.12 [3067 1.38 [1559 1.51 [978 0.882 [6155 3.4 [5509 2.45 [7176 1.83 [859 1.3 [6607 1.57 [2273 1.4 [814 0.838 [5222 0.644 [6336 2.16 [5034 0.914 [6266 1.6 [1389 0.766 [4611 1.89 [1575 11 [7101 2.22 [4189 1.33 [2847 6.33 [5211 2.56 [7425 11.5 [2616 11.4 [6883 2.28 [3659 4.07 [7343 1.61 [5472 1.63 [5693 7.05 [377 0.447 [2259 12.1 [3004 4.42 [4338 3.88 [36 42] [19 33]] [36 100]] [1089 2.44 [1025 7.84 [2753 13 [1169 3.4 [6920 4.5 [36 77] [36 100]] [36 100]] [12 57]] [24 61]] [24 44]]] [28 69]] [36 54]] [36 96]] [36 45]] [24 77]] [29 50]] [24 89]] [24 100]] [22 83]] [22 100]] [4495 2.53 [24 91] [24 100]]] [22 75]] [24 100]] [144 3.06 [118 2.76 [5454 4.85 [36 72] [36 100]] [36 100]] [36 77]]] [24 93]] [24 94]] [30 48]] [24 93]] [30 100]] [36 100]] [36 94]] [28 88]] [30 54]] [7176 11.5 [22 86] [22 100]]] [7210 1.99 [28 66] [28 57]]] [30 80]] [791 15 [996 2.06 [312 1.89 [4338 2.04 [24 57] [24 92]] [24 57]] [8 100]] [2832 3.32 [24 30] [24 50]]]] [36 100]] [36 100]] [4611 1.85 [36 77] [36 100]]] [1053 1.55 [6732 14.7 [28 97] [28 70]] [28 100]]] [1011 1.58 [2526 8.62 [4991 0.917 [6337 8.56 [2771 1.43 [4357 2.89 [24 84] [24 100]] [24 100]] [19 50]] [24 55]] [24 100]] [19 50]]] [4189 13.5 [24 100] [4300 13.9 [24 87] [24 100]]]] [1078 11.5 [5647 2.35 [36 82] [36 60]] [28 70]]] [28 66]] [36 100]] [2752 17.3 [24 50] [6818 1.38 [22 75] [22 100]]]] [28 93]] [36 98]] [31 100]]] [1640 0.266 [978 0.553 [883 0.316 [2259 13.5 [2526 8.48 [1226 1.34 [7623 1.5 [23 45] [27 85]] [23 100]] [5225 0.467 [23 86] [23 100]]] [23 33]] [22 60]] [2752 13 [5999 1.5 [5211 0.632 [2143 1.55 [23 63] [23 87]] [23 91]] [23 71]] [7363 0.134 [1919 8.51 [286 3.79 [23 72] [435 0.346 [429 24.1 [5662 1.01 [23 91] [23 100]] [791 23.6 [23 100] [23 97]]] [23 100]]] [23 64]] [23 100]]]] [2 88]]] [27 100]] [4587 0.512 [4569 0.578 [2902 2.38 [5219 1.22 [4799 0.385 [5730 1.12 [4851 15.6 [4270 3.08 [2526 15 [6853 0.864 [5972 1.61 [3072 5.6 [3907 3.11 [7255 16.6 [32 72] [15 33]] [7512 31.8 [2628 1.59 [2259 25.6 [32 97] [32 100]] [32 100]] [32 57]]] [18 33]] [36 75]] [5412 2.39 [36 93] [36 71]]] [8 42]] [36 100]] [32 74]] [32 100]] [3265 8.05 [4684 1.72 [4310 1.51 [4799 31.4 [5509 2.09 [7704 4.09 [4414 0.385 [7717 1.03 [6727 3.19 [429 12.1 [32 81] [2323 2.15 [4801 0.96 [2331 6.95 [32 75] [32 100]] [32 100]] [32 100]]] [32 77]] [32 100]] [32 100]] [32 91]] [3905 13 [32 100] [32 75]]] [36 53]] [32 100]] [32 100]] [32 75]]] [8 100]] [2909 1.18 [1899 3.63 [1888 6.31 [2259 28.7 [32 68] [36 76]] [36 78]] [7354 7.51 [36 78] [36 57]]] [36 100]]] [4569 2.91 [36 90] [36 100]]] [32 100]]]] [1899 27.5 [4045 1.5 [5632 2.72 [1078 65.2 [7038 0.672 [2746 3.13 [4279 1.08 [4851 5.36 [1171 1.81 [286 3.07 [6776 1.39 [77 0.317 [3351 4.21 [3488 5.62 [132 3.39 [1545 19.7 [144 42.1 [7101 17.8 [2993 5.53 [3611 8.88 [3849 2.04 [800 6.16 [3080 19.6 [1995 16.3 [3561 6.48 [2765 3.7 [3843 1.39 [663 20.3 [1051 3.75 [836 0.65 [4663 7.25 [3908 11.7 [1908 0.488 [2844 1.27 [6621 15.5 [3929 20.7 [841 0.162 [5412 10 [3561 2.73 [4876 1.42 [832 6.29 [5673 6.95 [5662 4.41 [1429 3.03 [37 94] [3063 1.07 [3974 2.75 [3929 0.885 [1079 16.7 [28 1.86 [4063 2.04 [3342 3.03 [3371 1.31 [429 25.3 [3499 1.89 [2752 51.6 [3113 2.13 [3295 1.19 [1429 33.4 [3299 7.84 [37 100] [37 85]] [37 100]] [37 88]] [37 100]] [37 90]] [37 100]] [37 100]] [37 100]] [37 100]] [37 90]] [37 100]] [37 83]] [37 100]] [37 100]] [37 100]]] [37 100]] [37 83]] [37 97]] [37 100]] [37 80]] [37 83]] [37 100]] [37 90]] [37 90]] [37 75]] [37 100]] [37 85]] [37 93]] [37 100]] [37 85]] [836 2.65 [2939 2.7 [37 93] [37 100]] [37 88]]] [37 90]] [37 90]] [1179 3.45 [37 50] [37 100]]] [37 85]] [37 77]] [481 0.741 [37 88] [37 100]]] [37 70]] [37 85]] [37 69]] [37 60]] [37 81]] [16 33]] [3978 1.1 [4073 1.01 [37 85] [37 66]] [37 90]]] [37 70]] [8 28]] [37 70]] [37 33]] [16 25]] [37 61]] [37 66]] [37 69]] [112 12.6 [2746 3.75 [37 38] [791 15.4 [3691 1.29 [37 85] [37 71]] [37 100]]] [16 71]]] [37 50]] [37 43]] [16 42]] [37 54]] [37 60]]] [7451 2.29 [916 0.504 [438 2.85 [6310 0.559 [7382 1.36 [2526 2.45 [4518 0.741 [1240 15.4 [2458 2.24 [6110 2.17 [1641 7.36 [7176 0.697 [3103 0.468 [5472 0.935 [7106 3.58 [1047 1.63 [5420 0.3 [6082 4.54 [5412 0.115 [4611 0.838 [2902 0.773 [1788 1.83 [24 11] [36 44]] [24 33]] [35 71]] [23 26]] [21 100]] [23 44]] [2793 5.41 [24 70] [24 62]]] [24 85]] [36 50]] [35 100]] [12 50]] [36 75]] [22 92]] [5675 6.76 [24 85] [24 90]]] [24 75]] [24 96]] [6260 2.65 [184 6.71 [929 1.57 [6337 3.61 [435 1.24 [6621 1.9 [4818 9.8 [7461 3.45 [5781 0.935 [3666 1.29 [5792 0.384 [5007 2.76 [7454 1.54 [3429 0.647 [5833 6.49 [7722 2.79 [2763 11.9 [1888 4.83 [24 77] [24 90]] [23 33]] [24 100]] [24 68]] [3637 0.647 [24 99] [24 100]]] [23 50]] [24 58]] [5052 5.11 [5792 9.62 [24 100] [24 93]] [24 85]]] [24 53]] [4035 3.39 [791 6.51 [24 83] [24 100]] [24 100]]] [12 25]] [24 71]] [24 42]] [29 27]] [1025 12.6 [24 66] [19 77]]] [7210 0.754 [2 26] [2 42]]] [24 55]] [6860 0.262 [1025 13.7 [5673 0.618 [24 95] [24 100]] [7529 2.88 [6261 2.11 [24 62] [2795 5.13 [24 100] [24 81]]] [24 100]]] [24 100]]]] [7168 8.22 [631 11.3 [3642 2.11 [1593 3.77 [5130 1.8 [6859 35.2 [6265 6.71 [883 1.09 [4601 3.37 [6721 2.44 [4987 3.13 [4347 7.31 [7561 7.47 [1738 19.9 [6337 7.94 [3645 7.88 [1240 42.3 [7149 22.7 [6738 4.88 [4533 4.63 [1783 17 [2436 0.333 [3661 13.2 [5462 0.221 [2526 52.6 [1089 4.61 [2025 3.96 [4316 3.5 [3639 8.11 [6860 0.311 [5192 9.27 [3639 5 [4022 1.56 [6692 3.17 [7067 0.355 [3629 0.904 [2902 0.754 [7520 0.998 [4946 1.22 [2280 1.05 [1020 0.975 [2541 16.7 [24 100] [24 98]] [24 100]] [24 100]] [24 100]] [24 100]] [24 100]] [24 100]] [24 100]] [7512 6.87 [24 80] [24 100]]] [24 100]] [24 88]] [24 87]] [24 100]] [24 77]] [24 95]] [24 88]] [24 96]] [24 83]] [24 100]] [1429 2.82 [24 100] [24 75]]] [5641 0.745 [24 84] [24 100]]] [24 84]] [24 82]] [2259 12.6 [24 100] [24 71]]] [24 83]] [24 85]] [24 75]] [24 83]] [24 80]] [24 75]] [24 90]] [24 66]] [24 75]] [24 83]] [24 66]] [7067 1.72 [19 50] [24 100]]] [4154 8.44 [24 62] [7382 11 [24 100] [24 81]]]] [24 60]] [24 83]] [7530 2.72 [5270 0.562 [6373 2.85 [7009 2.12 [3660 3.15 [24 91] [24 60]] [38 88]] [24 55]] [19 66]] [24 56]]] [24 81]] [24 60]]] [19 30]] [23 37]] [21 100]] [23 29]]] [1159 2.61 [4120 3.35 [5219 2.54 [6026 2.54 [2846 1.68 [5420 0.77 [526 3.9 [957 1.46 [4141 20 [1460 3.94 [4665 15.6 [5174 2.16 [4929 12.3 [7324 14.5 [2259 7.26 [3003 1.74 [435 0.787 [5347 0.433 [2461 1.04 [4092 10.2 [3008 3.14 [7176 11.3 [2039 1.68 [6524 9.52 [7409 5.05 [906 5.42 [7169 12.3 [23 0.768 [7428 8.47 [4320 13 [2939 5.98 [144 3.94 [7491 3.15 [976 4.48 [27 21] [27 100]] [23 55]] [29 50]] [10 20]] [27 100]] [12 37]] [14 13]] [23 70]] [21 53]] [10 54]] [25 60]] [23 40]] [22 43]] [23 3.55 [30 28] [25 40]]] [35 90]] [27 100]] [27 100]] [2081 8.78 [23 38] [23 90]]] [27 100]] [2083 1.04 [3273 2.12 [2753 2.15 [29 9] [32 50]] [0 66]] [29 57]]] [23 92]] [4 80]] [33 77]] [791 3.94 [27 100] [27 75]]] [27 100]] [27 75]] [4115 6.62 [1108 1.37 [4663 3.03 [4124 1.93 [1429 30.5 [4114 38.8 [27 100] [286 1.64 [27 96] [27 100]]] [27 84]] [27 99]] [27 100]] [27 100]] [27 90]]] [21 100]] [23 82]] [2398 2.29 [12 57] [12 100]]] [10 100]] [5114 0.605 [8 84] [8 100]]] [2088 1.21 [4326 5.01 [939 8.72 [892 1.29 [2005 1.85 [2023 2.91 [392 3.55 [27 66] [23 60]] [27 30]] [12 30]] [10 92]] [7443 2.44 [774 4.75 [2149 0.826 [1429 25.2 [1078 38.4 [27 87] [27 100]] [27 42]] [27 85]] [27 87]] [27 100]]] [7169 1.27 [4382 1.17 [27 98] [27 100]] [27 100]]] [23 62]]] [2763 12.8 [2531 2.02 [819 0.523 [7491 6.47 [499 27.3 [7246 1.38 [6342 12.3 [6479 3.36 [929 3.74 [2023 11.6 [23 1.29 [3934 4.15 [4332 15.6 [1253 2.77 [3282 2.99 [784 0.521 [27 75] [7636 4.44 [791 1.27 [27 100] [27 57]] [27 100]]] [27 100]] [27 100]] [10 57]] [27 100]] [11 50]] [23 77]] [23 66]] [23 71]] [23 60]] [10 100]] [4136 30.4 [4154 3.58 [500 1.23 [27 94] [27 98]] [27 100]] [27 50]]] [23 50]] [27 100]] [23 69]] [27 47]]]] [6347 2.42 [429 114 [739 0.482 [1429 13.2 [3 100] [6029 3.31 [6131 4.4 [3 100] [3 85]] [3 100]]] [3 100]] [429 114 [3 66] [3 100]]] [6791 1.18 [6091 0.768 [6347 4.28 [3 81] [3 100]] [3 100]] [3 100]]]] [3492 0.176 [3366 0.347 [927 5.33 [8 100] [8 80]] [8 100]] [8 100]]] [6353 7.19 [685 10.3 [6997 32.1 [7680 0.307 [2464 11.4 [6733 0.129 [107 0.194 [2902 6.94 [598 13.9 [328 7.38 [2616 0.293 [2849 15.9 [1813 0.12 [1078 7.35 [2530 14.5 [25 100] [7576 9.8 [25 88] [25 66]]] [25 100]] [25 100]] [25 87]] [25 100]] [25 100]] [25 93]] [25 97]] [25 100]] [25 100]] [25 83]] [25 100]] [25 90]] [25 98]] [25 71]]] [7600 0.392 [6535 0.156 [7354 1.21 [3204 1.35 [6584 0.134 [3313 0.186 [2530 0.457 [4602 1.41 [4369 1.59 [4001 0.549 [134 1.04 [1587 0.977 [1400 0.395 [731 1.53 [4832 0.431 [1429 11.3 [6581 0.967 [3031 2.26 [6791 2.21 [5815 2.22 [2320 1.82 [3357 7.69 [248 22.4 [2616 0.416 [3034 4 [728 13.3 [32 24] [14 90]] [32 100]] [429 24 [4 23] [4 75]]] [2752 45.8 [26 66] [26 57]]] [32 100]] [32 100]] [1899 10.2 [4 100] [4 87]]] [32 85]] [32 94]] [5 45]] [6199 2.79 [5327 1.27 [3675 0.432 [6441 0.62 [2526 2.85 [5952 2.32 [4154 0.651 [392 2.74 [1533 1.23 [688 7.48 [6365 1.98 [5892 1.54 [6724 3.94 [1104 8.74 [602 0.0932 [377 2.09 [5972 4.5 [112 5.83 [442 4.99 [3056 11.2 [1707 20.3 [5566 2.92 [3915 2.02 [6581 4.4 [7742 1.79 [178 7.25 [1995 4.35 [7734 10.2 [3503 17.6 [3078 3.27 [896 14.4 [6239 4.57 [2968 18.1 [14 31] [6 50]] [14 100]] [5 28]] [17 65]] [17 100]] [18 72]] [5 62]] [17 37]] [17 44]] [17 55]] [17 83]] [14 100]] [17 55]] [5 100]] [32 42]] [14 50]] [12 100]] [14 95]] [4478 0.0932 [32 30] [17 47]]] [32 83]] [14 78]] [791 17 [14 50] [32 90]]] [12 100]] [7 50]] [5 90]] [14 66]] [7457 0.669 [6380 1.18 [7665 14.7 [602 1.76 [32 65] [32 40]] [32 42]] [32 92]] [32 100]]] [3915 1.98 [38 72] [19 66]]] [6581 0.393 [573 5.99 [573 3.91 [4159 0.104 [3558 15.5 [494 4.12 [5972 3.23 [2849 0.565 [5 20] [16 33]] [12 100]] [17 50]] [7 75]] [5 58]] [7 44]] [791 5.63 [1072 7.04 [17 100] [5 50]] [5 53]]] [4324 0.832 [5 44] [17 100]]]] [14 69]] [5 70]] [32 90]] [5034 1.43 [14 25] [14 97]]]] [4 81]] [3905 0.654 [896 0.158 [2752 24 [1011 0.579 [2178 3.95 [2466 3.1 [685 5.35 [6406 1.95 [2570 6.12 [17 38] [19 42]] [16 45]] [7 63]] [5 55]] [17 50]] [2752 12.8 [19 62] [17 50]]] [3057 3.34 [4876 3.69 [1507 0.928 [3901 2.49 [5904 3.31 [1668 0.599 [2526 12.1 [5034 2.26 [4479 15.2 [602 19.6 [7270 1.58 [23 2.37 [6310 4 [2628 7.69 [6396 4.35 [7009 3.82 [602 9.02 [5 24] [14 62]] [5 68]] [17 50]] [19 38]] [35 66]] [5 54]] [5 57]] [17 90]] [7 72]] [14 100]] [1475 2.13 [5 47] [5 50]]] [17 56]] [19 100]] [5 90]] [5 63]] [5 50]] [5 97]]] [5034 3.27 [6238 0.81 [7689 10.8 [3418 1.71 [4742 2.11 [6199 5.36 [6230 9.69 [1429 19.2 [5693 1.59 [26 40] [5 42]] [1919 5.3 [642 0.657 [4479 1.2 [1580 1.36 [3489 2.8 [7381 6.94 [5 74] [19 41]] [5 75]] [17 85]] [7 40]] [5 94]] [17 33]]] [2081 3.88 [6654 1.65 [3317 1.44 [1429 20.6 [5 31] [3554 6.99 [4766 1.04 [722 5.2 [6333 2.51 [1899 0.158 [6732 4.48 [5 35] [144 5.65 [2826 11 [19 42] [5 50]] [5 25]]] [5 61]] [7381 6.73 [5 85] [5 66]]] [5 77]] [5 81]] [5 81]]] [5 85]] [17 62]] [4 28]]] [5 88]] [17 66]] [5 100]] [38 55]] [17 41]] [14 87]]] [485 5.7 [5692 8.97 [4222 0.654 [4997 1.47 [1063 2.5 [931 3.74 [2570 2.99 [4968 4.05 [685 2.46 [17 47] [384 4.71 [7 40] [7 100]]] [19 55]] [17 75]] [17 100]] [35 62]] [7 100]] [7711 0.935 [4338 3.89 [17 93] [17 60]] [17 100]]] [17 38]] [19 45]]]] [2178 4.61 [7203 0.692 [3006 0.395 [7255 1.36 [1421 3.31 [7726 2.51 [248 11 [2966 1.02 [2259 9.16 [5812 1.51 [2846 2.44 [4 40] [14 100]] [4 63]] [112 2.73 [14 35] [14 100]]] [12 70]] [3332 1.49 [2753 4.78 [663 5.41 [26 93] [26 50]] [26 90]] [26 66]]] [14 100]] [4 100]] [12 64]] [6727 1.14 [2749 5.99 [26 100] [1429 7.98 [26 85] [26 85]]] [26 100]]] [26 86]] [12 77]]] [6380 1.22 [1463 0.835 [384 2.51 [3929 2.15 [1078 5.98 [2826 4.45 [38 72] [14 40]] [1899 1.17 [3742 1.73 [7445 1.53 [14 68] [26 30]] [14 100]] [7 37]]] [5 33]] [26 85]] [5 75]] [14 58]]] [4569 0.744 [7516 0.744 [2636 8.57 [3592 4.3 [3006 0.803 [3563 0.952 [1584 0.325 [5812 13.2 [7534 2.7 [6396 2.21 [6524 1.42 [1838 0.982 [1429 19.8 [5693 3.56 [26 28] [5 53]] [6199 3.54 [5904 2 [3192 1.24 [3057 1.21 [7210 14.3 [3503 35.6 [4478 3.95 [3928 1.37 [6436 3.62 [7333 0.978 [3519 4.67 [1079 7.36 [6804 1.35 [5564 1.93 [4154 0.474 [663 18.8 [3008 2.61 [3905 3.16 [1079 2.33 [17 22] [38 78]] [17 44]] [17 66]] [17 53]] [5 41]] [14 100]] [38 62]] [17 61]] [19 100]] [14 66]] [19 66]] [3342 0.821 [5 66] [5 83]]] [2763 1.49 [1557 14.2 [17 59] [17 93]] [17 42]]] [16 66]] [17 100]] [5 66]] [7009 1.41 [5 68] [5 88]]] [4851 0.873 [19 66] [19 57]]] [2939 1.92 [1919 1.83 [19 33] [19 85]] [19 66]]]] [7301 1.62 [19 100] [19 87]]] [7 90]] [3915 0.427 [5641 0.339 [2081 5.35 [1707 1.31 [3905 3.18 [17 35] [17 65]] [19 71]] [17 100]] [38 87]] [17 96]]] [5155 1.13 [731 3.85 [17 75] [2570 1.22 [17 90] [17 100]]] [17 66]]] [17 84]] [7722 2.89 [5969 3.61 [1584 13.4 [602 2.17 [2763 1.66 [731 14.8 [6230 7.74 [17 93] [17 85]] [17 40]] [4 33]] [17 60]] [14 37]] [7 25]] [17 76]]] [19 64]] [384 0.666 [26 88] [26 90]]] [5 100]] [17 70]] [1696 3.37 [26 100] [26 85]]] [2760 1.68 [17 0.538 [17 46] [7215 1.08 [19 88] [19 100]]] [17 55]]]] [31 0.949 [3213 1.38 [3057 7.58 [791 4.72 [5 78] [5 90]] [5 63]] [5 100]] [5 100]]] [3558 0.678 [32 54] [7 66]]] [7512 1.31 [2466 3.56 [5007 1.69 [26 86] [26 100]] [26 77]] [26 100]]] [419 0.442 [7681 0.16 [7472 1.69 [575 1.21 [6184 0.463 [1415 2.71 [685 0.36 [929 0.843 [26 86] [26 87]] [999 1.61 [26 100] [26 87]]] [26 77]] [26 58]] [26 87]] [38 50]] [26 100]] [26 60]]] [1475 3.34 [6575 1.64 [5693 0.136 [5 92] [5 100]] [1485 2.96 [1062 3.69 [5 77] [5 100]] [5 50]]] [35 72]]] [6395 0.773 [5597 3.42 [1089 0.227 [2616 8.77 [3944 0.434 [1535 0.816 [23 4.8 [3983 0.339 [791 7.84 [6584 9.26 [3243 1.78 [2469 2.25 [649 0.296 [17 74] [17 96]] [17 54]] [5 50]] [1429 17.9 [17 39] [17 85]]] [573 4.22 [6980 2.6 [602 3.3 [663 0.795 [3733 1.38 [17 27] [17 62]] [7665 17.5 [134 0.795 [19 55] [19 42]] [17 88]]] [38 42]] [17 100]] [17 75]]] [731 2.32 [38 62] [4870 0.259 [17 50] [19 57]]]] [3414 1.74 [3732 2.44 [2829 1.88 [5296 0.832 [17 40] [19 60]] [19 86]] [17 47]] [19 70]]] [5 71]] [35 100]] [5 52]] [17 83]] [17 100]] [4766 0.09 [733 1.69 [4870 5.38 [4564 1.41 [3302 0.489 [1000 0.468 [5843 2.88 [7677 2.01 [6591 2.19 [6074 4.7 [2616 2.58 [2849 0.211 [6396 8.46 [17 100] [1023 0.538 [17 86] [17 100]]] [17 100]] [7381 2.96 [2763 2.36 [17 83] [17 50]] [17 100]]] [17 100]] [17 50]] [17 71]] [6544 5.44 [17 80] [17 60]]] [17 100]] [17 100]] [17 66]] [17 57]] [6076 1.95 [19 71] [17 100]]] [17 44]]]] [1078 19 [23 8.13 [6584 0.894 [2526 5.81 [5 73] [5 98]] [5 40]] [7021 0.474 [5 48] [5 86]]] [12 50]]] [7340 2.53 [7512 12.4 [6524 0.999 [1671 0.31 [17 4.21 [1463 0.539 [3928 2.74 [4805 2.34 [3345 1.36 [6961 0.955 [7009 4.57 [388 0.399 [929 1.02 [6230 18.7 [968 0.715 [392 7.52 [1662 0.0562 [328 8.93 [7737 4.25 [685 0.464 [3558 4.97 [7722 2.02 [4154 8.41 [2752 29.8 [6981 0.763 [1754 1.02 [5894 0.83 [5480 1.09 [5 26] [18 40]] [16 50]] [16 42]] [18 80]] [5 48]] [19 17]] [18 38]] [5 80]] [685 13.2 [1911 0.689 [7 36] [18 42]] [18 76]]] [18 90]] [7512 1.8 [7 66] [16 58]]] [19 100]] [663 0.423 [7241 5.01 [18 68] [6 50]] [18 44]]] [7665 6.46 [38 73] [38 36]]] [731 31.3 [23 19 [1023 2.46 [1429 60.7 [735 13.3 [5 36] [5 41]] [5 22]] [7 57]] [16 33]] [18 44]]] [2526 11.5 [7 38] [38 48]]] [18 72]] [134 1.31 [7449 0.632 [5753 6.56 [5 62] [18 50]] [5 30]] [5 85]]] [2690 0.325 [16 84] [19 33]]] [5 100]] [19 64]] [5 70]] [726 1.29 [5 80] [5 83]]] [5 81]] [1662 0.719 [407 0.318 [2081 2.21 [18 50] [18 91]] [16 60]] [19 100]]] [6708 3.67 [5732 3.27 [7 96] [7 100]] [7 100]]] [642 1.87 [3515 1.19 [722 1.88 [4564 1.35 [7665 7.81 [397 1.7 [18 44] [19 70]] [6022 1.31 [3520 0.901 [7255 14.8 [5430 0.832 [2763 9.38 [2849 2.74 [4061 1.4 [144 10.2 [2607 2.82 [1429 31.7 [1072 0.456 [5 36] [19 40]] [906 1.01 [6243 0.904 [5 44] [5 58]] [2526 9.34 [5 100] [5 57]]]] [5480 0.724 [7 71] [18 81]]] [5 89]] [5 33]] [18 71]] [7 87]] [5693 1.46 [5 84] [1899 0.855 [2968 3.64 [5 87] [5 100]] [5 100]]]] [18 72]] [19 70]] [7 100]]] [18 71]] [5 76]] [791 9.83 [19 69] [19 35]]] [7588 4.42 [203 1.35 [6241 4.2 [1546 3.08 [6581 4.98 [3057 0.675 [5 87] [5 100]] [5 50]] [5 100]] [5 57]] [5 80]] [5 55]]]] [32 63]]] [3928 1.52 [7214 1.26 [3518 0.156 [1632 0.36 [5892 5.2 [5389 0.33 [3014 2.15 [7192 2.16 [731 26.7 [1610 0.59 [2939 5.72 [4870 0.413 [17 66] [7665 13.6 [17 85] [17 95]]] [16 33]] [38 54]] [19 66]] [17 100]] [19 40]] [19 54]] [17 100]] [19 100]] [957 2.61 [5522 0.749 [573 0.379 [7512 17.7 [19 75] [19 100]] [19 100]] [19 100]] [19 83]]] [2259 5.95 [5510 0.767 [602 3.24 [1740 0.375 [3516 0.55 [17 54] [19 100]] [2628 3.67 [19 92] [19 100]]] [929 3.46 [19 58] [19 100]]] [19 77]] [17 28]]] [3563 0.642 [5509 2.76 [4806 6.59 [4742 0.277 [602 0.4 [2526 3.05 [17 85] [17 100]] [17 72]] [17 100]] [17 55]] [19 80]] [19 68]]]] [438 0.133 [4587 0.383 [5693 0.867 [7169 5 [32 100] [4414 5.1 [32 81] [32 100]]] [32 100]] [32 100]] [32 100]]]] [7474 0.0578 [5189 0.846 [2571 0.169 [7019 0.187 [7354 0.975 [992 1.42 [1400 1.92 [1981 2.3 [4338 4.27 [7101 3.53 [2241 0.371 [5018 1.28 [3829 9.38 [5480 4.52 [6984 2.56 [2422 1.09 [2435 0.921 [2735 8.26 [2707 8.4 [7013 3.94 [2526 36.3 [874 1.3 [2752 7.94 [19 14] [12 88]] [12 100]] [8 34]] [8 100]] [19 26]] [38 81]] [8 50]] [38 44]] [4 100]] [8 53]] [8 100]] [30 100]] [8 66]] [26 66]] [3663 0.59 [8 47] [24 66]]] [38 77]] [5382 0.145 [6155 2.38 [3989 1.59 [3027 0.673 [144 9.15 [5999 1.9 [7657 1.82 [12 91] [12 100]] [12 80]] [12 50]] [12 84]] [12 86]] [12 75]] [12 100]]] [8 100]] [429 18.9 [5851 6.04 [3870 1.26 [8 81] [8 100]] [8 75]] [1899 0.328 [8 85] [8 100]]]] [3224 0.212 [1674 1.44 [3675 12.5 [826 6.55 [6230 1.98 [1078 3.84 [7025 1.04 [5509 1.31 [7428 6.6 [6342 18.5 [7512 10.8 [1493 1.95 [4696 0.627 [8 96] [8 100]] [8 100]] [12 47]] [8 62]] [8 50]] [8 100]] [12 100]] [286 2.94 [4693 0.393 [3972 0.487 [1064 1.35 [7179 0.898 [7255 7.15 [3183 0.624 [2752 0.559 [1068 1.42 [6342 2.33 [328 1.24 [978 2.82 [8 77] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 87]] [8 100]] [8 100]] [8 100]] [8 100]] [8 85]]] [8 59]] [8 62]] [12 65]] [12 100]] [8 100]]] [8 100]] [4909 8.74 [38 84] [2939 32.2 [7482 61.6 [38 94] [38 100]] [5189 14.8 [7482 8 [38 90] [38 100]] [38 66]]]]] [194 3.99 [7446 0.826 [2426 4.56 [8 62] [2242 0.235 [38 87] [14 40]]] [4648 0.957 [94 16.3 [38 76] [8 62]] [6141 3.01 [2399 0.44 [7347 1.23 [94 5.37 [38 90] [38 100]] [38 100]] [38 100]] [6199 15.3 [38 100] [38 80]]]]] [38 75]]]] [3207 1.31 [23 26.2 [3884 2.44 [1 4.89 [2178 8.59 [4560 0.143 [7656 17.6 [3994 1.71 [2259 3.07 [1919 3.69 [1239 7.68 [7590 4.2 [6920 0.328 [3102 2.3 [24 47] [24 90]] [24 90]] [24 100]] [24 89]] [24 100]] [1007 2.42 [1181 0.969 [18 1.74 [3639 11.7 [4564 4.9 [5408 3.38 [6337 2.47 [5288 0.215 [7321 0.0956 [5076 4.25 [3637 12.5 [5137 0.228 [2436 1.89 [2792 13.3 [4147 0.219 [5732 3.73 [4533 2.52 [2453 10.8 [1429 0.898 [6336 0.577 [4154 3.14 [24 50] [24 100]] [24 100]] [7376 7.63 [4279 0.161 [2593 2.22 [1389 0.773 [3652 3.55 [1911 1.37 [2275 6.44 [24 80] [24 100]] [2526 8.57 [24 83] [24 100]]] [24 100]] [24 100]] [24 100]] [1048 2.08 [885 0.384 [6335 0.451 [4299 0.445 [2314 0.843 [7169 7.95 [5692 10.4 [2259 49.8 [24 100] [24 85]] [24 85]] [24 83]] [24 100]] [24 100]] [24 100]] [2793 7.04 [24 100] [24 60]]] [24 88]]] [24 75]]] [24 100]] [4154 15.3 [24 60] [24 100]]] [23 9.74 [24 100] [24 75]]] [1025 4.31 [24 100] [4341 1.78 [3662 3.47 [631 3.52 [774 4.21 [772 0.219 [4342 39.8 [24 100] [24 90]] [24 100]] [24 90]] [24 94]] [24 87]] [2763 0.911 [24 100] [24 83]]]]] [24 85]] [24 72]] [24 66]] [24 62]] [24 81]] [24 66]] [24 50]] [4907 0.618 [1602 2.1 [2421 1.05 [2453 8.78 [24 100] [24 75]] [24 66]] [19 50]] [24 100]]] [24 78]] [24 55]] [24 42]] [24 71]] [24 57]] [24 66]]] [24 57]] [35 52]] [19 50]] [1 22]] [30 33]] [5 50]] [33 28]] [2466 1.65 [19 90] [1025 14.2 [37 33] [19 52]]]]] [6689 0.461 [2877 0.763 [5104 0.109 [5099 0.238 [2669 0.852 [2654 1.16 [4426 1.99 [4738 0.748 [2983 0.182 [7038 6.41 [7153 11.8 [7574 6.8 [5747 11.7 [1769 4.22 [5597 1.78 [2527 53.5 [4977 2.43 [5551 1.43 [2707 5.88 [6977 0.319 [7153 5.89 [1239 15.1 [221 11.3 [6 63] [6 100]] [1268 17.2 [6 92] [6 63]]] [1320 2.71 [6 83] [16 50]]] [6 50]] [16 50]] [6 60]] [18 70]] [6 45]] [2628 0.381 [7407 2.45 [5964 11.1 [4956 0.838 [5397 9.62 [1310 3.92 [7512 26.8 [5033 4.69 [2387 8.62 [1316 1.22 [2272 9.62 [2142 2.55 [4732 0.685 [6399 0.188 [7281 0.68 [6632 11.2 [6 100] [6 71]] [6 100]] [6 100]] [299 2.83 [6 100] [6 93]]] [6 95]] [6 77]] [1374 3.51 [2549 3.51 [6 100] [6 75]] [6 72]]] [6 63]] [6 80]] [6 87]] [6 75]] [6 69]] [6 66]] [6 62]] [6 80]] [7512 4.83 [16 42] [6 57]]]] [26 44]] [6 65]] [7421 9.08 [7574 9.71 [16 57] [6 100]] [6 90]]] [1289 4.53 [6 76] [16 52]]] [7040 7.99 [5396 4.95 [16 40] [6 75]] [5093 11.4 [6 100] [6 85]]]] [2709 1.7 [4731 0.477 [5093 2.92 [7 28] [16 50]] [6 50]] [6 66]]] [16 38]] [16 64]] [2466 1.81 [5632 8.13 [16 54] [6 60]] [16 72]]] [7 100]] [7512 6.52 [5435 0.534 [5681 0.669 [2079 2.43 [2649 3.51 [7666 4.12 [4851 0.797 [6 66] [23 6.39 [38 50] [7 50]]] [6 66]] [62 2.19 [2640 2.43 [16 57] [18 44]] [6 33]]] [6 93]] [7038 2.98 [2628 33.7 [2713 2.62 [28 30] [26 44]] [5 45]] [7134 2.13 [190 14.1 [2412 3.52 [1899 1.59 [2628 26.4 [18 45] [16 63]] [2939 17.4 [16 100] [16 71]]] [16 40]] [6 71]] [7 100]]]] [423 0.297 [2649 3.84 [16 50] [2650 1.01 [7 20] [18 33]]] [26 100]]] [1336 0.193 [4450 2.73 [4725 8.02 [2259 29.8 [6 36] [3238 0.913 [4727 5.19 [7038 1.35 [190 1.21 [7149 4.9 [4858 1.16 [299 3.88 [6 81] [6 100]] [6 81]] [6 62]] [6 100]] [6100 3.49 [7557 1.03 [1239 29.3 [6 71] [16 70]] [6 100]] [6 100]]] [16 71]] [6 71]]] [2412 0.637 [6 85] [6 100]]] [6 42]] [6 100]]]] [5598 7.93 [4533 0.188 [2713 1 [30 60] [1429 19.8 [2951 16.6 [18 38] [16 69]] [16 90]]] [6 46]] [16 68]]] [194 1.83 [2707 16 [16 71] [16 92]] [16 57]]] [5358 7.7 [2951 2.64 [2142 6.05 [7224 9.03 [1340 2.36 [5873 0.159 [5778 3.86 [2029 0.233 [1974 4.47 [434 6.1 [6289 1.52 [2177 0.985 [2079 1.01 [6129 1.39 [6423 0.999 [6 94] [6 100]] [6 66]] [6 100]] [6 55]] [4674 2.44 [5798 0.464 [6 94] [6 100]] [6 100]]] [6 71]] [6 70]] [2551 2.21 [791 0.349 [6 88] [7419 3.33 [4450 0.681 [6 87] [6 100]] [6 100]]] [6 100]]] [6 75]] [5944 0.136 [6 100] [6 88]]] [6 100]] [1273 0.277 [6 65] [6 87]]] [4889 0.571 [6 83] [16 54]]] [7224 0.785 [6 91] [5722 1.24 [2223 0.457 [7260 0.593 [6 87] [6 42]] [6 60]] [18 40]]]] [6 53]]]] [7072 0.143 [1838 0.162 [4865 0.926 [3 75] [4235 43.7 [808 0.761 [6395 0.258 [5965 0.0733 [6342 0.183 [1659 0.583 [1591 15.6 [3 100] [3 85]] [3 100]] [3 100]] [3 100]] [3 100]] [3 87]] [3 80]]] [3 77]] [3 57]]] [5472 0.786 [3587 0.362 [665 0.866 [3687 0.812 [6524 0.454 [6230 0.881 [701 0.707 [968 0.764 [1239 49.1 [3019 0.164 [5034 1.37 [7354 0.901 [6581 1.07 [1628 0.461 [7512 3.33 [1924 0.374 [1755 0.927 [7255 1.86 [3928 0.0479 [3771 0.649 [7176 1.57 [5040 2.56 [2688 3.7 [3125 1.74 [700 0.399 [3262 1.09 [6430 0.351 [660 2.07 [7352 0.779 [3182 6.49 [5226 0.535 [2990 1.73 [3273 1.75 [4870 4 [3831 4.53 [2831 1.31 [3297 0.231 [5539 3.68 [6809 0.585 [859 0.813 [5979 1.34 [631 0.283 [429 79.6 [6103 1.24 [6859 3.59 [3872 1.47 [4011 1.08 [2749 0.516 [695 8.22 [7512 0.617 [898 1.4 [538 0.529 [7241 1.6 [112 3.4 [685 2.72 [2004 0.929 [5844 2.61 [6780 1.67 [1078 5.23 [1260 0.746 [5941 1.33 [2023 2.82 [1906 2.72 [1905 0.51 [10 7] [31 33]] [26 60]] [29 36]] [14 31]] [29 50]] [1906 0.192 [4092 0.741 [28 18] [35 100]] [11 23]]] [14 85]] [17 77]] [23 37]] [1239 12.5 [328 29 [28 43] [28 77]] [377 1.69 [23 60] [19 37]]]] [4160 0.813 [7343 2.26 [126 0.761 [29 35] [35 42]] [29 78]] [29 57]]] [36 31]] [5972 1.67 [21 86] [5412 1.08 [9 83] [9 62]]]] [12 100]] [7693 0.433 [6883 1.95 [7327 0.313 [328 5.89 [7665 0.333 [4851 1.56 [1429 30.5 [16 54] [18 40]] [18 54]] [429 8.08 [24 36] [5007 0.666 [4 37] [18 40]]]] [26 58]] [4 100]] [29 33]] [16 23]]] [6544 4.41 [1429 30.7 [1696 5.15 [7657 4.2 [714 5.49 [5462 3.39 [1253 13.6 [4071 7.25 [5972 11.8 [3332 5.52 [5692 7.39 [4218 2.13 [696 8.49 [4332 7.12 [5110 4.85 [1239 20.2 [7288 4.35 [5480 28.4 [673 4.35 [802 9.88 [2011 8.23 [7411 10.8 [791 9.79 [22 8] [29 17]] [15 36]] [29 69]] [21 70]] [26 75]] [22 72]] [12 100]] [21 28]] [22 41]] [14 52]] [9 93]] [15 30]] [28 31]] [35 100]] [12 56]] [37 54]] [2 33]] [23 6.51 [35 32] [4 58]]] [22 100]] [12 100]] [26 100]] [6124 4.95 [1533 4.9 [663 6.49 [4079 4.27 [6621 17.2 [394 1.38 [3247 2.54 [5007 6.48 [1456 4.36 [6275 12 [7340 5.62 [1104 9.83 [1572 2.65 [1180 7.04 [1400 4.5 [5110 4.7 [6153 5.15 [1452 8.68 [6492 7.94 [1995 1.42 [3921 9.52 [6310 4.68 [7665 6.6 [5803 4.35 [2759 17.9 [1391 4.93 [7210 23.2 [7446 1.66 [3711 1.66 [2793 7.3 [2260 2.11 [713 1.66 [2967 6.33 [6413 2.44 [6710 16.3 [695 72.9 [6339 7.46 [6342 10.2 [812 14.6 [4876 0.496 [4611 11.5 [705 7.46 [7081 5.05 [6449 4.57 [6031 4.59 [726 14.9 [28 23] [36 60]] [22 100]] [13 40]] [28 85]] [12 55]] [28 78]] [22 33]] [31 55]] [14 33]] [28 100]] [36 29]] [28 81]] [7 25]] [5 62]] [12 45]] [36 100]] [36 37]] [35 100]] [28 90]] [14 54]] [22 90]] [14 62]] [22 50]] [14 21]] [14 55]] [37 78]] [28 73]] [28 100]] [20 41]] [28 100]] [22 44]] [12 73]] [13 100]] [36 100]] [28 77]] [12 43]] [22 100]] [2 33]] [28 67]] [37 88]] [28 72]] [28 62]] [31 100]] [5264 5.15 [1587 9.45 [6388 24.8 [13 20] [28 90]] [13 33]] [13 100]]] [37 82]] [12 100]]] [14 45]]] [5103 0.818 [2882 0.425 [6199 0.792 [26 68] [26 57]] [26 100]] [6 41]]] [1899 3.65 [28 54] [1925 0.291 [28 81] [28 100]]]] [898 1.5 [12 77] [12 100]]] [36 60]] [12 87]] [4154 9.38 [5937 15.8 [5692 1.63 [695 15.6 [21 90] [21 45]] [907 2.07 [21 60] [21 100]]] [21 100]] [3 100]]] [28 62]] [12 100]] [7197 1.73 [22 88] [22 60]]] [32 90]] [2009 0.126 [1899 8.37 [6483 4.69 [13 95] [13 100]] [12 54]] [13 100]]] [37 91]] [22 94]] [3088 3.18 [37 80] [37 100]]] [1783 7.71 [28 43] [28 66]]] [3438 5.98 [35 67] [35 100]]] [2628 1.73 [12 94] [12 100]]] [22 70]] [37 75]] [6915 0.4 [248 2.69 [2199 2.09 [7352 2.8 [35 37] [28 34]] [32 37]] [29 50]] [6682 1.1 [14 98] [14 100]]]] [1062 5.56 [6325 1.1 [5732 0.813 [1429 4.24 [21 42] [7456 1.71 [5007 0.844 [6674 0.982 [29 31] [28 40]] [29 73]] [35 27]]] [28 72]] [5364 6.33 [28 100] [28 55]]] [6732 0.994 [791 21 [2902 0.942 [7175 1.36 [7461 2.8 [29 71] [6406 3.12 [29 96] [29 100]]] [29 100]] [29 100]] [29 61]] [22 50]]]] [13 100]] [2466 0.429 [115 0.377 [2782 0.478 [3027 5.15 [791 8.14 [53 1.19 [3905 7.2 [3867 6.59 [2753 7.34 [3299 3.54 [37 96] [37 66]] [37 66]] [37 100]] [37 73]] [37 60]] [2081 4.07 [37 94] [3299 0.11 [37 76] [37 75]]]] [16 50]] [37 54]] [37 76]] [16 58]]] [328 17.2 [22 92] [22 88]]] [3085 2.51 [3831 1.08 [37 85] [37 100]] [37 100]]] [7475 4.51 [38 100] [38 75]]] [5937 0.775 [5192 0.701 [2178 0.818 [517 2.72 [429 12.4 [2 44] [535 5.74 [21 84] [21 100]]] [21 100]] [21 71]] [2 55]] [372 1.29 [633 0.52 [699 6.76 [21 100] [21 92]] [21 100]] [21 100]]]] [1539 1.27 [2934 0.881 [2902 0.589 [3056 3.31 [233 0.428 [1218 1.74 [6033 1.23 [4870 0.264 [5118 1.05 [4690 2.95 [939 2.58 [4478 1.18 [7314 3.11 [809 0.297 [22 51] [22 100]] [22 80]] [22 55]] [12 33]] [8 88]] [22 76]] [328 3.11 [1429 30.2 [22 100] [22 85]] [22 66]]] [22 100]] [22 100]] [33 92]] [12 66]] [6469 0.911 [3989 0.333 [5199 0.284 [22 98] [22 100]] [22 87]] [22 100]]] [33 100]] [12 80]]] [1474 0.649 [2466 1.1 [3295 6.92 [7343 7.42 [3564 4.28 [3374 9.43 [3771 3.6 [37 54] [2775 4.84 [3771 10.7 [3413 4.87 [37 97] [37 83]] [695 19.2 [3771 13.7 [37 87] [37 100]] [3921 44 [37 57] [37 91]]]] [37 66]]] [37 66]] [16 46]] [37 96]] [37 100]] [16 50]] [37 100]]] [845 0.197 [3335 0.756 [286 2.11 [3912 1.36 [6865 1.54 [3299 0.432 [3990 5.04 [3437 1.58 [3831 6.52 [7012 0.373 [3079 2.56 [2033 2.26 [3243 4.84 [1542 3.44 [5871 0.478 [494 0.544 [3715 0.141 [7009 1.45 [12 71] [12 100]] [37 31]] [791 21.8 [5 63] [37 38]]] [5 66]] [5 87]] [5 55]] [12 77]] [37 100]] [12 100]] [37 100]] [429 11.3 [37 66] [37 77]]] [37 100]] [37 100]] [4684 0.797 [839 0.478 [37 80] [37 100]] [37 100]]] [37 97]] [12 100]] [12 100]] [37 100]]] [6126 0.673 [7449 4.1 [2714 0.444 [7434 0.521 [7657 0.728 [4854 0.96 [6977 2.92 [5635 2.33 [429 19.2 [6831 0.36 [7432 3.72 [2259 9.52 [5019 0.935 [3130 0.914 [5267 1 [7169 7.89 [6363 8.35 [12 65] [12 100]] [32 42]] [26 57]] [12 77]] [12 100]] [12 29]] [12 100]] [16 33]] [1783 3.37 [112 1.94 [4414 8 [12 20] [15 37]] [29 50]] [19 41]]] [5632 11.2 [18 57] [7 60]]] [12 100]] [4977 4.31 [695 1.93 [18 40] [16 76]] [18 62]]] [12 97]] [12 100]] [2726 0.481 [26 81] [16 23]]] [12 86]] [12 100]]] [5526 0.726 [2025 2.19 [2354 0.475 [2763 1.41 [1695 0.282 [1078 6.15 [22 72] [6375 0.585 [22 100] [22 80]]] [22 100]] [22 100]] [22 100]] [22 87]] [29 100]]] [1533 4.93 [3998 0.2 [3921 3.17 [37 100] [706 1.64 [37 94] [37 100]]] [37 100]] [3262 14 [37 100] [37 85]]]] [5847 0.0927 [2752 3.97 [407 5.49 [6269 1.68 [5574 1.37 [7381 1.57 [6767 8.92 [132 7.88 [429 2.83 [5130 0.508 [2385 0.57 [11 9.8 [4991 2.69 [6174 1.75 [957 2.65 [232 3.58 [5593 2.66 [5833 7.35 [5317 5.88 [6859 4.35 [328 24.7 [2962 3.14 [2894 0.471 [7722 5.95 [5405 1.93 [2241 0.861 [4704 4.37 [71 2.37 [1025 19.2 [5322 2.3 [269 6.67 [5484 3.46 [5412 23.7 [2707 3.58 [1391 0.835 [7737 3.32 [2684 8.2 [2081 7.98 [1400 6.67 [33 29] [14 40]] [33 68]] [4 100]] [18 33]] [33 75]] [7 36]] [13 63]] [18 61]] [26 77]] [33 57]] [2 60]] [33 100]] [33 100]] [32 57]] [31 100]] [4414 4.89 [14 23] [31 44]]] [33 100]] [31 100]] [14 41]] [31 83]] [7 100]] [13 100]] [18 60]] [33 100]] [18 69]] [31 100]] [33 100]] [31 100]] [328 18.5 [18 47] [18 85]]] [6 30]] [7233 2.8 [6578 1.47 [1400 1.67 [662 1.41 [10 3.81 [964 1.51 [649 5.06 [4601 7.99 [6382 1.93 [5790 15.3 [673 1.9 [5871 15.9 [383 2.95 [1820 3.41 [5812 2.42 [7185 3.21 [5833 1.96 [5539 4.14 [2726 2.26 [5769 2.39 [6103 6.05 [1671 16 [5637 1.57 [7665 1.2 [18 46] [6724 0.601 [721 7.53 [7302 4.56 [7566 7.99 [2259 51.7 [2081 3.18 [1899 26.8 [7734 7.62 [4 12] [18 66]] [25 37]] [29 57]] [14 63]] [29 30]] [18 77]] [36 45]] [19 42]]] [18 69]] [18 88]] [31 66]] [6 36]] [187 1.42 [8 33] [19 40]]] [13 100]] [13 100]] [18 57]] [4 51]] [6 81]] [18 67]] [896 4.95 [18 46] [14 100]]] [18 65]] [36 100]] [14 100]] [26 83]] [36 61]] [328 9.64 [5131 24.4 [18 56] [18 93]] [5480 8.08 [19 46] [18 69]]]] [31 100]] [5 61]] [432 7.05 [31 42] [26 100]]] [31 100]] [31 93]]] [7245 3.38 [4977 17.8 [6911 10.1 [18 75] [6 50]] [6 50]] [18 61]]] [31 100]] [5322 7.39 [4 24] [4 69]]] [6989 0.826 [5574 10.6 [2 29] [4 59]] [2 86]]] [4767 1.12 [13 97] [13 100]]] [5734 2.26 [18 35] [7 100]]] [1011 3.17 [1429 21 [7414 1.27 [7434 1.82 [2530 0.395 [5239 1.54 [7029 1.52 [2259 4.78 [2748 0.373 [7671 0.389 [1400 38.6 [6260 0.221 [2616 1.42 [5403 0.454 [1812 1.85 [957 4.68 [2081 12.6 [6109 0.249 [4349 0.613 [6988 1.77 [5771 1.71 [1981 2.35 [7340 3.67 [688 3.67 [4627 12.9 [2 11] [12 81]] [2 33]] [32 72]] [33 100]] [2 66]] [2 100]] [4 75]] [22 60]] [22 40]] [2526 13.8 [18 77] [18 42]]] [33 100]] [31 92]] [6088 0.728 [6184 0.504 [7693 0.412 [1077 1.22 [4184 3.81 [7712 5.8 [5812 2.16 [1025 1.82 [4154 7.69 [26 29] [2 33]] [4 47]] [6732 5.68 [429 9.63 [4 71] [2 63]] [2 80]]] [7 50]] [4 53]] [3 33]] [26 52]] [4235 0.713 [2574 0.504 [2 33] [2 71]] [2 100]]] [2 93]]] [791 13.5 [22 80] [22 87]]] [7512 12.7 [26 92] [26 63]]] [22 62]] [2616 3.55 [26 100] [26 66]]] [5403 2.9 [4997 2.42 [308 1.75 [2795 1.1 [7566 1.74 [2846 4.8 [248 4.41 [560 1.47 [5482 2.59 [7737 1.24 [7571 5.26 [221 6.52 [4530 0.245 [31 15] [4 20]] [2 77]] [36 55]] [10 64]] [18 38]] [18 47]] [33 41]] [14 37]] [18 25]] [24 100]] [24 87]] [7 100]] [5647 3.04 [161 3.88 [6791 16.2 [4663 3.45 [11 1.15 [2526 1.47 [31 94] [31 100]] [31 100]] [31 100]] [31 87]] [31 100]] [7665 19.4 [31 75] [31 100]]]]] [2 100]] [4 100]] [7187 3.82 [1429 2.42 [26 60] [732 0.158 [2530 3.59 [26 88] [26 71]] [26 100]]] [26 100]]] [12 100]] [6281 1.41 [5192 0.743 [2 67] [221 5.13 [4 75] [2 100]]] [2 100]]] [680 0.752 [6245 0.481 [1657 4.65 [4627 0.952 [6033 0.44 [7665 7.14 [1995 2.23 [5480 2.22 [7449 0.981 [14 1.06 [392 8.7 [5819 0.6 [429 27.1 [2943 2.54 [6365 2.04 [826 0.914 [1400 5.73 [12 14] [12 84]] [12 100]] [12 100]] [2 100]] [36 25]] [5 29]] [28 88]] [36 100]] [2259 2.6 [12 30] [12 80]]] [2445 1.04 [695 5.62 [2939 6.41 [22 41] [19 62]] [2385 2.82 [18 47] [18 61]]] [18 80]]] [2846 3.6 [2764 2.75 [22 42] [22 100]] [22 100]]] [112 6.06 [5262 0.917 [6508 1.85 [4349 2.02 [5734 3.77 [383 5.28 [3768 1.47 [16 3.6 [3699 2.46 [5484 2.53 [7571 2.3 [5972 4.42 [5260 18.7 [2616 0.515 [7068 3.45 [7695 1.83 [5565 1.53 [2526 10.9 [6333 3.28 [7737 3.01 [6380 1.49 [99 0.745 [392 4.71 [429 5.9 [18 20] [957 4.87 [1078 19.5 [3558 2.35 [14 42] [14 55]] [14 20]] [32 36]]] [29 33]] [14 68]] [1457 1.05 [14 58] [14 57]]] [22 46]] [32 70]] [719 14 [695 16.2 [17 2.85 [5 35] [4 66]] [12 50]] [13 38]]] [14 100]] [22 85]] [7 64]] [2913 0.766 [4414 6.53 [6988 3.19 [5660 3.92 [7251 0.774 [7722 1.8 [5 22] [5412 0.515 [16 36] [4 75]]] [5 41]] [17 50]] [2 100]] [4 52]] [7 40]]] [13 100]] [1400 8.04 [7255 7.15 [36 53] [12 100]] [12 86]]] [1429 32.2 [7697 1.6 [31 68] [31 100]] [5753 12 [36 40] [36 75]]]] [7665 21.4 [5480 20.7 [18 75] [18 100]] [18 58]]] [31 100]] [36 100]] [13 100]] [18 78]] [7 100]] [24 100]] [7 100]] [13 100]] [36 43]]] [22 100]] [3901 1.75 [705 2.02 [12 74] [12 100]] [12 100]]] [31 75]] [22 100]] [1429 44.3 [18 90] [18 100]]]] [6853 4.85 [7461 4.24 [6989 0.426 [1005 1.59 [6544 3.33 [10 2.01 [1078 15.7 [3905 6.63 [5732 3.94 [5130 1.9 [2799 2.33 [6074 1.22 [5637 2.09 [1899 6.44 [7516 6.22 [2752 23.6 [5812 0.956 [2913 1.75 [18 34] [32 33]] [2 42]] [5 29]] [18 53]] [1919 3.97 [4 35] [2 63]]] [19 88]] [2 37]] [26 100]] [18 54]] [7 72]] [695 9.13 [7 55] [7 81]]] [434 2.77 [5480 1.1 [7677 2.24 [4991 2.06 [7169 0.986 [4 31] [2 75]] [2 90]] [24 42]] [7722 1.59 [16 42] [25 42]]] [2 60]]] [31 85]] [1690 3.14 [5972 2.59 [23 33] [31 100]] [19 62]]] [31 100]] [2 100]] [31 85]] [5670 2.82 [7032 1.23 [2259 13.7 [31 70] [31 71]] [31 100]] [31 100]]]]] [1025 7.33 [978 16.4 [573 7.86 [5770 0.181 [4931 1.5 [4 100] [4 70]] [4 100]] [731 0.861 [4 72] [4 100]]] [4 78]] [6982 3.45 [4 92] [4 76]]]]] [1783 3.63 [5526 0.301 [1101 0.849 [722 1.07 [221 1.01 [2259 11.1 [29 72] [36 92]] [29 100]] [29 88]] [29 100]] [29 100]] [2773 1.72 [1746 1.36 [29 62] [36 100]] [36 100]]]] [3008 2.21 [6074 0.878 [6554 0.776 [980 1.54 [6583 0.724 [2755 0.682 [1640 0.805 [1704 1.22 [269 2.3 [736 2.66 [6575 3.94 [7446 0.557 [7491 8.08 [1500 2.85 [134 4.05 [7665 14.8 [5211 10 [7725 1.31 [338 4.59 [1429 12.6 [7665 7.31 [7766 13 [695 29.8 [429 16.9 [4 88] [4 100]] [4 53]] [4 71]] [4 60]] [144 12.7 [5412 0.524 [906 2.73 [5637 1.19 [2752 14.9 [7512 8.06 [17 40] [7381 12.2 [5 64] [4 30]]] [12 56]] [14 28]] [17 55]] [5 27]] [5 60]]] [26 100]] [4 100]] [37 62]] [2752 4.9 [2081 1.47 [2594 3.94 [5 39] [429 5.17 [5 85] [5 62]]] [19 38]] [5660 0.593 [7188 1.9 [6977 9.27 [6582 0.879 [7586 4.6 [2608 1.9 [7381 17.6 [5509 7.53 [7722 14.1 [6732 15.1 [5 69] [19 46]] [429 12.7 [14 37] [2526 15.7 [5 54] [5 71]]]] [5 72]] [14 37]] [5 83]] [1429 13.3 [17 50] [17 54]]] [7512 25.3 [4 100] [4 92]]] [14 33]] [17 40]] [17 57]]]] [5 61]] [5 100]] [2616 18 [1429 18.3 [17 50] [17 55]] [12 44]]] [38 50]] [2417 5.76 [4 33] [4 100]]] [2752 26.6 [5 55] [16 41]]] [6581 8.86 [26 60] [26 92]]] [896 1.16 [17 81] [17 100]]] [4 100]] [732 6.8 [5851 1.12 [26 94] [26 66]] [19 37]]] [178 1.68 [31 2.26 [5509 13.6 [23 17.6 [17 48] [14 70]] [5 83]] [17 87]] [17 73]]] [7693 1.35 [26 100] [26 83]]] [6583 6.72 [7185 19.6 [17 85] [19 57]] [7203 4.91 [19 38] [19 100]]]] [4 67]] [3713 1.01 [6584 6.94 [6581 31.1 [7676 0.574 [269 3.34 [31 3.86 [429 14.6 [2541 2.88 [1060 5.28 [144 5.68 [3008 24.2 [17 30] [19 66]] [14 30]] [26 55]] [17 67]] [1633 0.846 [17 64] [35 42]]] [695 6.79 [17 90] [17 72]]] [26 91]] [26 48]] [19 52]] [17 78]] [26 100]]]] [7734 0.215 [4690 2.26 [5732 2.37 [5130 0.183 [7516 1.06 [7381 1.35 [2840 0.467 [5693 0.472 [1011 1.34 [7185 2.35 [3663 0.775 [1980 3.82 [5412 17.6 [7742 0.407 [1661 0.623 [4573 3.45 [1559 1.01 [1030 5.41 [731 3.61 [7009 5.42 [5812 0.512 [874 0.647 [7601 0.975 [5972 0.898 [392 4.59 [814 2.18 [978 1.73 [203 1.22 [695 6.45 [36 26] [6853 3.7 [3905 3.82 [5264 3.88 [36 55] [13 100]] [36 88]] [6859 14.7 [36 100] [36 85]]]] [36 60]] [2526 3.18 [6 26] [18 88]]] [36 87]] [18 75]] [36 92]] [791 1.45 [695 15 [18 55] [36 75]] [36 82]]] [36 100]] [13 50]] [13 61]] [2259 6.27 [5 48] [18 45]]] [26 100]] [36 100]] [13 70]] [16 63]] [18 78]] [13 87]] [36 28]] [36 100]] [18 27]] [18 50]] [18 45]] [18 81]] [5 60]] [26 57]] [2644 0.0844 [896 12.2 [1671 5.62 [4979 4.89 [4338 1.82 [5599 1.35 [18 60] [16 62]] [2993 1.58 [16 84] [16 44]]] [16 81]] [18 46]] [18 100]] [7048 1.48 [2862 1.77 [3993 0.0844 [16 68] [37 44]] [19 33]] [18 70]]]] [7068 1.86 [7 47] [7 90]]] [8 100]] [3742 0.214 [2732 0.122 [7601 1.46 [4781 1.14 [6592 1.15 [4513 1.1 [1783 4.23 [2526 17 [0 3.11 [2628 9.52 [5904 1.22 [7566 3.33 [5723 0.506 [421 3.52 [5007 14.4 [2108 0.848 [279 13.5 [788 6.18 [7722 1.62 [5484 0.465 [18 80] [144 4.85 [6740 0.458 [7057 1.5 [18 100] [18 85]] [18 100]] [18 93]]] [18 75]] [18 76]] [18 54]] [16 50]] [6 20]] [16 50]] [18 100]] [18 100]] [18 50]] [4851 1.36 [276 1.56 [18 75] [18 55]] [18 55]]] [16 44]] [18 61]] [3584 0.182 [1671 2.55 [4716 3.12 [964 3.19 [5509 0.279 [1587 0.4 [132 4.32 [18 65] [18 42]] [5480 7.82 [18 100] [18 83]]] [18 100]] [18 54]] [16 54]] [19 50]] [19 50]]] [19 50]] [18 100]] [19 69]] [3675 1.28 [964 2.61 [192 0.538 [429 49.1 [688 4.21 [7734 3.28 [7419 2.32 [18 64] [16 84]] [6181 1.41 [5480 2.41 [7 50] [2811 1.22 [145 7.23 [4860 2.8 [4332 0.433 [5154 11.3 [5632 10.3 [7203 8.25 [7038 2.16 [4571 3.18 [2381 3.22 [7735 5 [980 1.65 [2259 36.1 [4229 0.53 [2752 4.01 [18 75] [4684 1.13 [284 3.59 [896 0.506 [18 90] [7665 8.87 [18 92] [18 100]]] [5484 5.89 [18 83] [18 90]]] [18 80]]] [18 100]] [18 71]] [16 42]] [7512 17.2 [18 57] [2385 1.31 [18 80] [18 87]]]] [18 36]] [19 80]] [18 50]] [18 33]] [16 40]] [5 37]] [1783 4 [978 5.74 [18 91] [18 100]] [18 85]]] [6199 3.4 [1783 2.71 [7734 13.8 [18 40] [5480 19.3 [18 100] [18 83]]] [18 92]] [18 75]]] [6 25]] [5692 4.99 [18 57] [16 40]]]] [7 41]]] [1669 5.62 [7 75] [7 100]]] [16 72]] [16 57]] [276 19 [18 46] [6 81]]] [19 40]]] [1262 0.517 [4939 0.25 [16 44] [16 100]] [18 50]]] [1896 0.451 [163 3.14 [2671 0.488 [7255 3.85 [5345 2.74 [19 33] [7057 2.64 [18 90] [18 40]]] [18 57]] [2385 4.5 [18 50] [16 50]]] [18 37]] [19 75]]]]] [5593 2.86 [826 0.631 [333 0.675 [3377 0.963 [504 6.98 [6333 1.52 [5165 0.441 [7084 1.61 [3742 5.66 [6437 8.26 [5732 4.12 [2330 3.27 [5872 1.85 [4379 2.2 [7512 3.25 [2752 10.8 [30 25] [14 57]] [4309 4.7 [7682 2.79 [663 14.4 [7340 2.15 [7542 4.29 [695 75.5 [7139 0.952 [723 1.21 [6015 3.12 [112 3.88 [726 2.53 [7259 1.58 [2445 1.69 [791 20.4 [6544 2.35 [2939 1.25 [14 84] [14 100]] [14 100]] [14 72]] [14 100]] [14 55]] [14 55]] [14 70]] [14 100]] [32 66]] [14 100]] [32 71]] [32 100]] [7665 24.2 [32 100] [32 83]]] [32 52]] [14 100]] [32 100]]] [32 100]] [14 100]] [32 100]] [1761 1.08 [6544 1.29 [28 44] [14 90]] [14 100]]] [14 100]] [28 50]] [32 85]] [14 100]] [2259 1.93 [32 76] [7600 0.53 [32 86] [32 100]]]] [32 75]] [32 100]] [14 100]] [957 0.335 [32 80] [32 100]]] [32 92]]] [5574 0.164 [7381 2.24 [24 71] [24 100]] [7106 5 [631 4.15 [5412 0.402 [4191 6.36 [24 100] [24 96]] [24 100]] [24 83]] [5833 1.25 [19 57] [24 100]]]]] [699 0.755 [5803 0.767 [7665 1.7 [1771 11.7 [560 14.2 [5693 1.2 [4748 0.828 [5368 5.46 [6449 0.365 [696 0.818 [2143 2.51 [5042 1.4 [21 24] [21 100]] [17 20]] [9 86]] [14 21]] [9 100]] [9 80]] [5692 9.32 [9 100] [9 50]]] [18 83]] [21 100]] [6 23]] [696 4.35 [9 76] [9 100]]] [6910 0.294 [7203 1.74 [4751 0.23 [1312 3.45 [7428 14 [920 3.11 [1328 0.782 [578 1.9 [6837 4.29 [1338 2.28 [572 0.626 [1299 0.39 [9 57] [9 91]] [9 91]] [9 92]] [9 93]] [9 100]] [9 95]] [21 90]] [21 100]] [2526 1.22 [6897 7.21 [371 3.18 [9 89] [695 4.82 [3 25] [5937 8.81 [9 57] [9 100]]]] [9 100]] [9 69]]] [6136 1.8 [523 2.56 [9 100] [9 75]] [9 85]]] [21 90]] [6015 2.28 [9 60] [20 40]]]]] [4799 0.871 [2846 3.36 [5693 0.565 [4279 12.8 [4747 13.8 [1980 0.74 [5034 2.82 [6153 1.01 [978 5.37 [5534 2.99 [6668 0.383 [2199 0.513 [5480 1.36 [5732 2.9 [28 71] [28 82]] [26 40]] [28 57]] [2268 0.383 [1206 1.24 [28 91] [28 85]] [28 100]]] [28 44]] [8 66]] [28 100]] [5925 19.4 [2902 0.699 [5897 1.6 [5462 0.613 [7731 0.87 [5838 0.605 [2849 1.39 [4396 1.31 [5753 8.85 [1625 5.01 [5753 5.1 [1206 1.05 [6853 1.58 [1429 20.2 [28 50] [28 94]] [4414 2.97 [968 8.28 [28 77] [28 97]] [28 100]]] [28 100]] [28 100]] [28 80]] [4279 3.07 [28 88] [28 66]]] [28 100]] [28 100]] [28 62]] [28 100]] [392 0.218 [221 8.46 [28 100] [28 85]] [28 100]]] [28 87]] [28 100]] [28 66]]] [1745 0.6 [5753 1.96 [7149 0.146 [7413 1.87 [5732 0.414 [2897 2.67 [2466 0.562 [6199 4.52 [28 34] [37 37]] [22 23]] [28 100]] [28 100]] [5692 2.57 [28 100] [28 88]]] [4851 1.23 [28 85] [28 100]]] [6131 0.586 [1101 0.949 [4982 0.233 [2664 0.415 [6040 7.3 [4564 1.44 [855 0.322 [1429 20.7 [28 62] [328 12.4 [434 0.763 [28 88] [28 92]] [28 77]]] [28 100]] [28 30]] [28 57]] [28 97]] [28 50]] [28 56]] [28 55]]] [19 80]]] [22 100]] [2062 0.975 [695 5.73 [29 63] [28 70]] [29 87]]] [2616 1.49 [887 2.01 [2081 1.87 [28 34] [18 27]] [22 87]] [4 31]]] [32 61]] [32 71]]] [1409 1.2 [2488 2.62 [1078 17.5 [5309 1.63 [5420 0.838 [7428 1.4 [6579 2.79 [112 12.2 [6156 2.18 [3130 5.92 [10 33] [10 66]] [10 100]] [10 72]] [31 100]] [558 2.46 [12 68] [12 100]]] [12 75]] [10 100]] [7697 3.14 [7255 2.92 [2384 0.486 [1238 2.06 [695 12.1 [7554 0.49 [731 1.11 [10 100] [10 87]] [10 100]] [10 91]] [10 100]] [10 100]] [10 50]] [31 100]]] [12 100]] [36 100]]] [3929 1.04 [407 2.71 [1666 0.0664 [3517 0.413 [3732 0.459 [7657 0.599 [877 0.613 [5972 6.62 [7354 0.168 [6813 3.61 [6239 2.54 [5730 0.792 [5480 1.68 [5165 0.715 [2574 1.06 [685 0.227 [6077 0.255 [5566 0.106 [891 0.94 [5693 0.062 [6732 0.157 [2616 0.755 [855 2.99 [602 0.215 [1727 0.982 [736 1.16 [731 1.44 [826 1.01 [5276 1.17 [5007 0.441 [6650 3.04 [2826 2.36 [1300 0.726 [5637 6.19 [896 11.8 [5692 1.91 [1679 1.18 [7428 7.82 [4624 3.03 [7559 2.49 [2993 2.83 [7512 0.572 [906 2.92 [3905 0.657 [4478 1.27 [37 20] [13 33]] [37 66]] [9 69]] [7185 1.37 [14 32] [14 36]]] [10 62]] [31 100]] [14 69]] [2259 5.38 [12 33] [12 87]]] [30 36]] [7512 2.1 [23 17 [30 33] [22 50]] [13 43]]] [14 92]] [22 66]] [10 100]] [434 1.81 [7409 1.98 [2259 3.25 [1079 10 [1764 9.35 [4968 1.81 [906 1.98 [7214 8.85 [1557 3.69 [1630 4.12 [7185 17.8 [2759 1.37 [7233 11.8 [6883 7.23 [695 13.3 [14 54] [2752 83.5 [4414 3.18 [7526 6.17 [7381 17.2 [14 76] [5 42]] [14 100]] [14 96]] [18 36]]] [12 40]] [32 55]] [14 100]] [14 36]] [14 55]] [14 40]] [14 86]] [32 58]] [37 33]] [7 100]] [32 66]] [705 3.65 [889 0.75 [7665 40.4 [7210 5.84 [1630 2.51 [14 66] [14 88]] [14 100]] [32 57]] [32 100]] [12 58]]] [14 94]] [6808 2.73 [32 36] [32 100]]]] [32 100]] [5368 2.87 [3292 1.81 [32 34] [37 100]] [10 42]]] [10 100]] [12 57]] [3905 5.34 [3676 1.19 [791 5.04 [719 18.2 [5 30] [5 75]] [1078 9.07 [14 50] [17 57]]] [5 33]] [17 51]]] [1584 2.98 [7381 0.835 [5 38] [1580 1.78 [3008 2.18 [6442 2.35 [1899 7.48 [5 41] [5 100]] [5 100]] [17 60]] [17 66]]] [35 45]]] [32 100]] [1761 0.327 [131 0.875 [112 0.163 [7149 1.72 [7449 1.35 [2573 1.29 [7301 1.46 [3461 2.13 [328 5.76 [3057 0.389 [17 31] [978 2.15 [5 77] [5 100]]] [14 41]] [17 71]] [19 77]] [695 4.61 [17 100] [17 66]]] [731 7.28 [5 100] [5 33]]] [14 69]] [145 1.29 [2081 0.816 [1899 0.215 [32 32] [37 33]] [32 75]] [6 26]]] [32 66]] [14 100]]] [7472 1.65 [14 92] [14 100]]] [2199 2.1 [7251 3.63 [2752 3.46 [31 40] [494 0.824 [5155 0.592 [939 0.623 [5 56] [5 70]] [5 100]] [17 66]]] [17 30]] [5 81]]] [328 4.75 [7665 30.7 [6401 1.39 [2968 3.52 [6557 3.52 [663 0.314 [7590 3.62 [4083 3.03 [312 1.15 [1011 11.1 [1535 2.37 [602 7.69 [2628 0.703 [14 32] [5753 1.63 [719 3.17 [19 37] [5 50]] [28 50]]] [17 76]] [5 83]] [19 69]] [4 68]] [5 90]] [4414 3.43 [17 38] [4 33]]] [5891 0.31 [7548 1.65 [7526 0.882 [2616 6.85 [1980 5.77 [17 35] [5 38]] [17 63]] [17 70]] [14 100]] [5383 0.391 [7334 2.14 [17 84] [17 57]] [17 50]]]] [5 90]] [19 40]] [5 100]] [5 41]] [14 47]]] [2526 1.27 [3008 2.28 [2913 0.909 [724 0.496 [5692 23.8 [1025 0.419 [14 50] [21 23]] [5 72]] [17 38]] [32 80]] [613 1.03 [14 87] [14 100]]] [5742 0.177 [3057 0.665 [5515 2.18 [1400 0.813 [1505 0.205 [6591 1.07 [655 0.759 [5918 1.71 [184 2.41 [6230 1.68 [16 30] [2829 0.399 [3905 2.57 [3998 0.876 [6732 0.183 [5 36] [929 5.88 [17 42] [5 62]]] [5 100]] [7009 0.743 [134 2.11 [17 34] [17 60]] [5 33]]] [429 34.6 [17 37] [17 66]]]] [5 100]] [17 57]] [24 55]] [1919 3.07 [5509 2.06 [663 3.15 [17 74] [6310 4.94 [1062 0.719 [17 50] [17 71]] [14 40]]] [17 100]] [17 100]]] [1072 0.205 [5 100] [5 83]]] [2752 17.4 [4 41] [4 100]]] [5 96]] [5662 0.474 [2902 0.445 [978 8.45 [5 50] [5 100]] [5 100]] [5 100]]] [17 91]]]] [24 100]] [7139 0.319 [14 98] [14 100]]] [7677 0.455 [896 2.24 [1600 1.44 [4 51] [7 100]] [2763 0.517 [4 53] [4 92]]] [17 50]]] [4205 0.717 [2707 1.9 [7067 3.57 [2764 1.67 [7369 0.69 [1079 2.93 [4851 6.52 [673 3.07 [4716 1.84 [7149 7.06 [814 0.491 [721 0.227 [23 15 [5753 4.44 [7734 5.88 [1429 38.5 [14 48] [14 94]] [7 100]] [28 50]] [14 100]] [14 100]] [14 71]] [14 100]] [14 55]] [26 92]] [14 50]] [14 44]] [14 94]] [14 44]] [7 100]] [26 40]] [5753 0.838 [418 3.29 [26 62] [7 46]] [14 25]]]] [4960 0.666 [7327 0.543 [1429 11.6 [5660 1.48 [978 13.9 [17 40] [4 62]] [4 100]] [7449 0.685 [5462 0.271 [7693 1.88 [6732 3.24 [5 72] [17 69]] [17 30]] [17 77]] [17 61]]] [4 100]] [4 100]]] [5509 2.99 [791 15.8 [4768 0.894 [728 0.363 [14 97] [14 100]] [14 100]] [14 92]] [14 90]]] [6855 1.83 [7381 1.13 [1679 0.967 [1007 0.371 [7736 0.938 [248 7.68 [719 0.515 [1980 4.95 [5225 0.627 [22 47] [22 100]] [1429 27.7 [22 42] [29 62]]] [7693 2.69 [1899 3.13 [4851 1.77 [19 35] [4 58]] [2526 0.639 [16 55] [18 63]]] [26 44]]] [5869 0.312 [1783 5.74 [26 79] [26 100]] [26 100]]] [18 76]] [26 90]] [859 1.32 [22 96] [22 100]]] [4 50]] [22 100]]] [1552 3.19 [32 100] [32 77]]] [695 3.88 [14 45] [602 15.9 [5753 5.32 [429 30.3 [6977 2.73 [2739 0.707 [663 14.2 [4895 0.732 [14 95] [14 100]] [14 84]] [14 100]] [14 92]] [14 67]] [14 54]] [14 75]]]] [32 100]] [5430 1.07 [5635 0.765 [6040 0.11 [2913 0.312 [6581 1.22 [899 1.48 [7177 1.33 [5732 0.609 [2064 1.21 [826 1.41 [2902 4.2 [5484 0.883 [6241 1.26 [7260 0.247 [284 0.845 [5482 1.77 [7428 2.29 [1899 2.99 [18 25] [5723 0.302 [5851 0.624 [7 22] [18 66]] [18 100]]] [32 83]] [7734 5.42 [18 52] [18 75]]] [19 75]] [5516 0.247 [19 66] [2607 2.04 [18 87] [18 75]]]] [5 66]] [6139 0.399 [3381 0.791 [328 25.8 [2385 1.37 [5641 3.05 [1899 3.72 [7188 5.29 [1012 5.5 [6471 1.65 [6027 0.56 [985 1.63 [18 84] [7 37]] [18 80]] [18 44]] [18 54]] [18 100]] [4154 8.26 [1009 1.2 [16 84] [18 63]] [18 83]]] [18 41]] [5161 0.826 [685 5.18 [4154 1.57 [7255 0.583 [18 81] [19 53]] [16 42]] [5480 13.6 [18 83] [16 40]]] [19 62]]] [19 35]] [38 36]] [16 50]]] [5484 1.44 [324 1.43 [5 43] [5 40]] [16 26]]] [32 75]] [16 81]] [731 1.07 [32 54] [7 62]]] [7 100]] [2752 20.8 [16 33] [5692 3.3 [3905 1.62 [32 70] [32 85]] [14 42]]]] [6585 0.629 [4218 3.96 [1473 0.813 [2841 0.334 [6311 5.41 [1239 0.529 [7722 14.6 [2764 0.824 [1011 5 [7185 1.04 [695 14.5 [2968 1.78 [7601 1.09 [5 80] [5 95]] [5 66]] [5 42]] [5 100]] [6550 3.84 [5 66] [5 50]]] [5 44]] [38 36]] [19 47]] [5 44]] [7665 10.3 [5 75] [5 84]]] [5 37]] [5 87]] [26 50]]] [7340 1.49 [5322 3.1 [4110 5.08 [7722 5.3 [3604 0.791 [5154 4.28 [7343 2.15 [812 4.35 [7185 7 [2913 10.9 [6727 2.91 [1429 25.9 [7 70] [5 52]] [5 100]] [731 7.51 [5 80] [5 62]]] [26 57]] [5 69]] [7 69]] [7 63]] [18 80]] [5 81]] [12 41]] [5 28]] [3905 0.439 [6230 9.37 [32 93] [32 83]] [32 100]]]] [2268 6.67 [5368 5.67 [1239 4.99 [719 7.4 [4288 2.08 [6342 0.849 [7665 2.54 [18 100] [2445 0.53 [4154 5.44 [1011 5.31 [543 0.574 [5262 0.197 [2385 0.924 [18 72] [18 87]] [18 100]] [18 50]] [19 44]] [16 44]] [19 90]]] [16 62]] [32 57]] [7722 0.469 [18 92] [18 66]]] [7731 0.348 [7354 9.79 [18 100] [18 81]] [18 72]]] [16 62]] [4927 3.74 [18 45] [18 42]]]] [7665 2.1 [5637 2.37 [16 44] [18 72]] [1253 0.666 [4791 0.417 [429 7.4 [18 50] [896 5.04 [2607 2.66 [1011 1.18 [16 91] [16 50]] [16 55]] [7 40]]] [16 100]] [190 1.26 [19 50] [16 40]]]]] [17 3.41 [5 65] [5 100]]]] [802 6.23 [328 3.33 [2826 0.849 [6230 24.6 [31 41] [12 90]] [906 0.541 [2818 1.22 [12 98] [12 100]] [12 100]]] [12 97]] [12 50]]] [22 100]] [12 100]] [3599 0.65 [1201 2.1 [31 2.42 [6152 0.994 [5155 2.94 [5037 1.21 [4766 1.28 [1151 0.736 [4851 5.5 [2829 3.19 [5491 3.71 [5007 2.48 [442 0.227 [7595 5.16 [5742 1.84 [5345 2.61 [4991 1.67 [6724 0.759 [3014 19.2 [726 4.65 [2967 2.67 [7244 4.74 [7526 3.14 [2811 0.751 [1089 2.79 [7725 0.75 [1899 2.98 [7188 4.3 [649 1.21 [17 72] [17 80]] [17 100]] [2826 4.33 [17 100] [17 88]]] [17 100]] [17 75]] [17 71]] [17 66]] [17 100]] [14 28]] [38 57]] [17 30]] [19 63]] [17 60]] [17 33]] [17 100]] [17 33]] [17 62]] [19 50]] [17 100]] [19 50]] [722 2.43 [1980 1.59 [7067 4.65 [2939 5.01 [17 64] [19 63]] [17 72]] [17 46]] [14 77]]] [23 3.66 [7185 4.25 [7251 0.99 [38 48] [19 90]] [17 50]] [1062 0.846 [6 22] [17 77]]]] [19 40]] [19 41]] [7711 1.4 [896 9.32 [17 100] [4805 3.5 [17 83] [7253 4.83 [17 50] [17 71]]]] [17 81]]] [19 55]] [6311 0.966 [7682 2.84 [17 25] [17 85]] [19 70]]] [6199 0.365 [728 0.54 [35 37] [2381 0.319 [17 46] [35 100]]] [35 100]]] [7665 9.44 [19 75] [19 100]]]] [7214 2.77 [5413 0.246 [5523 1.44 [2902 2.11 [4535 0.388 [19 88] [19 83]] [19 100]] [19 53]] [3562 0.475 [1078 8.87 [19 100] [19 77]] [19 100]]] [19 100]]] [5519 0.137 [3905 4.03 [1059 2.59 [719 3.48 [3585 0.507 [4457 0.14 [733 1.82 [3983 3.01 [2570 0.572 [7381 5.39 [5952 2.9 [5007 0.818 [6732 0.511 [16 41] [6550 0.427 [19 66] [2573 11.3 [38 50] [19 85]]]] [19 75]] [17 35]] [17 55]] [38 69]] [5892 0.805 [2939 0.913 [38 45] [3008 4.37 [19 88] [38 77]]] [19 92]]] [17 84]] [4457 3.13 [6584 1.43 [17 100] [17 85]] [17 53]]] [17 100]] [738 0.243 [5155 3.52 [3983 1.87 [6557 1.17 [429 47.5 [7665 16.5 [2902 1.16 [5389 3.7 [38 64] [17 54]] [38 88]] [17 85]] [17 81]] [862 0.391 [17 91] [17 44]]] [38 57]] [19 50]] [35 66]]] [7526 0.974 [38 100] [38 77]]] [3519 0.991 [3908 1.26 [4876 0.338 [6313 0.352 [2199 0.93 [4851 0.834 [17 68] [7590 0.242 [134 1.42 [1566 0.323 [733 0.494 [17 73] [17 50]] [17 40]] [38 66]] [17 87]]] [6 33]] [1740 0.399 [3913 1.39 [19 76] [38 50]] [17 71]]] [19 55]] [6576 2.18 [7723 0.715 [6357 0.366 [19 93] [19 46]] [38 66]] [17 70]]] [5637 1.77 [7512 12.6 [19 100] [5812 1.05 [19 70] [19 85]]] [19 57]]]] [2588 2.77 [5883 0.857 [429 16.1 [19 71] [2760 1 [5953 1.87 [19 100] [19 85]] [3983 1.08 [6910 0.596 [19 100] [1580 0.934 [19 42] [19 100]]] [19 100]]]] [19 100]] [19 60]]]] [2748 0.548 [6732 0.503 [957 3.09 [4478 5.14 [4939 3.01 [5348 1.8 [2466 2.93 [2707 2.68 [7 86] [7 50]] [7 100]] [16 55]] [7 38]] [7 100]] [2826 3.54 [7 50] [7 50]]] [7588 1.41 [4997 0.945 [18 48] [7 100]] [26 100]]] [2259 3.72 [1696 1.21 [26 90] [26 100]] [26 71]]]] [7657 0.705 [5972 0.902 [6240 0.472 [7326 0.109 [4105 1.69 [2594 0.701 [494 0.102 [724 1.08 [6809 0.392 [710 1.14 [7251 1.08 [7693 4 [5732 0.412 [3315 0.586 [1011 1.11 [2763 1.26 [6581 1.62 [5647 0.994 [6124 2.37 [14 27] [12 100]] [32 33]] [2526 2.42 [17 30] [5 62]]] [32 50]] [647 0.473 [1704 0.677 [913 2.02 [7722 2.57 [5 94] [5 85]] [5 60]] [17 78]] [12 25]]] [731 7.37 [5 100] [5 83]]] [1690 1.24 [14 72] [17 55]]] [17 88]] [1463 0.711 [5345 2.94 [7253 6.18 [7590 0.975 [5692 4.76 [1429 52.7 [731 9.66 [17 92] [17 72]] [5 28]] [17 100]] [17 100]] [14 37]] [5 62]] [5 83]]] [14 100]] [32 100]] [1690 0.313 [6865 0.768 [7711 3.08 [7665 11.4 [5 38] [17 63]] [5 44]] [5 77]] [3078 2.72 [6230 16.1 [1703 3.16 [5677 2.06 [896 1.41 [17 95] [6395 4.53 [724 5.12 [5647 1.96 [17 100] [17 87]] [17 83]] [134 3.5 [17 54] [19 42]]]] [17 42]] [19 71]] [17 37]] [19 60]]]] [4338 4.99 [3415 0.591 [144 3.61 [4559 0.434 [5732 1.07 [1079 1.69 [722 4.48 [7534 5.24 [2616 0.54 [7253 0.615 [5693 0.661 [7722 2.54 [16 42] [17 70]] [17 50]] [4587 2.34 [17 77] [17 93]]] [6591 6.32 [6076 0.185 [2588 0.35 [17 100] [17 71]] [17 100]] [17 80]]] [17 67]] [14 50]] [5 42]] [2574 0.349 [178 1.43 [5743 5.55 [688 0.102 [5742 0.539 [17 83] [6544 8.65 [17 100] [17 83]]] [17 100]] [17 70]] [17 80]] [17 100]]] [14 50]] [906 0.459 [5155 1.75 [731 2.31 [17 71] [7722 2.08 [17 90] [17 100]]] [5 28]] [16 38]]] [14 80]] [17 42]]] [3929 5.52 [5 83] [5 91]]] [5 100]] [3977 0.885 [2081 2.03 [5693 3.11 [7665 32.3 [5509 4.28 [647 0.21 [4851 3.63 [2826 5.19 [978 5.86 [5 33] [5 66]] [5 85]] [5 100]] [5 100]] [5 50]] [5 50]] [5 100]] [12 54]] [1062 8.3 [1911 0.224 [7324 25.1 [5 100] [5 92]] [5 100]] [5 80]]]] [736 4.18 [19 100] [19 90]]] [12 100]] [12 100]]]] [5282 0.0855 [7512 2.98 [7176 1.53 [716 21.7 [377 0.179 [4851 0.282 [6699 0.869 [30 0.381 [4218 0.352 [178 2.7 [371 0.182 [4270 1.08 [5121 0.99 [645 3.83 [5556 2.22 [2902 3.47 [730 0.79 [7419 1.99 [6711 2.33 [2752 2.8 [802 1.31 [22 25] [21 76]] [663 19.6 [4897 0.599 [5413 0.781 [713 0.852 [5034 1.93 [7016 1.66 [859 1.09 [1400 0.914 [2813 2.22 [3879 0.234 [6883 3.27 [5911 0.518 [7449 14.2 [2093 0.537 [5824 0.967 [28 62] [11 87]] [28 92]] [28 88]] [28 77]] [22 55]] [7 40]] [22 100]] [11 22]] [22 93]] [22 84]] [791 5.03 [14 56] [28 81]]] [36 66]] [29 72]] [28 88]] [22 78]]] [80 1.19 [429 33.3 [22 100] [22 60]] [22 100]]] [29 90]] [28 91]] [6077 0.843 [3742 2.48 [1980 4.76 [404 4.58 [4154 5.06 [28 54] [28 88]] [28 100]] [1980 14.5 [7118 2.12 [880 0.64 [28 100] [28 83]] [28 100]] [28 77]]] [28 100]] [28 94]]] [22 100]] [22 70]] [22 100]] [36 100]] [21 66]] [25 81]] [697 0.521 [28 93] [28 100]]] [22 83]] [29 100]] [429 24.7 [4870 1.55 [2939 0.423 [28 80] [28 50]] [28 57]] [6761 0.382 [1980 8.66 [5289 3.75 [28 98] [28 75]] [28 81]] [28 90]]]] [663 14.7 [2521 0.942 [5211 2.23 [5154 6.07 [7359 0.467 [6885 0.682 [6353 2.83 [867 4.7 [4861 6.6 [2904 7.42 [7445 1.06 [5637 5.33 [1025 0.179 [880 5.68 [1752 3.51 [1429 5.78 [28 85] [4279 0.346 [6998 0.998 [377 21.7 [28 100] [28 87]] [28 100]] [28 100]]] [4568 0.394 [328 11.5 [28 100] [28 83]] [28 100]]] [28 81]] [28 100]] [28 87]] [429 16.2 [28 57] [28 100]]] [28 75]] [28 83]] [28 83]] [28 63]] [28 70]] [28 62]] [28 62]] [22 90]] [28 66]] [22 62]]] [22 80]] [826 0.818 [1226 0.422 [4876 2.76 [4154 3.39 [1980 10.8 [5692 19.5 [7197 9.15 [1899 0.421 [1215 1.07 [712 0.743 [112 1.42 [22 83] [22 100]] [22 100]] [22 100]] [22 100]] [22 85]] [22 75]] [5211 11 [791 14.8 [22 100] [11 57]] [22 100]]] [791 3.85 [22 36] [4279 8.96 [6031 0.21 [22 85] [22 100]] [22 75]]]] [22 71]] [22 37]] [12 40]]] [5228 0.2 [899 0.31 [3929 0.887 [1600 0.377 [7547 0.298 [3558 0.673 [1980 4.23 [7583 1.16 [2143 9 [5211 0.963 [7516 0.961 [2752 32.9 [5480 1.72 [6177 0.223 [6544 2.72 [7461 0.393 [6077 0.448 [5972 4.31 [1011 5.86 [2259 5.85 [7 40] [978 0.924 [32 22] [4 33]]] [1011 10 [7 100] [7 55]]] [695 11 [36 88] [36 100]]] [602 0.745 [7384 1.04 [7 81] [7 98]] [7 100]]] [7 88]] [14 34]] [28 38]] [896 0.84 [6 25] [17 37]]] [7 18]] [25 46]] [7491 0.485 [2259 16.6 [6732 5.78 [22 69] [22 100]] [22 100]] [22 57]]] [7 100]] [6529 7.17 [7301 6.36 [5110 2.62 [5972 2.18 [5904 0.849 [6851 1.47 [6525 2.11 [2939 4.63 [7177 1.35 [5034 6.02 [7067 2.04 [719 0.484 [25 37] [7 90]] [7 100]] [14 62]] [7 100]] [7 36]] [25 64]] [7 100]] [7 86]] [36 80]] [36 87]] [36 90]] [23 6.33 [7 95] [7 100]]]] [144 3.05 [685 2.59 [6031 2.37 [1995 0.307 [939 4.77 [178 1.89 [5403 2.54 [33 24] [31 100]] [25 66]] [31 66]] [5851 0.701 [7 42] [22 33]]] [22 94]] [5267 0.869 [2178 0.593 [7 80] [7 60]] [7 44]]] [22 28]]] [7 100]] [4 100]] [7 100]] [6729 0.365 [1690 1.63 [5 31] [145 0.556 [4895 0.454 [3302 0.211 [6977 5.8 [17 100] [17 83]] [17 100]] [17 66]] [17 46]]] [14 75]]] [896 2.92 [1068 0.227 [5268 0.662 [2259 10.5 [1429 31.6 [29 44] [32 60]] [36 94]] [36 84]] [12 33]] [2259 10.7 [6524 3.6 [29 58] [29 43]] [5692 7 [36 100] [14 42]]]]] [22 100]]] [2616 0.644 [7671 0.0917 [2752 7.61 [22 53] [978 4.7 [6820 0.366 [5704 3.06 [2752 15 [22 83] [22 100]] [22 80]] [22 100]] [22 70]]] [22 100]] [7 57]]]] [2832 0.682 [7516 0.266 [5892 0.629 [3905 1.36 [7665 2 [6848 5.29 [1445 0.657 [248 0.728 [5267 2.05 [6935 3.31 [6776 0.96 [5480 2.8 [685 1.66 [3157 0.498 [3867 11.2 [3066 0.595 [7472 2.98 [6015 3.48 [3338 9.21 [5412 5.07 [3772 0.193 [5647 11.4 [6068 7.64 [3247 0.843 [906 4.07 [1463 0.534 [1995 3.48 [791 31.9 [1533 12.8 [4108 0.775 [1992 1.12 [4017 2.25 [3087 6.48 [145 3.34 [3243 7.12 [3171 0.69 [3879 17.4 [2259 6.95 [3783 0.677 [2775 0.422 [4874 4.92 [2752 9.9 [3464 1.56 [37 84] [37 100]] [37 100]] [37 100]] [37 100]] [37 100]] [37 90]] [37 42]] [37 100]] [37 75]] [37 87]] [37 88]] [37 90]] [37 83]] [37 100]] [37 92]] [2752 1.64 [37 60] [37 100]]] [37 81]] [4065 1 [3715 0.493 [37 97] [37 100]] [37 100]]] [328 9.75 [3056 2.26 [957 0.287 [37 76] [37 87]] [37 100]] [37 100]]] [37 100]] [37 75]] [37 90]] [2754 0.193 [839 0.271 [791 3.94 [37 90] [37 100]] [37 100]] [37 100]]] [37 55]] [37 79]] [37 86]] [38 54]] [37 66]] [37 84]] [37 100]] [37 37]] [23 16.3 [18 36] [22 85]]] [11 44]] [37 44]] [37 52]] [16 36]] [37 57]] [37 41]] [7241 2.07 [23 25.1 [1980 2.26 [7009 1.56 [112 6.32 [37 42] [13 63]] [5 38]] [4 15]] [22 44]] [17 55]]] [4748 11.6 [6349 0.201 [6732 0.602 [4496 2.05 [1463 19.1 [5642 0.588 [731 1.76 [791 0.838 [37 85] [791 12.4 [1986 1.49 [2469 2.25 [3929 13.6 [328 5.76 [3057 0.325 [4154 2.64 [3317 0.402 [452 0.514 [3359 0.873 [3701 1.11 [37 98] [37 100]] [37 100]] [37 100]] [37 100]] [37 92]] [37 100]] [706 1.06 [4414 0.843 [3492 2.57 [3300 3.69 [3688 0.271 [2780 5.02 [37 100] [37 88]] [37 100]] [37 80]] [37 80]] [37 100]] [37 84]]] [429 12.9 [37 100] [19 62]]] [37 75]] [695 5.2 [37 42] [37 87]]] [5605 2.28 [3087 0.249 [3374 24.7 [6657 10.3 [112 3.38 [37 100] [3724 0.276 [3831 0.786 [906 2.79 [37 100] [37 85]] [37 100]] [37 100]]] [37 90]] [37 87]] [37 100]] [3299 1.25 [37 75] [37 100]]]]] [17 42]] [37 82]] [37 62]] [37 76]] [3057 0.523 [429 29.9 [37 50] [19 50]] [37 100]]] [37 50]] [13 50]]] [17 85]] [26 43]] [22 38]]] [7241 1.1 [4895 0.483 [7722 0.419 [5034 1.04 [7381 0.275 [2029 0.347 [2259 13.4 [5693 1.02 [5819 1.11 [5820 0.589 [4154 10.9 [1640 1.4 [28 27] [2 100]] [2 57]] [2526 34.3 [6988 7.3 [2 100] [2 91]] [2 83]]] [2 100]] [2553 1.02 [567 4.73 [429 27.5 [2 100] [2 87]] [2 85]] [2 100]]] [22 71]] [2 54]] [2199 1.49 [2 92] [2 100]]] [28 100]] [4154 0.385 [6537 3.1 [2 44] [2 100]] [4279 10.5 [7512 21.1 [2 100] [2 83]] [2 87]]]] [17 28]] [4533 1.81 [22 30] [22 100]]]] [1783 5.85 [7722 0.562 [328 22.2 [708 0.0753 [3850 0.37 [3308 3.25 [3675 0.457 [5296 0.754 [3771 4.31 [5692 2.63 [1507 0.282 [939 0.879 [5285 0.883 [906 1.56 [3220 1.04 [3990 0.654 [2753 1.95 [37 97] [37 72]] [37 100]] [37 100]] [37 80]] [37 100]] [37 100]] [37 100]] [37 85]] [37 100]] [37 85]] [37 100]] [37 75]] [37 77]] [37 100]] [791 7.64 [7169 6.67 [37 58] [37 100]] [37 100]]] [5 30]] [2178 0.451 [957 1.95 [37 75] [18 50]] [37 50]]]] [3432 0.162 [2259 9.82 [1674 0.559 [5459 1.17 [5402 0.269 [20 0.385 [1025 4.47 [2259 2.82 [7068 2.09 [596 0.283 [5225 2.73 [2752 14.4 [7722 17.3 [2616 1.56 [538 1.01 [4376 1.18 [6230 0.428 [5472 27.8 [1888 24.5 [7665 1.4 [13 57] [7698 0.381 [13 91] [13 99]]] [13 80]] [791 4.27 [6074 6.49 [13 52] [13 100]] [13 72]]] [13 70]] [13 100]] [9 70]] [2 42]] [5412 6.49 [36 86] [13 90]]] [6031 8 [6853 4.76 [13 49] [36 100]] [22 100]]] [22 100]] [28 100]] [36 100]] [5454 2.08 [4851 0.203 [4630 0.291 [1078 7.62 [7169 2.74 [7693 4.53 [1888 1.04 [2752 8.32 [13 35] [36 83]] [36 53]] [36 71]] [36 100]] [5851 3.12 [1400 3.97 [13 51] [36 85]] [36 100]]] [36 50]] [112 0.936 [36 72] [36 91]]] [36 100]]] [24 1.09 [1883 2.44 [4929 1.17 [663 1.24 [7665 3.37 [13 30] [13 94]] [13 100]] [2 55]] [2 42]] [13 100]]] [5531 0.235 [5642 2.59 [791 14.1 [7255 0.324 [4369 1.19 [125 0.722 [1180 1.88 [36 59] [13 100]] [13 60]] [13 100]] [13 100]] [112 0.487 [5462 1.27 [7009 0.562 [13 97] [13 100]] [13 81]] [13 100]]] [13 66]] [13 100]]] [5733 0.701 [7512 21.5 [5835 0.319 [1980 0.184 [5473 0.515 [2501 0.931 [144 8.07 [13 100] [6227 0.894 [17 0.843 [13 97] [13 100]] [13 100]]] [13 100]] [13 100]] [13 100]] [13 100]] [888 6.95 [6388 17.9 [13 100] [13 87]] [13 81]]] [13 100]]] [695 10.4 [36 70] [36 100]]] [12 33]] [6416 0.404 [3813 0.265 [293 2.11 [7009 6.68 [826 1.63 [6429 0.693 [131 10.6 [1025 6.67 [7198 4.33 [1513 0.494 [5034 0.695 [4898 3.65 [7251 7.06 [1180 2.61 [6027 2.74 [5211 7.42 [2100 1.33 [286 3.71 [853 4.22 [5037 4.38 [5274 4.27 [1662 3.54 [6230 5.64 [2259 11.5 [6294 0.878 [5454 2.33 [701 2.56 [2259 11.2 [2753 0.208 [36 97] [36 90]] [36 80]] [36 100]] [36 77]] [36 66]] [6406 10.8 [2091 5.51 [312 3.94 [328 8.36 [10 2.53 [978 3.68 [583 0.96 [1059 7.92 [7571 1.86 [2846 3.66 [4611 22.4 [2841 0.212 [6853 0.316 [7210 10.8 [7520 14.7 [4041 1.25 [7107 0.709 [7601 0.707 [36 99] [36 100]] [36 100]] [36 100]] [36 83]] [36 86]] [36 100]] [36 100]] [36 83]] [36 83]] [36 100]] [36 85]] [36 83]] [7732 1.17 [1429 11.2 [36 87] [36 100]] [36 62]]] [36 71]] [36 84]] [36 90]] [36 66]] [36 66]]] [13 50]] [36 75]] [36 70]] [36 79]] [36 75]] [36 70]] [36 75]] [22 77]] [36 81]] [13 100]] [36 60]] [36 60]] [28 62]] [36 53]] [13 50]] [6074 0.675 [7373 0.699 [5972 3.51 [13 73] [36 100]] [36 100]] [13 44]]] [36 57]] [13 100]] [36 50]] [2488 2.56 [7571 1.87 [36 70] [36 100]] [13 100]]] [13 100]] [13 88]] [13 100]]] [4569 3.85 [4615 5.2 [4084 5.77 [3916 1.98 [36 100] [36 91]] [36 85]] [36 83]] [36 66]]]]] [1078 37.6 [865 0.155 [5440 1.62 [5413 0.129 [2752 5.1 [665 6.32 [1007 0.556 [6269 0.248 [430 0.227 [5401 0.824 [146 2.59 [4253 2.41 [7449 0.28 [1980 0.398 [10 58] [10 28]] [2 50]] [1520 1.27 [5818 0.441 [5472 1.01 [1783 15.7 [1899 3.11 [6077 1.61 [2 50] [2 83]] [5851 1.11 [144 14.3 [2 95] [2 62]] [2 100]]] [3 26]] [13 85]] [2 83]] [13 100]]] [4991 1.86 [6537 7.56 [25 57] [1 63]] [33 57]]] [13 100]] [13 80]] [13 100]] [1079 0.556 [2 80] [2 100]]] [7584 0.882 [5472 1.85 [4159 3.94 [2 84] [13 45]] [13 100]] [2 83]]] [248 1.26 [1071 0.68 [978 2.03 [6091 3.18 [2526 7.36 [695 1.43 [4235 0.714 [10 33] [7354 1.95 [22 26] [13 88]]] [4870 0.611 [7034 0.952 [5264 0.543 [13 36] [13 100]] [13 100]] [22 80]]] [2674 0.51 [2 55] [2 100]]] [13 93]] [4214 1.23 [5918 5.69 [3905 0.661 [520 0.431 [5439 0.567 [3765 1.23 [3342 5.69 [6926 0.213 [2574 1.88 [6230 2.93 [4594 8.43 [1436 3.86 [2739 3.96 [5211 5.24 [2902 11.7 [361 1.38 [1927 0.446 [1218 3.88 [985 6.17 [4225 3.69 [719 16.2 [1023 8.27 [6929 0.956 [429 23.2 [4665 5.15 [6109 0.631 [731 3.39 [2760 6.58 [2 96] [2 80]] [2 86]] [2 100]] [2 90]] [1007 3.42 [985 1.23 [477 6.26 [6187 4.37 [2 100] [7584 4.87 [2 79] [2 100]]] [2 100]] [2 72]] [2 71]]] [2 75]] [2 76]] [2 61]] [2 44]] [2 100]] [2 66]] [2 71]] [2 60]] [2 57]] [2 55]] [2 50]] [2 53]] [2 100]] [5 40]] [1883 0.386 [4253 5.5 [1239 0.867 [2 83] [2 100]] [666 0.669 [2 95] [2 100]]] [2 100]]] [144 7.3 [7241 0.571 [2 100] [2 75]] [665 0.336 [2 86] [2 100]]]] [2 42]] [13 60]] [31 45]] [5355 5.29 [573 2.47 [2 100] [4288 1.4 [2 90] [2 100]]] [2 83]]] [17 66]] [5 50]] [24 88]]] [13 100]] [5431 0.524 [6537 0.624 [7185 0.239 [26 32] [26 63]] [2101 1.89 [6177 1.3 [7668 0.532 [6074 0.829 [1899 11.9 [1 50] [1 88]] [2 66]] [25 50]] [25 100]] [1 91]]] [26 100]]]] [5812 0.998 [5665 3.34 [3278 0.357 [435 1.04 [4991 2.67 [7381 0.485 [6537 1.66 [29 44] [1 33]] [24 78]] [2570 8.51 [663 5.17 [2 75] [2 100]] [1 50]]] [25 69]] [1 100]] [2 100]] [7584 0.616 [7384 0.599 [1429 16.8 [6276 2.05 [6988 0.507 [6927 0.591 [362 0.431 [4253 0.372 [2 57] [5197 1.45 [7139 0.23 [1993 1.36 [6538 0.992 [2764 0.249 [1078 13.2 [2 75] [2 50]] [4 66]] [1899 6.45 [2 88] [2 100]]] [2 90]] [2 100]] [2 61]]] [2 71]] [324 1.3 [6537 3.23 [5662 2.77 [2 100] [2 80]] [2 100]] [2 88]]] [2674 5.47 [567 8.85 [4279 3.65 [1429 6.4 [4601 0.832 [5412 1.69 [2 88] [2 100]] [2 80]] [2 100]] [2 100]] [2 77]] [1899 14.2 [2 66] [2 93]]]] [2 69]] [1062 0.992 [6538 0.503 [13 40] [2 82]] [2 40]]] [731 0.318 [2 100] [17 87]]] [896 0.32 [2 92] [228 9.87 [7198 0.463 [1640 0.136 [144 5.26 [2 96] [2 100]] [2 100]] [2 85]] [2 83]]]]]] [701 1.14 [939 1.55 [10 79] [10 100]] [10 100]]] [5401 0.155 [13 88] [13 100]]] [5769 1.12 [1521 0.783 [5310 0.31 [4154 1.19 [6077 1.04 [2752 25.7 [1083 3.28 [2 50] [2 86]] [29 41]] [13 91]] [2628 4.21 [2149 2.88 [929 0.715 [4414 8.34 [4120 0.635 [1149 1.31 [2384 0.838 [811 0.891 [978 2.37 [429 13.9 [10 78] [29 66]] [2 100]] [10 100]] [10 100]] [10 100]] [10 100]] [2 50]] [2 50]] [2 57]] [2 28]]] [10 100]] [13 100]] [6735 0.251 [2 50] [2760 0.251 [2091 2.56 [6989 1.95 [2 100] [2 81]] [2 63]] [2 100]]]]]] [5829 0.228 [2739 1.02 [7559 0.182 [4414 12.5 [6077 0.575 [1081 0.237 [7381 0.136 [6982 0.851 [2580 0.56 [5731 0.126 [3111 0.206 [6665 0.473 [4154 3.15 [3443 0.121 [6484 0.118 [7397 0.483 [5589 0.271 [728 2.48 [3480 0.596 [2472 0.793 [232 2 [567 2.67 [2808 0.795 [7512 1.31 [5222 0.459 [4520 0.942 [2951 0.994 [384 1.69 [6660 0.542 [6647 0.909 [3458 0.822 [2259 6.94 [685 7.85 [673 1.06 [4703 0.626 [3805 1.47 [2466 3.38 [3523 1.67 [7052 0.876 [939 0.514 [3909 1.72 [791 15 [2199 6.15 [5122 1.57 [7497 25 [4210 14 [1587 1.68 [7665 9.83 [6471 6.73 [6791 15.5 [4414 0.894 [734 2.93 [4218 12.3 [1679 2.49 [5826 2.56 [15 19] [11 100]] [6713 3.94 [30 92] [30 100]]] [12 76]] [31 100]] [4 38]] [15 47]] [26 94]] [4 64]] [25 62]] [30 100]] [31 76]] [30 92]] [25 70]] [15 34]] [15 100]] [248 1.3 [7255 9.81 [3235 0.864 [6434 3.76 [1239 13.6 [1083 2.36 [11 54] [11 100]] [25 33]] [11 100]] [11 100]] [11 96]] [29 62]]] [2764 1.22 [11 86] [11 100]]] [15 100]] [6513 3.77 [2470 6.62 [30 50] [30 60]] [30 60]]] [11 100]] [6457 0.625 [25 26] [25 100]]] [7665 1.48 [663 1.06 [2470 9.8 [26 95] [25 49]] [26 80]] [25 42]]] [663 1.92 [1429 50.7 [429 9.58 [26 92] [26 67]] [30 100]] [30 28]]] [820 0.581 [2628 28.8 [6209 1.46 [1594 2.35 [6078 0.517 [3521 4.71 [6711 0.701 [6434 4.53 [6915 1.27 [5225 1.01 [4445 1.15 [4210 1.36 [7233 5.15 [7449 21.5 [429 19.3 [4235 0.304 [2232 4.65 [23 27.5 [6768 0.858 [2912 1.83 [312 0.239 [2464 0.387 [4761 4.9 [5211 0.952 [7413 1.23 [3008 9.03 [685 3.49 [1795 1.06 [1400 3.66 [7665 2.26 [1783 7.59 [2100 6.56 [30 25] [14 50]] [6772 0.726 [3310 0.792 [2259 87 [5989 0.826 [6031 3.72 [30 50] [35 42]] [25 33]] [32 42]] [29 66]] [30 100]]] [6 75]] [15 39]] [25 100]] [26 36]] [30 84]] [30 85]] [2916 5.75 [30 95] [30 88]]] [31 80]] [25 38]] [31 30]] [10 86]] [31 100]] [30 83]] [21 25]] [25 33]] [6231 8.42 [5368 0.149 [2939 4.88 [7428 0.124 [328 0.711 [30 19] [15 18]] [11 50]] [15 24]] [33 47]] [31 83]]] [15 79]] [31 100]] [30 100]] [31 100]] [30 100]] [15 100]] [31 58]] [3008 4.07 [30 87] [30 100]]] [10 100]] [31 80]] [4398 3.23 [1980 7.49 [4 70] [4 100]] [4 75]]] [5138 5.67 [31 54] [31 100]]] [31 63]] [11 66]]] [2913 12.2 [4235 9.5 [1429 31.8 [1069 0.539 [7411 2.99 [15 82] [15 100]] [15 100]] [6074 1.62 [15 50] [15 100]]] [15 50]] [25 100]]] [4564 7.72 [6074 0.229 [1429 66 [5037 1.14 [30 100] [30 87]] [19 40]] [30 100]] [30 86]]] [6406 1.83 [6342 0.34 [1025 4.46 [11 100] [11 97]] [11 100]] [11 100]]] [673 6.49 [1899 4.29 [1888 2.31 [791 1.66 [25 52] [26 40]] [26 87]] [8 27]] [26 87]]] [6848 5.2 [4854 8.77 [3006 0.994 [1429 3.69 [190 1.45 [26 36] [6 44]] [38 34]] [26 85]] [26 80]] [673 0.967 [5641 0.472 [1295 1.03 [38 75] [38 100]] [38 100]] [38 66]]]] [11 100]] [30 96]] [683 0.536 [1713 2.62 [719 0.329 [3896 1.34 [1078 8.11 [5812 2.63 [731 4.9 [1400 1.8 [5962 0.194 [7043 6.99 [1078 2.37 [7133 6.17 [248 2.4 [695 5.88 [7737 1.02 [2143 1.65 [4533 1.95 [5871 3.66 [429 21.1 [31 18] [2259 14.1 [4 44] [31 45]]] [30 57]] [25 45]] [30 83]] [31 47]] [4 75]] [5480 4.07 [25 77] [26 100]]] [4 100]] [5034 1.24 [30 26] [30 100]]] [25 100]] [4712 0.518 [6 60] [6 100]]] [4154 1.16 [978 2.58 [6579 2.09 [5110 3.72 [3868 1.85 [6471 1.03 [25 27] [26 100]] [31 100]] [15 66]] [31 100]] [1420 1.25 [2915 1.65 [1239 7 [6585 1.19 [26 41] [26 80]] [25 58]] [26 50]] [25 100]]] [31 42]]] [1420 1.56 [7516 0.675 [31 33] [5431 0.675 [7373 1.74 [7665 19.1 [791 14.9 [26 96] [26 80]] [25 57]] [26 100]] [26 100]]] [25 100]]] [7665 8.01 [4 100] [4 69]]] [2526 3.67 [6293 0.392 [3806 0.978 [3905 13 [6578 1.85 [5225 2.59 [4206 2.04 [4601 1.39 [5693 4.57 [99 0.288 [5110 4.12 [7742 3.78 [31 26] [31 50]] [30 84]] [30 100]] [4 75]] [26 83]] [15 90]] [30 100]] [31 100]] [15 90]] [10 100]] [10 100]] [4 53]]] [31 100]] [1429 12.8 [6184 1.72 [6433 0.377 [2748 0.455 [26 62] [5673 2.05 [26 100] [26 57]]] [26 100]] [25 44]] [23 7.75 [2822 3.82 [31 53] [31 100]] [4 78]]]] [31 100]] [31 100]]] [4611 0.835 [3905 0.963 [2260 2.67 [4369 4.12 [15 100] [5110 7.78 [15 83] [15 100]]] [15 100]] [15 100]] [15 100]]] [4871 0.544 [802 0.474 [7665 1.46 [5412 3.74 [6184 7.78 [1089 0.688 [6920 0.535 [1029 1.5 [11 93] [11 100]] [11 100]] [11 100]] [11 91]] [11 88]] [5812 5 [2470 7.56 [29 66] [31 77]] [4 46]]] [15 83]] [11 100]]] [25 93]] [7255 5.79 [7512 23.3 [5721 6.15 [4851 0.605 [23 6.4 [30 93] [30 90]] [7695 3.03 [30 100] [30 94]]] [30 83]] [30 66]] [30 70]]] [4154 0.693 [1405 6.25 [3928 1.34 [2083 6.3 [492 7.6 [1132 27.6 [939 5.29 [826 8.54 [2199 1.21 [6614 0.855 [660 9.12 [3586 1.23 [2752 8.07 [15 90] [3884 0.77 [2752 19 [15 93] [15 100]] [15 100]]] [15 100]] [15 91]] [15 100]] [15 100]] [1132 1.55 [15 83] [15 100]]] [15 60]] [15 77]] [15 92]] [15 42]] [15 100]] [15 100]] [15 81]]] [1922 1.43 [663 12.9 [7590 3.05 [6545 1.08 [31 86] [31 100]] [4 50]] [31 77]] [10 100]]] [30 97]] [25 100]] [4063 0.0798 [25 97] [25 100]]] [1192 0.154 [1899 0.26 [6660 0.223 [791 14.1 [11 94] [11 100]] [11 100]] [11 100]] [11 100]]] [4218 0.387 [7135 0.855 [2630 0.99 [6457 0.664 [2976 3.59 [2475 2.83 [4309 0.492 [6184 9.28 [1410 0.542 [5732 3.66 [6768 4.07 [4963 1.31 [2975 8.41 [3693 0.84 [3523 0.632 [939 2.04 [3905 7.05 [1997 10.7 [5981 0.555 [7512 2.12 [6604 1.85 [569 1.23 [4895 2.47 [1420 3.88 [4625 0.339 [1783 2.18 [726 1.85 [1429 1.42 [1906 4.42 [15 57] [15 100]] [3458 1.47 [985 1.42 [1911 1.74 [1899 3.69 [30 24] [30 44]] [30 40]] [4 62]] [15 100]]] [31 44]] [2138 5.4 [221 0.703 [4876 0.797 [2470 4.47 [16 21] [30 21]] [10 37]] [30 59]] [25 60]]] [30 100]] [25 100]] [2039 1.01 [30 31] [1 50]]] [3 100]] [30 100]] [392 1.92 [5066 1.68 [7255 6.14 [4414 7.11 [1705 0.734 [5034 3.86 [728 5.78 [1888 0.921 [3807 1.79 [431 1.21 [5967 2.49 [695 6.88 [1429 7.4 [15 33] [4 24]] [2526 7.82 [4 50] [4 100]]] [31 100]] [25 40]] [10 100]] [6732 1.01 [4 48] [4 68]]] [31 90]] [32 60]] [31 76]] [31 80]] [31 47]] [15 100]] [2752 17.4 [26 47] [25 61]]]] [21 88]] [32 65]] [2259 2.82 [15 88] [15 48]]] [5211 0.287 [6199 3.77 [25 17] [25 87]] [11 42]]] [15 96]] [32 100]] [2350 0.867 [7512 3.83 [31 100] [31 75]] [31 100]]] [25 100]] [31 100]] [15 90]] [5647 5.94 [23 1.37 [1899 1.51 [15 98] [15 100]] [23 9.96 [15 66] [15 100]]] [15 87]]] [6528 1.09 [3929 1.17 [1404 2.48 [1914 6.43 [7623 1.25 [15 73] [15 95]] [15 71]] [15 100]] [15 100]] [15 57]]] [32 100]] [6080 0.967 [4312 1.47 [1844 6.13 [15 82] [31 100]] [15 100]] [15 100]]] [31 96]] [25 97]] [30 100]] [38 100]] [4308 1.05 [1783 3.35 [7480 47.4 [811 0.33 [6103 3.29 [7480 2.24 [791 7.52 [429 5.52 [15 100] [15 53]] [1400 17.2 [15 100] [7649 1.33 [15 96] [15 100]]]] [15 100]] [12 76]] [15 100]] [15 80]] [15 50]] [15 75]]]] [6191 0.703 [2471 4.04 [2701 6.53 [5480 17.8 [1505 1.77 [1418 0.473 [12 94] [12 100]] [12 100]] [12 66]] [12 90]] [12 77]] [12 66]]] [2787 0.844 [2906 0.206 [4768 0.981 [4517 0.444 [6524 0.491 [1429 23.6 [5154 1.62 [5753 0.483 [6342 1.47 [6727 1.28 [6074 3.83 [5192 0.707 [15 97] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [3480 1.16 [15 94] [15 100]]] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]]] [11 100]] [25 100]] [5403 0.69 [5137 0.847 [2350 0.599 [5972 1.71 [2071 0.478 [7742 0.701 [5242 2.99 [4734 0.441 [5447 3.39 [6982 7.25 [2178 1.53 [2526 23.3 [4 52] [4 100]] [4 72]] [527 9.28 [6977 14.8 [806 6.15 [1769 28.9 [7014 1.39 [1888 22 [4651 1.44 [5142 9.32 [4235 2.95 [2964 0.598 [5270 7.88 [7665 13.9 [2199 9.62 [5812 0.434 [978 5.99 [4851 3.44 [4 86] [4 100]] [4 98]] [4 100]] [4 75]] [4 100]] [4 61]] [4 100]] [4 100]] [4 81]] [4 100]] [4 82]] [4 66]] [4 78]] [4 81]] [4 71]] [4 77]]] [6767 3.03 [31 58] [31 100]]] [31 100]] [31 100]] [7363 11.4 [2417 1.27 [6582 0.159 [3936 2.37 [4 83] [4 100]] [228 0.638 [5812 1.22 [4 95] [4 100]] [4 100]]] [4 96]] [4 100]]] [31 100]] [31 100]] [31 100]] [31 88]] [31 100]]] [2379 1.89 [2131 0.402 [5154 4.79 [2048 1.66 [4398 1.75 [2228 0.117 [2986 2.7 [248 1.09 [3544 3.16 [4235 12.6 [1888 3.56 [429 55.9 [1 1.8 [2657 11.3 [1980 14 [5462 2.58 [2826 7.11 [791 6.28 [2595 2.64 [6074 0.194 [896 3.02 [1072 0.826 [312 8.49 [695 16 [4 100] [4 92]] [4 96]] [4 100]] [4 69]] [4 50]] [4 88]] [1899 0.42 [2616 8.46 [2752 11.6 [4 100] [2483 3.14 [4 91] [4 100]]] [4 100]] [4 100]]] [4 84]] [4 88]] [4 72]] [4 80]] [4 66]] [4 69]] [2567 2.29 [7168 5.68 [3424 9.22 [6015 0.511 [2470 13.2 [2417 0.268 [1429 41.8 [5962 0.637 [228 0.403 [5110 0.73 [5753 2.77 [6595 0.911 [896 6.59 [4 96] [6732 1.01 [2536 1.88 [4 64] [4 100]] [4 75]]] [4 100]] [4 100]] [4 55]] [4 100]] [4 44]] [4 40]] [4 100]] [7381 18.2 [1640 8.62 [4 100] [4 77]] [6582 1.42 [4 70] [4 62]]]] [4 81]] [4 50]] [4 44]] [4 45]]] [4 68]] [4 55]] [15 23]] [4 50]] [4 27]] [4 35]] [4 27]] [6581 1.25 [4 75] [19 55]]] [2137 0.236 [2081 0.735 [4 61] [24 80]] [24 27]]] [4 43]]] [724 0.0952 [7007 0.172 [6177 2.38 [5776 1.14 [2826 0.156 [1011 3.9 [2752 23.2 [429 6.96 [26 81] [26 42]] [913 0.699 [26 96] [26 100]]] [2470 6.86 [26 84] [26 93]]] [1059 0.942 [4601 0.901 [26 93] [26 100]] [26 85]]] [26 100]] [6134 4.54 [7043 7.93 [25 100] [2526 13.2 [25 91] [25 100]]] [25 77]]] [25 100]] [385 0.0952 [1081 3.07 [731 1.31 [25 62] [26 80]] [26 66]] [26 100]]]] [7568 0.441 [11 0.303 [6732 2.68 [719 1.36 [31 40] [7585 1.11 [7592 2.15 [7032 9.46 [4184 4.97 [2398 0.826 [6395 1.38 [328 7.88 [723 0.52 [221 9.47 [791 12.8 [4967 0.3 [7335 10.4 [7742 6.48 [7512 8.83 [978 8.22 [31 95] [31 70]] [6074 26.8 [5972 1.28 [7665 14.3 [31 85] [31 100]] [31 100]] [31 88]]] [31 91]] [31 100]] [31 100]] [7665 17.4 [1899 3.02 [31 93] [4 45]] [31 95]]] [4 100]] [31 66]] [31 71]] [31 63]] [4 54]] [4 60]] [1429 3.69 [31 83] [4 50]]] [4 80]] [31 100]]] [4369 1.09 [1769 1.44 [7590 7.44 [7305 2.8 [2752 4.37 [6074 10.2 [6077 3.21 [4 90] [4 100]] [4 81]] [4 97]] [31 68]] [31 55]] [4 50]] [31 100]]] [2259 0.739 [31 96] [31 100]]] [4 87]]] [7032 2.39 [7665 4.54 [939 0.482 [1055 1.09 [4095 3.5 [350 4.45 [2023 15.4 [2700 1.29 [802 0.381 [1 1.71 [3111 0.548 [828 0.719 [5328 1.38 [1106 4.19 [7428 7.86 [5730 4.59 [4416 13.9 [791 7.53 [1410 1.95 [3484 1.54 [791 6.67 [7613 3.23 [3130 2.99 [1017 8.47 [4530 6.9 [15 64] [31 50]] [15 100]] [15 85]] [15 100]] [12 40]] [15 100]] [2259 21.6 [15 100] [15 92]]] [871 6.45 [5509 2.49 [6732 0.684 [5480 13.8 [5267 3.14 [5329 1.14 [429 56.3 [7451 4.89 [6342 15.7 [2476 9.18 [3554 2.75 [4414 27.2 [2939 4.44 [6103 1.14 [5110 1.17 [15 86] [15 100]] [15 75]] [15 41]] [2924 1.71 [4424 11.6 [7623 1.68 [688 3.27 [15 94] [15 100]] [15 100]] [15 75]] [15 100]]] [15 84]] [15 100]] [15 60]] [15 100]] [820 2.72 [15 66] [11 100]]] [15 100]] [15 50]] [11 57]] [3210 2.4 [15 98] [15 100]]] [15 100]] [15 44]]] [11 64]] [11 100]] [6015 3.4 [12 40] [12 100]]] [15 43]] [15 100]] [2950 3.18 [1407 1.81 [1412 1.42 [1078 13.3 [15 98] [7169 1.55 [7411 1.3 [4663 11.6 [6184 6.9 [4154 12.4 [15 100] [15 83]] [15 100]] [15 79]] [15 100]] [15 100]]] [15 100]] [15 100]] [15 85]]] [4369 20.9 [5851 1.08 [4179 1.33 [4424 4.89 [15 100] [15 88]] [15 100]] [15 100]] [15 85]]] [504 7.93 [11 51] [11 100]]] [6015 6.72 [6910 0.305 [2913 1.27 [4429 0.423 [1402 1.06 [1239 0.773 [15 96] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 83]]] [31 70]] [5824 3.55 [11 63] [11 100]]] [15 53]] [11 100]] [11 96]] [893 0.722 [438 0.843 [4398 1.18 [11 57] [15 66]] [2081 14.1 [11 100] [11 83]]] [15 100]]] [5403 0.864 [5322 4.41 [15 50] [15 84]] [31 100]]] [7566 0.864 [31 87] [31 100]]]] [5816 1.71 [31 100] [31 90]]] [685 1.84 [2796 0.683 [5843 1.24 [4369 1.48 [178 0.791 [4721 1.47 [5110 1.23 [2962 5.13 [5260 2.22 [896 2.81 [2526 5.47 [2259 46.8 [4 54] [30 55]] [4630 3.98 [3222 0.366 [144 1.04 [6983 15.7 [5393 1.53 [1253 1 [704 4.39 [4279 2.19 [4 95] [2470 12.4 [4 100] [4 66]]] [4 85]] [4 80]] [4 50]] [2616 4.88 [719 1.47 [1919 4.1 [4 100] [4 86]] [4 100]] [4 100]]] [1429 22.7 [4 100] [4 86]]] [4 75]] [4 72]]] [6732 6.18 [4226 0.304 [141 0.283 [7512 26 [504 1.41 [2628 0.535 [5192 3.38 [4 85] [4 100]] [7268 3.33 [5819 3.78 [4 100] [4 85]] [4 90]]] [4 90]] [4 60]] [4 57]] [4 100]] [4 100]]] [2 42]] [4 50]] [4 48]] [4 100]] [5155 1.36 [6177 0.339 [1783 11.1 [221 22.7 [2259 14.6 [4 100] [5413 0.956 [4 93] [4 100]]] [4 85]] [4 80]] [4 75]] [4 88]]] [25 44]] [4 57]] [30 100]] [4 46]]] [4523 0.366 [1094 0.294 [144 4.54 [6524 0.78 [2763 0.407 [6732 1.02 [5412 0.699 [11 98] [11 100]] [11 100]] [11 100]] [11 100]] [5211 11.8 [11 100] [11 77]]] [11 100]] [11 100]]]] [228 0.0445 [1533 0.297 [802 6.9 [3332 2.25 [5219 1.98 [2242 0.0719 [248 8.83 [537 0.259 [4519 0.154 [7419 0.68 [3004 0.343 [7034 0.157 [4997 0.213 [5117 0.166 [1521 0.274 [7722 0.239 [7615 1.82 [6868 0.184 [7475 0.259 [976 0.171 [2780 0.161 [819 0.224 [5163 0.644 [3297 0.436 [2630 0.327 [2482 0.432 [4213 0.31 [7685 0.661 [3905 0.35 [957 5.35 [5564 0.197 [2849 5.52 [5254 0.0714 [685 0.29 [558 1.25 [1679 0.613 [705 0.582 [3652 0.191 [695 0.636 [5824 0.176 [6394 0.165 [2526 4.33 [5892 0.0309 [5122 0.052 [1783 5.16 [2470 1.76 [2913 1.45 [5472 1.22 [5809 2.14 [6065 1.07 [2764 0.579 [2517 1.92 [6031 2.07 [4342 1.83 [5073 0.056 [5011 0.0197 [2453 1.16 [7739 0.66 [169 5.54 [3743 0.577 [826 1.78 [6578 3.13 [3605 0.595 [968 1.13 [756 3.04 [4556 1.28 [5236 2.02 [2698 1.09 [4293 1.23 [536 1.49 [1980 1.87 [6438 5.02 [7514 4.47 [1078 0.231 [6757 1.59 [4282 1.26 [6235 2.7 [5099 0.994 [23 4.81 [134 0.943 [3292 6.14 [6230 4.02 [5972 5.45 [5542 9.15 [2939 87.6 [4799 11.7 [535 2.13 [5225 10.2 [5211 12.5 [1722 6.32 [7381 2.4 [6809 3.59 [429 1.97 [4338 11.9 [3691 7.32 [5632 17.9 [3475 7.33 [7233 4.95 [7254 2.48 [2939 25.8 [1 15] [16 10]] [2081 4.07 [33 33] [1 75]]] [32 74]] [15 100]] [16 43]] [37 76]] [2259 3.31 [2793 7.25 [2 32] [4154 54.2 [23 50] [24 57]]] [24 82]]] [2515 4.76 [2944 6.74 [3687 2.67 [5995 4.85 [5390 4.35 [6042 4.35 [306 9.09 [21 5] [29 100]] [18 50]] [38 62]] [876 10.6 [29 82] [29 100]]] [3056 2.67 [37 89] [37 100]]] [21 67]] [24 93]]] [4364 1.63 [4183 4.13 [1552 6.62 [32 98] [32 100]] [32 100]] [32 100]]] [7535 4.85 [5812 50.7 [1390 6.85 [4681 5.05 [6581 1.67 [7169 11.7 [4 27] [5 36]] [17 28]] [5 100]] [24 95]] [2 64]] [24 88]]] [33 90]] [7139 34.3 [978 15.9 [4235 9.8 [791 22.7 [4061 7.69 [2081 11.9 [3920 1.96 [2143 13.4 [2902 7.25 [7009 11.1 [6287 8.77 [30 46] [11 100]] [4 30]] [30 69]] [22 37]] [8 100]] [23 44]] [30 100]] [1400 14.3 [5142 13.3 [22 46] [11 71]] [10 100]]] [22 26]] [23 42]] [11 81]]] [30 86]] [7139 7.55 [6342 3.55 [21 97] [21 88]] [21 100]]] [3482 6.49 [791 10.3 [6333 8.2 [15 31] [32 100]] [7665 18.6 [15 26] [36 69]]] [32 85]]] [5059 3.21 [6371 16.1 [429 23.9 [4564 7.19 [7343 24.1 [5601 10.6 [2955 1.47 [38 21] [7282 4.35 [4533 9.16 [5635 15.3 [6113 1.82 [5578 1.69 [1245 0.432 [2048 6.86 [2712 9.38 [38 61] [6 20]] [38 38]] [38 100]] [16 39]] [17 75]] [16 54]] [16 62]] [16 37]]] [16 36]] [38 92]] [7 42]] [22 37]] [16 77]] [17 45]]] [13 100]] [4611 2.13 [5978 5.14 [896 4.95 [5462 3.36 [5871 15.4 [1400 14.3 [5396 8.47 [916 3.14 [3896 13.2 [2624 34.8 [5973 5.88 [5138 2.04 [7449 41.7 [915 12.6 [978 11.2 [569 4.13 [3895 3.36 [12 58] [12 100]] [3 71]] [31 66]] [915 23.8 [21 85] [21 66]]] [2844 9.09 [12 64] [12 100]]] [31 85]] [12 100]] [12 100]] [31 77]] [21 84]] [12 100]] [5322 16.1 [1400 48.2 [12 93] [12 76]] [12 77]]] [4 33]] [21 62]] [36 100]] [31 100]] [36 73]]] [1400 12.6 [328 51.4 [3027 23.4 [2752 5.02 [34 10] [5904 5.15 [5972 7.46 [7149 8.84 [4154 16.7 [5462 12.9 [3251 4.42 [978 1.56 [14 20] [3078 3.02 [7665 9.26 [5 27] [5 59]] [17 71]]] [14 63]] [5 88]] [32 38]] [14 50]] [12 96]] [19 85]]] [32 48]] [34 68]] [4 42]]] [3317 4.35 [3125 1.12 [37 62] [836 10.6 [37 100] [37 90]]] [37 100]]] [1769 19.7 [4768 10.7 [5647 3.3 [17 24] [17 63]] [2 42]] [16 42]]] [3056 9.72 [1332 14.6 [7619 21.2 [144 3.09 [65 22.9 [114 1.45 [2426 2.44 [4210 15.1 [79 3.94 [6711 16.1 [7611 2.67 [4851 22.1 [7254 33.4 [6602 1.29 [5211 8.62 [2944 2.37 [7657 3.82 [5976 3.36 [1365 4.27 [5872 3.36 [4026 4.69 [33 9] [36 100]] [14 93]] [9 69]] [3 100]] [12 100]] [21 65]] [30 33]] [15 96]] [33 65]] [30 43]] [28 82]] [23 61.4 [22 62] [22 100]]] [12 64]] [3 63]] [12 100]] [371 4.85 [21 35] [21 60]]] [30 89]] [203 0.388 [906 2.59 [286 22.6 [125 4.07 [2752 78.1 [4663 20.2 [145 6.33 [5680 7.44 [1684 15.9 [14 14] [11 55]] [5 70]] [144 81.5 [4768 4.59 [6342 8.11 [978 7.7 [6524 5.62 [2259 67 [3353 3.72 [19 18] [7 30]] [32 66]] [22 80]] [18 17]] [37 30]] [29 73]] [29 28]]] [13 50]] [22 68]] [32 41]] [2 30]] [29 40]] [15 18]]] [13 100]] [9 100]] [144 12.2 [37 72] [5 58]]]] [1278 2.33 [2661 24.8 [6471 0.0397 [7619 5.42 [5090 2.98 [5103 20 [5102 36.3 [16 26] [6 78]] [5100 24.2 [6 76] [414 24 [16 37] [6 50]]]] [18 55]] [2713 24.9 [19 42] [7 45]]] [16 75]] [16 50]] [7 91]]] [34 86]] [4317 3.14 [3 78] [3 100]]] [2707 4.13 [30 12] [3675 3.6 [38 88] [38 66]]]] [5034 2.92 [7578 0.15 [5629 2.42 [5994 4.39 [1400 0.234 [5023 0.451 [6537 2.09 [7354 3.6 [6529 1.89 [4120 4.72 [1078 131 [5155 6.9 [5462 1.76 [5482 5.62 [2306 2.37 [7009 1.87 [7357 0.523 [4832 1.67 [2488 1.44 [6491 2.59 [7405 1.2 [3086 1.33 [4114 33.6 [3292 4.25 [3320 1.09 [4769 0.581 [28 5] [29 96]] [27 100]] [37 74]] [27 82]] [429 35.7 [37 100] [37 83]]] [791 2.26 [6 86] [6 100]]] [23 56]] [5968 6.17 [4765 2.79 [1899 6.38 [6040 3.65 [3391 1.15 [13 58] [13 100]] [13 88]] [13 44]] [13 100]] [13 100]]] [3130 1.67 [2 44] [4 70]]] [35 82]] [4369 10.9 [1025 5.43 [2846 5.88 [6581 4.18 [7149 13.6 [1754 0.792 [4190 1.57 [2837 2.42 [5 21] [22 59]] [13 100]] [9 55]] [12 38]] [19 40]] [12 75]] [12 35]] [13 37]]] [30 89]] [5007 14.1 [7723 4.97 [6707 2.68 [6040 2.86 [2846 0.797 [1170 1.59 [731 7.25 [29 47] [18 90]] [29 60]] [22 100]] [18 50]] [18 90]] [18 85]] [7301 3.23 [29 54] [19 100]]]] [6937 2.73 [6005 1.13 [6353 8.48 [1899 21.8 [1429 59.5 [4895 1.25 [5054 1.48 [7411 9.62 [1217 6.61 [4764 4.04 [2526 0.632 [5393 8.26 [5110 2.67 [28 16] [32 44]] [27 25]] [35 22]] [2752 1.66 [35 69] [35 100]]] [23 50]] [35 92]] [23 27]] [26 30]] [4533 11.9 [35 51] [35 100]]] [11 20]] [4533 15.6 [35 90] [35 66]]] [6 100]] [20 42]]] [5 63]] [2188 3.38 [4158 0.495 [2033 6.18 [4802 2.2 [7512 0.462 [5462 7.81 [4772 11.6 [1104 13.9 [2110 39.9 [1932 8.03 [5347 1.25 [2164 2.9 [7241 4.85 [2628 2.4 [4769 0.849 [1 33] [29 100]] [19 28]] [27 53]] [28 55]] [27 100]] [1 75]] [32 63]] [1104 50 [2091 16.3 [1 84] [32 38]] [15 38]]] [1078 181 [27 42] [1 83]]] [35 83]] [10 34]] [1 85]] [25 40]] [27 62]] [1 38]]] [27 61]] [867 1.63 [22 61] [22 75]]] [361 1.65 [2809 1.75 [6042 1.13 [1546 2.7 [2411 2.65 [2259 8.93 [178 3.31 [5904 23.6 [515 5.08 [3675 3.88 [6260 2.79 [134 13.1 [2902 4.45 [735 3.32 [978 1.83 [112 2.39 [13 26] [29 28]] [5 58]] [5 46]] [30 33]] [18 30]] [13 100]] [5 85]] [13 100]] [13 55]] [18 60]] [884 3.36 [36 45] [36 90]]] [36 100]] [5 71]] [4927 10.4 [18 63] [18 54]]] [18 61]] [18 60]]] [178 2.16 [2 73] [2 100]]] [35 78]] [98 2.59 [4414 1.13 [7657 4.44 [2259 12 [3931 7.37 [1911 17.9 [788 0.48 [5154 15.9 [221 5.8 [6537 5.92 [10 25] [2 80]] [10 80]] [12 70]] [10 93]] [4 73]] [10 81]] [6351 0.904 [5753 3.68 [10 52] [429 16.9 [29 66] [7512 12.8 [36 86] [36 100]]]] [10 100]]] [12 100]] [5154 1.92 [12 34] [14 33]]] [12 100]]] [4768 1.44 [29 68] [791 21.5 [29 100] [29 92]]]] [15 100]] [10 100]] [6379 2.51 [3027 7.09 [859 1.6 [1906 7.6 [6437 3.7 [6544 1.49 [906 3.54 [4154 12.4 [7169 18.7 [818 8.61 [14 31] [32 66]] [30 62]] [5034 13.8 [32 64] [14 61]]] [32 50]] [14 100]] [14 100]] [32 55]] [30 92]] [32 96]] [14 80]]]] [6091 6.17 [61 2.65 [42 30.6 [19 46] [7737 2.25 [19 46] [1429 8.46 [19 78] [19 50]]]] [22 100]] [13 77]]] [30 100]] [7460 1.27 [1429 1.4 [1078 8.56 [5404 4.67 [4214 6.54 [5683 14.2 [791 7.5 [3625 5.38 [2948 0.562 [285 1.89 [2000 9.44 [3675 8.79 [5673 4.42 [1246 0.975 [5578 19.7 [3435 2.11 [6457 2.67 [7282 0.522 [4280 2.72 [4338 26.3 [906 13 [7729 1.39 [2259 3.05 [1237 7.44 [1958 2.79 [2178 24.2 [3463 5.98 [5140 10.2 [7628 3.72 [1 16] [35 60]] [33 80]] [35 88]] [1925 2.11 [2184 19.9 [1 21] [23 24]] [23 40]]] [35 78]] [29 100]] [5211 3.54 [4550 5.92 [2955 5.33 [4253 3.94 [6276 1.67 [4517 8.3 [1 10] [13 71]] [30 55]] [2 87]] [38 68]] [31 100]] [23 38]]] [1 100]] [5040 3.31 [21 47] [21 100]]] [23 75]] [29 87]] [2006 7.38 [6 28] [6 70]]] [25 77]] [35 60]] [16 87]] [29 43]] [7499 2.3 [35 60] [29 45]]] [35 48]] [5673 23.4 [23 27] [35 50]]] [23 3.76 [33 81] [33 57]]] [38 56]] [2199 1.67 [29 90] [29 100]]] [5192 12.4 [801 1.29 [1987 1.3 [3029 11.5 [917 1.01 [2004 3.75 [4630 12.5 [5034 10.3 [6015 6.46 [1239 26.1 [2039 2.66 [2944 16.3 [3944 4.2 [2280 21.4 [1025 19.2 [7428 8.96 [5040 2.46 [793 15.8 [438 1.44 [5673 7.52 [2624 23 [7169 4.57 [29 14] [23 20]] [33 70]] [35 75]] [23 18]] [26 44]] [21 71]] [1239 14.2 [12 50] [36 50]]] [21 25]] [3 75]] [35 66]] [21 60]] [35 27]] [6193 26.6 [328 38.8 [21 29] [21 91]] [12 71]]] [5040 2.79 [21 82] [21 100]]] [3 65]] [11 97]] [29 44]] [1899 8.19 [21 62] [21 84]]] [23 62]] [21 86]] [21 84]] [12 27]]] [38 85]] [29 54]] [3 100]] [3159 2.78 [2004 2.26 [1993 4.62 [663 4.17 [384 6.47 [7353 19.5 [23 46 [438 1.47 [791 3.01 [4154 0.206 [2183 1.77 [4331 22.9 [2160 5.6 [4517 6.43 [2701 1 [2939 5.74 [2058 0.635 [3609 9.09 [2098 18.6 [1123 17.2 [1400 20.8 [4279 0.739 [941 27.4 [660 5.62 [2128 4.02 [1917 10.8 [1 24] [3 25]] [1 55]] [29 50]] [32 71]] [23 30]] [4 43]] [1 93]] [35 44]] [35 100]] [29 23]] [10 35]] [29 73]] [4 33]] [35 61]] [27 48]] [29 50]] [4380 2.42 [1104 8.95 [2139 2.57 [1219 5.05 [4601 8.19 [4179 10.4 [6524 1.49 [2280 2.97 [1017 3.88 [4320 6.33 [2132 0.509 [23 14] [29 56]] [27 100]] [11 38]] [2293 1.58 [14 55] [14 84]]] [1 35]] [27 54]] [23 64]] [10 100]] [27 37]] [1099 11.1 [4331 13.3 [15 21] [15 73]] [27 60]]] [27 100]]] [4781 3.88 [5225 7.88 [3449 2.49 [7522 17.5 [5480 1.07 [3008 4.8 [2752 12.2 [4663 34 [6310 1.33 [7358 1.01 [1078 40.7 [2 15] [5412 7.83 [2199 19.5 [1094 9.53 [1980 63.9 [5462 7.7 [4279 21.3 [29 16] [29 50]] [35 88]] [26 40]] [29 21]] [27 40]] [32 35]]] [35 87]] [35 71]] [9 33]] [2083 2.59 [896 2.06 [5972 3.55 [2259 15.2 [5007 4.42 [1218 6.17 [2091 5.18 [23 36] [32 25]] [23 72]] [29 66]] [10 43]] [12 58]] [2 28]] [29 33]]] [35 75]] [2011 3.45 [1023 2.22 [504 5.86 [1980 19.1 [29 47] [12 25]] [11 33]] [29 100]] [29 60]]] [22 100]] [35 85]] [22 93]] [11 91]]] [429 48.8 [27 31] [2199 8.43 [23 22] [1980 35.8 [32 41] [11 50]]]]] [19 31]] [35 100]] [4068 4.65 [23 85] [35 87]]] [29 37]] [1226 4.85 [470 11 [2178 13.3 [23 46] [11 38]] [22 100]] [23 100]]] [29 42]] [2024 1.74 [27 84] [27 100]]]] [4558 0.144 [4231 0.281 [4614 0.66 [6198 0.544 [1609 1.07 [6325 0.0591 [5498 0.574 [5972 2.22 [3003 0.782 [2225 0.682 [2701 1.28 [3687 5.99 [3555 1.74 [2939 73.9 [2008 2.51 [6529 0.743 [798 2.76 [6025 1.09 [3311 2.01 [2489 1.27 [7514 0.431 [7340 0.756 [310 3.58 [6899 0.365 [4743 1.11 [3335 4.59 [791 2.59 [1 14] [28 7]] [12 100]] [7 82]] [33 85]] [1696 20.4 [26 93] [26 62]]] [7600 0.928 [7340 17.3 [32 71] [32 88]] [32 91]]] [19 59]] [32 88]] [23 100]] [10 83]] [23 80]] [4154 1.04 [2939 24.3 [22 62] [22 100]] [22 40]]] [11 94]] [4609 3.13 [2178 2.71 [5683 0.943 [1896 1.68 [38 66] [38 55]] [38 84]] [16 42]] [4896 4.41 [1451 3.44 [17 57] [17 87]] [19 64]]]] [2081 11.5 [32 60] [32 94]]] [37 60]] [144 0.756 [435 4.95 [5655 8.86 [1068 1.92 [29 77] [32 60]] [15 50]] [29 100]] [3959 0.942 [29 90] [29 100]]]] [4769 1.57 [4743 0.538 [6641 0.459 [5891 0.186 [4326 1.3 [2091 4.26 [371 5.17 [430 0.617 [1371 0.197 [1260 0.0748 [5007 0.172 [6074 1.15 [7623 0.29 [4158 0.763 [1899 30.9 [1249 2.25 [1229 4.58 [29 22] [1 70]] [1244 1.21 [29 55] [29 70]]] [1110 3.73 [7314 1.13 [29 33] [15 80]] [17 40]]] [23 24]] [1 40]] [15 45]] [2225 4.66 [29 84] [29 52]]] [1261 2.78 [429 7.54 [1 21] [3 28]] [1 68]]] [30 86]] [32 81]] [21 100]] [4161 1.47 [5007 0.821 [7169 2.26 [2251 4.55 [429 25.1 [1429 68.2 [1112 9.85 [28 33] [25 57]] [31 22]] [32 57]] [23 14]] [16 30]] [28 46]] [10 20]]] [28 41]] [14 66]] [15 40]] [7 81]] [29 100]]] [27 100]] [663 5.57 [1094 2.18 [4312 3.5 [556 0.986 [939 1.99 [2752 10.5 [12 28] [12 67]] [12 100]] [21 75]] [12 100]] [36 34]] [2143 4.59 [36 71] [12 100]]]] [5500 0.574 [30 95] [30 100]]] [5732 3.65 [28 100] [28 93]]] [24 63]] [29 97]] [4326 0.494 [5007 0.33 [221 3.33 [29 92] [29 100]] [29 100]] [29 100]]] [10 67]] [5056 0.287 [6943 0.595 [5889 1.21 [17 46] [19 50]] [32 100]] [17 58]]]] [1104 4.21 [23 28.6 [29 84] [29 62]] [29 95]]]] [1429 7.02 [4407 16.7 [6997 8.02 [1980 3.11 [4716 23.3 [3 72] [3 87]] [3 94]] [3 100]] [3 51]] [3 100]]] [2132 0.246 [29 95] [29 100]]] [2267 1.15 [1025 2.19 [5308 1.49 [12 72] [31 62]] [791 2.96 [12 93] [2848 1.05 [12 93] [12 100]]]] [31 100]]] [7665 45.2 [20 100] [4245 23.1 [20 63] [20 100]]]] [4154 24.1 [2259 25.8 [23 98] [23 88]] [23 95]]] [766 2.04 [5871 2.01 [1626 1.98 [3 54] [30 100]] [328 1.66 [30 76] [30 100]]] [3 100]]] [4353 3.81 [6668 0.867 [5588 5.74 [1685 1.51 [7665 6.49 [6147 0.454 [6530 1.08 [3309 1.12 [975 3.09 [7340 1.31 [6074 1.41 [4105 1.36 [5343 0.0687 [5333 0.535 [5034 0.298 [4851 3.03 [1684 3.68 [1963 0.808 [5766 1.33 [2178 0.595 [7173 1.94 [221 2.48 [969 11.1 [7343 2.76 [7449 12.5 [7139 4.35 [4904 1.31 [6524 5.49 [663 9.13 [4592 4.85 [5812 1.47 [28 11] [4 41]] [16 33]] [28 77]] [28 82]] [8 71]] [11 42]] [28 58]] [22 44]] [1 50]] [4154 7.84 [28 46] [28 92]]] [12 100]] [29 14]] [28 78]] [23 60]] [7151 3.76 [2 75] [22 42]]] [28 93]] [5110 19.3 [4772 1.17 [7449 45.8 [4279 13.9 [6853 1.8 [362 2.9 [4611 9.21 [4279 0.945 [28 81] [883 3.31 [5420 6.09 [28 97] [28 83]] [28 80]]] [28 46]] [28 46]] [1206 1.49 [28 96] [28 100]]] [28 73]] [28 60]] [3 62]] [28 60]]] [11 100]] [4 21]] [29 35]] [21 20]] [32 55]] [5192 1.58 [28 97] [28 100]]] [15 55]] [906 1.08 [28 95] [28 100]]] [11 100]] [7566 1.34 [7704 0.994 [32 70] [32 100]] [32 100]]] [28 90]] [12 61]] [28 98]] [32 69]]] [5018 6.61 [28 100] [28 85]]] [5807 5.26 [4079 2.13 [7032 3.24 [31 71] [31 100]] [31 100]] [7 100]]] [7241 1.15 [1888 3.65 [7012 1.3 [4309 1.23 [760 0.939 [2398 2.92 [4369 4.19 [435 5.78 [6920 3.74 [350 15.8 [7324 2.25 [3308 2.2 [7456 10.7 [5110 5.08 [2818 11 [7233 3.88 [4218 5.35 [7411 0.516 [1104 3.64 [4422 3.02 [2083 1.47 [3008 0.644 [7354 3.94 [2629 2.8 [2178 0.668 [1899 10.8 [2023 14.6 [12 30] [12 70]] [826 14.7 [23 31] [11 17]]] [23 22]] [12 87]] [32 62]] [8 29]] [23 47]] [32 73]] [32 46]] [15 59]] [15 97]] [32 100]] [12 95]] [12 73]] [7449 41.6 [12 100] [12 80]]] [23 75]] [23 72]] [12 95]] [11 53]] [1101 4.5 [23 43] [23 33]]] [2822 0.903 [791 34.1 [15 73] [15 45]] [12 100]]] [12 100]] [23 94]] [32 97]] [12 95]] [5412 2.62 [7210 12.5 [7665 4.19 [5972 2.99 [429 31.5 [12 50] [32 50]] [12 100]] [32 68]] [32 71]] [1078 5.73 [12 70] [12 90]]]] [1025 5.26 [5192 2.46 [12 95] [12 86]] [12 88]]]] [35 77]] [1661 2.16 [791 3.01 [4496 0.586 [19 56] [19 81]] [2259 8.29 [144 1.68 [13 20] [19 35]] [18 38]]] [18 54]]] [2232 9.83 [2229 0.951 [4308 0.414 [1233 1.7 [2846 0.16 [78 0.613 [6965 1.08 [19 39] [10 100]] [19 85]] [4198 1.27 [22 37] [18 71]]] [10 100]] [19 75]] [10 80]] [26 29]]] [7382 0.849 [1240 0.882 [2241 0.541 [24 25] [10 44]] [24 91]] [7382 17.9 [655 15.6 [24 93] [24 56]] [3646 9.43 [24 93] [24 100]]]]] [6213 0.0197 [6732 3.28 [1108 0.274 [978 3.71 [2707 2.42 [4769 0.44 [168 2.23 [2251 1.31 [4583 2.33 [1735 1.57 [661 1.44 [29 54] [29 80]] [29 100]] [29 100]] [2225 0.808 [29 70] [906 0.758 [29 96] [29 100]]]] [28 55]] [29 100]] [16 58]] [2752 35.4 [7734 11.3 [1429 23.7 [23 50] [18 45]] [19 87]] [2 50]]] [29 100]] [1023 4.84 [19 46] [29 88]]] [6214 0.6 [1901 0.0734 [4769 0.0394 [29 69] [29 100]] [29 100]] [29 100]]]] [422 2.06 [3624 1.08 [1913 50.1 [328 4.38 [2704 0.522 [6304 2.96 [4768 0.59 [1239 9.56 [906 10.3 [29 53] [29 100]] [29 76]] [5527 2.18 [5075 0.334 [29 86] [29 100]] [29 100]]] [29 100]] [29 99]] [5007 1.04 [28 73] [29 63]]] [23 1.49 [29 100] [29 87]]] [29 100]] [28 66]]] [2793 22.4 [2752 13.7 [24 94] [24 83]] [24 84]]] [857 0.487 [7369 1.39 [1769 4.63 [5211 2.44 [6641 1.45 [2826 2.79 [1899 62.1 [939 6.67 [6134 7.57 [4684 1.44 [2207 8.45 [7665 7.06 [2752 14.7 [2707 7.63 [22 15] [38 66]] [22 90]] [22 90]] [22 66]] [22 40]] [30 87]] [10 30]] [22 100]] [32 50]] [22 100]] [2108 4.3 [5704 0.805 [2909 0.768 [6641 1.61 [5283 30.2 [2846 1.32 [429 10.4 [22 88] [906 5.52 [1239 1.66 [883 1.46 [4154 1.56 [5225 13.2 [22 100] [22 80]] [22 100]] [22 100]] [22 100]] [22 97]]] [22 100]] [22 85]] [22 100]] [22 100]] [22 100]] [22 72]]] [22 61]] [28 52]] [5753 2.48 [22 85] [22 100]]]] [1390 1.48 [308 13.3 [2517 28.1 [2341 1.08 [1048 3.03 [3659 27.2 [978 1.99 [4851 0.994 [208 11.8 [24 89] [24 100]] [24 83]] [24 100]] [24 80]] [24 75]] [24 100]] [24 82]] [24 83]] [24 100]]] [1628 0.397 [3808 0.241 [2902 0.319 [860 1.07 [7442 0.325 [4103 2.7 [6109 0.942 [5223 0.901 [3139 0.502 [998 1.01 [929 0.521 [2807 0.728 [3274 1.25 [663 0.107 [6848 1.47 [3480 5.45 [859 3.35 [6753 1.56 [4184 6.07 [436 5.81 [462 10.6 [2705 2.09 [5211 3.52 [7255 5.37 [2081 75.5 [5994 3.49 [5368 7.59 [1997 5.15 [2989 4.82 [6543 2.42 [6883 63.1 [5110 3.05 [3262 4.07 [2202 5.95 [939 1.92 [438 1.79 [2048 12.6 [1980 119 [2178 32 [6665 4.59 [4288 21.7 [3079 6.02 [23 25.7 [3027 7.29 [1077 5.82 [6524 13 [6193 13.5 [6920 14.2 [2039 3.01 [23 9] [1 28]] [23 85]] [15 100]] [22 29]] [28 63]] [23 41]] [12 22]] [37 100]] [22 33]] [12 70]] [23 45]] [23 72]] [23 65]] [27 36]] [2091 1 [29 32] [2939 1 [28 28] [29 60]]]] [23 72]] [37 72]] [857 0.887 [5647 2.8 [11 55] [11 73]] [11 81]]] [13 75]] [12 100]] [28 90]] [23 30]] [11 50]] [29 100]] [23 77]] [12 66]] [7505 11.9 [1986 7.86 [2931 1.11 [5120 0.982 [7512 8.1 [567 13.2 [7085 7.56 [23 42] [23 71]] [23 88]] [23 80]] [22 100]] [23 100]] [23 82]] [11 56]]] [29 100]] [429 46.3 [11 77] [11 100]]] [11 77]] [22 56]] [29 100]] [22 50]] [2081 6.39 [32 73] [32 44]]] [5462 2.57 [22 37] [35 87]]] [3931 0.775 [2225 2.32 [29 32] [29 85]] [29 100]]] [11 100]] [22 100]] [764 1.19 [23 95] [23 100]]] [23 100]] [11 93]] [11 100]] [22 97]] [4103 8.69 [1477 3.44 [8 66] [8 100]] [8 100]]] [1239 2.65 [11 85] [11 70]]] [11 100]] [4184 2.37 [429 33.9 [6469 0.879 [2178 0.928 [7043 0.763 [22 25] [22 100]] [22 45]] [22 100]] [5192 2.61 [906 6.82 [11 45] [23 77]] [23 33]]] [7338 0.816 [22 87] [22 100]]]] [3425 0.241 [11 86] [11 100]]] [435 0.595 [2786 0.435 [2752 12.8 [29 87] [4414 1.05 [29 96] [29 100]]] [29 80]] [29 100]]]] [22 100]] [3694 0.675 [589 3.23 [3658 1.12 [6342 4.39 [4279 0.846 [429 56.4 [3537 5.62 [15 52] [15 100]] [15 100]] [24 43]] [5419 1.82 [7210 8.62 [7 18] [12 25]] [15 100]]] [1428 18.3 [4154 3.76 [36 100] [36 66]] [24 92]]] [21 100]] [2975 5.41 [15 100] [404 1.74 [15 77] [15 100]]]]] [3431 1.08 [6187 1.52 [5211 3.51 [5972 2.59 [7024 1.23 [5477 2.51 [5401 1.99 [1403 0.8 [5833 1.51 [5692 2.73 [7605 35.8 [6082 3.23 [7512 2.11 [13 20] [2488 1.85 [6342 11.8 [429 47.9 [7009 16.3 [1079 3.5 [5716 8.17 [4876 2.65 [36 69] [36 77]] [36 66]] [13 71]] [13 100]] [13 55]] [13 57]] [13 100]]] [13 85]] [36 85]] [1253 13.6 [5967 2.65 [1037 1.37 [791 13.2 [36 31] [13 71]] [13 100]] [13 100]] [36 50]]] [13 95]] [36 100]] [13 100]] [36 100]] [13 100]] [6404 0.978 [2259 2.76 [12 61] [7185 0.876 [1429 3.5 [12 58] [36 100]] [36 75]]] [36 100]]] [2764 2.4 [22 47] [11 33]]] [13 100]] [36 100]]] [3896 0.928 [5034 1.06 [2009 1.28 [3072 0.949 [590 6.22 [896 1.17 [1674 3.42 [1648 0.421 [7512 0.684 [4425 1.02 [2227 3.55 [7463 1.51 [4602 0.637 [4597 1.93 [2917 2.03 [2920 1.52 [371 1.63 [1445 1.64 [663 3.85 [791 6.55 [4533 13.1 [6910 1.52 [4991 23.5 [4663 6.8 [978 2.56 [2143 11.1 [148 2.38 [6425 3.18 [2379 1.41 [1913 1.61 [7322 2.46 [6722 7.46 [4414 19 [1116 5.34 [5851 1.75 [30 28] [25 22]] [30 96]] [15 45]] [30 100]] [30 100]] [30 88]] [32 77]] [26 62]] [144 12.8 [30 83] [30 100]]] [2002 5.65 [2913 20.1 [25 37] [3 38]] [3 70]]] [25 43]] [23 34.7 [12 50] [12 33]]] [14 36]] [30 100]] [30 81]] [15 25]] [2628 3.5 [32 23] [5 81]]] [30 55]] [21 58]] [30 95]] [2156 1.36 [429 46.6 [2916 24.4 [3 72] [25 100]] [1062 4.27 [3 81] [3 87]]] [3 91]]] [15 100]] [26 90]] [32 38]] [15 81]] [5809 6.12 [15 25] [15 100]]] [4921 4.5 [2919 0.632 [6813 1.23 [7411 1.23 [6382 2.3 [44 8.24 [5680 1.07 [731 1.65 [899 2.37 [6179 3.5 [248 0.684 [3463 1.99 [1769 21.5 [1078 19.7 [7737 2.78 [4312 7.72 [32 56] [32 55]] [25 65]] [30 30]] [32 55]] [5 22]] [25 100]] [25 100]] [32 94]] [5 57]] [5 35]] [30 73]] [32 100]] [5 37]] [32 100]] [7742 3.65 [25 69] [25 85]]] [30 100]]] [30 100]] [32 90]] [6310 1.99 [2752 7.63 [5 31] [939 2.77 [978 1.96 [2913 12.7 [5 40] [19 30]] [5 75]] [32 62]]] [5 93]]] [3 100]] [2921 8.34 [26 82] [26 98]]] [26 79]] [1757 2.76 [7317 1.26 [7665 4.07 [2920 2.82 [1239 14.7 [3483 1.92 [30 49] [32 100]] [3 95]] [30 100]] [32 93]] [30 93]] [30 100]]] [2926 1.39 [32 70] [32 90]]]] [5403 1.91 [4425 0.77 [4781 0.443 [4220 1.46 [882 1.42 [6660 0.713 [3274 0.484 [939 2.12 [3803 1.55 [5211 3.14 [5270 2.53 [2521 0.234 [1116 3.62 [3443 0.605 [4723 2.76 [1209 4.21 [5412 2.44 [811 0.381 [5999 10.5 [7434 1.43 [2740 8 [820 8.05 [7133 4.76 [573 7.2 [6982 5.12 [3939 1.04 [144 0.622 [3480 0.806 [726 1.08 [1436 3.61 [2911 2.89 [1980 1.27 [6230 3.37 [7189 1.25 [4420 0.37 [4218 12.5 [791 8.99 [1888 3.63 [2993 4.59 [1429 26 [2476 2.18 [15 50] [15 97]] [30 29]] [30 53]] [7512 3.23 [4 31] [31 50]]] [5066 0.395 [4429 3.27 [2814 4.43 [2471 1.1 [7480 22.1 [4417 2.46 [978 16.4 [7512 22.9 [112 10.9 [4851 2.76 [3458 2.33 [7453 1.21 [2752 3.03 [15 25] [15 73]] [15 100]] [15 100]] [15 92]] [22 40]] [4 87]] [4 95]] [15 96]] [12 85]] [15 100]] [1400 16.9 [12 62] [15 100]]] [15 100]] [15 100]]] [826 20 [15 93] [15 80]]] [7462 2.51 [2752 2.76 [15 96] [15 100]] [15 100]]] [4 33]] [4 52]] [2821 1.43 [978 2.06 [4895 0.735 [15 46] [36 33]] [4 51]] [15 100]]] [10 93]] [10 42]] [4 57]] [7613 0.267 [7061 18.6 [3484 0.403 [1986 8.87 [7085 20.2 [429 35.3 [1391 7.32 [23 1.26 [15 97] [15 100]] [15 100]] [15 94]] [15 87]] [15 75]] [15 100]] [15 50]] [15 100]]] [30 20]] [32 100]] [1899 1.51 [4 83] [4 94]]] [4 100]] [2939 23 [4 100] [4 92]]] [11 81]] [4 100]] [12 100]] [1239 6.71 [4630 9.09 [4 50] [25 57]] [6 50]]] [6103 1.68 [3606 25.7 [5692 4.53 [1239 8.76 [15 97] [15 80]] [15 88]] [15 66]] [12 69]]] [5856 0.568 [1899 24.7 [15 31] [10 38]] [6103 1.31 [15 81] [15 100]]]] [4 100]] [4 100]] [11 100]] [30 96]] [1078 3.06 [4 50] [818 0.68 [4 73] [4 100]]]] [2379 2.04 [6784 1.38 [6209 0.99 [2259 45 [31 71] [5423 1.32 [4404 3.45 [4398 3.15 [31 91] [31 100]] [31 100]] [31 100]]] [31 100]] [31 100]] [4 88]]] [1614 4.59 [392 8.74 [4839 6.02 [5222 2.3 [2752 24.7 [1078 49.8 [5225 1.4 [820 3.36 [30 78] [11 86]] [2752 7.64 [30 100] [6260 2.9 [30 90] [30 87]]]] [11 54]] [30 36]] [2752 20.2 [30 100] [30 85]]] [11 100]] [30 100]] [4 100]]] [11 100]] [3273 0.26 [818 6.01 [435 0.509 [5322 2.56 [791 16.7 [7665 6.76 [11 25] [1899 5.24 [31 61] [4 50]]] [4414 24.3 [11 73] [15 94]]] [15 100]] [2752 19.5 [11 62] [11 100]]] [4 88]] [11 100]]] [11 100]] [5829 0.713 [11 92] [11 100]]] [11 100]] [5926 6.13 [7343 2.02 [12 84] [12 100]] [12 100]]] [820 0.581 [429 22 [4 25] [11 78]] [11 100]]] [2939 32.5 [6196 1.3 [3243 1.54 [3729 2.56 [15 99] [15 100]] [15 100]] [15 100]] [15 66]]] [2966 2.43 [312 1.28 [978 2.14 [31 77] [31 100]] [31 100]] [31 100]]]] [7512 0.207 [4682 1.45 [1700 0.118 [7222 0.0344 [791 0.0349 [4305 0.77 [5759 3.32 [395 0.564 [6773 0.478 [1672 1.34 [233 1.49 [2362 4.02 [5541 0.348 [5258 2.7 [1708 0.548 [6774 0.219 [3281 12.3 [6945 7.31 [2628 32.2 [5480 0.129 [6458 1.06 [1849 0.0958 [7650 7.64 [1943 1.13 [5267 0.193 [6713 3.45 [3811 0.377 [4951 9.62 [6484 0.456 [6809 0.743 [4868 1.05 [1429 7.34 [2201 3.37 [6899 4.63 [907 2.46 [2913 3.36 [5641 10.7 [534 2.62 [2062 1.71 [6844 1.93 [4338 3.23 [4681 17.4 [7488 5.38 [1786 4.34 [5593 0.608 [4414 27.6 [5170 1.46 [6877 6.42 [2272 5.62 [1239 18.8 [4680 13.6 [3435 7.75 [2247 50.9 [2199 3.29 [33 13] [1 23]] [1 78]] [35 66]] [33 70]] [203 8.82 [1260 2.16 [5509 3.36 [5753 5.22 [4790 0.821 [33 22] [4 60]] [9 25]] [3 33]] [5 27]] [3 100]]] [13 54]] [13 30]] [33 66]] [33 42]] [1 66]] [35 24]] [38 100]] [15 38]] [33 79]] [33 68]] [35 26]] [3 100]] [19 17]] [30 37]] [3 92]] [33 76]] [28 38]] [3622 0.222 [5776 5.3 [5524 1.19 [5632 4.66 [5211 2.77 [4963 1.71 [3576 8.34 [4964 8.02 [5732 1.85 [3311 4.85 [4867 2.86 [2752 0.204 [2194 0.357 [6471 0.673 [2081 0.468 [4506 2.27 [6610 1.44 [5072 3.19 [5965 0.512 [1870 4.98 [5022 13 [5531 5.95 [5333 5.49 [33 17] [11 100]] [1587 16.7 [13 27] [13 65]]] [3 84]] [13 40]] [3 100]] [33 52]] [28 87]] [32 100]] [6780 4.6 [7058 3.04 [1077 3.6 [1239 32 [1587 7 [3735 1.25 [4684 2.08 [1742 17 [33 13] [25 38]] [3 50]] [29 50]] [1239 18.5 [1 29] [1 60]]] [15 14]] [32 92]] [10 18]] [28 85]]] [4704 4.18 [2707 3.65 [26 60] [26 83]] [26 100]]] [33 58]] [2517 3.36 [4802 1.38 [1713 0.673 [112 5.28 [663 5.31 [2009 3.16 [1671 7.51 [3659 5.15 [3334 4.5 [7301 6.79 [731 5.75 [33 10] [5 33]] [328 8.7 [17 33] [28 36]]] [12 100]] [24 100]] [28 45]] [26 90]] [17 28]] [22 17]] [31 100]] [33 72]] [24 76]]] [3 100]] [23 100]] [7210 1.46 [28 44] [13 30]]] [4 66]] [15 81]] [25 100]] [30 47]] [4566 3.94 [7391 7.15 [4279 17.2 [1587 2.56 [16 22] [16 33]] [3 71]] [16 87]] [30 53]]] [11 100]] [6199 3.03 [663 7.69 [26 39] [26 50]] [7 71]]] [29 100]]] [3 100]] [32 100]] [25 64]] [3 100]] [392 5.62 [30 100] [30 83]]] [30 100]] [5152 2.26 [4893 2.18 [4611 6.5 [6809 2.89 [6199 2.79 [4861 3.32 [6960 12.4 [3993 5.78 [5462 6.33 [6768 1.5 [6935 0.429 [1830 0.684 [5539 3.12 [6363 1.59 [5271 7.64 [6397 2.66 [1722 7.4 [6032 1.85 [7446 0.824 [6328 8.95 [1451 3.56 [2793 6.49 [7354 7.96 [4754 5.82 [2260 0.642 [5373 4.7 [5211 7.33 [1799 3.76 [2259 10 [2259 0.567 [26 28] [16 21]] [2466 7.29 [38 10] [18 50]]] [24 50]] [30 87]] [11 28]] [30 58]] [19 30]] [26 42]] [19 37]] [15 60]] [4 42]] [26 66]] [5368 1.06 [2 31] [21 30]]] [33 90]] [33 40]] [32 55]] [4 33]] [13 100]] [5495 15.6 [1783 69.4 [2 71] [4 44]] [0 83]]] [15 60]] [31 100]] [1078 15.7 [4 34] [25 50]]] [12 55]] [31 82]] [26 63]] [31 41]] [32 100]] [31 83]] [18 50]] [1713 15.3 [31 55] [31 100]]]] [6353 0.87 [2092 1.41 [2057 8.91 [4414 15.4 [2182 3.14 [6276 1.13 [1456 0.0663 [1951 2.64 [2143 6.9 [5618 1.59 [2132 2.45 [2110 2.81 [2139 0.298 [1 17] [1 53]] [30 42]] [1 37]] [33 54]] [35 24]] [2131 1.07 [35 35] [1 57]]] [11 23]] [19 40]] [29 62]] [12 33]] [25 33]] [4 28]] [22 23]]] [33 85]] [25 100]] [1913 1.51 [25 92] [25 100]]] [7151 0.945 [1874 1.72 [1051 3.5 [7734 2.18 [1069 0.728 [3130 0.795 [2093 1.04 [6328 7.02 [3 12] [2 81]] [28 33]] [7255 0.322 [22 70] [13 54]]] [4 50]] [19 42]] [10 100]] [2 70]] [5525 1.08 [2460 4.7 [11 76] [11 45]] [11 100]]]] [4030 16.9 [5569 2.12 [7472 2.62 [2649 6.15 [7210 5.84 [5833 14.3 [2439 2.7 [38 35] [38 100]] [24 75]] [26 40]] [16 65]] [17 38]] [6380 4.47 [17 66] [17 33]]] [24 100]]] [33 100]] [27 67]] [30 88]] [2752 23.6 [2232 0.763 [2628 1.53 [4703 0.355 [4395 3.11 [1783 22.2 [13 43] [28 53]] [28 100]] [33 55]] [1078 18.7 [28 97] [28 83]]] [28 96]] [1 28]]] [10 100]] [4064 4.3 [4414 3.65 [1870 0.348 [13 90] [13 100]] [13 84]] [13 84]]] [3 94]] [23 44.5 [33 81] [33 76]]] [4165 1.34 [22 97] [22 100]]] [30 92]] [5532 7.29 [2306 0.517 [30 97] [30 100]] [30 63]]] [1997 7.45 [30 82] [30 100]]] [31 100]] [3803 0.381 [1817 0.613 [429 27 [5903 2.22 [2394 0.173 [153 0.648 [5732 0.424 [753 14.5 [6767 1 [1870 1.44 [4625 1.38 [6809 1.24 [1340 1.12 [5501 0.5 [5972 8.3 [5808 0.471 [5225 0.164 [5258 0.54 [6122 13.4 [5455 0.741 [1680 1.75 [570 7.66 [1623 3.4 [5202 1.81 [6612 0.606 [3073 4.1 [4802 0.497 [4779 0.534 [2899 0.0827 [1879 0.938 [3203 1.38 [4703 3.11 [1592 2.87 [4865 0.738 [7142 1.53 [663 0.677 [1400 6.81 [6910 3.3 [3698 0.45 [3311 1.14 [1850 0.509 [4566 0.154 [5540 0.56 [6773 0.42 [6848 4.98 [3565 0.313 [6382 0.401 [6899 0.945 [6830 2.67 [6011 5.84 [30 6] [0 58]] [33 36]] [33 65]] [6199 1.14 [1429 83.6 [4896 2.53 [3 36] [32 70]] [17 75]] [32 83]]] [22 100]] [791 13.6 [35 60] [35 80]]] [30 100]] [13 100]] [24 29]] [25 100]] [23 100]] [28 58]] [30 84]] [2225 0.695 [15 40] [25 33]]] [1899 0.867 [6184 4.35 [1888 3.07 [29 29] [13 44]] [29 66]] [4235 20.7 [145 7.09 [22 23] [16 33]] [22 100]]]] [20 85]] [3 100]] [3 83]] [248 2.4 [2202 2.93 [1769 7.53 [2081 8.33 [3993 0.275 [5299 0.353 [1867 3.15 [3694 0.445 [33 29] [11 50]] [33 57]] [4566 2.22 [20 28] [24 50]]] [5 44]] [25 31]] [22 60]] [10 60]] [33 50]]] [15 68]] [5495 1.58 [2274 2.09 [1684 0.113 [1239 35.9 [2 20] [1458 1.99 [16 41] [29 75]]] [31 52]] [30 37]] [11 88]]] [2259 8.36 [33 78] [33 55]]] [15 100]] [33 62]] [26 100]] [1783 38 [28 62] [28 95]]] [9 84]] [11 100]] [827 16.4 [2 60] [2 92]]] [22 100]] [29 100]] [13 90]] [10 100]] [6882 1.78 [7168 0.328 [6647 0.756 [22 60] [30 100]] [30 80]] [30 100]]] [15 87]] [12 92]] [30 100]] [1986 4.27 [2752 5.66 [2 21] [11 68]] [11 100]]] [32 100]] [30 67]] [1832 0.778 [2004 2.16 [6812 1.73 [2199 1.78 [7329 4.16 [1980 5.25 [17 17] [11 37]] [13 62]] [22 66]] [32 100]] [13 45]] [13 100]]] [6074 0.573 [31 87] [31 100]]] [30 100]] [2225 2.58 [7330 3.26 [13 34] [28 50]] [28 53]]] [1457 7.85 [3281 1.03 [2464 0.463 [1841 7.1 [28 90] [28 75]] [28 100]] [13 60]] [6606 14.2 [28 100] [28 85]]]] [4279 2.6 [4760 0.093 [2993 2.6 [1459 0.268 [6904 1.73 [4712 0.144 [5481 2.51 [2178 8.63 [4064 0.659 [5759 1.71 [30 71] [30 100]] [1899 3.93 [30 83] [30 88]]] [30 71]] [22 100]] [30 100]] [22 78]] [4704 0.61 [30 94] [30 100]]] [22 92]] [30 100]] [22 63]]] [2286 2.1 [2944 0.724 [1899 4.12 [2259 34.6 [18 100] [18 75]] [18 66]] [18 50]] [7 33]]] [1899 0.505 [2917 5.17 [2752 1.92 [6897 2.22 [757 0.982 [5989 0.982 [1783 52.5 [774 7.39 [6388 0.527 [4214 2.51 [5539 2.73 [5513 2.65 [1592 3.74 [3 27] [3 100]] [3 100]] [3 50]] [3 88]] [13 50]] [21 66]] [13 14]] [2 32]] [3 100]] [1239 62.6 [10 75] [9 62]]] [6696 2.96 [6732 2.42 [23 18] [22 42]] [28 100]]] [1980 12.2 [3 100] [3 86]]] [3274 0.258 [2701 4.66 [4369 0.558 [6109 5.29 [3616 3.31 [7316 1.05 [23 11.5 [3265 1.25 [1788 13.2 [435 1.69 [11 18] [1094 3.15 [11 45] [11 75]]] [36 61]] [15 66]] [3 27]] [3 85]] [11 50]] [22 77]] [10 44]] [29 75]] [11 100]]]] [3 100]] [11 100]]] [1014 0.0344 [4533 1.06 [30 33] [22 33]] [5795 0.973 [6562 0.294 [30 100] [30 66]] [30 91]]]] [4703 0.304 [7329 8.11 [2470 14.1 [25 97] [25 83]] [25 100]] [25 100]]] [2241 0.539 [4235 16.7 [1881 3.99 [2199 3.45 [2763 4.1 [6959 8 [33 86] [13 70]] [13 62]] [4703 21.3 [33 76] [33 50]]] [33 66]] [33 64]] [33 36]]] [5402 1.27 [4790 0.687 [23 55.4 [3824 1.09 [2436 7.43 [1161 0.445 [1841 8.65 [7340 0.729 [1672 0.407 [5310 0.938 [4214 0.986 [1078 45.2 [4682 2.18 [1661 6.3 [1844 7.35 [7302 1.13 [2464 0.189 [1180 0.713 [6524 1.31 [4207 0.761 [7525 0.84 [5009 4.71 [5480 3.67 [6947 6.06 [227 3.57 [755 1.04 [5972 4.95 [4655 3.18 [5092 2.79 [7474 3.16 [6768 2.95 [2923 0.435 [134 0.0668 [1078 27.6 [4851 0.917 [6103 2.67 [405 2.43 [6581 3.06 [4198 0.79 [6727 1.79 [6544 1.47 [5110 0.415 [2268 30.7 [7259 6.32 [1982 0.971 [6903 0.947 [2841 0.44 [168 5.17 [2764 4.22 [6899 0.188 [7554 0.823 [6031 7.16 [5539 2.92 [1918 0.331 [14 8] [21 77]] [13 61]] [22 80]] [10 100]] [33 71]] [13 47]] [19 52]] [32 50]] [22 57]] [10 42]] [14 85]] [18 91]] [2445 1.12 [33 47] [30 100]]] [14 80]] [19 41]] [2466 1.04 [19 68] [19 60]]] [5 25]] [28 87]] [31 40]] [26 23]] [10 32]] [2902 4.47 [3563 0.901 [5 18] [19 44]] [2 40]]] [25 88]] [31 100]] [10 83]] [22 100]] [1 100]] [36 52]] [20 100]] [24 85]] [30 100]] [18 23]] [1429 28.1 [19 100] [19 75]]] [7665 12.5 [30 50] [19 61]]] [29 100]] [1 48]] [13 100]] [5785 2.99 [2752 21.1 [17 21] [14 62]] [32 100]]] [19 49]] [31 89]] [18 70]] [33 85]] [1104 6.34 [429 27.3 [1400 1.08 [2939 1.23 [10 51] [1 33]] [10 100]] [10 23]] [10 85]]] [24 63]] [10 100]] [22 100]] [2846 4.73 [32 85] [32 66]]] [10 48]] [10 87]] [6 84]] [13 100]] [3616 0.382 [2004 1.66 [78 0.794 [5509 5.35 [2093 6.04 [7729 2.06 [5480 0.294 [7329 0.516 [5345 0.455 [1913 4.3 [107 3.58 [429 6.51 [4279 6.85 [4154 0.317 [163 1.69 [19 41] [14 21]] [19 82]] [19 22]] [13 31]] [19 100]] [19 25]] [23 92.8 [19 92] [6 33]]] [16 33]] [18 60]] [1 23]] [26 83]] [30 80]] [19 85]] [28 50]] [19 100]]] [2143 0.678 [2204 0.613 [31 72] [31 100]] [31 90]]] [13 100]]]] [1710 3.51 [7281 0.236 [2936 1.39 [5647 35.6 [4421 2.87 [247 13.2 [1913 4.63 [1 9.28 [2752 31.8 [7314 11.5 [6710 2.41 [5326 2.33 [6390 0.491 [2695 0.65 [30 97] [30 100]] [30 100]] [30 99]] [30 63]] [2697 2.8 [30 83] [30 100]]] [5225 5.96 [30 95] [30 75]]] [30 75]] [30 62]] [30 83]] [30 87]] [30 57]] [30 70]] [30 66]] [30 71]]] [4783 0.331 [1659 0.15 [534 1.29 [5972 1.59 [3072 0.873 [5555 0.647 [4862 0.169 [7301 2.96 [4915 0.924 [6811 1.22 [1658 4.24 [4867 0.924 [1692 0.151 [3251 14.3 [498 20.9 [3271 5.46 [7665 1.98 [7333 14.6 [6134 1.87 [2275 1.11 [2329 3.27 [6382 0.0309 [3989 3.88 [1986 10.1 [3 35] [3 90]] [17 41]] [17 32]] [17 60]] [3 90]] [3 66]] [14 59]] [32 49]] [19 66]] [17 100]] [3 73]] [3 28]] [3 100]] [14 42]] [32 100]] [32 50]] [17 72]] [3 100]] [14 94]] [32 100]] [3 100]] [3 100]] [6388 0.14 [588 0.366 [4639 0.108 [5839 2.43 [1479 1.9 [1673 0.162 [522 2.46 [4414 2.52 [7373 0.949 [1078 2.13 [5895 0.58 [5844 6.65 [1656 0.621 [1769 0.252 [7210 3.28 [17 51] [3 82]] [14 28]] [3 81]] [38 42]] [17 77]] [4530 0.372 [32 39] [17 50]]] [19 77]] [19 62]] [3 100]] [17 77]] [3 100]] [791 24.8 [3 100] [3 54]]] [4635 2.93 [284 0.431 [6971 0.91 [2057 1.06 [6380 19.2 [791 20.8 [17 42] [1997 3.51 [5125 2 [5941 18.7 [5297 0.978 [17 81] [17 66]] [17 42]] [14 66]] [17 50]]] [5892 0.997 [17 92] [17 100]]] [17 33]] [2081 1.86 [4059 1.04 [429 23.4 [17 55] [3 50]] [38 50]] [32 42]]] [3597 2.23 [32 100] [3599 4.32 [32 87] [32 100]]]] [17 77]]] [3 100]] [1653 1.04 [19 40] [6920 0.291 [7373 0.366 [5893 8.98 [17 77] [19 44]] [4635 8.6 [38 35] [4896 1.64 [17 50] [5941 1.81 [17 33] [4851 0.578 [38 90] [38 100]]]]]] [17 90]]]]] [4058 7.93 [2214 0.495 [2259 49.8 [4059 0.171 [6970 0.251 [791 22.6 [17 37] [17 100]] [14 37]] [17 75]] [971 12.8 [19 100] [19 81]]] [19 45]] [17 37]]]] [6982 1.13 [5448 0.459 [221 4.44 [1240 2.27 [2488 0.874 [3022 3.36 [2081 2.99 [6166 0.709 [3558 0.96 [637 0.568 [3633 5.25 [6732 1.23 [3659 1.42 [5360 0.97 [5349 4.1 [5140 5.7 [5482 0.891 [7540 1.15 [5970 1.07 [4851 0.752 [3851 3.53 [2846 3.47 [5598 3.15 [7292 0.545 [2259 33.7 [6457 1.42 [6088 1.59 [4189 2.32 [934 2.65 [5462 6.14 [5972 2.03 [1511 0.432 [1013 0.236 [2531 0.879 [6926 1.81 [7512 2.94 [4690 1.93 [1226 1.47 [1047 3.08 [2739 1.16 [2583 3.45 [1413 2.39 [2004 2.39 [1078 15.4 [5904 4.5 [2587 2.07 [3040 5.38 [2752 0.566 [7609 9.55 [232 1.86 [3944 2.76 [2604 11.2 [621 0.697 [6148 3.14 [4967 15.2 [915 2.2 [6382 1.65 [3462 4.5 [1 10] [0 93]] [17 43]] [4279 2.28 [21 47] [3 100]]] [31 100]] [9 70]] [21 100]] [0 100]] [35 90]] [233 12.1 [33 42] [33 92]]] [8 100]] [1746 2.67 [2987 20.4 [1783 45.3 [1704 2.17 [2027 13.7 [2466 1.14 [5211 6.85 [3515 3.14 [2832 2.59 [7354 10.6 [5 13] [18 40]] [4154 2.59 [24 63] [24 100]]] [19 62]] [448 1.98 [5110 2.28 [23 67] [22 60]] [23 75]]] [328 2.57 [5 22] [16 37]]] [1 66]] [5142 7.59 [6396 17.8 [17 63] [17 92]] [17 100]]] [33 22]] [23 77]] [24 100]]] [35 100]] [2 92]] [2526 19.5 [19 92] [19 100]]] [6571 4.59 [4288 3.66 [941 2.51 [2793 18.8 [4320 11.9 [312 1.32 [5816 15.2 [435 11.7 [3003 1.65 [7491 8.18 [3027 9.5 [7154 2.4 [3148 3.14 [3069 6.62 [23 13] [8 81]] [24 77]] [22 40]] [23 53]] [23 66]] [27 100]] [23 83]] [4 90]] [2536 6.63 [2 39] [2 100]]] [27 89]] [27 82]] [27 88]] [23 65]] [23 100]]] [23 96]] [10 100]] [0 92]] [4414 4.76 [2752 40.4 [4 74] [4 40]] [4 90]]] [2 35]] [2628 1.23 [2594 1.47 [23 95] [23 100]] [23 87]]] [4716 1.39 [0 51] [0 100]]] [4 4.35 [3057 1.47 [4342 1.11 [6184 6.79 [5155 0.952 [7324 6.37 [7132 8.01 [7266 2.16 [5509 19.7 [5054 3.28 [6251 8.84 [7354 2 [1059 2.81 [43 1.28 [4959 1.71 [4041 9.09 [6578 2.18 [2574 5 [3278 1.51 [1058 0.816 [2470 1.3 [5812 7.88 [5 11] [2 29]] [4 61]] [8 100]] [1 100]] [2 54]] [31 100]] [24 100]] [4 81]] [4 100]] [2259 19.4 [1400 8.03 [2 62] [2 62]] [6 72]]] [4288 2.28 [5480 1.41 [5666 1.82 [7016 1.19 [5 22] [5 66]] [18 88]] [18 50]] [36 46]]] [2526 30.4 [31 40] [2 76]]] [4 96]] [5 61]] [2 84]] [4 68]] [5 70]] [1239 7.81 [6230 5.04 [6557 3.9 [5 55] [5 100]] [5 83]] [35 60]]] [4154 6.45 [7512 17 [896 5.31 [2 24] [17 3.94 [286 3.31 [2 33] [4 50]] [2 100]]] [1 36]] [5812 6.79 [1072 1.28 [328 2.02 [144 5.65 [2 40] [2 50]] [25 33]] [2 50]] [7169 3.27 [134 2.62 [2 66] [2 75]] [2 83]]]]] [24 100]] [7381 5.46 [5 97] [5 66]]] [6 100]]] [1004 0.599 [5647 40.5 [1047 7.1 [2570 5.85 [731 1.4 [7210 1.03 [7665 11.5 [1429 33 [2 45] [2 73]] [2 85]] [2 69]] [2 75]] [2 88]] [2 100]] [4 50]] [2 87]]] [906 3.69 [23 87] [23 81]]] [1068 0.699 [1192 1.82 [23 90] [23 100]] [23 80]]] [5753 0.432 [5 97] [5 100]]] [2266 2.25 [4421 2.22 [4611 8.56 [6103 0.699 [2536 1.83 [4301 1.2 [12 41] [12 80]] [31 84]] [1400 9.01 [31 66] [12 100]]] [31 93]] [12 69]] [31 100]]] [35 42]] [429 20 [23 44] [929 3.25 [23 94] [23 57]]]] [24 96]] [2 82]] [25 100]] [2628 7.5 [5480 9.71 [2259 50 [5799 15.2 [1320 6.51 [5308 3.14 [6851 2.96 [5851 14.6 [2004 19.1 [1838 1.33 [1389 0.911 [3208 8.6 [978 22.7 [5609 0.999 [2411 4.2 [7665 13.6 [1025 4.2 [8 10] [24 54]] [6 59]] [24 76]] [6 100]] [8 60]] [8 45]] [24 100]] [19 76]] [23 100]] [0 76]] [24 100]] [21 60]] [6 100]] [6 78]] [6912 6.02 [4446 0.59 [6148 0.795 [2526 20.3 [4279 5.54 [3207 1.86 [1239 33.9 [31 15] [6 70]] [6035 3.23 [19 25] [5 57]]] [24 28]] [6560 3.18 [5962 3.88 [2616 3.23 [6 20] [2579 26.6 [7149 1.27 [4725 16.1 [1059 4.07 [6 94] [6 100]] [2292 18.8 [6 66] [6 100]]] [6 100]] [6 62]]] [2551 14.1 [1320 20 [6 90] [6 63]] [6 80]]] [8 66]]] [8 44]] [31 100]] [34 100]]] [2596 5.38 [8 66] [8 100]]] [1899 13.4 [31 47] [21 75]]]] [2 62]] [6 93]] [2199 2.6 [1083 2.54 [7514 1.92 [4991 5.35 [12 66] [2 33]] [2 54]] [4 100]] [1429 8.71 [19 40] [12 42]]]] [3944 14.5 [35 72] [35 100]]] [3964 1.05 [6977 17 [1025 0.963 [3931 3.41 [6887 3.88 [728 1.33 [7512 1.39 [8 38] [7620 0.565 [527 2.39 [3357 38.5 [5821 2.42 [3794 3.94 [2753 9.98 [6380 5.24 [7032 8.03 [2398 4.13 [4 21] [4 73]] [4 87]] [17 80]] [17 66]] [17 33]] [4 66]] [4 90]] [4 92]] [7 33]]] [17 35]] [7535 7.94 [7563 27.5 [5 100] [5 66]] [19 60]]] [4 47]] [4 78]] [4 57]] [17 81]]] [6791 8 [2845 0.967 [23 95] [23 100]] [1 55]]] [6 87]] [383 9.38 [7331 2.02 [1239 3.85 [5007 35 [7343 1.9 [1648 1.31 [5282 5.05 [663 10.3 [560 10.4 [1888 1.02 [5660 1.59 [7185 2.42 [18 46] [18 37]] [18 90]] [18 70]] [18 100]] [18 36]] [22 50]] [18 83]] [19 50]] [19 71]] [18 42]] [19 64]] [19 62]]] [33 75]] [2280 6.06 [4674 7.02 [2939 5.88 [6 78] [6 23]] [6 66]] [6 100]]] [7623 4.43 [4338 2.05 [33 78] [1783 14.1 [33 100] [33 85]]] [33 100]]] [24 82]] [7584 0.787 [4214 2.44 [6230 2.19 [5211 8.9 [1400 4.17 [4960 2.18 [1059 2.08 [7354 3 [4995 0.736 [6537 0.761 [2456 2.38 [7133 2.2 [4338 12 [1047 3.17 [6926 3.42 [5430 2.22 [1391 5.82 [6582 1.1 [2568 1.29 [5239 3.65 [3327 1.4 [6735 7.94 [4832 1.52 [7737 2.96 [4414 3.67 [1025 4.99 [7734 3.45 [1023 1.34 [2617 1.14 [4304 10.5 [7711 2.13 [2616 13.5 [7568 8.95 [4200 1.21 [1668 1.83 [1909 0.768 [248 5.54 [2571 8.4 [2470 1.33 [2902 12.4 [5142 5.43 [791 13 [5 13] [5851 2.33 [5 29] [2 28]]] [4 87]] [4 30]] [4 68]] [3 50]] [25 50]] [2 25]] [17 50]] [5 36]] [4 87]] [17 17]] [5 87]] [19 66]] [30 37]] [5348 3.27 [5692 8.83 [2 34] [17 50]] [19 33]]] [18 31]] [2259 7.28 [2 43] [24 57]]] [2701 3.78 [1888 4.19 [1980 1.22 [896 20.2 [1239 18.7 [4 53] [3 80]] [2 71]] [4 33]] [22 37]] [15 100]]] [18 61]] [2 63]] [2 69]] [2 84]] [4 100]] [0 100]] [4 100]] [0 55]] [5 87]] [2 63]] [573 3.85 [24 46] [2 77]]] [2760 1.02 [1429 11.2 [24 72] [24 93]] [24 46]]] [4 100]] [24 76]] [2 86]] [2 77]] [791 27.5 [7512 21.9 [2752 32.1 [134 0.577 [1011 4.95 [18 43] [5 40]] [18 50]] [5482 8.67 [18 41] [18 100]]] [1078 13.9 [18 87] [18 57]]] [5 42]]] [4929 2.79 [939 0.873 [4279 2.13 [4414 4.12 [2 84] [2 81]] [2 75]] [2 70]] [2616 4.65 [38 40] [2 62]]]] [4 100]] [328 9.29 [5007 11.4 [5812 3.28 [5472 3.4 [7512 18.5 [4 37] [31 50]] [36 100]] [7742 2.11 [5962 1.65 [2570 1.93 [2 76] [4 55]] [4 62]] [4 54]]] [2 84]] [15 75]]] [7176 1.31 [1025 2.15 [0 43] [2 42]] [5412 0.937 [22 66] [22 81]]]] [2752 1.39 [0 64] [6243 1.78 [5480 9.36 [7241 1.73 [4154 3.29 [7712 1.04 [2526 37.9 [738 0.818 [7512 13.3 [5 37] [5 53]] [17 75]] [4 80]] [5 46]] [4 24]] [5 55]] [18 83]] [5 76]]]] [24 100]] [1173 0.795 [2553 1.07 [7712 6.6 [2 91] [2 57]] [2 100]] [2 100]]]] [4411 2.62 [1980 5.73 [35 77] [35 68]] [35 100]]] [4324 4.23 [1076 2.56 [2526 11.8 [4 50] [5804 0.894 [1023 9.42 [1883 5.84 [7266 6.94 [5299 1.17 [2 90] [2 71]] [2 82]] [2 71]] [2 100]] [2 100]]] [2 66]] [2 66]]] [2536 9.71 [3056 4.58 [5 34] [5 91]] [7 55]]] [7234 5.75 [7281 0.275 [5962 8.18 [6422 2.58 [6 94] [6 62]] [6 75]] [6 63]] [6 100]]] [4253 2.76 [435 0.438 [6230 0.695 [1038 0.259 [2574 0.535 [2547 6.64 [110 5.95 [7623 4.38 [7665 0.471 [3207 0.224 [4160 2.24 [1062 2.99 [2005 3.33 [4279 0.808 [286 5.64 [3667 6.4 [906 1.13 [4338 3.66 [5152 1.07 [3492 3.76 [5278 2.67 [2178 17 [2628 19.1 [1101 8.49 [5225 4.07 [328 14.3 [2099 6.39 [660 8 [2225 3.39 [1239 0.952 [429 34.4 [23 12] [23 50]] [1 12]] [2259 34.5 [1 20] [21 36]]] [23 62]] [3 71]] [35 40]] [23 83]] [23 45]] [4 50]] [23 51]] [7210 16.4 [21 50] [21 100]]] [0 50]] [31 100]] [1911 0.935 [23 69] [24 57]]] [21 64]] [35 89]] [996 0.994 [23 75] [23 100]]] [2149 10.2 [4286 6.1 [2939 2.52 [2154 1.03 [4768 11.4 [23 71] [21 37]] [23 50]] [25 22]] [3 50]] [23 52]]] [3379 1.93 [2156 1.4 [1101 3.11 [2205 20.8 [7663 1.71 [2058 3.41 [1783 7.32 [5972 4.74 [23 45] [12 100]] [33 23]] [8 41]] [12 100]] [12 61]] [23 87]] [23 100]] [1 77]]] [7507 0.62 [7742 2.62 [1044 0.707 [7491 1.41 [2089 3.23 [7428 1.77 [1094 0.701 [23 36] [23 73]] [23 57]] [4365 2.28 [23 88] [23 100]]] [23 83]] [2083 0.353 [23 100] [23 57]]] [18 45]] [23 100]]] [4350 2.13 [2232 1.97 [7176 2.22 [2 25] [22 85]] [23 61]] [1 45]]] [7472 1.9 [1783 11.2 [19 42] [1997 0.267 [17 38] [14 22]]] [38 50]]] [3706 2.44 [2021 0.484 [2470 0.935 [2846 6.79 [6515 2.06 [4583 0.387 [1281 2.28 [6926 5.08 [1389 2.9 [5812 2.92 [1919 0.173 [6859 3.4 [7381 0.637 [6791 16.1 [2526 56 [2241 4.04 [6310 1.06 [978 8.91 [1980 17.9 [5110 14.3 [2902 8.77 [31 13] [1 57]] [12 88]] [1 27]] [18 17]] [33 50]] [2241 9.94 [1 33] [23 50]]] [1980 9.2 [23 21] [24 31]]] [1 68]] [2 46]] [24 44]] [2029 0.373 [7737 8.54 [18 19] [19 50]] [2 55]]] [5693 5.16 [2011 5.13 [429 9.18 [1429 22.2 [4 80] [12 42]] [6735 5.35 [2 42] [2 44]]] [2 80]] [1899 7.2 [2 27] [7 40]]]] [24 100]] [7665 8.91 [2 61] [2 100]]] [6 100]] [2 62]] [6 100]] [7703 2.3 [12 41] [12 100]]] [4 57]] [23 81]] [1 100]]] [1036 2.13 [1 29] [35 80]]] [3028 3.03 [12 66] [12 100]]] [27 93]] [2628 8.64 [23 7.63 [2 64] [4 70]] [4 70]]] [23 100]] [2752 5.17 [17 33] [5413 3.46 [5 42] [4 50]]]] [6363 0.8 [4312 7.34 [4286 0.78 [5345 2.05 [5693 7.06 [5692 0.209 [826 0.412 [1987 2.99 [1888 1.39 [5211 0.249 [4517 6.97 [23 69] [21 50]] [978 1.35 [23 83] [7185 4.43 [2088 5.5 [23 100] [23 85]] [23 88]]]] [5 33]] [23 57]] [791 16 [4122 0.914 [23 100] [23 80]] [23 100]]] [924 0.634 [2764 3.93 [23 100] [5480 0.537 [435 7.88 [23 100] [23 90]] [23 100]]] [23 87]]] [4 37]] [23 50]] [27 57]] [10 50]] [12 57]]] [2232 0.405 [4324 5.31 [1062 1.47 [2 49] [2 78]] [2 94]] [1 57]]]] [24 92]] [5967 1.23 [5860 0.41 [7305 0.486 [3576 4.11 [5420 1.93 [6671 1.07 [4716 1.17 [7491 15.9 [4007 0.901 [873 0.528 [6310 0.467 [2488 15.4 [939 4.6 [663 1.32 [978 8.36 [2526 22.8 [34 37] [8 62]] [8 65]] [0 75]] [8 100]] [6050 1.89 [407 4.5 [3547 1.81 [1906 1.34 [3130 12.4 [5647 21 [7512 9.35 [1980 11.4 [3222 1.78 [2536 1.81 [2562 14.2 [328 18.8 [2550 1.13 [8 90] [8 100]] [0 62]] [0 54]] [8 100]] [8 100]] [8 65]] [13 50]] [38 37]] [0 66]] [8 77]] [8 100]] [1078 3.11 [8 94] [8 100]]] [0 100]]] [35 72]] [0 100]] [34 78]] [8 38]] [5753 2.34 [0 68] [0 95]]] [0 100]] [8 47]] [0 85]] [3988 1.06 [0 86] [0 100]]] [0 100]] [13 100]]] [4353 1.57 [2143 4.74 [5662 6.62 [1919 12.4 [807 3.05 [2574 6.27 [6353 4.02 [4533 1.32 [438 1.29 [6284 0.768 [7461 1.3 [1089 11.6 [3008 53.3 [1062 12.5 [2029 0.577 [2411 9.16 [891 1.25 [4040 7.37 [2793 24.2 [883 3.32 [5675 20.1 [4356 7.38 [6336 8.85 [3638 1.96 [6337 3.33 [6742 11.4 [7210 2.68 [7512 1.2 [24 95] [1602 2.09 [3147 1.2 [6336 1.3 [1919 6.87 [24 99] [24 92]] [24 100]] [24 100]] [24 100]]] [24 93]] [24 80]] [24 83]] [24 100]] [24 71]] [24 80]] [24 88]] [24 100]] [24 62]] [24 80]] [1239 13 [24 84] [24 100]]] [24 86]] [24 62]] [24 73]] [24 81]] [24 60]] [24 55]] [24 98]] [24 50]] [4189 1.99 [24 55] [24 80]]] [24 61]] [24 50]] [23 80]] [24 45]] [24 35]] [23 76]] [24 57]]] [1047 1.24 [5408 1.12 [1382 0.33 [1783 1.55 [4191 2.73 [2617 1.93 [2541 5.77 [2526 28.9 [2259 21.8 [5238 0.47 [660 2.46 [7305 4.34 [7766 1.6 [7667 6.7 [2529 6.57 [2 14] [25 54]] [25 55]] [2 27]] [25 66]] [28 46]] [2 37]] [731 2.44 [6 50] [31 66]]] [2628 2.34 [2763 9.38 [4725 1.23 [1025 3.18 [7665 3.6 [25 17] [6361 3.14 [4414 11.4 [7549 15.9 [6 77] [1429 4.2 [6 85] [16 62]]] [6 97]] [6 100]]] [17 20]] [2558 5.42 [2275 20.2 [6749 1.23 [6 97] [6 100]] [6 85]] [6 83]]] [2 80]] [5412 2.73 [4 20] [6 25]]]] [1239 2.96 [24 71] [24 50]]] [2 66]] [24 100]] [2177 1.23 [5368 0.408 [5833 0.381 [5753 4.26 [4154 1.66 [6920 2.73 [2549 2.76 [6499 8.13 [25 21] [6 100]] [6 100]] [6 87]] [33 24]] [33 47]] [24 93]] [7210 2.74 [33 33] [32 40]]] [6 100]]] [6 90]] [6287 7.39 [6098 13.6 [7505 2.5 [1364 3.25 [6020 0.449 [7406 0.363 [6 91] [6 100]] [6 100]] [5358 3.03 [6423 1.87 [1974 6.71 [7405 2.09 [4820 1.85 [1303 5.14 [6 94] [6 86]] [6 80]] [6 100]] [6 66]] [6 100]] [6 70]]] [6 50]] [6 50]] [1239 43 [6 90] [6 100]]]] [5238 2.03 [5728 1.65 [24 89] [24 100]] [2 60]]]] [3480 3.33 [32 93] [32 100]]] [7588 0.917 [2536 6.02 [6395 1.23 [7133 1.45 [7363 0.782 [2526 5.56 [31 53] [7491 3.03 [2199 3.55 [4851 2.89 [660 1.83 [2526 30.9 [4 70] [4 93]] [4 46]] [4 100]] [4 50]] [31 62]]] [978 2.82 [4 92] [4 100]]] [4 100]] [4 100]] [4 100]] [7512 6.34 [4 88] [4 100]]]]] [4369 17.6 [6342 0.596 [4011 0.785 [6068 0.921 [4369 0.826 [1899 2.73 [15 97] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [15 91]]] [4971 1.85 [4154 3.58 [1025 0.919 [4719 0.684 [7665 1.58 [2562 5.1 [92 6.61 [1391 0.632 [5829 0.938 [2752 0.247 [11 32] [906 2.06 [5826 0.202 [1101 7.44 [6566 0.935 [6661 3.44 [4533 4.37 [5873 4.13 [5692 9.51 [5143 1.36 [2259 23.2 [429 7.42 [11 39] [1995 1.67 [11 64] [11 84]]] [8 40]] [11 100]] [11 80]] [11 62]] [8 37]] [11 100]] [1104 0.96 [2023 0.978 [5110 1.19 [11 96] [11 100]] [11 100]] [11 100]]] [10 50]] [2251 0.172 [7169 8.33 [11 100] [11 57]] [11 100]]] [5826 0.732 [579 3.08 [5223 1.36 [11 94] [11 100]] [11 100]] [11 100]]]] [11 100]] [0 47]] [30 100]] [0 100]] [7255 16 [8 18] [19 71]]] [2259 41.5 [10 42] [8 50]]] [3527 0.197 [567 5.26 [4665 0.78 [2081 2.28 [872 0.858 [5851 2.1 [2764 0.615 [1986 1.91 [11 64] [11 80]] [11 95]] [11 60]] [11 100]] [6663 0.684 [7441 0.324 [2199 4.78 [6290 0.0441 [1980 3.9 [11 100] [11 70]] [11 100]] [11 53]] [11 100]] [11 100]]] [11 100]] [11 75]] [11 62]]] [2701 5.45 [5211 5 [2 25] [11 63]] [29 100]]] [30 97]]] [5812 1.95 [5978 0.671 [5264 0.385 [5972 1.33 [2470 1.49 [5647 0.412 [2354 0.198 [7381 0.78 [3295 1.13 [5539 2.01 [7340 2.91 [6669 0.116 [4011 0.396 [865 1.04 [3921 2.01 [6859 1.44 [4500 0.654 [5472 1.97 [5092 1.14 [2385 0.57 [6547 2.28 [700 0.438 [2705 0.485 [714 0.202 [7734 1.38 [867 1.15 [3262 1.23 [1078 17.7 [712 0.341 [719 0.718 [6148 7.72 [1239 44.9 [5110 3.26 [5732 2.78 [6417 0.889 [2842 4.76 [7367 0.496 [6153 1.51 [5049 1.04 [7665 4.12 [1664 0.29 [1400 15.6 [221 2.65 [2817 2.51 [3928 5.19 [6471 4.84 [836 1.81 [877 1.13 [1888 3.95 [7176 7.78 [2752 6.49 [362 2.29 [5234 6.17 [4205 7.52 [6914 0.726 [2913 19.7 [1239 20.8 [3273 1.27 [4414 22.6 [7665 1.03 [5040 1.55 [22 12] [21 85]] [19 31]] [21 58]] [11 55]] [21 32]] [3 33]] [2 47]] [28 66]] [11 100]] [33 42]] [978 3.32 [1391 2.93 [2760 4.2 [6530 2.66 [5267 10.5 [560 5.26 [7149 8.24 [418 2.54 [5968 0.599 [6340 7.03 [28 20] [28 100]] [28 85]] [1078 3.27 [28 81] [28 83]]] [2752 31.7 [14 66] [14 88]]] [22 62]] [32 63]] [119 1.46 [22 88] [22 100]]] [5 25]] [22 90]] [5 19]]] [1899 11.4 [22 65] [22 92]]] [5588 3.03 [5605 10.6 [985 1.81 [6015 4.24 [14 30] [14 50]] [2 30]] [4 35]] [7 57]]] [22 100]] [37 100]] [4414 0.661 [4684 1.08 [26 85] [26 100]] [26 100]]] [3602 4.19 [3488 0.671 [12 27] [5 41]] [12 90]]] [22 94]] [1453 0.659 [1025 5.3 [5463 3.22 [2259 15 [5480 6.6 [404 2.01 [968 2.6 [28 46] [28 93]] [28 100]] [22 60]] [28 24]] [2 50]] [19 27]] [11 38]]] [6187 1.31 [10 33] [10 100]]] [4154 0.539 [1653 2.04 [17 40] [17 55]] [4630 13.1 [5753 1.41 [17 37] [17 42]] [32 57]]]] [1752 4.85 [5403 2.67 [6549 3.41 [929 3.41 [5316 9.78 [723 11.6 [736 1.48 [4851 3.8 [5198 2.86 [731 2.73 [4369 10.7 [4478 5.88 [7149 7 [7251 3.76 [2526 4.29 [7665 32 [710 1 [6134 2.76 [814 7.82 [695 3.69 [4 50] [14 61]] [36 71]] [14 42]] [14 96]] [14 37]] [896 10.3 [5692 4.35 [16 17] [4 28]] [17 50]]] [14 92]] [14 73]] [14 100]] [32 42]] [4 17]] [36 27]] [144 4.95 [14 23] [18 37]]] [17 34]] [4 88]] [32 55]] [5 53]] [17 50]] [31 100]] [14 33]]] [21 80]] [2259 7.89 [3604 11.2 [28 87] [28 100]] [28 71]]] [26 88]] [3298 14.3 [37 50] [37 100]]] [29 78]] [6791 2.39 [429 29 [2939 0.406 [7149 3.76 [4768 1.5 [28 72] [28 100]] [16 43]] [14 53]] [28 87]] [1899 0.555 [28 92] [28 100]]]] [711 1.01 [22 33] [22 82]]] [6267 2.18 [6260 8.25 [699 3.72 [915 2.26 [4851 3.48 [802 0.463 [21 16] [9 100]] [21 100]] [21 81]] [9 71]] [9 92]] [9 100]]] [9 93]] [4157 0.51 [5322 1.15 [5130 3.73 [5403 1.31 [7132 10.4 [721 2.16 [731 2.41 [5071 0.719 [107 1.71 [4703 1.5 [2466 8.93 [7585 28 [6042 2.12 [5412 12.7 [7588 8.01 [7354 3.97 [3554 3.82 [5170 3.98 [4235 3.31 [7693 11.6 [14 17] [18 25]] [2 29]] [33 80]] [19 43]] [18 50]] [4 43]] [31 50]] [18 87]] [14 66]] [18 71]] [33 97]] [7512 18.6 [33 90] [33 70]]] [33 100]] [7472 4.04 [560 1.4 [4927 5.99 [4083 2.95 [3675 0.763 [2752 19 [17 27] [4851 10.1 [719 10.4 [5 55] [5 26]] [7 57]]] [5 50]] [1078 3.27 [23 18.3 [5 89] [5 42]] [5 100]]] [18 71]] [18 84]] [19 42]]] [14 68]] [4 100]] [31 88]] [5692 7.18 [18 63] [18 37]]] [33 61]] [33 100]]] [6184 1.2 [22 52] [22 93]]] [2993 0.677 [221 1.82 [1400 1.51 [5405 3.4 [631 7.35 [5843 1.61 [4369 9.46 [1640 1.81 [2826 0.858 [1584 3.26 [6491 2.92 [4920 0.686 [144 5.79 [17 1.93 [7241 1.89 [404 3.18 [3928 1.03 [5034 1.87 [6054 4.55 [5897 1.39 [6732 0.73 [5211 2.19 [7354 5.66 [434 1.18 [6653 0.192 [5851 4.51 [2701 2.3 [5270 2.39 [28 26] [36 50]] [29 100]] [7210 2.05 [29 50] [2 22]]] [28 44]] [28 33]] [36 33]] [22 81]] [22 49]] [35 46]] [22 100]] [702 1.69 [28 58] [14 83]]] [3929 20.7 [37 37] [12 75]]] [28 84]] [22 56]] [2 41]] [6732 4.53 [22 45] [22 81]]] [22 100]] [28 90]] [28 95]] [2902 0.429 [14 22] [5 50]]] [22 100]] [13 60]] [22 76]] [28 93]] [31 100]] [711 0.935 [5845 0.664 [10 59] [10 100]] [10 100]]] [730 0.911 [6301 0.855 [28 38] [28 100]] [28 100]]] [10 75]]] [3701 8.27 [37 97] [37 90]]] [6710 2.61 [1094 1.39 [392 1.17 [5706 0.978 [5281 1.7 [1911 2.88 [7176 2.74 [14 30] [22 98]] [22 100]] [22 100]] [22 100]] [28 50]] [28 54]] [28 100]]] [4627 1.54 [2753 10.3 [4926 5.36 [6970 3.35 [6831 0.942 [279 7.58 [5851 4.46 [4859 5.84 [2628 2.1 [284 7.81 [2526 10.3 [7203 0.99 [18 55] [18 40]] [7354 2.06 [18 58] [719 6.58 [16 85] [7 33]]]] [19 76]] [5 29]] [18 78]] [18 70]] [791 1.62 [18 79] [16 40]]] [18 78]] [7 33]] [18 87]] [23 22.6 [5 88] [5 85]]] [5 54]]] [22 100]] [29 100]] [1101 0.921 [7176 0.707 [1899 1.55 [22 98] [22 100]] [22 100]] [22 100]]] [14 100]] [145 3.16 [4509 1.31 [7188 6.72 [5007 5.59 [2628 5.29 [429 31.2 [6732 2.32 [791 0.57 [19 37] [23 6.86 [18 76] [18 40]]] [896 5.49 [18 62] [18 100]]] [28 54]] [16 70]] [19 60]] [18 80]] [2466 1.31 [18 47] [19 71]]] [19 82]]] [5692 4.03 [6711 0.485 [1755 0.68 [695 22.7 [22 94] [22 50]] [22 100]] [22 100]] [6456 0.282 [4533 1.29 [22 72] [22 100]] [22 100]]]] [2488 1.01 [3068 1.81 [4030 1.3 [6077 2.39 [4895 9.19 [1078 1.59 [1400 2.62 [23 45.5 [36 48] [13 66]] [36 92]] [1602 1.59 [5753 6.29 [4279 4.88 [1078 6.63 [36 80] [36 50]] [28 45]] [36 83]] [36 100]]] [13 87]] [13 100]] [36 100]] [36 100]] [5637 1.59 [7698 1.21 [13 98] [13 100]] [13 100]]]] [5969 0.521 [2849 0.835 [4889 5.05 [2143 4.83 [29 100] [2704 1.43 [29 85] [29 100]]] [29 85]] [29 100]] [29 100]]] [4851 0.383 [968 1.2 [6896 0.701 [2268 0.326 [859 0.438 [1169 2.65 [2811 1.8 [163 2.51 [877 2.01 [731 0.803 [2311 1.01 [1391 1.53 [3644 1.59 [794 2.06 [221 4 [36 67] [24 45]] [28 90]] [36 100]] [22 100]] [36 100]] [19 38]] [22 100]] [28 85]] [36 86]] [36 100]] [22 100]] [28 58]] [22 100]] [1078 12.4 [28 64] [28 100]]] [2199 2.58 [7085 1.66 [28 80] [28 100]] [28 71]]]] [3159 3.3 [37 94] [37 83]]] [23 11.4 [13 50] [13 100]]] [3264 1.96 [3779 1.02 [3292 1.55 [5211 0.829 [1062 0.313 [7009 0.942 [5289 1.02 [6230 4.36 [28 77] [28 42]] [28 100]] [28 85]] [28 100]] [22 44]] [37 77]] [37 94]] [37 62]]] [6853 3.14 [596 2.54 [28 96] [28 100]] [1445 0.445 [6919 0.652 [4781 1.55 [28 36] [1239 1.44 [28 83] [28 100]]] [28 100]] [28 100]]]] [2624 5.78 [1078 32.5 [383 3.12 [7354 4.65 [6230 6.37 [2232 2.36 [32 77] [32 33]] [721 1.14 [32 93] [32 100]]] [18 36]] [18 76]] [1429 26.4 [22 46] [32 66]]] [12 100]]] [4768 25.9 [5543 1.17 [7085 2.17 [1870 1.1 [84 1.04 [6524 1.4 [13 75] [22 50]] [13 100]] [13 100]] [13 46]] [13 100]] [13 71]]] [1899 9.43 [906 2.7 [37 98] [37 100]] [37 75]]] [1240 2.53 [1669 1.99 [2617 1.36 [312 0.886 [1025 10 [721 1.25 [731 0.592 [899 1.62 [6550 4.22 [3732 2.8 [7548 3.45 [328 12.1 [6530 12.1 [1429 26.9 [4 19] [5 33]] [7 100]] [14 66]] [14 100]] [17 48]] [5 67]] [14 73]] [5389 0.945 [5155 3.6 [5953 4.24 [6230 3.88 [3732 1.89 [5 25] [17 88]] [5 51]] [17 100]] [896 10.1 [7381 10.1 [5 100] [5 80]] [5 72]]] [38 61]]] [14 88]] [2 34]] [2526 12.7 [1078 20.3 [4 90] [26 30]] [2 47]]] [4 100]] [7 100]] [227 5.32 [24 97] [24 88]]]] [22 100]] [2828 0.493 [4011 0.282 [7512 7.42 [5211 1.78 [4159 6.05 [4614 0.537 [3292 2.65 [5668 0.342 [906 3.42 [6853 2.2 [392 4.87 [6015 2.85 [4279 0.431 [18 18] [11 33]] [28 45]] [28 55]] [28 100]] [29 27]] [6525 0.634 [576 0.382 [5970 0.649 [6364 0.84 [6524 0.816 [28 58] [5766 0.816 [28 76] [28 100]]] [28 83]] [29 100]] [29 70]] [28 100]]] [37 100]] [29 100]] [29 84]] [859 0.132 [5345 0.835 [560 1.92 [2526 4.78 [1899 17.7 [7181 1.02 [2232 2.79 [5883 19.4 [1742 1.44 [809 0.808 [22 93] [22 100]] [22 100]] [22 66]] [22 87]] [22 100]] [22 66]] [23 72]] [22 100]] [22 100]] [22 100]]] [1888 8.77 [7734 2.23 [5400 1.39 [1980 3.91 [1769 7.59 [13 22] [14 50]] [5664 3.27 [1089 0.316 [7512 20.8 [29 26] [13 40]] [22 90]] [29 75]]] [13 100]] [5647 7.18 [18 40] [1919 0.728 [18 60] [18 75]]]] [5753 0.666 [2628 8.42 [18 59] [7 50]] [31 35]]]] [28 73]] [28 100]]] [758 0.556 [639 1.01 [3459 0.456 [6983 2.21 [7512 1.45 [4790 0.453 [6310 1.31 [5270 3.87 [4235 17.6 [6532 0.812 [6191 1.97 [5730 0.509 [3095 0.678 [2753 4.39 [5211 0.89 [2068 0.321 [7480 2.57 [4929 0.709 [1906 3.18 [3747 0.566 [5267 1.1 [5732 9.02 [6333 4.61 [15 32] [11 66]] [15 100]] [4 16]] [11 100]] [3 58]] [4 30]] [15 100]] [2072 1.59 [24 55] [24 36]]] [11 73]] [29 87]] [12 37]] [11 100]] [11 100]] [11 100]] [26 100]] [31 91]] [11 87]] [30 37]] [5267 3.13 [929 11.6 [6970 0.524 [7009 0.956 [4721 0.795 [4967 7.25 [1764 1.93 [7187 2.49 [7512 7.61 [4 48] [2939 13.5 [4 65] [4 33]]] [4 100]] [4 57]] [31 100]] [4 100]] [4 41]] [4 61]] [31 72]] [31 72]]] [5851 4.68 [7365 4.75 [4253 0.448 [663 9.12 [23 0.489 [985 1.18 [4 68] [4 100]] [4 88]] [4 62]] [4 100]] [4 63]] [31 62]]] [15 100]] [4 100]] [11 95]]] [7742 3.34 [6077 2.65 [248 1.91 [1544 1.12 [3191 0.867 [2784 0.843 [731 4.48 [7449 6.52 [6542 0.431 [6544 0.963 [699 0.73 [3458 0.908 [2260 0.818 [2902 0.543 [7176 0.324 [4398 2.85 [7657 1.4 [2939 0.821 [4424 5.06 [5980 1.3 [3685 2.04 [7374 0.428 [3335 3.76 [6363 0.358 [3698 3.08 [1776 1.54 [5110 18.5 [7731 1.21 [7434 2.35 [907 1.37 [4677 1.47 [5472 1.02 [874 1.85 [36 55] [36 77]] [811 0.609 [814 1.99 [2259 3 [5972 17.1 [36 100] [36 71]] [36 100]] [36 100]] [36 100]]] [36 100]] [916 1.86 [9 57] [9 71]]] [12 100]] [4154 1.21 [36 95] [36 100]]] [12 94]] [12 100]] [12 90]] [12 80]] [12 100]] [36 97]] [12 100]] [12 100]] [12 93]] [12 59]] [12 100]] [31 90]] [7176 13.1 [12 79] [12 100]]] [36 82]] [7449 1.51 [168 3.67 [3429 0.813 [5458 1.2 [5345 0.741 [1701 1.82 [5052 0.928 [4045 2.7 [7571 1.07 [5267 8.7 [7373 0.894 [7512 12 [36 100] [7665 15.5 [36 71] [36 100]]] [36 100]] [36 85]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [36 71]] [36 88]]] [1400 9.9 [15 68] [15 92]]] [9 50]] [5972 16.6 [36 100] [36 75]]] [2826 3.9 [12 100] [12 85]]] [5040 4.34 [7241 1.48 [7009 3.31 [2628 1.17 [7456 2.22 [12 28] [12 91]] [12 88]] [12 100]] [12 87]] [21 85]]] [31 85]] [12 100]] [12 100]] [12 100]] [1404 0.617 [2752 13.8 [33 55] [15 100]] [15 100]]] [31 100]] [7746 1.33 [31 87] [31 100]]]] [13 100]] [31 100]] [6081 0.808 [144 6.26 [5460 4.21 [321 1.69 [719 0.937 [5813 1.87 [2701 0.441 [1723 2.07 [2673 0.419 [2259 5.3 [567 8.02 [5696 0.319 [1400 0.885 [3929 1.04 [1535 1.87 [7512 24.4 [2826 2.7 [5812 20.9 [4 37] [4 17]] [5 48]] [13 72]] [5 61]] [12 50]] [4 33]] [2 75]] [13 57]] [1190 0.546 [731 2.55 [6184 2.04 [2818 0.805 [7335 4 [978 1.6 [12 35] [4 23]] [12 55]] [12 100]] [12 80]] [4 66]] [4 92]]] [4 100]] [4 71]] [12 67]] [4414 3.72 [28 84] [1429 6.52 [28 50] [28 100]]]] [2616 2.92 [2417 1.17 [7571 4.1 [6555 0.545 [6539 0.697 [2742 1.21 [6077 0.986 [7734 3.49 [2488 3.88 [4160 1.8 [6310 3.02 [3732 1.39 [2470 0.502 [6342 5.45 [4 23] [14 68]] [4 90]] [17 83]] [5 88]] [17 42]] [13 100]] [17 29]] [1059 5.94 [2478 6.47 [7449 12.5 [7381 17.1 [5007 8.57 [7512 32.8 [2 42] [695 34.3 [4 66] [2 40]]] [4 66]] [4 93]] [4 61]] [4 85]] [2 100]]] [4 100]] [2 100]] [5 44]] [6544 5.33 [31 85] [31 100]]] [4 100]] [1059 4.34 [4601 5.7 [3667 7.42 [7568 5.69 [2526 10.2 [4 30] [178 0.745 [2556 0.571 [573 15.8 [3027 11.1 [4 65] [731 1.27 [4 90] [4 100]]] [4 37]] [4 100]] [4 96]]] [4 55]] [2 76]] [2 81]] [2 86]]]] [31 100]] [2 93]] [7414 1.08 [5820 0.525 [7665 2.79 [28 42] [4992 8.13 [2 31] [2 100]]] [7665 22.9 [719 5.21 [1980 5.12 [2 90] [2 53]] [2763 3.4 [2 98] [2 81]]] [2 50]]] [2 97]]] [13 100]]]] [3665 3.53 [999 0.428 [7665 15.3 [3636 7.22 [4943 3.95 [6260 3.24 [4214 5.92 [6846 2.85 [4046 2.82 [14 3.11 [3652 7.44 [4324 0.808 [2516 3.04 [7665 5.79 [24 100] [24 95]] [24 80]] [24 100]] [3424 2.92 [2517 19 [655 1.32 [2264 7.63 [1899 4.78 [1011 1.05 [2526 16.3 [24 90] [24 100]] [24 100]] [1919 2.92 [24 88] [24 71]]] [24 52]] [4340 1.29 [24 94] [24 100]]] [24 70]] [24 75]]] [36 100]] [19 66]] [24 57]] [24 100]] [1587 0.78 [2265 11 [7381 4.46 [3637 3.09 [1888 12.7 [4338 2.33 [24 62] [2259 30.5 [24 61] [24 94]]] [24 90]] [24 60]] [24 100]] [19 100]] [36 40]]] [24 68]] [24 73]] [695 13.5 [3661 1.66 [3642 1.99 [24 95] [24 92]] [24 100]] [36 66]]] [24 61]] [24 50]]] [3079 8.44 [4851 10.4 [7461 13.1 [2526 20.9 [896 0.487 [6074 6.37 [5605 6.35 [1783 13 [2259 2.51 [7176 1.31 [5979 2.56 [112 15.3 [874 1.87 [6537 3.76 [3093 1.16 [6216 3.82 [7009 7.58 [12 87] [12 85]] [12 100]] [12 100]] [12 100]] [12 100]] [12 57]] [12 100]] [12 100]] [291 0.935 [1913 5.14 [4279 6.11 [328 8.35 [6232 0.637 [2270 4.46 [5412 3.53 [2628 0.27 [1511 0.745 [7456 2.01 [7188 2.62 [429 21.7 [12 100] [12 85]] [12 100]] [12 100]] [12 100]] [12 100]] [12 85]] [12 75]] [12 100]] [12 100]] [12 60]] [12 87]] [12 85]]] [12 37]] [12 63]] [4 28]] [32 50]] [4 44]] [12 75]] [4 55]] [37 100]]] [1068 0.177 [1452 0.489 [883 1.14 [1753 1.03 [716 0.879 [122 3.45 [1108 1.93 [5217 0.978 [5673 0.486 [7101 2.01 [695 0.618 [7623 1.54 [5647 8.51 [663 11.2 [7315 1.51 [5851 7.52 [791 26.5 [6375 6.49 [2470 45.8 [5410 2.33 [1913 2.79 [2470 8.31 [4210 3.83 [4851 1.03 [1716 1.33 [4517 0.792 [30 81] [30 90]] [30 100]] [30 96]] [30 98]] [30 100]] [29 37]] [30 50]] [30 71]] [30 53]] [23 4.85 [30 62] [30 50]]] [30 60]] [30 100]] [22 50]] [22 46]] [30 97]] [6232 3.13 [112 1.1 [791 8.23 [30 75] [22 71]] [22 78]] [22 74]]] [22 76]] [6203 1.04 [5443 2.61 [4061 0.566 [30 97] [30 100]] [30 100]] [30 100]]] [22 100]] [22 100]] [22 100]] [22 66]] [22 80]] [22 89]] [5211 6.48 [30 42] [22 100]]] [22 74]]] [4176 4.28 [7768 0.682 [7455 0.185 [392 1.17 [5843 0.843 [5310 0.726 [5970 3.87 [811 19.9 [859 0.703 [7731 4.75 [3616 1.9 [6074 0.935 [5563 2.13 [3008 10 [2004 1.91 [4584 5.44 [5393 6.52 [3584 1.21 [811 8.89 [7657 0.599 [435 5.16 [7512 16.1 [6613 3.11 [2698 1.2 [7176 0.921 [1 8.19 [5467 38.5 [4420 1.98 [5926 6.38 [12 96] [12 100]] [12 100]] [12 50]] [12 62]] [12 100]] [12 100]] [12 62]] [12 50]] [12 75]] [12 100]] [12 91]] [12 100]] [12 66]] [12 68]] [12 66]] [12 57]] [12 83]] [12 50]] [12 75]] [12 76]] [10 100]] [12 54]] [10 46]] [10 100]] [10 100]] [2752 14.9 [10 63] [12 75]]] [12 100]] [10 100]] [10 87]]] [7512 3.67 [5211 1.06 [5412 0.561 [4851 0.678 [2897 0.861 [6708 0.659 [386 0.281 [4005 0.154 [1993 0.484 [2815 0.545 [6271 7.11 [398 0.325 [4769 0.395 [6524 2.76 [2698 1.27 [6457 0.52 [7734 0.585 [383 0.431 [1696 2.02 [5366 2.86 [5170 17.9 [3450 0.613 [730 1.06 [384 1.18 [2913 22.9 [3008 25.2 [6260 1.82 [2748 1.69 [6230 2.7 [6446 1.24 [3311 2.65 [2521 2.24 [1233 6.43 [2828 0.703 [3033 2.56 [2461 1.04 [5454 1.96 [4927 1.46 [7623 2.21 [4944 2.01 [2701 1.79 [3944 0.683 [5105 3.55 [1700 5.01 [4420 6.33 [5462 0.576 [631 2.77 [1672 8.24 [2764 0.647 [5632 2.91 [4690 4.35 [4279 5.85 [4768 3.33 [4279 3.13 [1062 26.9 [2707 3.76 [1752 6.85 [5482 4.06 [404 3.4 [7352 1.23 [2913 10 [1463 2.35 [6959 6.49 [6375 8.52 [6715 11.3 [7032 1.71 [28 23] [23 77]] [22 100]] [30 38]] [4 33]] [8 90]] [30 87]] [35 87]] [28 70]] [29 50]] [28 88]] [26 77]] [8 75]] [27 57]] [29 42]] [6732 0.928 [23 45] [28 83]]] [8 88]] [1429 14.9 [26 100] [7 38]]] [11 32]] [22 100]] [28 100]] [2199 1.23 [28 47] [35 50]]] [12 100]] [25 100]] [28 100]] [4093 2.52 [35 82] [35 44]]] [29 95]] [28 88]] [7623 28.6 [12 80] [35 50]]] [18 71]] [29 55]] [27 90]] [23 100]] [28 91]] [23 100]] [23 41]] [23 100]] [29 100]] [14 40]] [26 88]] [8 77]] [35 51]] [978 4.45 [26 65] [26 76]]] [7343 1.08 [2550 2.59 [2813 1.46 [2488 3.26 [2268 1.54 [23 39] [6 37]] [384 31.1 [8 97] [8 80]]] [18 88]] [8 100]] [23 55]]] [28 84]] [4409 12.3 [35 81] [35 71]]] [26 95]] [1783 3.14 [23 100] [23 87]]] [1696 16.3 [26 60] [26 92]]] [18 26]] [377 5.17 [7203 1.03 [282 1.46 [7057 0.861 [1429 0.967 [18 42] [18 75]] [18 50]] [18 88]] [16 55]] [18 64]]] [25 100]] [12 91]] [5692 3.97 [6997 6.76 [28 50] [28 100]] [28 87]]] [29 100]] [7204 1.3 [695 0.649 [1957 0.286 [5075 1.95 [5034 0.921 [1099 1.01 [7449 3.44 [6490 1.68 [2023 1.49 [23 41] [29 33]] [23 100]] [978 11.5 [23 60] [23 100]]] [29 50]] [28 57]] [29 100]] [35 81]] [1899 5.86 [28 53] [28 100]]] [23 100]]] [1216 1.56 [27 86] [27 100]]] [23 100]] [4858 0.32 [2241 0.782 [23 79] [23 100]] [23 100]]] [4235 59.4 [1708 5.72 [28 88] [4395 0.505 [28 95] [28 100]]] [28 62]]] [23 100]] [7329 3.03 [1084 2.09 [6363 4.97 [1078 1.2 [28 67] [6724 2.63 [5462 6.96 [1239 10.5 [28 89] [28 57]] [28 100]] [28 33]]] [7 28]] [685 7.46 [28 100] [28 91]]] [28 57]]] [6406 4.47 [435 2.41 [5034 1.17 [5769 3.83 [906 6.64 [5322 3.26 [7494 0.578 [2108 0.546 [2753 2.44 [2241 5.54 [398 0.327 [1429 23.4 [23 31] [28 76]] [35 38]] [29 42]] [28 33]] [28 50]] [28 50]] [28 90]] [29 88]] [28 100]] [28 96]] [29 35]] [29 40]]] [6230 3.68 [6333 3.75 [103 1.36 [248 1.22 [1429 33.6 [429 9.76 [6 16] [28 81]] [2787 0.43 [4611 1.77 [28 93] [28 57]] [28 100]]] [26 84]] [28 100]] [28 55]] [7 28]]] [2526 0.847 [2053 0.139 [2939 9.84 [328 22.2 [4838 0.236 [2131 0.519 [7085 10 [5753 0.155 [7329 0.849 [28 46] [28 61]] [5509 6.73 [384 1.73 [6732 7.94 [5856 1.08 [201 0.531 [685 27.2 [7176 0.337 [5937 3 [3308 1.2 [806 1.39 [4611 0.0889 [4583 0.439 [5110 2.91 [6644 0.34 [6529 5.56 [5673 1.78 [3344 7.34 [7343 3.12 [5967 0.161 [4991 2.19 [5007 0.126 [6199 5.31 [1078 7.57 [28 93] [28 100]] [28 71]] [28 100]] [28 91]] [28 100]] [28 81]] [28 83]] [1899 0.662 [28 69] [28 100]]] [28 81]] [28 100]] [28 66]] [28 83]] [6342 0.183 [5706 0.245 [1783 7.28 [5967 0.257 [28 95] [28 100]] [28 80]] [28 100]] [28 100]]] [28 50]] [28 62]] [28 57]] [35 40]] [28 64]] [28 71]] [28 55]] [28 65]] [23 60]] [28 66]]] [15 30]] [28 46]] [31 42]] [28 48]] [29 30]] [8 40]] [6592 0.733 [981 0.227 [1783 0.164 [23 29] [28 37]] [23 100]] [18 83]]]] [1215 2.4 [2837 0.174 [5803 1.81 [5824 1.86 [1 0.913 [6711 0.435 [23 5.42 [6531 0.353 [5122 0.978 [2550 0.873 [1078 1.76 [2764 1.55 [2081 0.61 [23 32] [23 70]] [23 93]] [1429 33.6 [5651 0.139 [5692 11.9 [5110 4.58 [7176 1.8 [1218 15.8 [3308 1.02 [429 7.14 [23 46] [6732 6.42 [5412 0.31 [5509 0.664 [5462 1.21 [1445 1.68 [394 8.6 [387 0.4 [23 97] [23 100]] [23 85]] [23 77]] [23 71]] [23 100]] [7061 0.272 [7305 2.44 [2259 5.09 [7491 0.251 [4350 0.713 [906 1.31 [23 100] [23 85]] [23 100]] [23 100]] [23 100]] [23 85]] [23 100]]] [23 87]]] [23 85]] [23 71]] [35 52]] [22 50]] [23 42]] [23 100]] [2628 0.536 [23 36] [30 50]]]] [8 100]] [30 100]] [22 79]] [30 50]] [435 0.2 [4205 0.87 [30 54] [22 75]] [22 100]]] [939 0.657 [30 39] [11 44]]] [11 65]] [1995 2.21 [7176 3.05 [23 37] [22 100]] [22 100]]] [22 91]] [22 94]]] [388 0.652 [2385 0.448 [384 0.371 [2759 7.41 [1163 3.18 [5034 5.79 [7038 14.2 [6719 4.01 [5484 4.35 [7723 0.432 [286 3.03 [2809 2.26 [968 1.83 [3423 2.54 [6909 8.52 [7665 9.2 [1391 3.12 [6184 0.913 [6027 1.28 [906 3.86 [1661 1.46 [5007 3.61 [695 2.69 [7601 6.76 [6959 1.63 [1094 1.47 [4946 3.37 [380 1.18 [6040 3.6 [7255 2.49 [145 0.472 [377 9.43 [4478 1.74 [7176 5.62 [397 1 [18 29] [18 90]] [7 78]] [7 44]] [7 28]] [35 28]] [18 40]] [7665 6.81 [18 72] [16 62]]] [18 70]] [18 76]] [23 54]] [18 75]] [16 53]] [392 7.74 [7 24] [1899 1.54 [18 32] [18 36]]]] [18 44]] [18 87]] [28 27]] [19 33]] [4253 0.304 [10 16] [25 42]]] [22 100]] [1980 9.26 [18 19] [896 2.37 [7 30] [25 44]]]] [30 73]] [7 100]] [28 71]] [18 81]] [2846 1.89 [7512 5.72 [28 66] [23 53]] [28 55]]] [7566 3.27 [738 0.432 [6152 3.11 [532 3.98 [5692 4.41 [2445 3.4 [18 58] [16 33]] [30 55]] [26 55]] [19 100]] [18 100]] [18 85]]] [5693 3.82 [383 9.12 [5516 2.42 [6091 8.28 [5484 33.4 [6353 4.49 [18 78] [18 50]] [18 61]] [18 44]] [18 60]] [5345 4.35 [18 54] [16 50]]] [18 63]]] [547 1.96 [18 86] [18 75]]] [6 100]] [2259 5.86 [14 85] [14 65]]] [10 100]] [22 41]] [996 0.51 [5349 1.79 [7522 0.544 [7381 2.79 [5509 9.2 [4926 0.37 [5413 2.42 [6230 7.19 [5749 0.448 [4859 1.64 [1991 0.224 [673 5.09 [5211 1.17 [279 2.18 [5717 2.51 [1239 21.5 [2470 2.96 [2897 1.98 [6883 1.14 [6354 0.768 [4414 4.13 [6711 3.45 [397 4.16 [18 25] [18 90]] [18 75]] [18 81]] [18 100]] [23 66]] [6 25]] [26 66]] [6 80]] [1701 3.14 [6 80] [6 100]]] [18 77]] [7734 2.89 [23 76] [23 55]]] [1429 29.4 [26 83] [18 62]]] [23 100]] [5154 6.85 [7340 2.56 [18 78] [18 50]] [16 37]]] [23 100]] [1429 56.1 [7 40] [7 85]]] [19 36]] [6043 4.03 [4927 12.2 [695 5.15 [18 92] [18 68]] [333 2.25 [18 85] [18 64]]] [6043 7.44 [18 37] [18 100]]]] [26 57]] [7665 8.15 [7 37] [7 70]]] [23 100]] [5439 2.2 [6 71] [6 97]]] [5692 3.01 [23 100] [23 55]]]] [7241 9.37 [3515 2.1 [7373 0.726 [4569 3.07 [4229 0.448 [4507 1.9 [282 6.43 [1429 50.5 [695 17.7 [4504 2.54 [6007 1.03 [7601 3.9 [731 0.612 [978 9.6 [18 95] [18 83]] [18 100]] [18 73]] [18 100]] [18 57]] [7 55]] [18 48]] [5482 11.2 [18 85] [19 41]]] [532 6.84 [1783 1.18 [18 55] [16 61]] [18 44]]] [18 80]] [19 100]] [19 58]] [19 58]] [19 57]]] [6230 6.33 [6711 2.11 [7546 3.24 [18 65] [8 33]] [2342 0.699 [5511 1.01 [18 95] [18 83]] [18 60]]] [18 66]]]]] [2753 0.307 [6970 0.0816 [5513 0.595 [871 0.566 [2521 0.911 [1163 23.1 [10 100] [10 66]] [10 91]] [10 100]] [10 83]] [10 100]] [10 62]]] [7135 0.196 [165 2.53 [2955 1.06 [4538 31.6 [5526 0.657 [131 0.51 [631 0.151 [1820 0.08 [188 7.04 [6136 0.307 [2697 2.2 [7453 1.31 [233 0.339 [6653 0.371 [3435 6.86 [5681 2.3 [4940 7.5 [6850 3.65 [7048 4.81 [3107 4.99 [5170 1.28 [6340 1.92 [5539 3.45 [6961 0.369 [2868 2.86 [859 0.264 [5140 5.74 [2149 2.82 [6031 5.95 [6687 10.9 [1078 15.6 [5972 2.35 [7369 1.31 [4851 11.5 [429 7.59 [6959 11.1 [1239 9.93 [1452 6.47 [2651 4.95 [4738 4.99 [7428 7.73 [3008 24 [5626 9.35 [7231 18 [7255 13 [1722 4.42 [5132 3.27 [5267 3.8 [7314 4.85 [3243 4.82 [1662 5.91 [7474 10.8 [7512 6.3 [7446 0.648 [7347 45.7 [2130 2.4 [6199 30.4 [6406 18.9 [187 6.71 [16 12] [38 32]] [16 47]] [38 62]] [1 50]] [16 80]] [16 42]] [1 23]] [38 90]] [19 75]] [6207 9.9 [37 40] [5 53]]] [32 63]] [28 46]] [18 75]] [33 100]] [1899 3.76 [16 27] [38 66]]] [16 69]] [23 18.4 [16 49] [16 68]]] [30 45]] [16 75]] [16 65]] [14 90]] [25 46]] [6152 3.14 [6098 1.49 [7254 9.02 [2619 3.07 [7428 10.3 [1980 8.02 [1748 2.89 [2667 10.7 [2688 3.5 [2752 2.43 [187 18.4 [5037 2.45 [4235 19.5 [6199 11.5 [4851 4.53 [2436 6.33 [18 15] [6 83]] [2849 31.9 [6 37] [16 40]]] [17 40]] [23 42]] [9 28]] [7 37]] [2241 42 [1239 14.8 [16 22] [13 16]] [15 50]]] [38 83]] [6 70]] [16 71]] [2143 3.57 [33 34] [38 62]]] [38 85]] [6 42]] [33 75]] [6 60]] [18 71]]] [1783 7.04 [16 60] [16 86]]] [968 1.45 [3008 18.5 [7064 4.41 [5480 3.27 [3971 2.53 [5668 2.96 [5812 3.89 [31 1.04 [4851 0.816 [5492 4.78 [5412 8.55 [1981 4.2 [600 8.2 [6184 16 [5211 7.68 [29 16] [22 60]] [8 50]] [31 71]] [1 40]] [18 37]] [14 100]] [18 30]] [5 27]] [573 7.41 [5 71] [1 33]]] [29 41]] [0 50]] [187 1.12 [18 47] [18 83]]] [5 62]] [1885 4.76 [17 48] [26 100]]] [28 73]]] [6941 39.1 [7693 0.735 [1646 3.1 [2861 1.9 [1239 82.8 [2689 1.68 [7759 12.2 [62 14 [193 21.4 [3422 17.7 [7185 0.411 [392 3.15 [429 11.9 [5851 1.47 [5647 22.7 [7281 4.03 [2939 3.36 [16 46] [5753 6.03 [6940 66.5 [5799 4.2 [195 1.12 [6959 5.26 [6 43] [18 40]] [6 62]] [16 27]] [6 54]] [18 60]]] [18 40]] [7 42]] [7 28]] [1429 5.75 [26 37] [16 36]]] [26 40]] [18 42]] [6 54]] [6 33]] [18 29]] [13 77]] [16 84]] [6 94]] [16 26]] [16 36]] [18 60]] [6 81]]] [38 61]] [5467 1.24 [12 91] [12 100]]] [2786 0.728 [5037 1.09 [1239 13.5 [434 5.44 [6446 1.89 [3677 4.84 [5211 8.15 [5462 5.11 [112 3.26 [178 7.73 [29 24] [4 40]] [695 5.74 [144 22.2 [3130 1.92 [5994 1.11 [7255 2.35 [29 34] [29 100]] [29 100]] [11 75]] [29 100]] [28 100]]] [28 36]] [11 46]] [37 62]] [29 100]] [29 80]] [16 21]] [28 75]] [29 100]]] [16 67]] [22 66]] [29 63]] [33 61]] [22 74]] [77 1.4 [23 6.82 [978 10.7 [5480 6.19 [6830 6.13 [6 50] [18 39]] [18 75]] [16 57]] [6207 11.6 [7347 9.71 [392 1.75 [4738 2.02 [16 25] [18 44]] [30 62]] [16 66]] [7149 19.2 [187 20.2 [16 64] [6 41]] [16 42]]]] [19 61]]] [6230 3.24 [5894 1.39 [5637 16.6 [2649 2.6 [6500 5.03 [5901 18.7 [190 11.4 [6409 5.01 [16 69] [16 91]] [16 87]] [18 91]] [16 81]] [6 50]] [6 38]] [18 43]] [18 55]]] [13 96]] [28 100]] [33 47]] [5 68]] [16 44]] [38 94]] [1896 20.8 [5632 23.5 [16 91] [16 80]] [16 77]]] [560 0.503 [6953 1.74 [4351 1.96 [91 2.48 [6355 4.2 [6877 0.129 [5438 2.83 [1900 10.3 [7372 30.5 [2694 2.56 [2752 4.19 [23 48.2 [2696 4.95 [3007 1.41 [6848 1.53 [2526 1.62 [5103 8.48 [5415 5.7 [6207 19.6 [194 40 [4426 17.9 [6199 4.92 [5681 22.6 [6677 2.02 [2862 6.86 [78 9.72 [2667 11.6 [5681 13.9 [2259 31.8 [16 40] [19 28]] [18 23]] [16 63]] [6 52]] [6 58]] [17 55]] [16 44]] [2868 5.26 [2939 7.1 [17 42] [16 30]] [6 58]]] [16 72]] [3 37]] [38 55]] [5102 3.36 [6 33] [6 53]]] [6 35]] [1239 34.6 [2951 2.33 [16 85] [26 60]] [6 50]]] [26 30]] [26 71]] [30 80]] [2849 99.8 [4895 1.2 [4762 11.2 [7149 19.8 [16 42] [38 62]] [18 52]] [16 71]] [94 6.29 [6 20] [6 40]]]] [5345 3.58 [18 42] [16 44]]] [30 45]] [16 100]] [38 46]] [16 56]] [16 53]] [7 100]] [6878 2.73 [429 8.76 [18 36] [18 72]] [18 71]]] [30 77]] [17 75]] [2868 2.19 [4859 3.39 [731 0.952 [18 66] [18 57]] [18 85]] [19 50]]]] [2628 29.7 [37 43] [5 42]]] [4207 0.545 [29 31] [29 100]]] [33 100]] [1913 1.25 [29 57] [29 100]]] [2628 15.3 [30 100] [2694 7.35 [30 100] [30 88]]]] [94 6.29 [7042 4.92 [2897 0.469 [6830 0.991 [29 38] [2713 6.58 [7301 1.83 [195 1.49 [2752 10.6 [2939 24.3 [18 65] [6 30]] [18 50]] [18 66]] [19 72]] [18 100]]] [18 83]] [7042 12.3 [16 40] [6 50]]] [18 88]]] [95 4.99 [2682 0.876 [2650 0.468 [6 75] [5801 3.07 [16 83] [16 60]]] [16 37]] [16 64]]] [7474 0.24 [1980 2.56 [1895 9.04 [2616 2.28 [4977 45.6 [7149 3.29 [2526 0.56 [6 87] [6 40]] [7038 29.7 [6 50] [6 75]]] [16 66]] [6 100]] [6 35]] [6199 2.53 [4939 0.997 [94 10.1 [18 56] [6 55]] [19 42]] [16 62]]] [16 66]]] [28 91]] [7449 1.09 [29 63] [29 100]]] [29 100]] [5148 8.57 [1429 64.6 [2951 7.01 [5958 10.2 [2405 7.74 [38 100] [2638 1.89 [38 100] [38 83]]] [2888 11.1 [38 69] [2884 4.2 [38 80] [38 100]]]] [38 81]] [38 46]] [5147 10 [38 60] [38 87]]]] [4541 0.186 [3920 2.92 [2690 0.476 [4623 7.44 [5985 6.39 [7472 0.0539 [1355 1.3 [5632 1.95 [2259 39.1 [2867 0.264 [5626 1.19 [7765 0.921 [6848 0.454 [7132 16.7 [7124 2.09 [6257 3.38 [3897 0.894 [7232 5.24 [1783 21.1 [2695 0.524 [1364 0.28 [7242 0.581 [5722 8.12 [1896 2.35 [187 27 [4104 0.928 [5673 0.803 [7449 6.07 [429 1.88 [7480 3.72 [1260 4.42 [3107 1.17 [6224 0.465 [5933 2.44 [2955 24.7 [3436 2.08 [2861 2.96 [6941 2 [5873 26.6 [1253 4.16 [2006 3.72 [2939 65.3 [6 27] [2259 7.86 [2732 3.17 [38 53] [38 84]] [16 40]]] [38 72]] [6 87]] [2939 52.8 [38 94] [38 62]]] [6 41]] [16 42]] [38 88]] [2851 2.51 [38 61] [38 100]]] [16 60]] [16 53]] [1429 23.9 [5 85] [5 66]]] [6 90]] [6 70]] [7153 1.5 [6 22] [18 71]]] [5099 8.16 [5 74] [5 50]]] [3006 9.94 [5102 0.24 [6833 0.928 [6974 0.392 [2721 3.34 [5681 10.7 [7348 2.6 [16 30] [17 44]] [1395 1.55 [7041 7.94 [78 7.08 [7255 5.86 [4716 31.2 [187 13.3 [2978 2.73 [16 34] [6 60]] [1239 23.8 [5605 3.7 [16 34] [16 71]] [7 55]]] [16 100]] [6 50]] [5799 6.91 [38 41] [16 86]]] [6 58]] [38 50]]] [38 58]] [18 54]] [18 72]] [5962 0.632 [6 33] [6 63]]] [26 100]]] [5 75]] [5799 6.56 [2858 10.4 [1395 2.82 [6207 2.27 [4768 5.77 [4851 7.77 [1783 0.824 [4937 7.04 [2649 5.26 [38 76] [16 50]] [6 87]] [16 66]] [1981 1.82 [6 55] [6 75]]] [6 77]] [38 72]] [2628 43.9 [32 42] [38 46]]] [6 80]] [5801 10.9 [16 37] [6 57]]]] [5799 0.838 [1981 1.21 [1900 1.09 [5103 1.23 [2890 1.71 [23 37.1 [1239 21.8 [37 19 [1239 4.74 [38 29] [38 54]] [38 85]] [17 40]] [37 33]] [5 66]] [6 33]] [5 31]] [38 60]] [4851 0.994 [190 1.18 [16 50] [16 87]] [18 31]]]] [6 100]] [1239 27.4 [17 22] [16 51]]] [16 72]] [30 89]] [38 50]] [4879 7.87 [7679 0.383 [2679 4.35 [2955 15.7 [16 55] [16 86]] [1888 2.51 [16 51] [18 44]]] [6 40]] [16 66]]] [3470 0.802 [38 47] [5 86]]] [18 65]] [7150 0.664 [16 78] [16 57]]] [7 71]] [2851 3.35 [2666 6.87 [7726 3.45 [6207 16.8 [5673 3.73 [5435 1.07 [38 45] [26 41]] [2081 0.227 [18 41] [18 63]]] [17 36]] [17 50]] [2948 7.15 [4457 0.612 [16 58] [16 93]] [18 50]]] [2199 1.75 [18 29] [18 57]]]] [6355 2.86 [7 32] [7 100]]] [2897 8.49 [1 1.36 [2707 36.3 [6256 4.45 [5723 17.3 [2878 13.5 [4764 0.242 [312 4.01 [190 9.64 [6940 21.3 [3424 3.27 [5898 0.883 [2891 3.96 [2723 3.48 [5627 9.41 [16 60] [16 100]] [6 40]] [26 42]] [6 55]] [16 27]] [18 72]] [4882 3.64 [685 4.38 [7038 3.23 [4738 0.39 [187 16.6 [6941 1.04 [6 41] [6 50]] [2955 23.4 [5724 3.95 [2727 1.1 [16 71] [6940 17.4 [16 100] [16 77]]] [16 66]] [16 37]]] [16 90]] [6 50]] [6 53]] [6 57]]] [6 55]] [6 58]] [6 100]] [6 60]] [18 58]] [2628 45.9 [4426 16.4 [1980 6.29 [190 15.6 [18 68] [6 41]] [3 33]] [16 50]] [5102 1.79 [2628 61.1 [16 57] [5 33]] [6 53]]]] [26 63]] [18 26]]] [649 0.324 [2259 19 [2748 0.498 [3435 0.668 [4457 0.641 [4762 4.81 [7324 1.34 [2619 0.119 [2081 0.383 [16 78] [18 46]] [16 100]] [18 40]] [2951 7.95 [6 58] [16 36]]] [187 31.5 [7762 1.06 [2713 12.9 [4854 4.18 [194 1.14 [5681 7.87 [16 35] [16 58]] [16 69]] [2661 0.514 [5100 11.2 [6717 5.58 [5609 4.43 [7049 5.26 [2660 6.04 [7343 4.08 [28 57] [16 62]] [13 37]] [6199 11 [28 57] [26 83]]] [26 70]] [16 66]] [18 37]] [16 100]]] [26 66]] [26 30]] [16 85]]] [6 23]] [26 62]] [17 80]] [6152 3.31 [5 72] [35 33]]]] [6199 3.75 [5148 3.5 [23 44.6 [4851 4.43 [38 27] [4854 14.9 [6 33] [6 75]]] [2888 6.27 [19 25] [38 82]]] [38 100]] [7210 0.444 [2628 36.1 [38 69] [38 92]] [38 57]]]] [4527 2.09 [305 2.49 [1454 0.611 [2651 4.34 [85 2.44 [6832 6.06 [78 6.09 [276 4.14 [6507 4.08 [4746 8.4 [5901 1.58 [731 5.43 [2897 14.1 [4051 1.87 [1696 1.1 [5454 3.6 [2729 9.67 [6424 0.79 [2993 0.808 [7537 0.673 [6909 1.53 [2717 9.62 [2728 4.19 [4854 7.75 [5007 2.44 [16 61] [16 38]] [2939 37.9 [16 35] [2951 25 [2628 38.2 [6 20] [16 66]] [5099 16.7 [16 42] [16 90]]]]] [38 33]] [16 78]] [13 57]] [16 77]] [16 30]] [16 57]] [16 100]] [16 100]] [26 53]] [6199 5.73 [16 50] [16 57]]] [7 42]] [26 35]] [2870 2.5 [18 40] [13 37]]] [26 50]] [7 55]] [18 55]] [18 36]] [6136 4.62 [18 86] [16 37]]] [18 90]] [14 100]] [18 71]] [30 63]] [1646 4.7 [16 88] [16 84]]]] [5878 13.1 [7763 1.08 [1356 1.01 [7765 8.57 [23 7.04 [23 1.66 [18 61] [18 66]] [6409 1.56 [5873 6.23 [2660 2.42 [1282 1.73 [18 93] [18 77]] [18 100]] [18 61]] [18 100]]] [18 52]] [18 90]] [187 10.6 [7 33] [7 42]]] [7 100]]] [2750 3.91 [2876 1.48 [328 2.3 [2983 4.48 [6409 1.36 [429 0.57 [1895 10.6 [38 71] [1429 28.3 [17 28] [17 50]]] [38 100]] [38 50]] [16 37]] [38 28]] [19 37]] [7472 16.7 [7370 10.4 [2665 6.21 [1997 4.29 [38 100] [76 4.55 [7260 4.43 [38 80] [38 50]] [38 100]]] [38 57]] [38 69]] [38 100]]]] [6257 6.57 [5753 6.04 [6756 9.97 [5626 27.8 [6409 26.8 [7255 7.57 [5334 3.29 [5099 8.92 [1587 6.22 [4854 0.764 [5103 2.52 [328 3.39 [2978 9.67 [1239 24.9 [2640 10.3 [5626 4.3 [6 31] [6 87]] [16 69]] [7 44]] [2081 0.341 [16 44] [16 88]]] [26 40]] [16 55]] [7282 6.47 [4465 3.05 [1783 4.1 [1078 6.5 [16 32] [30 42]] [5681 1.37 [16 71] [16 57]]] [2951 12.8 [6 44] [6 75]]] [23 32.6 [5777 1.77 [5626 25.5 [6 52] [16 80]] [6 90]] [6 92]]]] [2984 3.12 [16 92] [6 30]]] [5985 7.23 [18 62] [190 0.678 [6 44] [5580 5.95 [5102 5.16 [6129 0.409 [7139 0.277 [1078 3.91 [2877 4.91 [5103 3.5 [16 73] [4414 19 [6 64] [4851 4.15 [6 50] [18 42]]]] [18 54]] [16 44]] [6 75]] [190 9.83 [6 100] [5983 41 [6 90] [6 50]]]] [5985 16.4 [1660 1.03 [6 64] [6 100]] [6 84]]] [16 37]]]]] [16 50]] [5435 8.09 [16 67] [6 46]]] [38 52]] [6 74]] [4854 7.23 [16 55] [16 57]]] [16 28]] [248 2.6 [6199 3.23 [2661 15.9 [7 42] [18 54]] [18 87]] [18 100]]]] [7122 16.5 [6409 6.81 [2752 3.74 [2143 2.71 [5007 3.63 [2707 17.6 [6878 13.1 [37 68] [5 36]] [37 37]] [19 57]] [6778 6.05 [5 66] [37 50]]] [5 37]] [5 60]] [16 60]]] [5485 3.98 [2868 10.4 [3477 0.79 [1895 7.1 [5632 0.75 [38 55] [685 2.24 [6941 1.1 [4851 2.02 [2259 13.8 [2469 4.66 [5099 5.47 [7154 6.26 [2671 6.82 [5641 5.42 [2733 4.8 [6008 0.934 [16 77] [16 100]] [16 50]] [16 100]] [3 33]] [16 45]] [16 55]] [16 89]] [16 27]] [5577 1.32 [194 4.03 [23 27.6 [5635 4.09 [7665 1.4 [16 66] [16 87]] [16 46]] [16 22]] [2717 2.09 [16 37] [6 62]]] [6074 0.376 [6 66] [16 37]]]] [7149 0.262 [16 37] [1436 0.272 [6 57] [6 88]]]] [7255 2.19 [16 50] [26 33]]]] [1997 1.91 [16 57] [6 31]]] [1429 22.1 [6 58] [16 31]]] [2689 5.82 [6 31] [3 45]]] [18 100]]] [7449 12.8 [5 81] [37 54]]] [1793 0.231 [4717 1.63 [18 87] [18 100]] [18 81]]]] [3510 1.48 [2650 0.393 [2888 4.78 [2653 0.497 [2869 0.885 [3338 1.67 [60 4.18 [5188 0.943 [1899 11.8 [4685 2.01 [2671 1.94 [1454 3.25 [3980 8.28 [5904 2.46 [5723 4.1 [3928 5.63 [2259 41.2 [4074 1.27 [2643 3.03 [6439 9.14 [5577 2.28 [85 3.14 [4738 5.72 [4717 14.1 [7472 0.153 [1341 0.943 [2951 0.485 [38 25] [6031 4.42 [165 31.9 [7255 6.2 [6758 7.54 [4011 4.42 [7476 0.389 [38 49] [17 60]] [28 55]] [38 100]] [2656 6.79 [38 35] [7255 16.9 [6 41] [16 100]]]] [38 74]] [37 50]]] [38 88]] [1997 4.1 [38 78] [38 58]]] [16 62]] [16 87]] [18 58]] [16 44]] [14 54]] [16 50]] [3776 5.24 [38 62] [5 70]]] [5007 1.65 [38 72] [38 46]]] [37 50]] [16 36]] [19 81]] [5 75]] [5 30]] [18 62]] [17 68]] [38 27]] [23 38.5 [38 96] [38 90]]] [2707 14.4 [16 100] [16 58]]] [4103 5.8 [5 68] [5 66]]] [4854 0.454 [3130 1.17 [2859 1.07 [38 30] [1395 0.645 [37 22] [5 37]]] [17 37]] [1726 7.15 [17 43] [19 62]]]] [4762 0.497 [5724 6.53 [16 51] [16 83]] [18 50]]] [38 79]] [2983 5.78 [16 44] [17 54]]] [5 72]]] [4648 16.8 [193 0.299 [2717 0.196 [248 1.03 [38 96] [38 83]] [38 83]] [38 100]] [38 75]]]] [1726 8.59 [1062 3.49 [5641 6.77 [6449 1.11 [6207 0.778 [4877 1.24 [3308 1.06 [6495 0.38 [1980 12.6 [429 0.0863 [5296 2.65 [4754 3.31 [5555 0.797 [1899 1.04 [1888 3.14 [5891 3.72 [2259 3.18 [14 94] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 100]] [14 97]] [14 100]] [14 90]] [14 100]] [14 100]] [14 95]] [14 92]] [14 96]] [14 76]]] [2259 0.178 [1429 6.1 [3931 13.7 [7731 2.86 [791 1.88 [4120 1.01 [560 1.75 [1166 1.09 [134 5.49 [6945 9.09 [276 3.36 [1239 22.9 [2157 2.7 [6794 28.2 [1170 1.89 [462 5.05 [5110 16.5 [221 4.85 [1123 0.882 [499 2.86 [3843 5.05 [6732 14.8 [2793 10.6 [1078 21.7 [27 65] [906 18.5 [2225 0.217 [7139 15.4 [328 30.6 [429 43.7 [4315 4 [27 91] [27 100]] [2108 2.51 [27 99] [27 100]]] [27 85]] [27 66]] [27 100]] [27 80]]] [2199 14.3 [27 100] [1233 6.02 [1094 2.99 [27 95] [27 100]] [27 100]]]] [28 37]] [27 100]] [27 100]] [27 100]] [10 62]] [30 60]] [27 42]] [27 100]] [27 66]] [27 75]] [27 40]] [18 69]] [10 100]] [16 25]] [961 3.6 [4993 1.47 [1170 1.09 [27 90] [27 100]] [27 100]] [27 100]]] [7693 2.3 [2726 13 [7185 33.1 [18 64] [6 50]] [16 30]] [18 66]]] [27 100]] [6155 1.87 [5482 0.492 [7340 1.56 [892 1.92 [939 1.58 [774 4.59 [731 2.59 [27 32] [18 34]] [27 83]] [1062 0.719 [503 4.76 [1995 9.08 [27 82] [27 100]] [27 72]] [27 92]]] [10 100]] [32 54]] [896 6 [18 50] [18 75]]] [10 100]]] [18 45]] [27 92]] [4645 2.36 [7185 0.99 [3687 1.73 [957 31.4 [384 0.52 [5347 3.5 [7270 1.85 [3085 2.22 [5211 6.03 [2461 2.67 [5131 3.81 [2180 9.49 [5472 0.406 [7665 0.838 [2149 8.65 [3222 4.15 [438 14.3 [5034 1.87 [1078 59.8 [1674 3.07 [1926 2.59 [6230 1.89 [5972 4.5 [4122 8.4 [3837 5.62 [2488 8.78 [6909 4.07 [7222 0.709 [2828 3.45 [774 1.59 [2951 1.29 [7085 16.6 [5157 12.5 [6809 5.52 [5192 0.987 [4876 10.3 [7354 3.5 [7247 2.68 [2752 23.1 [5480 3.7 [695 6.18 [3474 3.11 [286 21 [2232 8.96 [7314 8.83 [32 17] [30 66]] [27 57]] [26 36]] [37 100]] [37 29]] [18 83]] [1062 11.3 [28 36] [37 36]]] [27 100]] [5 40]] [27 30]] [14 44]] [32 100]] [5 75]] [5 50]] [16 50]] [10 92]] [28 100]] [13 62]] [8 28]] [13 52]] [37 100]] [27 91]] [1429 37.7 [12 57] [12 100]]] [731 5.41 [1783 1.98 [5 19] [5 33]] [5 41]]] [10 85]] [32 71]] [27 89]] [6239 1.49 [377 2.79 [5034 25.5 [1053 11.8 [1078 21.5 [28 48] [28 100]] [28 100]] [14 87]] [28 100]] [14 100]]] [32 73]] [8 72]] [27 79]] [485 5.62 [6866 1.46 [3516 3.41 [3895 5.24 [5660 3.53 [7548 3.07 [5564 2.73 [896 0.495 [6092 1.49 [2149 2.75 [736 1.44 [1764 5.26 [32 28] [14 62]] [5 37]] [31 80]] [32 100]] [7711 2.59 [5812 8.52 [5 32] [7 41]] [19 57]]] [14 100]] [14 80]] [17 64]] [31 69]] [19 100]] [5 90]] [17 90]]] [13 97]] [27 87]] [18 77]] [6654 2.62 [27 98] [27 100]]] [6945 1.58 [30 64] [10 100]]] [37 100]] [5 100]] [27 100]] [18 32]] [2091 9.62 [27 53] [27 100]]] [3779 1.55 [37 80] [37 100]]] [6830 11.3 [2756 2.86 [560 4.08 [6230 7.64 [5 21] [17 31]] [5693 8.35 [5386 5.47 [18 61] [18 100]] [18 75]]] [1429 14.4 [18 100] [18 63]]] [18 84]]] [1429 32.7 [7149 7.12 [18 82] [18 91]] [18 64]]]] [6666 1.25 [906 6.66 [811 1.02 [788 1.77 [6436 5.43 [978 2.83 [701 7.05 [2488 8.81 [4135 11.5 [2939 12.5 [899 2.12 [5211 6.93 [1995 13.2 [6960 2.71 [5978 1.92 [6813 1.83 [276 6.34 [2847 1.92 [6767 4.29 [631 0.832 [660 5.61 [1239 13.9 [695 5.21 [5534 6.56 [4583 5.97 [1219 1.44 [3931 24.2 [2259 32.9 [2260 6.13 [2776 1.17 [4517 3.35 [377 1.17 [7340 1.99 [5393 10.1 [3003 1.77 [957 33.2 [567 5.71 [6230 4.22 [2526 9.53 [2270 1.82 [7085 2.7 [10 17] [35 33]] [26 37]] [31 50]] [14 23]] [23 62]] [27 84]] [27 100]] [36 85]] [791 4.16 [32 68] [32 89]]] [11 45]] [13 30]] [32 90]] [36 40]] [4114 2.89 [434 1.82 [7241 5.68 [392 5.29 [10 39] [27 60]] [27 50]] [30 30]] [27 84]]] [32 58]] [10 76]] [27 82]] [27 100]] [32 15]] [957 5.92 [10 72] [1899 1.81 [10 20] [5753 1.49 [10 76] [17 25]]]]] [32 40]] [28 82]] [31 100]] [28 100]] [5348 0.686 [276 33.3 [429 8.14 [30 66] [695 14.8 [18 78] [6 40]]] [20 44]] [18 57]]] [32 100]] [31 100]] [13 77]] [286 3.23 [27 55] [27 70]]] [5110 6.17 [30 41] [30 93]]] [144 5.22 [32 60] [14 53]]] [10 69]] [27 91]] [34 62]] [10 100]] [965 1.99 [5281 2.57 [7177 1.27 [4645 2.59 [5420 0.266 [286 2.09 [2081 3.59 [7186 3.11 [18 24] [18 66]] [957 14 [31 38] [23 63]]] [23 100]] [23 87]] [18 94]] [7 90]] [18 81]] [31 100]]] [30 89]] [567 0.555 [1429 2.7 [282 1.89 [560 2.16 [429 7.83 [18 50] [6156 1.32 [10 57] [10 100]]] [5484 18.6 [5007 1.55 [18 51] [18 90]] [16 36]]] [18 77]] [7736 0.935 [1078 29.6 [6732 1.22 [1023 3.51 [2526 2.94 [5386 8.95 [2671 2.7 [18 47] [5 44]] [38 80]] [18 75]] [38 53]] [18 82]] [10 70]] [985 1.17 [5435 0.935 [18 65] [18 88]] [18 100]]]] [19 50]]] [1911 0.787 [7295 1.12 [5403 1.58 [6025 1.03 [663 2.93 [10 87] [1980 0.832 [1333 0.924 [10 83] [10 100]] [10 100]]] [10 100]] [791 9.89 [31 80] [31 100]]] [31 100]] [10 100]]] [32 66]] [7674 1.12 [1429 17.5 [558 0.747 [791 9.77 [10 100] [30 71]] [10 100]] [30 75]] [10 100]]]]] [7411 1.06 [6859 1.95 [834 0.463 [7354 3.79 [3563 0.337 [5034 0.92 [2526 1.69 [2323 0.938 [3079 3.37 [1690 1.08 [7480 0.881 [4312 3.94 [5940 3.43 [4885 0.945 [1391 1.69 [5403 1.92 [558 0.682 [2483 0.763 [3586 1.1 [4611 1.82 [3218 1.29 [7533 13.9 [7032 6.15 [5316 10.6 [6885 1.23 [3906 2.12 [7680 1.35 [5472 1.1 [1116 1.18 [3929 0.372 [7512 0.0984 [7623 3.65 [2470 1.93 [4288 5.39 [1674 3.19 [6205 2.86 [3480 4.95 [663 4.53 [2983 3.48 [5904 0.304 [460 1.06 [5587 1.61 [2955 7.92 [4170 1.46 [7185 9.56 [5673 3.32 [5809 15.1 [2259 30.3 [6445 11.3 [3554 11.7 [2849 31.3 [7472 0.784 [968 0.381 [6959 0.688 [1239 0.442 [494 1.71 [17 21] [37 30]] [2752 2.03 [17 35] [14 50]]] [17 41]] [28 50]] [38 75]] [38 41]] [7 69]] [13 62]] [6342 0.989 [32 24] [31 20]]] [15 100]] [5 33]] [38 25]] [32 68]] [38 66]] [23 100]] [37 100]] [1078 0.32 [19 76] [19 86]]] [38 68]] [1079 2.89 [6294 3.36 [3008 17.6 [3715 12 [17 29] [17 63]] [19 58]] [29 25]] [35 41]]] [4663 3.7 [32 72] [32 85]]] [32 79]] [32 85]] [32 80]] [3884 1.61 [5322 18.7 [1783 0.835 [1410 3.76 [7176 2.24 [2808 1.09 [4417 2.3 [15 63] [15 100]] [15 100]] [15 100]] [15 100]] [15 22]] [15 100]] [15 100]]] [5066 1.58 [15 54] [15 100]]] [6943 2.24 [853 0.924 [2826 0.642 [771 6.96 [178 1.48 [731 1.57 [899 2.67 [2636 4.93 [2939 21.1 [722 3.95 [5007 3.55 [5693 1.44 [5833 15.4 [2929 4.67 [3554 4.6 [3867 1.01 [4222 7.04 [7334 0.885 [6581 2.53 [377 9.09 [7340 2.59 [14 34] [32 100]] [14 100]] [1888 5.95 [17 36] [19 62]]] [19 41]] [17 90]] [37 100]] [32 61]] [32 87]] [17 50]] [32 61]] [3884 1.6 [7512 16.9 [15 44] [15 100]] [15 100]]] [17 50]] [19 62]] [7665 22 [429 11.5 [17 42] [7 63]] [14 72]]] [7343 6.62 [14 51] [14 77]]] [6977 3.26 [2628 8.53 [144 3.4 [17 20] [38 42]] [17 62]] [17 90]]] [978 8.91 [429 14.3 [7 66] [17 68]] [19 24]]] [7526 4.5 [19 46] [19 77]]] [6584 0.642 [1429 12.2 [7 35] [23 3.76 [6535 1.45 [4478 2.65 [4588 1.6 [1666 6.58 [3579 2.15 [1580 3.47 [7734 3.89 [7381 5.51 [17 42] [17 53]] [17 44]] [19 54]] [17 60]] [19 81]] [17 77]] [17 77]] [19 60]] [17 29]]] [17 80]]] [32 57]] [32 85]]] [3027 0.343 [1484 2.81 [6074 5.26 [3591 1.51 [1773 0.468 [2951 1.95 [3989 0.856 [791 23 [12 66] [5 47]] [1151 0.544 [12 40] [37 60]]] [38 62]] [19 54]] [4587 0.467 [5 47] [37 83]]] [15 71]] [5 44]] [12 54]]] [30 100]] [36 71]] [10 85]] [36 36]] [565 2.76 [5509 7.09 [23 63] [12 50]] [23 100]]] [32 64]] [5679 4.5 [31 93] [31 100]]] [5833 11.1 [14 91] [17 27]]] [15 93]] [2839 0.898 [36 39] [36 100]]] [15 100]] [31 100]] [2426 0.227 [12 93] [12 100]]] [31 98]] [7169 5.75 [15 76] [15 100]]] [32 89]] [3715 2.43 [4877 0.301 [2069 0.264 [14 36] [17 28]] [14 100]] [14 93]]] [811 1.59 [32 49] [15 42]]] [15 100]] [4870 5.86 [4414 7.37 [17 71] [17 42]] [17 100]]] [1997 5.49 [3079 20.7 [3610 0.429 [706 2.09 [1079 1.49 [452 3.87 [312 42.5 [3069 2.01 [37 93] [37 50]] [37 66]] [37 81]] [8 44]] [37 100]] [37 42]] [5108 9.03 [2488 7.14 [37 95] [37 75]] [37 70]]] [37 75]]] [2259 11 [32 87] [429 10.8 [32 87] [32 100]]]] [1531 1.03 [2331 0.367 [6560 1.39 [2259 14.6 [5520 0.312 [996 0.24 [573 4.15 [6554 1.57 [2707 4.37 [4851 14.7 [4806 0.273 [5581 1.54 [3554 1.26 [6885 0.247 [3858 0.588 [663 0.213 [685 4.12 [2470 13.6 [5154 9.08 [6548 4.87 [1587 2.97 [5368 5.45 [7210 7.42 [4478 8.5 [3088 1.62 [221 1.26 [6581 4.48 [6342 3.48 [6311 4.17 [6555 0.891 [429 60.5 [3027 4.11 [2143 1.25 [1530 1.75 [5969 1.29 [985 1.01 [134 1.55 [17 28] [19 44]] [38 75]] [16 36]] [12 60]] [17 42]] [19 40]] [3 63]] [17 80]] [19 66]] [7 42]] [6732 8.13 [2541 3.25 [6584 3.9 [5509 2.29 [724 0.322 [1078 26.9 [7381 20.8 [19 37] [17 66]] [17 93]] [17 100]] [19 46]] [2526 31.7 [17 92] [17 44]]] [17 84]] [7185 20.4 [17 39] [19 50]]]] [14 70]] [37 75]] [38 33]] [2259 2.01 [15 41] [7 28]]] [17 88]] [19 57]] [17 94]] [38 29]] [31 63]] [7 54]] [7009 1.76 [6524 4.52 [4588 0.203 [4279 0.521 [5742 0.31 [3079 4.14 [7472 0.981 [6544 0.867 [7373 1.59 [1089 2.84 [2259 2.58 [17 3.13 [5637 1.27 [1630 1.19 [6199 3.47 [178 1.58 [1888 2.42 [791 6.92 [17 34] [17 93]] [17 40]] [5 55]] [5 45]] [19 66]] [19 55]] [17 66]] [17 37]] [16 35]] [17 44]] [17 90]] [38 80]] [37 100]] [17 83]] [14 30]] [17 100]] [7 57]] [5 33]]] [35 100]] [23 68]] [728 2.31 [6134 1.31 [17 27] [17 50]] [19 71]]] [23 100]] [4568 1.21 [791 17.1 [23 8.26 [7251 2.77 [19 41] [17 64]] [17 75]] [19 57]] [19 90]]] [6199 26.3 [23 16.9 [3251 2.97 [791 13.6 [1011 10.4 [3908 12.1 [5509 1.58 [19 31] [19 54]] [19 66]] [7 100]] [7 45]] [14 63]] [7 80]] [7 90]]] [7665 3.51 [16 88] [16 37]]] [1190 1.68 [2829 1.36 [3928 4.72 [6207 9.56 [7711 17.7 [2636 2.54 [17 45] [19 85]] [7188 15.8 [19 88] [19 54]]] [5812 1.29 [38 45] [19 50]]] [17 62]] [19 90]] [17 87]]] [494 0.387 [5654 9.71 [4154 7.13 [5647 21.8 [17 56] [19 60]] [17 62]] [19 33]] [17 86]]] [392 6.26 [23 57] [23 100]]] [726 0.312 [19 100] [19 90]]] [7665 0.24 [2975 1.66 [32 20] [32 91]] [7241 3.16 [7 24] [10 30]]]] [0 100]] [3055 1.5 [2435 1.45 [6074 1.11 [6413 1.29 [5368 1.12 [2939 8.65 [8 44] [31 33]] [36 40]] [0 100]] [31 100]] [32 100]] [0 100]]] [0 100]]] [719 1.13 [2320 0.78 [1738 0.615 [5872 2.28 [4322 0.0904 [4050 5.54 [124 0.534 [112 2.75 [3726 1.27 [4451 0.879 [6401 1.15 [3480 2.07 [5812 2.02 [377 4.9 [494 1.44 [7233 3.07 [3580 0.671 [7600 1.61 [5767 0.356 [4307 1.33 [4279 26.3 [1674 4.93 [5566 1.78 [3027 5.08 [2760 4.32 [5034 4.27 [32 50] [4288 4 [2826 2 [1980 2.16 [6199 14.2 [32 72] [14 81]] [14 56]] [2752 19.7 [14 50] [14 85]]] [32 100]]] [32 100]] [32 90]] [14 100]] [32 100]] [32 100]] [32 100]] [14 80]] [32 100]] [32 100]] [32 100]] [1429 23.7 [14 74] [14 96]]] [14 95]] [14 75]] [3916 1.57 [32 91] [32 100]]] [32 100]] [32 89]] [32 97]] [5673 4.41 [628 1.83 [4168 1.11 [2753 3.05 [7241 1.13 [2826 6.43 [32 89] [32 60]] [32 50]] [32 60]] [32 100]] [32 100]] [32 100]]] [32 100]] [14 88]] [906 4.72 [32 100] [906 7.01 [32 80] [32 100]]]] [14 100]] [14 100]] [32 100]] [14 90]]] [6657 1.01 [3516 0.509 [6557 0.873 [649 0.434 [5154 1.13 [6584 0.391 [1633 1.89 [3014 4.8 [19 38] [17 57]] [19 84]] [35 66]] [736 5.26 [31 3.1 [1598 2.62 [6230 6.5 [19 50] [19 100]] [17 57]] [19 87]] [19 100]]] [19 44]] [19 45]] [19 100]] [19 100]]] [2607 0.548 [3113 1.22 [641 0.829 [2913 1.38 [5264 1.18 [3067 0.803 [2526 3.9 [1400 1.16 [7255 12 [5 1.43 [6342 2.92 [7340 3.23 [36 66] [6230 1.68 [32 90] [32 100]]] [32 50]] [36 100]] [18 78]] [36 86]] [1429 64.7 [731 2.67 [18 18] [7 58]] [38 45]]] [36 100]] [13 100]] [7 48]] [7 46]] [3908 7.49 [32 62] [32 41]]] [978 1.64 [8 40] [18 27]]]] [4875 2.75 [2081 0.277 [3170 2.5 [3907 8.02 [3190 5.32 [939 1.12 [37 97] [37 100]] [37 75]] [37 80]] [37 85]] [37 100]] [37 85]]] [6230 2.65 [3067 1.33 [1 0.921 [5034 2.04 [6867 1.22 [791 2.49 [36 66] [3907 1.33 [36 90] [36 100]]] [36 100]] [30 44]] [36 100]] [36 100]] [17 33]]] [1218 0.722 [5472 1.35 [377 0.405 [2526 0.8 [7169 5.79 [3929 2.1 [7664 1.61 [328 2.56 [2143 2.65 [7340 3.6 [2939 0.952 [6791 11.3 [3586 0.697 [1404 1.21 [7613 0.524 [3554 5.45 [1400 1.23 [15 65] [15 98]] [15 40]] [15 100]] [15 100]] [15 100]] [791 17.6 [15 87] [15 83]]] [15 37]] [32 60]] [15 50]] [4663 4.84 [15 84] [15 62]]] [15 50]] [15 54]] [15 34]] [31 23]] [4418 0.405 [15 93] [15 100]]] [36 60]] [15 100]]]] [7176 0.41 [5267 3.74 [4831 0.305 [4149 1.05 [5692 2.83 [2935 5.19 [4876 7.11 [1445 3.92 [7428 5.59 [5211 0.0652 [1769 18.3 [328 6.3 [6894 1.77 [20 88] [20 100]] [20 90]] [20 43]] [5253 24.8 [4650 7.69 [2199 16.4 [5365 11.1 [939 0.13 [7755 0.268 [4154 0.688 [4243 16.7 [5647 3.5 [4690 7.53 [20 96] [20 100]] [20 100]] [4245 20 [20 88] [20 100]]] [20 100]] [20 100]] [20 100]] [20 85]] [20 57]] [20 75]] [20 57]]] [20 66]] [20 78]] [20 58]] [20 83]] [20 56]] [20 50]] [20 100]] [20 72]] [33 62]]] [1231 0.328 [7301 0.803 [695 3.52 [1400 0.411 [2939 0.886 [110 1.47 [4279 26.6 [791 6.41 [3971 1.51 [2993 0.944 [12 86] [12 100]] [12 100]] [660 0.652 [6155 1 [12 96] [12 100]] [12 100]]] [12 40]] [12 100]] [7255 3.07 [10 23] [1436 1.56 [328 1.86 [2818 0.982 [12 96] [12 100]] [12 100]] [12 100]]]] [4876 0.198 [7176 0.42 [4369 7.61 [12 100] [12 88]] [12 100]] [12 100]]] [4154 16.1 [12 100] [12 80]]] [12 83]] [10 100]]] [2957 0.824 [811 0.736 [6184 3.06 [7665 6.48 [2913 13.8 [5972 1.3 [1239 3.25 [4398 4.99 [31 80] [31 100]] [31 60]] [31 100]] [31 91]] [31 100]] [429 10.3 [31 62] [31 100]]] [31 100]] [31 100]]] [4210 19.7 [4517 0.876 [328 0.684 [4851 41.5 [30 99] [30 92]] [30 100]] [30 100]] [30 90]]] [3829 0.849 [4109 5.92 [3306 0.336 [23 6.36 [5652 0.293 [7149 2.59 [2259 1.72 [7428 1.29 [3701 10.8 [3912 0.422 [5883 2.36 [3082 5.8 [3920 0.32 [832 0.778 [695 0.512 [1062 4.67 [434 1.83 [3610 2.76 [1541 9.01 [3922 1.45 [328 8.05 [3675 1.47 [3464 10.1 [37 71] [3113 2.62 [37 98] [37 100]]] [37 100]] [1899 1.22 [37 100] [37 85]]] [37 100]] [37 100]] [37 100]] [37 85]] [37 85]] [37 100]] [37 100]] [37 87]] [37 85]] [37 80]] [37 100]] [37 100]] [37 83]] [144 3.92 [328 1.24 [37 85] [37 100]] [37 70]]] [37 70]] [11 50]] [144 13.1 [3318 1.47 [37 86] [16 57]] [791 7.63 [38 63] [37 81]]]] [16 28]] [37 50]] [11 83]]] [2713 3.82 [7726 15.7 [6937 2.15 [6408 1.41 [5637 0.935 [5999 16.4 [6131 2.99 [6711 1.08 [1562 0.573 [2661 13.8 [2259 25.8 [23 41.6 [429 1.51 [5851 5.26 [2694 3.17 [30 97] [30 100]] [30 100]] [30 100]] [30 85]] [30 95]] [30 77]] [30 100]] [30 100]] [30 100]] [30 87]] [30 92]] [30 81]] [30 83]] [30 66]] [6009 4.82 [30 97] [1676 1.36 [30 77] [30 71]]]]] [2939 4.72 [4315 0.185 [4135 0.732 [4373 42.4 [27 100] [27 80]] [27 100]] [27 100]] [27 99]]] [4086 1.21 [2469 1.85 [4895 3.47 [6333 1.77 [6581 3.5 [3914 1.21 [2618 1.41 [35 2.9 [3297 0.406 [5287 5.07 [3779 42.6 [2024 1.93 [4071 1.05 [1545 5.57 [3724 5.43 [3831 5.81 [37 96] [37 92]] [37 80]] [37 77]] [37 100]] [37 100]] [37 66]] [37 78]] [3080 2.53 [567 6.69 [3883 0.281 [3715 0.759 [328 1.94 [37 100] [37 98]] [37 100]] [37 100]] [37 83]] [706 1.95 [37 95] [37 87]]]] [37 80]] [35 44]] [3879 2.35 [707 0.611 [37 100] [37 81]] [35 50]]] [37 66]] [957 0.377 [37 83] [16 42]]] [4895 7.59 [37 55] [37 100]]] [37 61]] [37 66]]] [5509 0.944 [4137 0.0814 [244 0.901 [1253 16.4 [1062 0.294 [5647 0.652 [928 0.154 [4118 0.349 [3533 1.14 [1911 1.39 [7441 0.596 [1121 1.18 [6125 1.07 [1429 33.8 [27 100] [27 87]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 87]] [27 100]] [27 100]] [27 77]]] [7137 0.334 [3418 0.35 [4854 2.19 [2468 8.92 [6719 0.0902 [6131 3.75 [5570 1.39 [2737 0.942 [2076 0.0902 [5188 1.21 [1429 12.4 [38 82] [2993 1.76 [3548 0.834 [7304 6.68 [1436 6.36 [1720 0.291 [4991 1.9 [6382 0.527 [7242 0.757 [7210 1.92 [97 2.12 [2851 5.26 [2199 0.29 [1769 1.46 [38 64] [38 83]] [38 91]] [38 85]] [3687 0.784 [1789 5.95 [1981 4.47 [6822 17.7 [2955 5.52 [38 33] [7445 5.16 [38 62] [1789 3.35 [38 65] [38 100]]]] [17 50]] [28 36]] [1789 6.25 [14 33] [5637 13.9 [14 27] [38 67]]]] [38 50]]] [38 38]] [37 3.5 [17 30] [5 33]]] [6382 3.63 [17 70] [14 37]]] [5 44]] [17 63]] [38 73]] [7390 2.28 [38 58] [38 100]]] [5 35]] [17 20]]] [2241 0.717 [6717 3.64 [2939 41.1 [5189 4.31 [38 87] [38 100]] [38 94]] [38 71]] [38 100]]] [38 44]] [2075 8.27 [97 2.66 [5209 2.18 [1395 0.718 [38 97] [38 100]] [6207 1.14 [38 81] [38 88]]] [38 100]] [38 87]]] [6199 0.735 [38 45] [1687 3.71 [17 85] [2955 14.8 [17 88] [14 57]]]]] [5641 11.3 [6397 1.03 [3 27] [26 33]] [38 44]]] [7161 6.25 [7222 3.03 [1897 7.58 [1732 9.42 [6422 0.674 [6129 0.38 [187 7.46 [6199 1.55 [2386 4.94 [190 3.73 [190 2.69 [38 89] [4563 2.99 [38 62] [38 94]]] [38 100]] [38 72]] [38 66]] [5678 4.91 [38 100] [17 44]]] [38 100]] [2857 1.16 [38 72] [7474 2.42 [38 85] [19 75]]]] [17 50]] [38 50]] [17 33]] [17 50]]] [6719 4.61 [1981 1.18 [6383 5.41 [5312 1.12 [7449 10.3 [38 47] [37 41]] [5 78]] [38 82]] [5 55]] [192 2.39 [38 76] [38 87]]]] [6822 2.8 [38 40] [17 100]]] [4004 2.76 [5 54] [5 77]]] [5130 4.06 [6276 0.197 [1895 12.4 [38 100] [38 90]] [38 100]] [38 80]]]] [452 7.39 [37 100] [3292 33.5 [663 9.26 [37 100] [37 96]] [37 71]]]] [5100 2.12 [5257 0.823 [7615 12.1 [4457 0.978 [2914 3.18 [1436 0.068 [906 2.16 [4318 0.477 [5154 0.624 [5404 1.93 [915 1.6 [5122 1.23 [2472 0.684 [756 7.82 [4952 0.707 [3 77] [3 100]] [3 45]] [30 100]] [30 100]] [3 100]] [3 100]] [3 100]] [3 100]] [3 98]] [7615 2.99 [3 86] [7241 0.378 [3 99] [3 100]]]] [30 93]] [30 96]] [24 1.01 [6373 7.73 [395 4.76 [4284 2.11 [2366 2.92 [6350 3.23 [1429 13.5 [2004 2.76 [4768 2.92 [7298 1.13 [7731 1.87 [6436 7.94 [2752 5 [7606 5.75 [39 4.98 [4154 1.28 [1995 3.32 [791 2.86 [1078 26.3 [3 85] [3 100]] [3 96]] [3 100]] [3 98]] [3 100]] [3 100]] [3 40]] [3 100]] [3 100]] [6910 1.13 [3 83] [30 100]]] [3 100]] [5034 2.33 [1980 22.2 [3 100] [3 88]] [3 100]]] [2259 28 [7314 3.4 [3 72] [3 100]] [2232 1.54 [2913 20.5 [3 87] [30 66]] [3 100]]]] [10 100]] [4680 3.55 [3 98] [3 100]]] [3 100]] [30 87]] [3 50]] [3 100]]] [10 100]] [30 100]]] [7384 0.0974 [736 0.062 [7571 0.189 [6883 3.52 [5 0.179 [7381 0.104 [23 72.7 [6403 0.387 [2331 0.174 [4799 1.61 [2962 3.02 [5705 0.682 [7374 0.921 [5260 2.75 [1899 0.321 [4081 1.13 [899 1.46 [7600 0.756 [6853 4.09 [5484 0.728 [2749 0.327 [7737 0.973 [7588 0.998 [2573 2.49 [6545 3.03 [4056 2.42 [5730 1.53 [2588 1.08 [6544 1.9 [3917 1.55 [7354 1.11 [5412 1.91 [1173 0.364 [811 1.53 [1011 2.67 [2671 0.861 [1552 2.65 [134 1.14 [3008 12.3 [5472 1.61 [1 4.1 [2846 1.02 [5406 3.36 [4699 0.805 [5480 2.93 [6674 13 [5692 6.67 [647 2.49 [7512 9.74 [14 17] [2616 7.05 [1769 65.5 [7517 12.2 [7525 3.76 [731 8.78 [7428 1.34 [1844 5.32 [6227 1.36 [5554 4 [7409 2.65 [4895 4.5 [5381 0.885 [2526 6.06 [4279 10.5 [7605 58.6 [145 5.7 [429 2.49 [14 44] [6333 3.23 [7185 8.54 [7548 2.39 [6791 1.29 [14 59] [14 54]] [14 89]] [14 100]] [32 57]]] [19 27]] [4 26]] [32 31]] [5 23]] [19 60]] [4896 3.14 [2466 10.4 [14 33] [14 72]] [429 2.24 [14 61] [14 90]]]] [7169 1.74 [14 84] [14 100]]] [14 100]] [14 100]] [14 82]] [695 1.55 [14 53] [14 100]]] [5 25]] [30 60]] [19 50]] [32 33]] [7563 4.13 [6 17] [5 86]]]] [7 100]] [4832 1.32 [2616 2.49 [5695 3.65 [14 45] [25 50]] [24 26]] [2 40]]] [6 100]] [18 36]] [20 100]] [31 100]] [7085 0.852 [1239 22.4 [14 72] [22 44]] [14 66]]] [32 33]] [312 1.99 [7566 13.9 [7583 1.61 [36 69] [36 100]] [7722 18.1 [13 87] [13 62]]] [13 75]]] [6550 1.31 [695 6.15 [7590 9.89 [14 26] [17 60]] [2428 3.45 [6581 4.27 [14 75] [17 67]] [7 100]]] [17 70]]] [5 17]] [32 100]] [18 64]] [602 8.95 [7689 1.01 [5205 1.22 [6310 9.66 [384 1.55 [7665 22.4 [19 2.2 [7665 21.2 [7343 2.89 [7210 6.51 [144 5.59 [19 26] [14 29]] [28 33]] [4 23]] [6 35]] [2 100]] [791 7.38 [6 24] [3905 2.76 [7188 6.98 [429 36.7 [1011 14.5 [5 50] [2 21]] [5429 6.02 [5692 15.4 [7 45] [5 62]] [5 100]]] [7 25]] [978 12.2 [17 53] [31 55]]]]] [7 50]] [17 47]] [24 50]] [17 36]] [16 40]]] [31 52]] [2 50]] [3278 1.87 [1614 2.51 [99 4.28 [2802 2.38 [3554 10.2 [1011 1.08 [429 47.5 [5757 1.51 [2259 1.4 [6083 1.78 [5403 8.44 [6230 5.12 [6413 1.68 [13 30] [13 100]] [14 77]] [31 100]] [13 100]] [7677 2.14 [5480 2.2 [3660 1.92 [6199 3.54 [5647 5.57 [17 18] [13 20]] [14 80]] [4342 1.51 [24 66] [24 100]]] [32 33]] [19 28]]] [29 100]] [29 76]] [5812 7.6 [19 20] [4 71]]] [17 66]] [29 85]] [14 58]] [4 100]] [1 100]]] [3434 1.35 [7250 0.739 [6581 3.36 [7321 2.44 [2868 0.475 [3905 6.31 [2826 3.79 [5516 1.15 [653 0.468 [5130 1.88 [6040 10.4 [2259 9.84 [7413 4.46 [18 29] [5 85]] [4414 1.47 [5012 1.39 [7665 39.4 [2526 2.67 [36 63] [1078 3.46 [7 60] [18 75]]] [36 86]] [19 62]] [18 66]]] [19 60]] [18 72]] [5 26]] [18 62]] [5 42]] [7 66]] [18 50]] [16 77]] [2752 9.81 [5 50] [3056 0.96 [791 15.3 [1429 34.8 [5 61] [5 100]] [458 1.95 [5 70] [5 60]]] [5 91]]]] [36 78]] [36 100]]] [4279 6.26 [5345 1.79 [14 81] [14 66]] [14 96]]] [724 0.782 [458 0.949 [429 23.2 [7692 0.768 [957 5.26 [2143 1.57 [14 77] [17 71]] [32 54]] [5692 0.768 [2752 22.2 [14 100] [14 94]] [14 100]]] [6548 1.16 [663 3.6 [14 95] [14 29]] [32 32]]] [17 54]] [17 64]]] [17 56]] [32 98]] [32 96]] [31 100]] [1580 2.3 [1888 1.81 [17 50] [19 57]] [17 100]]] [5892 1.6 [999 0.611 [6583 6.44 [5 34] [17 57]] [5 86]] [17 91]]] [6031 1.69 [5732 2.1 [4926 2.21 [5377 3.3 [23 4.15 [4279 3.82 [7520 1.67 [2445 1.16 [20 33] [18 50]] [18 62]] [18 61]] [5270 0.864 [4895 4.97 [1429 0.917 [19 40] [19 48]] [19 58]] [19 42]]] [6 85]] [18 73]] [14 50]] [22 100]]] [978 0.327 [26 92] [26 100]]] [5484 4.5 [279 0.441 [4414 1.5 [7734 5.91 [18 81] [6 66]] [16 22]] [5 44]] [18 67]]] [1078 17.1 [1651 1.41 [811 7.13 [7701 1.66 [7698 1.22 [6173 1.86 [4344 1.93 [2753 1.45 [2259 23.5 [4338 2.22 [4611 4.88 [36 51] [36 100]] [24 86]] [36 81]] [36 100]] [24 100]] [31 100]] [36 100]] [31 100]] [31 90]] [36 100]] [7701 1.29 [7512 36.6 [31 43] [31 83]] [31 100]]]] [7354 0.942 [5744 2.17 [7512 27.5 [32 98] [695 2.89 [2310 3.88 [32 90] [32 100]] [32 66]]] [32 100]] [32 100]]] [7697 1.03 [4769 1.73 [3905 11.8 [710 1.5 [2705 0.921 [4309 0.879 [1078 12.2 [6436 1 [4806 4.25 [109 1.62 [3434 2.13 [6404 1.49 [6865 1.69 [6977 5.31 [1651 3.47 [5316 2.64 [3644 1.92 [871 2.99 [811 1.61 [5476 3.8 [4316 1.29 [2753 0.494 [429 34.3 [14 58] [2701 1.46 [14 36] [32 76]]] [32 35]] [3905 1.29 [32 83] [32 100]]] [13 100]] [36 58]] [36 100]] [36 100]] [32 88]] [36 100]] [14 100]] [36 94]] [36 100]] [36 100]] [14 100]] [14 100]] [14 96]] [722 2.28 [1025 0.975 [6436 7.59 [36 34] [14 87]] [7665 18.7 [13 47] [13 94]]] [36 69]]] [32 100]] [29 100]] [14 100]] [2434 1.89 [2939 2.13 [14 81] [14 90]] [14 100]]] [29 80]] [31 100]]] [31 100]] [7354 0.264 [5658 0.855 [2517 0.96 [6089 0.34 [4769 0.197 [6537 1.38 [5034 1.84 [4547 1.14 [2701 1.62 [1069 0.905 [1078 9.37 [6853 2.46 [2760 0.462 [7755 0.882 [6495 0.842 [3517 0.87 [2526 4.93 [6524 1.34 [6227 2.64 [4535 18.1 [2144 0.373 [1980 12.9 [444 0.315 [7139 0.448 [4861 2.96 [719 6.49 [2913 1.09 [1011 3.17 [4896 4.01 [5753 1.67 [6544 2.26 [2849 9.44 [5345 0.98 [2628 3.59 [5462 0.707 [4279 0.921 [14 25] [19 22]] [6 20]] [26 44]] [12 28]] [35 42]] [14 55]] [32 22]] [14 53]] [17 41]] [32 38]] [31 75]] [19 66]] [14 44]] [26 75]] [26 26]] [18 41]] [38 46]] [14 100]] [36 34]] [3516 1.39 [3099 0.858 [3057 1.58 [112 0.858 [5967 2.13 [3077 2.95 [2573 2.18 [1980 15 [2570 2.19 [2752 3.37 [1919 10 [1906 2.71 [6 24] [4 55]] [6 87]] [5969 0.546 [7711 1.79 [1025 1.54 [6395 1.43 [2763 4.81 [5 34] [4 37]] [17 58]] [978 3.17 [2 62] [6230 1.33 [4 50] [4 62]]]] [17 70]] [17 66]]] [5851 5 [6396 1.35 [4349 1.1 [5383 0.671 [4 24] [17 83]] [2 58]] [3929 9.37 [17 100] [17 85]]] [2 50]]] [2 25]] [38 75]] [17 100]] [31 100]] [4851 0.858 [17 30] [17 80]]] [5 96]] [1 100]] [19 100]]] [19 100]] [3 60]] [20 94]] [5692 2.94 [5 32] [4154 10.9 [17 52] [4 55]]]] [7512 17.4 [2616 3.26 [24 58] [24 100]] [811 5.15 [5198 3.99 [36 76] [36 87]] [31 75]]]] [2526 3.16 [2470 0.486 [6404 0.986 [6310 1.26 [1391 4.78 [6416 0.352 [3480 4.12 [1089 37.8 [4369 1.98 [2752 35.1 [2385 2.37 [19 11] [18 100]] [22 68]] [13 75]] [22 100]] [36 100]] [13 100]] [22 100]] [19 72]] [36 100]] [1078 27.9 [4 66] [25 50]]] [1023 5.52 [6859 2.02 [6927 0.677 [1910 0.41 [5851 2.2 [5403 1.64 [7711 0.797 [3099 1.25 [4184 18.9 [4184 1.42 [4 22] [2939 1.96 [4 52] [4 27]]] [2 85]] [1 100]] [5812 1.29 [5 100] [17 75]]] [31 100]] [1888 4.09 [5 38] [5 53]]] [4 88]] [1429 2.12 [2 66] [4 85]]] [31 100]] [1429 10.5 [2 78] [17 92]]]]] [5509 0.68 [19 0.675 [4308 0.592 [4288 0.497 [2570 0.612 [5692 14 [6732 3.21 [4 31] [5 30]] [36 57]] [6983 2.99 [4 50] [4 100]]] [5753 2.31 [4 84] [2 40]]] [1 100]] [2 71]] [1 25]]] [4214 1.21 [29 88] [29 100]]] [7682 0.425 [7234 5.15 [6 76] [6 100]] [6 100]]] [1391 0.967 [7061 3.51 [6943 2.04 [4478 0.441 [7409 0.562 [721 0.496 [4885 0.931 [5371 0.935 [4158 0.534 [2913 0.548 [6333 1.48 [1783 3.55 [1078 12.1 [429 43.5 [14 100] [14 66]] [7722 7.5 [14 55] [14 75]]] [14 71]] [32 71]] [32 100]] [7722 9.82 [14 100] [14 87]]] [14 100]] [32 90]] [6199 0.945 [14 81] [14 100]]] [14 100]] [14 96]] [32 100]] [32 46]] [14 63]]] [1239 2.88 [7568 0.446 [7254 3.87 [2259 5.98 [4992 3.94 [6186 0.597 [2 79] [5198 4.63 [2 100] [2 83]]] [2 75]] [2 63]] [1 28]] [2 100]] [2 69]]] [4770 0.762 [29 100] [29 85]]] [2610 0.397 [1047 3.8 [5692 7.31 [2 100] [791 11.6 [2 100] [2 85]]] [2 76]] [2 100]]] [24 81]] [13 100]] [3317 1.42 [328 0.141 [865 0.36 [1705 1.27 [2259 17.4 [7514 1.29 [1071 3.37 [978 0.426 [6865 2.49 [2616 2.79 [2793 1.39 [1931 2.2 [7340 0.588 [896 11.9 [36 36] [16 28]] [6230 1.62 [663 6.94 [32 100] [32 71]] [32 100]]] [13 42]] [36 100]] [2809 3.1 [18 34] [18 75]]] [36 100]] [2826 0.585 [2570 9.12 [4338 4.22 [7722 2.48 [18 50] [2726 0.426 [18 63] [18 87]]] [17 28]] [18 85]] [957 2.57 [2571 0.721 [906 5.35 [2826 6.02 [896 3.37 [5 31] [32 35]] [7 36]] [5 100]] [19 37]] [5 53]]]] [5658 1.98 [13 54] [13 100]]] [18 77]] [719 0.797 [2570 7.05 [5472 0.597 [36 41] [36 100]] [18 71]] [2421 0.921 [5851 0.808 [6401 0.473 [1078 3.03 [36 90] [36 100]] [36 100]] [36 100]] [36 100]]]] [18 81]] [13 86]] [7155 0.868 [1705 4.34 [2607 2.21 [187 3.7 [1436 1.91 [5131 1.03 [1911 2.23 [5516 0.509 [2268 0.58 [2616 0.586 [7512 16.1 [1783 1.26 [2526 6.28 [7601 1.97 [18 27] [36 71]] [18 75]] [18 57]] [19 60]] [1899 7.62 [1012 0.223 [18 55] [7 37]] [18 80]]] [18 85]] [5412 1.27 [18 100] [18 72]]] [328 6.51 [3 27] [7 36]]] [18 80]] [25 17]] [16 38]] [5654 1.45 [7520 1.3 [18 100] [18 60]] [18 70]]] [18 40]] [19 87]]] [5 81]]]] [1899 14.2 [5472 0.564 [5482 5.64 [13 45] [18 100]] [13 100]] [13 44]]] [6581 2.7 [1888 2.76 [36 65] [1078 4.03 [36 66] [36 100]]] [36 40]]] [6857 6.33 [5763 0.803 [4041 0.454 [429 34.8 [6401 0.792 [36 98] [36 100]] [36 77]] [36 100]] [36 100]] [31 57]]] [5725 0.686 [4369 2.92 [6982 2.09 [1406 2.57 [7463 1.9 [3554 8.38 [695 22.6 [17 20] [36 53]] [5 66]] [5 69]] [31 100]] [31 100]] [36 75]] [31 100]]] [4379 0.356 [178 0.197 [2004 0.201 [7548 0.326 [5753 1.61 [5424 0.589 [7520 3.34 [1075 0.664 [5730 1.09 [6581 0.773 [2323 1.42 [6848 3.18 [6732 1.21 [4370 1.72 [2260 1.93 [2913 1.26 [23 1.24 [5692 1.55 [36 25] [24 25]] [429 28.8 [13 50] [4 25]]] [32 100]] [36 37]] [32 100]] [2420 7.89 [32 23] [36 63]]] [13 100]] [32 100]] [731 0.829 [5 52] [17 57]]] [32 100]] [2 66]] [13 44]] [6848 0.507 [13 66] [13 100]]] [1062 0.611 [1025 1.74 [36 58] [2 42]] [13 35]]] [2752 29.8 [7169 4.13 [7253 0.328 [2760 0.917 [3095 1.61 [144 2.44 [32 100] [32 88]] [32 100]] [32 100]] [32 88]] [32 81]] [32 57]]] [2628 2.54 [2 26] [4 50]]] [2081 5.11 [4 26] [24 30]]] [32 100]]] [7548 0.283 [4801 0.385 [7032 0.998 [3554 2.25 [5316 0.393 [4851 1.05 [2628 3.7 [6230 1.79 [101 1.07 [811 0.519 [4326 1.48 [36 60] [36 55]] [36 100]] [36 100]] [32 63]] [36 86]] [4851 9.22 [112 5.9 [1078 0.73 [36 85] [36 100]] [36 93]] [7591 2.3 [1400 2.54 [36 70] [36 100]] [36 100]]]] [32 100]] [32 90]] [5789 1.44 [31 72] [36 100]]] [32 100]] [7442 2.23 [2466 1.09 [32 100] [32 80]] [32 66]]]] [2323 2.75 [7451 7.03 [4288 3.32 [7542 0.392 [4057 0.773 [32 98] [32 100]] [32 100]] [4279 6.2 [32 85] [32 100]]] [32 90]] [32 75]]] [4716 6.26 [6074 1.62 [4231 2.64 [4718 3.58 [2058 1.83 [177 23.6 [1943 0.747 [23 90.4 [5753 8.18 [19 39] [32 44]] [2752 2.55 [5534 1.67 [6201 4.95 [172 5.18 [6199 8.79 [172 2.64 [6616 3.14 [19 53] [19 55]] [19 35]] [3 22]] [19 72]] [1436 1.01 [4308 0.869 [19 71] [7739 3.47 [19 88] [19 100]]] [19 66]]] [13 28]] [7665 34.1 [19 28] [28 50]]]] [19 90]] [19 89]] [7738 2.83 [19 85] [19 50]]] [14 55]] [1239 3.06 [19 93] [19 88]]] [13 83]] [14 60]]] [2793 1.14 [5820 0.252 [3018 0.511 [1721 0.255 [643 0.609 [3629 3.51 [7365 0.508 [6866 0.186 [899 0.196 [731 0.469 [1240 1.98 [3327 0.344 [1704 0.642 [1025 3.95 [7585 0.741 [1646 6.93 [5316 0.216 [3014 0.77 [5812 0.96 [2903 3.1 [494 1.93 [4338 9 [7512 58 [2826 2.98 [1079 0.267 [7382 2.79 [1899 5.35 [5429 2.24 [6980 8.41 [5 27] [6581 18.5 [5 100] [5 81]]] [5 79]] [4 37]] [24 66]] [5 54]] [2902 1.65 [1888 15.5 [2259 4.76 [2939 1.64 [7381 3.77 [5 100] [14 55]] [5 66]] [7 26]] [5 100]] [14 85]]] [7 37]] [24 83]] [7381 11.1 [494 4.38 [19 33] [17 65]] [19 41]]] [5 83]] [2470 0.971 [112 1.96 [7512 23.3 [407 4.12 [1995 4.18 [286 0.202 [5 31] [2 92]] [2 46]] [2 100]] [6591 5.05 [5 55] [17 44]]] [17 35]] [4338 0.682 [4 89] [4 100]]]] [1078 7.38 [7693 0.413 [6581 26.4 [17 55] [7598 11.7 [19 62] [19 50]]] [17 45]] [17 75]]] [7595 0.419 [7718 2.9 [5564 1.48 [17 37] [14 100]] [7 78]] [7373 0.419 [5953 3.61 [17 40] [16 34]] [26 37]]]] [7 95]] [14 100]] [2588 0.365 [1885 2.62 [5652 5.57 [655 0.589 [2 49] [7665 25.6 [1062 1.12 [2 85] [2 100]] [2 55]]] [4 44]] [17 34]] [17 80]]] [328 4.53 [2023 0.717 [5693 7.93 [17 87] [6544 10.1 [17 40] [17 88]]] [17 87]] [17 60]]] [2 100]] [5851 1.41 [1023 2.22 [1888 6.73 [24 87] [24 100]] [24 100]] [24 86]]] [1601 1.27 [4681 0.736 [4478 6.56 [485 2.92 [3732 0.905 [3204 0.921 [6591 0.92 [6241 1.02 [2470 0.472 [685 2.3 [6538 1.31 [3591 0.666 [6725 1.72 [1704 1.69 [1429 21.8 [1986 2.16 [17 27] [2 62]] [791 4.39 [1919 0.611 [1888 0.402 [5 72] [5 37]] [38 47]] [2902 4.24 [6550 2.05 [5 56] [17 43]] [5 84]]]] [7534 1.9 [17 71] [17 83]]] [19 50]] [5 87]] [2 90]] [3905 2.62 [7 57] [7 100]]] [4 100]] [7 81]] [1023 6.32 [7067 0.263 [6396 1.17 [883 0.794 [144 1.29 [17 56] [134 2.87 [17 44] [5 100]]] [5 85]] [1690 6.19 [17 68] [17 100]]] [19 36]] [7665 21.8 [17 85] [17 100]]]] [6980 0.592 [5 90] [5 100]]] [722 1.45 [2764 0.964 [1023 2.35 [6230 13.7 [21 1.45 [4774 1.68 [6581 3.54 [17 63] [7210 1.85 [4943 1 [17 93] [17 77]] [17 50]]] [17 71]] [19 44]] [17 50]] [17 92]] [35 40]] [723 2.13 [14 40] [17 57]]]] [6129 2.61 [7381 2.48 [16 77] [2541 1.58 [38 70] [16 33]]] [6584 1.84 [38 100] [38 85]]]] [17 90]] [5 68]] [7722 2.95 [38 70] [5480 4.86 [14 33] [38 88]]]]] [7605 0.975 [7682 3.05 [6544 1.09 [7548 0.196 [14 87] [14 100]] [14 100]] [14 83]] [14 62]]] [4654 1.33 [2005 3.5 [3463 1.16 [7248 3.74 [7169 10.4 [3308 2.64 [7188 5.84 [4766 2.43 [5 90] [5 71]] [5 100]] [5 87]] [5 80]] [7512 17.1 [5 66] [5 83]]] [5 62]] [5 70]] [5 62]]] [731 3.22 [4 100] [4 81]]] [24 96]] [2571 3.71 [2 96] [2 60]]] [2826 1.62 [7417 1.59 [7373 0.834 [17 52] [17 93]] [17 72]] [6581 7.58 [3008 5.72 [7188 0.232 [19 48] [19 80]] [38 45]] [3798 5.96 [17 77] [17 44]]]]] [24 100]] [7414 0.933 [4833 1.41 [4991 0.514 [4 67] [2 100]] [1239 0.745 [2 84] [2 85]]] [1993 0.657 [2 95] [2 77]]]] [5480 1.09 [4968 1.11 [5637 1.55 [2947 3.19 [3662 3.73 [324 0.768 [2902 9.88 [4741 1.06 [2548 3.85 [5866 0.659 [4342 0.615 [663 2.05 [3661 8.49 [7751 0.586 [7665 27.4 [2517 12.3 [24 100] [24 90]] [14 44]] [24 100]] [24 75]] [14 63]] [5454 0.669 [24 100] [24 80]]] [24 100]] [24 80]] [24 66]] [24 56]] [24 100]] [24 69]] [24 50]] [16 33]] [14 33]] [24 44]]]] [1980 2.48 [36 100] [5732 3.1 [36 100] [36 80]]]] [3480 2.19 [6544 1.29 [7067 0.488 [6887 2.17 [2526 7.82 [4663 1.02 [791 0.952 [36 62] [6885 4.74 [2939 2.04 [36 27] [5 31]] [32 50]]] [3 28]] [3435 1.69 [6685 1.06 [1919 0.707 [5 64] [5412 4.19 [5 25] [17 50]]] [5 100]] [5 100]]] [663 1.68 [7021 0.635 [2594 11.7 [5 79] [5 59]] [19 53]] [5851 0.966 [5 80] [5 90]]]] [7 53]] [7722 3.92 [32 50] [14 83]]] [6859 2.4 [32 58] [36 100]]]] [978 0.197 [4081 0.763 [5978 1.26 [7701 1.29 [6260 0.309 [6231 0.756 [6164 1.47 [2967 5.28 [5812 4.79 [6173 1.47 [2339 0.281 [1017 2.82 [4279 13 [6545 4.27 [5403 1.71 [7343 12.9 [7156 4.1 [7561 1.79 [2259 11.3 [896 0.883 [2259 8.79 [36 93] [36 44]] [36 100]] [36 100]] [36 75]] [36 100]] [36 72]] [31 100]] [31 100]] [31 54]] [31 60]] [36 100]] [31 100]] [31 100]] [31 75]] [31 62]] [31 100]] [17 3.34 [901 3.4 [5851 0.417 [7156 0.213 [118 0.803 [3068 0.499 [3664 0.639 [2342 5.07 [36 100] [36 80]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]] [7693 1.43 [36 80] [36 100]]] [1409 2.67 [2832 1.28 [36 97] [36 100]] [36 87]]]] [31 100]] [31 100]] [31 100]] [5403 0.454 [36 53] [5154 0.654 [7449 13.7 [31 100] [31 95]] [31 100]]]]] [7009 3.46 [3905 1.83 [7325 0.553 [6233 0.639 [7701 0.357 [4718 0.815 [7192 0.855 [2591 0.646 [2385 0.865 [731 9.21 [5521 0.439 [1400 9.56 [5952 0.0846 [1570 0.442 [6334 0.324 [665 1.46 [6040 0.563 [3381 2.82 [2649 0.415 [384 0.48 [5871 5.24 [6241 0.326 [5403 0.624 [442 0.489 [7563 0.824 [6557 0.872 [6342 1.67 [5130 1.95 [4741 0.15 [6581 0.124 [685 1.85 [14 14] [18 55]] [7722 9.09 [6977 0.924 [7520 2.31 [17 40] [17 50]] [19 23]] [5 70]]] [7210 1.32 [2 43] [38 42]]] [18 33]] [7665 13.4 [4 42] [4 80]]] [17 71]] [5 89]] [7 36]] [31 100]] [5 81]] [14 77]] [7722 2.93 [18 52] [18 47]]] [6831 1.8 [16 83] [16 27]]] [141 3.64 [26 60] [26 44]]] [18 69]] [2 91]] [5 100]] [17 100]] [573 0.708 [4719 1.29 [957 0.452 [38 58] [38 70]] [17 44]] [7335 0.32 [6920 0.746 [7241 0.493 [17 50] [38 66]] [19 80]] [17 75]]]] [682 0.383 [4 61] [4 100]]] [19 87]] [2487 1.47 [7354 0.695 [4869 5.36 [5972 2.3 [3014 0.539 [6396 1.18 [3461 1.65 [6216 0.661 [4929 3.44 [6442 2.3 [6581 1.83 [1059 1.27 [4991 0.858 [7248 1.44 [6333 0.967 [6074 2.35 [5429 3.27 [7551 1.48 [731 39.8 [7 16] [8 27]] [17 50]] [5 83]] [2 64]] [5 95]] [5 50]] [19 54]] [8 50]] [458 2.18 [2753 4.05 [610 1.64 [5383 3.31 [5021 4.22 [6732 19 [4851 11 [957 3.6 [4806 2.13 [1919 1.24 [17 62] [5 37]] [17 100]] [17 50]] [6732 4.95 [2826 5.62 [429 20.1 [5 57] [4 28]] [5 63]] [5 37]]] [5 52]] [35 50]] [17 90]] [5 100]] [17 50]] [17 62]]] [5 100]] [4 100]] [5 77]] [1078 1.24 [19 62] [17 85]]] [5154 5.08 [5197 0.876 [7512 13.5 [17 100] [17 85]] [17 100]] [17 75]]] [4479 0.392 [7551 1.57 [5316 5.14 [3734 5.28 [1011 2.45 [17 92] [17 66]] [663 1.2 [695 7.08 [17 50] [17 100]] [19 42]]] [7722 9.64 [17 100] [17 66]]] [19 45]] [17 57]]] [5403 11.1 [31 83] [31 100]]] [31 100]] [7722 3.39 [18 71] [5 31]]] [31 100]]] [144 0.416 [18 77] [736 2.5 [18 100] [18 83]]]] [7566 6.38 [1128 0.872 [1648 1.41 [649 1.25 [112 0.714 [2552 1.03 [7601 2.18 [2939 5.69 [7586 1.08 [695 0.236 [17 100] [5316 0.18 [1025 1.67 [5 57] [17 60]] [17 65]]] [1429 17.3 [17 50] [7665 14.5 [17 77] [6977 0.715 [17 82] [17 80]]]]] [5509 1.53 [5 50] [5 100]]] [5 66]] [17 50]] [17 76]] [5693 2.39 [17 100] [17 85]]] [1079 0.599 [7068 0.52 [1429 49.2 [38 50] [1648 4.14 [19 92] [1750 1.06 [19 62] [19 60]]]] [695 2.9 [17 40] [17 60]]] [17 90]]] [5 88]] [5 92]]] [7241 0.483 [6977 1.87 [7722 6.54 [17 75] [978 2.41 [19 55] [17 70]]] [17 100]] [17 100]]] [725 0.532 [429 32.7 [7718 1.98 [5157 1.71 [6313 0.644 [5 80] [5 100]] [5 85]] [4 64]] [17 0.635 [7 44] [5 42]]] [5 28]]] [31 100]] [31 100]] [5 90]] [1072 0.0891 [3415 1.2 [734 1.42 [2802 1.02 [7534 0.613 [929 0.449 [5632 2.15 [5641 0.917 [7722 6.82 [5853 0.263 [6859 2.14 [1652 0.858 [4896 0.832 [5520 1.01 [7214 2.2 [6911 2.22 [3251 0.57 [736 1.15 [19 64] [184 2.79 [7343 3.51 [3928 0.792 [5744 0.768 [3798 1.84 [7533 0.455 [3905 3.86 [17 47] [5413 1.85 [145 0.82 [731 11.1 [6588 0.728 [4806 1.46 [17 75] [17 90]] [17 54]] [4806 2.6 [38 50] [19 80]]] [19 90]] [19 72]]] [7251 0.478 [14 50] [4851 0.754 [17 66] [17 75]]]] [7185 1.4 [38 60] [19 63]]] [17 90]] [6313 0.508 [17 64] [17 81]]] [18 25]] [17 100]]] [17 92]] [7251 2 [19 64] [17 57]]] [4851 0.181 [19 53] [7381 2.61 [2616 2.71 [17 80] [17 66]] [38 43]]]] [19 100]] [5729 0.529 [1025 0.876 [7533 0.496 [4805 1.41 [17 81] [17 55]] [19 60]] [1689 0.234 [17 50] [35 60]]] [17 90]]] [35 100]] [31 100]] [19 100]] [5969 1.19 [7590 11 [682 1.67 [1011 6.41 [3119 2.47 [1239 2.86 [17 58] [17 50]] [17 57]] [719 5.31 [38 55] [17 28]]] [31 100]] [17 31]] [17 70]]] [134 1.71 [4805 0.495 [978 4.3 [7 28] [19 83]] [19 40]] [722 0.4 [141 0.441 [19 90] [17 45]] [19 93]]]] [16 80]] [5413 0.172 [931 2.32 [6591 1.13 [3734 0.725 [6891 1.88 [4806 2.04 [429 36.5 [4870 0.252 [19 42] [14 33]] [17 62]] [985 1.6 [724 3.63 [2260 1.1 [1078 1.53 [19 84] [5296 0.711 [19 91] [19 100]]] [19 84]] [19 60]] [19 75]]] [16 42]] [3913 0.21 [17 55] [19 50]]] [731 7.95 [6725 0.763 [6199 1.71 [38 59] [17 57]] [19 83]] [458 1.26 [1557 0.91 [6977 1.31 [896 5.79 [19 83] [17 41]] [35 57]] [19 91]] [17 88]]]] [17 46]] [1703 0.741 [6727 0.715 [1745 0.329 [17 60] [17 90]] [19 57]] [1703 2.63 [19 88] [19 50]]]]] [2628 1.81 [145 1.02 [1980 0.346 [1008 0.4 [6548 5.53 [17 85] [17 100]] [17 71]] [7381 0.9 [17 83] [17 100]]] [17 72]] [728 0.603 [6544 4.17 [17 60] [17 76]] [17 50]]]] [7722 2.86 [35 66] [35 80]]] [31 100]] [4851 3.82 [5969 0.242 [2573 3.03 [5953 1.44 [7068 0.188 [7251 2.42 [19 100] [19 66]] [19 100]] [19 60]] [19 61]] [19 100]] [19 42]]] [3517 0.381 [2902 1.05 [3563 0.13 [201 0.237 [896 4.91 [38 38] [17 69]] [19 88]] [5637 0.346 [728 0.65 [38 46] [19 61]] [19 100]]] [1690 0.137 [5812 3.19 [17 81] [38 42]] [17 100]]] [4802 0.899 [7711 2.14 [7203 5.62 [3879 2.65 [155 0.103 [7210 0.191 [2763 4.08 [19 100] [5412 4.98 [19 85] [19 100]]] [19 100]] [3014 2.12 [19 100] [19 62]]] [19 71]] [19 75]] [17 50]] [19 75]]]]] [5677 1.31 [7244 1.41 [2739 1.82 [4414 2.17 [5019 1.2 [5480 0.423 [5692 4.47 [7535 4.51 [4851 9.77 [1511 4.2 [4533 0.481 [429 3.05 [5509 17.1 [5 72] [5 80]] [112 1.33 [6334 3.99 [6724 2 [7598 2.48 [1062 8.23 [3252 2.64 [7566 0.695 [906 1.87 [6980 0.935 [5412 2.5 [5 94] [5 83]] [5 100]] [5 88]] [5 100]] [5 71]] [5 84]] [5 77]] [5 80]] [5 75]] [5 87]]] [5 100]] [5 62]] [5 82]] [5 45]] [2826 3.55 [1546 0.26 [5 80] [5 100]] [5 57]]] [19 58]] [5 66]] [6313 0.949 [4218 1.65 [5 58] [5 100]] [19 80]]] [4 100]] [5 54]] [17 71]]]] [688 9.54 [5821 4.49 [1062 0.135 [731 1.56 [695 2.96 [17 66] [14 43]] [7139 0.316 [286 6.83 [1429 18.3 [429 2.73 [7 85] [17 68]] [985 5.01 [6380 2.96 [663 0.624 [5413 1.84 [2199 0.3 [3905 2.06 [7 60] [17 82]] [17 60]] [5412 6.81 [17 100] [17 77]]] [1884 4.95 [141 6.92 [2259 1.61 [906 0.659 [1919 5.12 [1023 0.296 [5732 0.816 [7253 3.68 [17 97] [17 80]] [17 100]] [17 100]] [17 75]] [17 100]] [1078 11.4 [144 3.27 [4218 1.99 [3905 5.42 [17 80] [17 100]] [17 100]] [17 71]] [17 62]]] [17 57]] [17 62]]] [4558 1.5 [1025 0.632 [7512 18.9 [17 100] [3 20]] [14 55]] [17 85]]] [17 45]]] [17 41]] [6396 2.35 [19 40] [17 90]]]] [5383 5.98 [3353 0.458 [4312 2.18 [2064 1.8 [6187 0.415 [7520 4.5 [2260 8.3 [5648 2.33 [1023 6.5 [5211 1.14 [4218 0.231 [1723 0.974 [724 3.49 [17 100] [17 71]] [17 81]] [429 35.8 [7586 2.86 [724 0.117 [1704 9.03 [6015 2.67 [5732 6.28 [17 100] [17 95]] [17 93]] [1253 1.98 [3929 13.4 [17 85] [17 100]] [17 83]]] [7414 0.195 [1980 1.51 [17 100] [6732 0.211 [17 92] [17 100]]] [17 100]]] [17 90]] [17 75]]] [17 62]] [17 75]] [17 78]] [17 58]] [17 42]] [17 71]] [17 66]] [17 44]] [17 57]] [17 50]]] [2 33]] [7 83]]]] [6083 13.3 [6040 0.492 [5637 0.496 [5812 0.508 [1783 0.491 [721 8.07 [5647 2.86 [2143 1.47 [6621 1.65 [429 53.2 [13 100] [906 4.35 [13 84] [13 100]]] [13 100]] [13 100]] [13 100]] [13 96]] [13 100]] [13 100]] [13 100]] [13 100]] [13 72]]] [2993 0.979 [4279 3.75 [2029 17.5 [5119 0.143 [2559 2.25 [7413 2.92 [5648 0.23 [2025 5.6 [2480 0.314 [5116 0.362 [2752 5.07 [11 50] [1995 0.68 [2081 4.06 [11 63] [11 80]] [11 100]]] [11 100]] [11 100]] [11 80]] [11 100]] [11 60]] [11 85]] [11 100]] [11 62]] [11 80]] [11 17]]] [7742 3.75 [1899 12.3 [1646 0.312 [2199 0.0611 [719 0.412 [2993 9.3 [1783 0.69 [2826 0.901 [5634 1 [7 98] [7 100]] [7 100]] [7 100]] [7 83]] [7 100]] [7 100]] [7 100]] [3008 0.32 [2093 1.02 [6524 1.68 [7 98] [7 100]] [7 100]] [7 100]]] [7 95]]] [2259 2 [1004 1.49 [5820 0.285 [1253 2.26 [4218 0.609 [5260 2.39 [1218 20.4 [2048 1.25 [5473 1.04 [5400 1.34 [2752 8.13 [2535 2.97 [2608 2.91 [13 74] [2 84]] [2 90]] [6077 3.11 [2 50] [13 100]]] [13 100]] [6621 2.03 [7449 3.24 [13 98] [13 100]] [13 100]]] [22 40]] [2 50]] [13 100]] [7169 0.238 [896 4.56 [13 100] [6413 1.24 [13 94] [13 100]]] [13 100]]] [2 72]] [2616 5.93 [2 83] [2 100]]] [2 100]] [2536 1.38 [906 0.155 [3769 0.302 [888 0.355 [2005 2.56 [7491 6.64 [7722 0.356 [4253 6.99 [978 3.85 [1239 7.41 [7520 2.99 [6187 4.33 [791 3.03 [13 89] [7009 0.766 [13 75] [13 100]]] [13 85]] [13 77]] [13 87]] [2 44]] [13 100]] [13 100]] [4 77]] [2 100]] [13 100]] [13 100]] [13 100]] [2 71]]]] [6015 0.817 [2951 0.449 [95 1.68 [685 0.96 [5871 11.8 [1062 11.7 [1630 1.03 [2754 3.76 [2832 0.67 [1078 4.47 [3067 0.623 [7571 0.158 [6223 2.82 [5197 7.3 [7156 2.53 [36 71] [36 100]] [36 57]] [36 100]] [36 100]] [36 100]] [23 36.9 [1400 11.9 [1409 0.294 [4545 1.34 [7381 1.37 [112 0.671 [4326 0.998 [5673 0.96 [3424 2.74 [3905 3.03 [2411 0.64 [7590 2.93 [4815 12.9 [7698 0.917 [4818 0.801 [2752 4.07 [36 80] [2993 2.89 [1986 0.846 [36 96] [36 100]] [36 100]]] [36 100]] [36 100]] [36 71]] [36 90]] [36 100]] [36 100]] [36 62]] [36 54]] [36 100]] [1 5.77 [36 100] [36 96]]] [5 77]] [36 100]] [36 100]] [36 61]] [36 75]]] [36 100]] [36 58]] [14 100]] [14 27]] [14 66]] [14 100]] [14 90]] [2651 4.64 [14 62] [14 100]]] [14 72]]] [4713 0.704 [5457 0.409 [7423 0.627 [4674 1.29 [3004 0.0963 [6502 0.38 [4500 0.632 [6031 1.26 [429 5.42 [4450 0.15 [7421 4.43 [6424 0.264 [7738 0.274 [6959 0.645 [2628 0.508 [7514 2.22 [4891 0.366 [2763 4.01 [2275 0.675 [7449 17 [7620 0.28 [5558 0.975 [4239 0.911 [2187 0.77 [6 16] [24 38]] [4245 13.9 [20 90] [20 100]]] [20 100]] [20 83]] [2 44]] [6 31]] [20 80]] [6 42]] [19 59]] [7422 0.191 [2869 0.227 [4623 5.23 [7260 2.94 [7489 9.43 [7390 0.341 [7428 0.761 [2644 0.13 [2733 1.29 [2232 0.81 [6 24] [6 50]] [16 39]] [16 71]] [19 42]] [6 72]] [38 100]] [18 35]] [37 33]] [16 40]] [5409 2.2 [1384 2.44 [4431 2.02 [16 44] [16 66]] [1899 1.43 [16 33] [6 52]]] [6 44]]]] [3238 1.32 [4889 2.25 [1821 0.483 [6257 0.559 [2671 3.97 [5716 8.43 [5103 2.66 [2199 0.0878 [2858 0.34 [2654 1.42 [2618 0.873 [7048 0.539 [5723 11.9 [6375 0.551 [2727 1.24 [1899 9.7 [7282 0.314 [2649 1.09 [16 91] [16 100]] [16 100]] [16 33]] [16 75]] [16 54]] [16 55]] [16 50]] [16 58]] [16 50]] [6 53]] [2939 9.96 [19 44] [16 50]]] [6959 4.52 [1429 11.6 [6 78] [16 68]] [18 66]]] [7 42]] [7445 1.01 [2178 0.679 [2093 0.137 [2713 0.634 [16 75] [16 83]] [16 60]] [16 100]] [16 45]]] [18 54]] [7 100]] [6 37]] [7 45]]] [19 90]] [7040 0.302 [5130 1.11 [5632 3.14 [6923 0.132 [5627 0.637 [7041 2.47 [6 94] [6 42]] [6 66]] [6167 0.0659 [30 36] [16 50]]] [16 70]] [16 100]] [2259 49.7 [6 70] [6 100]]]] [7582 1.23 [2707 0.568 [6750 0.873 [7203 0.756 [6 73] [6 45]] [1429 16.6 [4726 1.29 [6423 5.38 [6 86] [6 50]] [6 100]] [5609 0.485 [4732 1.29 [6 95] [6 87]] [6 100]]]] [1895 2.33 [2680 0.84 [2857 2.45 [7603 3.54 [5104 18.2 [7122 3.72 [5724 4.63 [5484 1.29 [2728 2.24 [23 5.01 [6287 1.08 [5099 45.5 [5102 10.7 [6 64] [6 80]] [6 100]] [6 87]] [2978 3.08 [7347 6.39 [1587 3.39 [2871 15.8 [4977 1.31 [4651 3.35 [62 3.17 [7150 2.84 [2871 4.33 [5632 1.36 [16 68] [16 85]] [187 3.44 [16 55] [6 63]]] [16 37]] [16 88]] [16 30]] [6 77]] [18 58]] [6 87]] [16 85]] [6 47]]] [16 42]] [18 44]] [16 90]] [187 1.09 [16 78] [16 44]]] [6 100]] [4651 8.31 [6424 4.78 [190 4.83 [6 82] [6 100]] [6 50]] [6 50]]] [16 85]] [7 100]] [2733 1.94 [4851 5.67 [2551 2.97 [16 76] [16 64]] [7255 6.12 [16 66] [18 45]]] [16 57]]]] [7665 16.2 [2275 0.646 [6 77] [6 100]] [6 100]]]] [6136 8.76 [1895 4.35 [2616 8.75 [5358 0.501 [5963 2.61 [190 3.6 [6 100] [6 77]] [6 62]] [16 57]] [6100 6.73 [1239 58.9 [6 96] [6 62]] [6 77]]] [16 54]] [6 50]]] [3147 0.312 [6230 0.304 [7723 0.205 [7404 1.22 [7512 15.4 [2707 0.893 [730 0.121 [4725 9.76 [6401 0.349 [5812 2 [1391 0.901 [1723 1.94 [6644 2.52 [5132 0.652 [874 0.597 [6100 0.935 [1384 4.22 [7736 2.44 [968 0.325 [384 0.948 [2180 3.6 [876 0.551 [276 4.86 [1239 52.8 [4027 1.83 [6490 0.655 [1020 1.54 [4338 6.81 [1751 0.697 [4675 2.86 [2004 3.89 [5641 0.218 [1980 13.4 [1400 1.04 [248 1.57 [221 5.88 [4646 3.56 [4414 0.603 [5154 5.64 [7185 1.82 [6621 4.9 [1429 33.9 [132 2.55 [6 15] [16 33]] [28 21]] [13 42]] [11 37]] [37 62]] [11 32]] [18 88]] [29 42]] [29 90]] [36 25]] [23 18]] [19 75]] [23 50]] [6 64]] [1641 8.41 [1997 1.09 [7512 7.73 [22 28] [36 60]] [36 71]] [16 33]]] [24 77]] [24 75]] [29 72]] [24 100]] [9 85]] [18 50]] [29 100]] [29 87]] [23 54]] [6859 2.72 [1899 4.8 [1429 34.7 [28 100] [16 57]] [23 55]] [28 100]]] [18 100]] [6 80]] [6 100]] [3149 0.597 [36 87] [36 100]]] [16 57]] [28 100]] [1788 3.64 [36 44] [36 94]]] [1899 7.11 [1400 5.82 [22 64] [15 100]] [22 90]]] [291 1.25 [4851 4.46 [5599 2.29 [978 6.36 [2 28] [4 67]] [2 52]] [7 37]] [2 71]]] [7374 0.79 [36 97] [36 100]]] [6 100]] [221 0.395 [28 47] [28 100]]] [62 1.15 [7491 2.55 [5627 0.484 [7424 0.351 [2897 5.3 [663 3.35 [6515 0.589 [5480 3.11 [5799 0.35 [5597 0.644 [7 25] [16 84]] [16 100]] [18 55]] [16 57]] [1899 5.57 [18 75] [16 66]]] [18 71]] [16 90]] [429 8.78 [6 87] [16 40]]] [18 81]] [16 66]]] [7354 3.04 [5972 3.7 [7413 1.43 [6098 2.15 [2763 0.942 [939 0.693 [4651 3.69 [6514 5.41 [7449 1.23 [6923 4.77 [7682 5.44 [2275 3.27 [6 61] [6 84]] [6 92]] [6 100]] [18 33]] [2259 58.8 [6 90] [6 100]]] [6 75]] [6 33]] [20 26]] [6 100]] [2 36]] [31 64]] [18 26]]] [4891 0.576 [6901 1.34 [6 100] [6 83]] [6 69]]] [5679 0.223 [1239 21.6 [7222 2.86 [2199 0.485 [18 78] [18 58]] [16 42]] [16 57]] [19 87]]] [1000 0.122 [7354 2.99 [2573 1.6 [3312 0.43 [6980 0.649 [6311 0.479 [6524 0.232 [5972 1.84 [7561 2.97 [1883 1.24 [1011 0.235 [392 5.84 [939 7.45 [602 7.13 [7188 1.33 [1909 0.645 [2616 0.649 [7722 0.485 [5130 0.338 [34 23] [16 44]] [32 33]] [2763 1.22 [5 40] [5 40]]] [4 33]] [16 44]] [21 55]] [29 61]] [18 36]] [2628 2.71 [695 6.47 [7 50] [4 38]] [1025 3.32 [19 41] [17 62]]]] [24 55]] [17 55]] [31 52]] [22 23]] [7 50]] [17 100]] [7 69]] [7241 0.65 [17 100] [17 63]]] [6657 0.531 [6632 0.356 [7381 3.92 [957 2.64 [284 1.58 [5345 0.698 [4716 5 [5692 2.17 [1997 1.14 [2813 0.726 [4717 0.768 [5099 0.38 [663 2.63 [19 42] [38 33]] [18 82]] [18 60]] [18 85]] [7 44]] [18 80]] [19 55]] [4673 0.158 [5693 0.717 [19 50] [16 46]] [16 87]]] [19 92]] [5753 0.167 [18 61] [18 75]]] [38 78]] [16 92]] [1078 15.4 [16 100] [16 53]]]] [736 0.199 [17 47] [17 66]]]] [4174 1.29 [7673 0.355 [2259 17.3 [6920 2.16 [4154 2.74 [36 77] [24 100]] [24 100]] [4022 1.43 [5597 2.74 [36 56] [7491 0.751 [36 83] [36 100]]] [36 100]]] [24 100]] [24 100]]]] [5227 0.255 [7512 7.33 [7335 0.704 [6475 0.618 [2241 1.62 [5090 1.6 [22 83] [22 100]] [22 63]] [22 100]] [22 71]] [22 72]] [22 100]]] [29 97]] [2752 32.3 [5211 1.72 [7422 0.629 [19 35] [29 72]] [22 100]] [7197 1.16 [1078 32.7 [6529 0.9 [6031 1.86 [22 85] [22 100]] [22 83]] [22 65]] [22 100]]]] [874 0.32 [5716 1.34 [5693 0.652 [36 100] [36 87]] [36 83]] [36 100]]] [1239 19.3 [2733 0.319 [1899 13.3 [5647 0.186 [4854 12.2 [2866 9.69 [791 4.14 [23 9.17 [1661 0.182 [2628 29.9 [7301 2.66 [2292 6.04 [2649 0.892 [6 65] [6100 1.47 [6 76] [16 100]]] [16 88]] [6 58]] [6 100]] [6 62]] [299 1.64 [16 34] [6 50]]] [6 40]] [37 85]] [16 90]] [16 80]] [7224 1.27 [6 91] [6 69]]] [16 72]] [6876 6.91 [2275 2.56 [2716 0.332 [190 0.0692 [5349 2.4 [7041 2.76 [1364 1.68 [1349 3.16 [7405 3.39 [2551 5.85 [2526 89.2 [5722 4.54 [5716 15.1 [7665 6.71 [6 68] [429 0.904 [2406 11.5 [2554 2.15 [2029 7.62 [6 89] [6 100]] [6 50]] [6 71]] [2584 1.36 [1384 9.03 [6 92] [6 100]] [6 100]]]] [16 55]] [6 96]] [6 55]] [2279 4.85 [16 61] [6 83]]] [6 100]] [6 95]] [2549 12.9 [4712 3.63 [6 100] [6 87]] [6 91]]] [16 50]] [5962 2.54 [6 70] [5409 8.35 [7675 1.38 [6 55] [16 90]] [6 88]]]] [2551 1.5 [7675 1.42 [6 50] [6 100]] [16 42]]] [2689 1.28 [5626 0.903 [6 50] [16 80]] [6 81]]] [1276 8.46 [6277 8.08 [5797 0.852 [6328 1.57 [4651 3.08 [1940 0.724 [5721 2.59 [1364 2.66 [5962 6.46 [1349 0.281 [5408 2.89 [1239 41.7 [4513 0.334 [6 80] [6 100]] [6 100]] [6 57]] [6 100]] [6 100]] [1078 19.3 [6 100] [6 85]]] [6 83]] [6 100]] [2275 19.2 [1883 1.39 [4513 1.35 [6 76] [6 100]] [6 100]] [6 40]]] [1340 3.3 [6 66] [6 100]]] [299 1.32 [6 61] [6 100]]] [6 60]] [16 57]]] [16 58]]]] [4414 27.2 [2248 2.45 [7454 0.732 [1808 0.907 [2748 0.155 [2202 1.56 [4854 22.4 [5647 10.2 [2383 6.02 [3972 0.628 [6779 2.42 [964 0.0939 [4647 0.455 [7281 1.4 [7726 3.14 [75 0.128 [1011 0.516 [2877 0.35 [165 1.81 [2029 4.87 [7391 1.37 [2653 0.594 [7421 0.216 [2955 8.79 [5680 0.465 [5627 1.42 [194 2.8 [78 0.68 [16 65] [16 90]] [16 70]] [16 33]] [16 54]] [7101 11.5 [2650 0.222 [16 39] [18 37]] [16 80]]] [2939 31.6 [16 40] [6 45]]] [16 87]] [29 33]] [96 8.85 [7222 3.29 [2653 0.971 [2029 10.4 [2707 32.5 [16 93] [16 80]] [7038 4.95 [16 100] [6 57]]] [16 85]] [16 55]] [7255 9.35 [16 52] [16 100]]]] [187 11.2 [16 43] [38 75]]] [7222 0.179 [2733 1.07 [16 60] [16 92]] [16 83]]] [18 45]] [5010 6.59 [5799 12.4 [2108 6.48 [5983 0.116 [1980 15.7 [1948 0.128 [5643 10.7 [97 5.09 [6471 5.1 [221 4.34 [5673 16.6 [1783 17.9 [2690 0.321 [7423 16.1 [2809 0.535 [7428 0.372 [4851 13.1 [2655 10.9 [2466 7.5 [4892 0.201 [2849 23.9 [5724 2.33 [16 70] [6 55]] [5130 0.73 [5100 15.7 [2611 3.35 [5898 0.319 [16 84] [2729 1.96 [16 70] [16 100]]] [16 66]] [16 57]] [16 66]]] [190 2.78 [16 83] [16 100]]] [16 53]] [16 100]] [4414 7.01 [6 33] [16 85]]] [6 54]] [16 100]] [7372 24.4 [16 50] [16 66]]] [5594 9.76 [16 100] [16 83]]] [76 2.34 [2877 0.655 [2640 0.371 [16 90] [16 100]] [16 85]] [16 66]]] [16 47]] [16 52]] [6 55]] [16 60]] [16 33]] [16 50]] [38 28]] [16 44]] [6 25]] [8 50]] [18 71]]] [38 37]] [2259 8.69 [5593 2.12 [6 67] [16 28]] [16 85]]] [18 71]] [1837 1.09 [16 41] [18 60]]] [37 0.382 [37 52] [37 66]]] [88 9.52 [190 4.21 [16 58] [5 23]] [37 77]]] [38 100]] [18 58]] [78 0.876 [75 5.84 [194 7.06 [2939 30 [6 93] [6 75]] [6 75]] [6 70]] [16 42]]] [6 80]] [7476 2.25 [3238 0.65 [38 44] [16 100]] [38 81]]] [190 6.73 [38 80] [38 100]]] [16 85]] [6 54]] [6 88]]] [4495 0.41 [4493 0.349 [6076 0.111 [5345 0.353 [2259 10.4 [7722 3.1 [2536 0.48 [1746 3.83 [1911 5.35 [6920 3.52 [28 42] [24 75]] [36 66]] [24 100]] [24 100]] [36 70]] [4087 0.205 [899 0.336 [3148 2.73 [36 65] [24 69]] [36 100]] [36 100]]] [2260 0.49 [1078 12 [36 100] [906 1.03 [36 83] [36 100]]] [36 100]]] [17 92]] [1641 0.275 [2273 0.782 [36 100] [36 77]] [36 100]]] [24 100]]] [3836 0.365 [2728 0.169 [278 0.202 [2654 0.875 [2716 0.607 [6674 4.67 [6100 6.8 [5480 0.15 [6499 1.22 [7043 0.157 [2554 0.619 [2251 1.12 [2292 7.25 [2619 6.08 [4893 3.66 [2577 5.53 [190 3 [7519 1.08 [7506 5.65 [7404 2.34 [7560 0.188 [7665 1.04 [6 60] [4675 0.104 [7675 17.1 [6287 9.55 [2611 0.244 [6 85] [6 96]] [6 81]] [6 71]] [6 100]]] [6 100]] [6 100]] [6 62]] [221 3.06 [6 100] [6 60]]] [5597 2.35 [30 37] [6 93]]] [6 66]] [6 62]] [6 50]] [6 57]] [6 40]] [6168 1.48 [6423 8.48 [6099 3.05 [6 95] [6 100]] [6 87]] [6 72]]] [5776 1.17 [6 72] [6 50]]] [4889 0.412 [7283 0.552 [2280 0.891 [6 90] [6 100]] [6 100]] [4450 1.68 [7675 10.8 [1384 0.171 [434 1.05 [4673 6.75 [6 50] [6 85]] [16 55]] [6 100]] [16 63]] [978 0.861 [6 83] [6 100]]]]] [6 36]] [2577 2.24 [4673 4.99 [4820 0.588 [2282 4.91 [6 95] [6 66]] [6 100]] [7574 4.37 [2259 80.5 [6100 7.95 [6 75] [6 50]] [6 100]] [16 80]]] [6 66]]] [6 67]] [16 57]] [2412 0.477 [4717 4.26 [16 80] [6 66]] [2717 1.5 [6 90] [6 54]]]] [18 60]] [7260 0.0671 [5093 2.28 [16 100] [16 54]] [6 50]]] [16 54]]]] [2517 7.21 [4546 1.95 [2793 5.54 [2453 23 [4908 3.43 [4342 1.32 [7673 4.9 [6937 0.798 [5833 6.99 [4356 3.59 [2993 2.74 [2451 6.32 [6692 8.35 [4346 0.259 [7722 9.6 [2264 1.71 [5368 3.42 [1919 0.368 [7591 10.7 [141 4.98 [896 0.384 [1206 13.7 [1239 0.521 [6266 2.46 [2752 51.1 [5692 1.11 [24 99] [24 100]] [24 82]] [24 100]] [24 100]] [24 70]] [7566 9.62 [24 100] [24 87]]] [24 87]] [24 90]] [24 100]] [24 80]] [24 85]] [24 83]] [4815 1.49 [24 90] [24 80]]] [24 75]] [24 72]] [24 70]] [6732 8.48 [1746 1.72 [1888 1.85 [2259 19.5 [24 100] [24 91]] [24 66]] [24 100]] [24 71]]] [24 75]] [24 57]] [24 85]] [1738 1.76 [144 19.1 [4185 0.774 [4457 0.217 [4025 0.266 [2081 4.65 [1913 0.208 [221 0.592 [4339 15.9 [6265 0.341 [4145 13.9 [24 100] [24 83]] [24 100]] [24 57]] [24 100]] [24 100]] [1888 3.21 [24 100] [24 80]]] [24 100]] [24 100]] [24 83]] [24 84]] [1047 8.68 [4037 1.08 [24 93] [24 100]] [24 81]]]] [24 71]] [24 85]] [6338 1.15 [985 2.91 [5907 1.78 [2526 6.03 [6861 2.97 [2773 0.463 [6860 2.44 [4789 1.43 [168 0.675 [4217 0.154 [3026 5.88 [7530 3.87 [5693 4.7 [4356 6.02 [5733 0.38 [24 93] [24 100]] [24 72]] [24 100]] [24 72]] [3645 0.383 [24 91] [24 80]]] [24 100]] [24 55]] [24 62]] [24 66]] [24 100]] [19 55]] [6373 3.74 [2777 3.74 [4046 1.8 [2548 6.09 [3665 3.6 [5814 0.865 [7665 0.358 [24 97] [24 100]] [1239 1.89 [24 83] [24 100]]] [24 77]] [24 95]] [1240 0.968 [24 82] [24 66]]] [3630 4.81 [19 62] [24 100]]] [24 62]]] [24 60]] [4340 0.743 [24 60] [24 50]]] [3640 0.919 [7169 0.339 [24 62] [24 81]] [19 66]]]] [2517 3.52 [24 100] [978 3.76 [24 100] [4338 22.4 [24 100] [24 85]]]]] [6223 3.2 [4353 0.316 [6616 1.91 [5867 8.19 [286 0.351 [5904 0.54 [4341 2.11 [4895 0.288 [6338 6.67 [1050 10.3 [4045 2.14 [2526 2.82 [4342 12 [5427 16.2 [5052 1.15 [24 87] [4279 11.8 [24 86] [24 44]]] [24 63]] [24 97]] [5686 0.402 [7351 3.73 [24 100] [1035 1.02 [24 81] [24 87]]] [24 90]]] [19 50]] [24 66]] [4299 0.669 [24 76] [24 65]]] [2771 1.4 [6337 1.44 [896 8.7 [1239 4.52 [24 57] [24 66]] [24 100]] [19 62]] [24 100]]] [24 60]] [5753 0.352 [4895 0.617 [6373 2.33 [4573 2.85 [24 83] [19 75]] [19 100]] [24 90]] [208 6.21 [19 66] [19 90]]]] [3636 2.59 [4338 15.9 [5007 1.23 [19 53] [19 66]] [24 92]] [24 100]]] [4338 18.1 [38 66] [24 83]]] [24 37]] [5076 0.816 [3663 2.2 [19 57] [19 69]] [24 85]]] [24 100]]]] [2145 3.69 [3 100] [3 92]]] [7176 2.75 [267 3.59 [1239 12.3 [2529 0.154 [3278 0.745 [396 0.565 [685 0.209 [4703 0.929 [5972 1.09 [2936 0.194 [7007 0.478 [423 0.258 [7516 1.15 [5007 0.22 [1400 1.74 [896 2.76 [4369 4.86 [3333 1.08 [5839 5.21 [1696 0.6 [7623 9.62 [1429 19.7 [1059 5.65 [4769 1.63 [663 0.434 [3635 2.44 [5527 2.09 [6304 1.33 [249 6.5 [3458 3.89 [6472 0.87 [1 9.1 [2978 3.82 [695 6.45 [567 2.82 [2752 5.95 [7609 18.4 [5171 2.65 [978 3.12 [5172 1.99 [6492 1.16 [187 1.36 [2081 12.4 [4655 5.43 [7318 11.1 [5170 10.7 [4592 7.98 [2915 4.92 [4768 34.8 [2011 3.4 [5140 1.82 [2225 10.6 [4398 10.7 [4690 1.93 [1587 4.8 [5170 2.36 [6653 9.29 [2707 4.5 [7759 7.53 [2379 2.24 [2058 2.92 [4684 3.36 [4680 9.8 [6899 6.33 [2072 0.146 [6177 1.46 [2939 42.2 [23 79.7 [2005 11.2 [4154 45.1 [4991 12.1 [4799 5.88 [33 16] [33 60]] [25 66]] [13 25]] [25 62]] [4154 8.2 [33 56] [29 85]]] [29 42]] [25 69]] [6 28]] [33 100]] [1 60]] [25 25]] [2 50]] [32 42]] [13 87]] [26 36]] [19 40]] [33 46]] [13 88]] [20 100]] [29 38]] [29 28]] [33 100]] [29 88]] [15 25]] [2913 53.5 [25 60] [25 37]]] [33 66]] [33 74]] [3 100]] [1 97]] [328 1.93 [1 30] [1 50]]] [16 28]] [2 81]] [33 86]] [25 35]] [5368 2.39 [178 15.1 [33 91] [26 62]] [33 71]]] [25 87]] [2846 0.763 [2977 2.32 [5236 3.14 [6526 2.65 [6363 3.03 [250 2.49 [4205 1.72 [771 5.33 [6015 5.24 [7411 3.52 [5140 3.31 [5211 12.9 [1104 15.4 [4768 27.7 [995 1.93 [4874 6 [6074 6.53 [429 38 [5692 15.4 [2913 55.5 [1011 4.39 [1927 20.9 [328 88 [5170 2.39 [7742 2.89 [4349 4.07 [2199 10 [221 3.23 [5154 1.42 [2263 5.26 [3008 15.1 [6471 0.873 [2939 7.49 [26 35] [25 47]] [26 100]] [25 92]] [25 66]] [25 63]] [25 75]] [248 47.7 [25 88] [25 83]]] [26 100]] [25 84]] [2764 15.6 [5662 4.95 [26 53] [26 66]] [33 85]]] [25 66]] [25 87]] [26 100]] [978 11 [328 161 [26 50] [26 100]] [26 100]]] [25 75]] [29 41]] [15 66]] [25 85]] [26 100]] [25 81]] [25 66]] [30 29]] [33 88]] [15 75]] [29 75]] [25 100]] [26 80]] [1 41]] [25 100]] [25 100]] [20 88]] [25 97]] [25 92]]] [29 52]] [26 26]] [26 61]] [5830 5.28 [31 34] [11 100]]] [978 31 [1783 1.74 [1429 2.06 [26 94] [26 100]] [26 83]] [26 75]]] [1078 17.1 [15 100] [25 70]]] [1 71]] [29 100]] [29 100]] [1 100]] [4601 0.867 [2701 1.54 [2081 8.08 [1888 6.39 [2939 2.2 [25 38] [2 42]] [26 71]] [1 61]] [29 92]] [26 78]]] [791 27 [2004 0.914 [4154 2.46 [29 94] [29 100]] [29 100]] [29 90]]] [26 92]] [1783 38.8 [7334 0.0396 [4642 0.259 [1698 4.76 [5941 0.165 [2470 3.4 [6017 0.986 [6601 5.26 [5333 5.05 [6643 1.38 [3929 1.48 [1568 2.06 [6177 1.88 [6776 18.4 [5853 2.96 [2902 10.4 [4754 13 [2701 1.85 [5003 4.93 [6382 7.02 [3243 6.07 [1899 73.3 [248 28 [4895 25 [6544 2.46 [2748 3.56 [6395 2.34 [4655 3.45 [7085 7.71 [2202 1.83 [2232 3.39 [2130 3.32 [6899 5.49 [1708 9.09 [6653 10.6 [719 14.7 [6809 2.35 [2241 11.9 [1648 4.76 [1742 12.1 [7742 7.43 [1432 4.3 [978 9.65 [1445 15.1 [1587 16.4 [728 5.38 [2259 22.3 [29 12] [3008 6.94 [7665 0.901 [7 13] [14 54]] [10 40]]] [7 37]] [35 33]] [29 77]] [8 31]] [26 44]] [25 66]] [33 80]] [35 75]] [7 30]] [32 100]] [33 54]] [19 44]] [28 80]] [33 84]] [20 37]] [13 21]] [1 50]] [30 31]] [1 100]] [15 46]] [26 100]] [14 44]] [26 76]] [4802 2.73 [7472 0.775 [2913 16.5 [2225 14.1 [2993 6.39 [4738 4.76 [328 60.2 [2526 2.86 [33 21] [26 28]] [15 54]] [26 100]] [26 77]] [20 50]] [26 77]] [38 88]] [4802 38.5 [33 65] [1 50]]]] [29 66]] [15 100]] [14 77]] [7 100]] [29 82]] [13 46]] [1 73]] [29 100]] [13 65]] [25 83]] [32 100]] [12 40]] [13 78]] [11 100]] [15 100]] [2701 2.96 [29 85] [29 100]]] [6342 1.02 [15 54] [15 45]]] [1718 0.319 [3597 0.308 [4862 1.99 [5564 1.89 [3 53] [14 100]] [3 100]] [14 32]] [4643 4.12 [17 60] [3 37]]]] [25 95]] [1985 0.352 [32 94] [32 100]]] [5298 0.284 [2259 32.7 [1530 0.793 [4783 1.98 [5296 0.694 [3599 0.158 [2246 0.208 [1980 1.01 [14 27] [6650 1.36 [32 59] [32 100]]] [32 100]] [32 100]] [19 42]] [14 100]] [14 40]] [14 75]] [32 92]]] [1587 15.4 [2143 18.7 [5086 3.03 [5447 0.131 [7329 14.7 [13 31] [11 44]] [7 25]] [33 57]] [13 70]] [13 81]]]] [1239 4.18 [2259 51.8 [33 34] [34 77]] [6184 3.12 [6524 5.97 [33 50] [1 70]] [1 50]]]] [3006 8.62 [1239 7.64 [7385 2.13 [1445 1.09 [3006 0.6 [26 91] [26 100]] [26 100]] [26 75]] [3834 14.3 [26 57] [26 71]]] [26 72]]] [7065 5.09 [2402 0.0861 [6681 1.83 [5796 0.0905 [695 0.402 [4790 0.487 [3 94] [3 100]] [3 77]] [3 100]] [3 87]] [3 100]] [32 62]]] [5662 1.74 [250 15.1 [1 100] [1429 13.8 [1 100] [1 87]]] [1 100]]] [791 2.6 [6177 2.15 [25 64] [25 100]] [6434 1.55 [25 51] [32 100]]]] [5757 0.728 [7583 3.51 [107 1.99 [504 2.88 [7381 5.42 [7453 2.42 [5173 0.631 [1698 3.94 [5995 0.873 [2836 1.65 [1764 3.36 [673 6.77 [7665 9.69 [144 0.986 [29 35] [1429 11.9 [29 81] [18 60]]] [25 35]] [771 3.82 [6471 1.02 [4391 1.98 [3008 10.9 [4235 9.33 [2763 4.41 [673 22.3 [26 61] [4611 2.62 [26 87] [26 100]]] [26 55]] [26 53]] [791 18.8 [6 45] [25 85]]] [26 100]] [2526 2.04 [26 91] [26 100]]] [25 100]]] [25 100]] [25 100]] [29 100]] [25 88]] [26 85]] [29 81]] [14 62]] [29 53]] [25 71]] [25 67]] [29 100]]] [731 0.387 [429 23.5 [786 1.22 [1888 2.46 [4611 3.76 [392 4.39 [6853 3.65 [3607 0.713 [5110 0.904 [1429 47.1 [2939 9.07 [4377 1.1 [5079 0.821 [7590 3.33 [7187 1.06 [1239 7.25 [25 50] [15 52]] [7665 8.7 [26 59] [26 95]]] [3008 5.54 [26 54] [26 100]]] [25 97]] [25 100]] [26 57]] [14 45]] [4369 9.55 [328 15.6 [5739 1.95 [15 94] [15 100]] [15 50]] [15 100]]] [15 100]] [25 95]] [2586 1.53 [2752 19.5 [2913 2.73 [25 55] [25 94]] [26 52]] [25 100]]] [2915 11.5 [695 2.09 [392 5 [26 84] [26 42]] [15 46]] [26 100]]] [26 72]] [5732 1.77 [6091 2.33 [7411 1.89 [15 66] [15 100]] [15 100]] [15 100]]] [258 1.24 [2526 3.95 [6177 7.25 [5170 6.67 [3458 1.03 [5809 2.39 [2701 3.94 [15 56] [15 95]] [15 100]] [15 100]] [26 80]] [25 100]] [1400 31.2 [1980 4.27 [25 59] [26 55]] [25 100]]] [15 100]]] [3006 0.193 [6182 0.73 [7722 5.16 [1223 6.68 [6727 9.71 [1023 4.49 [5368 10.6 [2259 6.35 [1995 1.67 [107 2.04 [26 57] [25 100]] [25 62]] [25 64]] [25 50]] [25 70]] [26 100]] [25 90]] [2826 2.37 [26 85] [26 100]]] [25 100]] [26 100]]]] [134 0.16 [906 0.321 [3905 1.88 [1980 1.99 [5482 1.01 [6080 2.76 [7512 5.16 [407 3.07 [29 32] [26 86]] [25 40]] [15 100]] [29 60]] [2154 0.561 [7385 1.83 [5482 0.879 [1223 1.31 [6997 0.998 [126 1.08 [978 7.28 [4611 2.05 [5969 0.949 [29 55] [29 100]] [1628 3.51 [29 80] [29 100]]] [25 60]] [29 100]] [29 100]] [26 50]] [29 92]] [29 100]] [29 100]]] [15 100]] [3480 0.978 [6653 0.52 [7512 4.74 [811 0.642 [6674 0.822 [7494 0.437 [2774 0.161 [4279 0.693 [29 95] [29 100]] [29 77]] [29 100]] [29 100]] [15 100]] [29 50]] [29 100]] [15 100]]] [26 48]]] [1888 0.467 [6375 0.985 [6182 1.23 [5660 8.52 [673 14 [3424 0.719 [1885 1.51 [6216 0.682 [2526 4.02 [7449 9.06 [2749 1.64 [4369 0.618 [5019 6.21 [2849 2.95 [26 32] [16 39]] [26 50]] [25 31]] [26 96]] [25 87]] [6776 1.67 [2983 0.782 [6551 2.67 [6189 0.745 [6177 1.66 [3006 1.5 [731 9.01 [673 9.87 [26 48] [26 40]] [2755 2.76 [26 80] [26 85]]] [248 57.8 [26 81] [26 100]]] [25 98]] [25 95]] [26 100]] [26 75]] [26 55]]] [26 100]] [26 100]] [25 100]] [7054 3.62 [4851 0.322 [7414 3.54 [4200 2.36 [145 1.14 [5412 2.85 [5483 3.89 [178 17.9 [257 1.52 [1084 1.36 [7301 2.26 [1076 2.54 [5692 20 [7516 11.4 [26 79] [719 13.2 [1081 14.3 [26 92] [26 70]] [26 85]]] [25 50]] [26 100]] [26 100]] [26 100]] [1899 3.1 [26 92] [26 100]]] [25 41]] [26 72]] [978 4.1 [25 71] [26 71]]] [135 1.64 [26 87] [26 100]]] [26 100]] [25 60]] [26 98]] [25 37]]] [25 83]] [25 100]] [25 87]] [6724 2.57 [2128 1.86 [3027 1.27 [4920 4 [7169 14.6 [2915 0.334 [5838 0.671 [2199 3.91 [7520 7.3 [5431 4.32 [906 0.571 [4200 11.5 [1 1.69 [5662 0.441 [4684 0.574 [7552 2.79 [2939 4.97 [681 3.76 [7665 6.1 [26 89] [7512 12.3 [26 100] [1888 11 [26 100] [26 90]]]] [26 87]] [26 83]] [26 88]] [26 100]] [26 100]] [26 44]] [26 50]] [26 100]] [26 60]] [26 57]] [26 44]] [26 71]] [26 100]] [26 58]] [26 60]] [26 50]] [1 71]] [26 50]]]] [7041 0.239 [2904 2.41 [1024 0.129 [7320 3.83 [2081 8.02 [7343 4.5 [2650 2.6 [7512 10.5 [1400 19.5 [328 7.54 [5632 4.93 [7512 3.51 [26 100] [7512 4.19 [26 75] [26 100]]] [26 90]] [1587 1.03 [26 80] [26 100]]] [2526 2.64 [26 85] [26 80]]] [5174 18.5 [4414 2.18 [248 74.8 [6575 0.576 [26 95] [26 66]] [26 53]] [26 100]] [26 75]]] [26 62]] [271 4.42 [5429 0.238 [26 85] [26 100]] [26 71]]] [26 63]] [26 57]] [26 66]] [26 58]] [26 71]]] [5007 0.304 [1993 0.478 [1062 1.11 [7310 0.864 [5999 2.25 [4279 0.935 [25 100] [25 60]] [25 100]] [25 100]] [25 100]] [25 100]] [25 100]]] [6186 0.464 [2986 2.78 [6002 0.579 [2936 20 [181 0.673 [6791 35.3 [6184 0.194 [248 15.3 [25 85] [25 100]] [25 100]] [25 87]] [25 100]] [7665 4.67 [673 7.94 [25 92] [25 100]] [25 100]]] [25 100]] [25 71]] [25 88]]] [5926 2.57 [5405 0.96 [4279 0.47 [7461 0.649 [883 3.51 [7449 26.9 [5972 11.1 [1069 1.38 [15 81] [15 100]] [15 28]] [15 72]] [15 28]] [15 90]] [3480 0.47 [4799 0.677 [15 81] [15 100]] [1980 0.986 [15 80] [15 100]]]] [31 100]] [15 100]]] [261 19.5 [285 4.95 [6458 0.525 [7007 0.397 [2526 2.63 [3130 0.635 [4802 1.16 [6230 4.13 [673 10.9 [1436 0.825 [1842 9.51 [6537 2.66 [6189 10.7 [4704 2.09 [33 33] [25 1.11 [221 12.7 [2900 1.54 [33 75] [33 100]] [233 2.83 [33 50] [33 75]]] [33 100]]] [25 88]] [1 72]] [33 50]] [3 33]] [25 50]] [1 50]] [33 90]] [33 45]] [6230 1.32 [4682 1.18 [6363 0.575 [1400 2.96 [896 2.71 [25 61] [25 88]] [25 100]] [221 3.85 [25 100] [25 80]]] [6653 5.66 [2752 10.9 [233 6.23 [33 100] [33 75]] [33 100]] [33 54]]] [25 100]]] [25 100]] [25 100]] [791 0.489 [33 100] [33 88]]] [33 93]]] [6585 0.193 [1813 0.699 [4390 1.28 [771 0.336 [5454 0.349 [6040 4.05 [2580 0.53 [6870 0.349 [6231 1.12 [248 24.6 [7354 4 [2385 6.63 [2799 0.498 [2707 0.935 [5994 7.63 [6616 1.37 [5174 5.04 [7009 0.264 [2802 1.95 [985 1.5 [383 2.28 [6974 2.2 [7428 0.484 [5871 0.592 [2913 8.51 [4154 3.42 [896 5.6 [7254 1.96 [6472 1.86 [26 52] [26 100]] [25 45]] [26 71]] [18 58]] [4154 1.99 [25 39] [26 88]]] [14 40]] [26 100]] [18 100]] [18 86]] [26 100]] [29 92]] [26 50]] [16 37]] [26 88]] [29 100]] [2723 0.156 [1400 5.73 [26 88] [6959 0.158 [26 75] [26 62]]] [26 50]]] [26 100]] [18 83]] [3008 3.76 [5693 5.09 [18 72] [6 71]] [26 66]]] [6036 18.3 [1759 3.53 [253 2.37 [879 5.34 [7118 2.11 [980 1.31 [731 6.91 [4897 7.91 [5695 0.503 [5007 4.25 [6177 4.95 [1081 25.2 [7185 11.9 [2752 2.42 [26 56] [2753 6.72 [7722 7.92 [384 33.3 [407 6.86 [4956 0.393 [7681 1.61 [4613 5.56 [896 7.48 [791 0.704 [26 89] [26 61]] [26 64]] [26 100]] [26 100]] [26 80]] [26 100]] [25 23]] [26 50]] [26 63]]] [26 87]] [26 50]] [7305 1.11 [25 82] [25 100]]] [26 45]] [7700 0.689 [685 3.53 [26 76] [5695 3.97 [26 81] [1899 5.59 [26 94] [26 83]]]] [26 100]]] [25 66]] [266 2.99 [1696 1.04 [6177 5.15 [2799 1.78 [731 23.8 [26 91] [26 61]] [26 100]] [25 100]] [26 100]] [26 100]]] [4279 3.46 [328 0.692 [6471 1 [26 76] [5429 0.609 [26 93] [26 100]]] [6377 1.11 [332 6.01 [269 17.3 [2530 5.04 [7244 4.25 [458 0.442 [2902 2.58 [6848 2.58 [2752 9.26 [26 94] [5643 1.57 [26 99] [26 88]]] [26 85]] [26 80]] [26 77]] [26 77]] [1239 3.6 [23 4.78 [26 84] [26 100]] [26 83]]] [26 79]] [26 70]] [26 75]]] [26 54]]] [6 41]] [19 33]] [25 100]] [18 35]] [18 50]]] [25 100]] [29 90]] [1913 1.03 [4895 7.88 [384 10.4 [25 100] [25 95]] [25 85]] [25 100]]] [7516 8.08 [18 62] [25 71]]] [4611 0.973 [29 100] [29 77]]] [25 85]] [2902 1.9 [37 1.7 [2717 1.26 [685 17 [5412 1.51 [7048 0.109 [7722 0.664 [2915 0.436 [4533 0.397 [26 86] [26 100]] [26 100]] [26 100]] [26 100]] [26 88]] [26 71]] [26 85]] [26 80]] [255 0.959 [2755 8.05 [26 100] [16 50]] [26 100]]]] [234 0.699 [178 1.47 [25 63] [25 100]] [6377 1.1 [7309 0.699 [1849 2.08 [25 77] [25 100]] [25 100]] [25 100]]]] [4799 1.72 [4456 0.0723 [6732 1.6 [2902 1.27 [2925 2.53 [7665 3.03 [16 42] [328 10.5 [7314 1.28 [732 16.9 [26 88] [29 50]] [26 78]] [26 98]]] [26 55]] [385 0.678 [26 100] [19 66]]] [7520 5.53 [6445 8.51 [791 7.75 [7516 0.377 [695 7.59 [4235 5.66 [26 100] [6733 4.36 [26 83] [26 100]]] [26 90]] [26 100]] [26 100]] [26 85]] [26 80]]] [26 100]] [26 66]]]] [379 4.28 [2707 8.49 [384 9.62 [6862 0.577 [2939 0.592 [4061 5.25 [2925 9.97 [134 2.16 [392 35.3 [26 100] [26 83]] [26 83]] [26 81]] [26 83]] [26 100]] [26 83]] [26 66]] [26 66]] [429 3.7 [26 83] [26 50]]]] [1 92]] [7355 1.1 [328 19.3 [2905 2.42 [791 18.9 [6036 1.85 [791 1.66 [201 2.68 [5692 0.307 [2753 4.52 [1742 4.53 [6184 1.22 [7397 1.08 [25 98] [25 100]] [25 100]] [25 85]] [25 85]] [25 100]] [25 93]] [771 0.188 [896 8.1 [25 100] [2580 0.516 [791 9.96 [25 88] [25 100]] [25 100]]] [25 100]]] [25 57]] [25 76]] [25 75]] [3268 0.539 [25 82] [25 100]]] [25 50]]] [1264 4.15 [2913 4.29 [1997 0.084 [6524 2.59 [1664 0.561 [2580 0.54 [5595 1.73 [5333 2.62 [384 0.208 [5141 1.34 [1576 16.1 [4682 0.316 [5531 15.2 [4291 2.26 [429 0.252 [7623 9.38 [1888 1.09 [3136 2.26 [4673 2.81 [1833 3.89 [5154 6.05 [1634 3.98 [5115 2 [5307 9.16 [4851 1.02 [7512 11.5 [1708 2.59 [1913 2.07 [1340 3.32 [4799 0.673 [23 22.2 [1379 14.7 [2439 1.22 [673 3.47 [190 2.85 [2117 2.54 [6471 3.31 [6413 2.56 [1239 86.7 [1722 3.23 [1772 13.7 [2752 10.6 [5170 7.17 [4369 0.823 [232 8.41 [4154 2.79 [1338 3.6 [7665 15.2 [2143 22.3 [5299 1.04 [33 37] [25 37]] [1 55]] [33 100]] [33 78]] [3 23]] [25 62]] [38 42]] [33 80]] [33 29]] [4 16]] [33 90]] [1 18]] [21 25]] [26 80]] [13 41]] [18 100]] [26 46]] [38 75]] [30 66]] [3008 11.7 [7512 4.03 [5491 7.17 [33 60] [33 63]] [33 100]] [10 28]]] [33 100]] [1783 31.6 [1429 42.5 [33 47] [31 25]] [2 30]]] [1078 3.1 [10 14] [15 37]]] [28 54]] [5776 1.6 [2081 0.724 [2752 7.87 [6 22] [25 40]] [25 28]] [30 33]]] [26 25]] [33 100]] [33 95]] [13 100]] [33 71]] [13 84]] [6 100]] [38 84]] [26 39]] [5174 2.67 [33 50] [5174 17.9 [5753 10.6 [4989 4.42 [5154 2.39 [33 85] [33 100]] [33 100]] [33 71]] [33 100]]]] [1432 1.66 [7077 1.52 [5307 9.21 [3008 17.2 [2011 3.79 [6658 1.38 [4851 2.75 [2702 0.569 [4655 3.26 [1436 13 [5170 2.46 [7623 1.38 [112 0.734 [3027 6.03 [2951 1.7 [7734 3.7 [1995 9.1 [1400 8.23 [5598 1.53 [29 12] [6 75]] [15 53]] [33 23]] [18 80]] [38 55]] [29 55]] [29 30]] [19 16]] [144 3.77 [328 6.72 [33 55] [33 50]] [1 37]]] [1912 8.93 [31 33] [31 100]]] [1 81]] [29 100]] [26 58]] [18 71]] [29 93]] [6 60]] [33 100]] [24 70]] [26 81]]] [15 100]] [1832 4.67 [13 40] [13 100]]] [1783 1.97 [1451 7.9 [33 73] [1451 24.5 [12 62] [33 44]]] [2329 3.27 [112 0.316 [6845 13.5 [6294 6.65 [5530 7.85 [2151 14.1 [5617 17.7 [1239 12.8 [33 60] [5618 5.15 [2526 1.26 [248 29.2 [33 94] [33 82]] [33 96]] [33 100]]] [33 75]] [33 60]] [33 100]] [33 50]] [33 77]] [33 100]] [33 57]]]] [2 72]] [1239 21.3 [33 77] [33 94]]] [6791 0.416 [2616 3.16 [26 71] [26 40]] [26 80]]] [11 100]] [6068 1.2 [1911 1.95 [221 1.78 [4571 6.77 [673 1.54 [26 28] [26 71]] [26 100]] [6 37]] [26 100]] [26 66]]] [25 100]] [4862 2.87 [3 55] [3 100]]] [1062 8.9 [2605 0.836 [6752 1.46 [4656 1.18 [7512 18.8 [5172 3.22 [5412 4.65 [7305 0.345 [4657 6.61 [5368 4.78 [1293 17.9 [184 0.404 [1913 1.69 [6177 2.44 [7413 9.04 [6457 1.72 [2902 2.82 [7254 2.18 [25 28] [1 55]] [1 100]] [25 88]] [25 85]] [25 100]] [22 50]] [25 100]] [1 63]] [25 75]] [7640 15.1 [33 65] [1 67]]] [25 100]] [33 52]] [33 91]] [1 79]] [7729 5.36 [1 69] [3099 7.23 [1 75] [1 100]]]] [1 66]] [25 100]] [1 66]]] [3207 0.525 [178 6.51 [1888 4.67 [847 0.214 [5564 2.59 [4682 1.14 [1391 6.95 [1696 7.69 [1769 2.15 [429 9.8 [3 14] [2039 1.06 [1899 11.9 [3 31] [1 31]] [32 44]]] [15 31]] [26 70]] [31 48]] [33 81]] [14 100]] [30 50]] [26 55]] [6189 3.14 [25 92] [25 100]]] [2526 3.42 [26 63] [685 0.525 [2259 19 [26 92] [26 71]] [26 80]]]]] [5436 3.63 [673 10.2 [25 61] [25 42]] [26 88]]] [5110 4.9 [7720 2.86 [1 81] [1 100]] [33 76]]]] [7546 9.69 [6827 4.95 [2526 10.8 [18 86] [18 66]] [177 1.27 [2806 6.34 [4200 2.23 [394 2.82 [7057 5.49 [6363 5.7 [1078 16.5 [18 100] [18 96]] [18 85]] [2259 18.8 [18 93] [18 80]]] [1980 2.7 [18 96] [18 90]]] [18 85]] [18 80]] [18 83]]] [18 50]]] [7737 0.244 [532 5.49 [685 1.44 [2470 3.65 [2760 0.934 [6524 11.2 [4160 2.84 [107 0.292 [560 2.46 [2808 4.65 [7512 16.5 [429 7.03 [1823 5.86 [4135 0.602 [2759 2.37 [5462 5.74 [6294 13.5 [2986 4.84 [1267 9.94 [5360 0.743 [33 68] [7115 6.09 [1769 12.5 [4348 3.31 [4156 2.3 [2005 1.6 [4235 2.92 [5196 6.28 [248 22.5 [33 100] [5174 7.64 [5702 6.94 [7665 2.26 [33 95] [33 100]] [33 87]] [33 100]]] [5174 3.36 [33 100] [33 81]]] [33 100]] [33 100]] [33 100]] [33 92]] [33 85]] [33 83]]] [33 75]] [33 57]] [33 66]] [33 50]] [33 50]] [33 57]] [33 100]] [26 18]] [33 30]] [15 100]] [18 100]] [361 3.63 [4155 0.437 [2752 9.2 [7623 13.3 [2939 8.4 [4802 2.44 [5662 0.509 [6524 3.59 [1068 0.6 [107 18.7 [5118 0.372 [4156 0.584 [5178 0.686 [7210 2.27 [7623 1.71 [1812 1.04 [221 11.1 [33 100] [33 88]] [33 100]] [33 100]] [33 100]] [33 100]] [33 100]] [33 100]] [33 96]] [33 83]] [33 77]] [33 100]] [33 78]] [33 85]] [7640 2.09 [33 81] [33 60]]] [33 84]] [33 100]] [33 70]]] [33 44]] [5647 3.72 [426 3.7 [33 42] [7176 12.7 [1 83] [1 71]]] [33 46]]] [15 60]] [15 98]] [18 51]] [18 66]] [7665 8.47 [685 4.47 [18 100] [18 55]] [19 42]]]]] [6382 0.554 [6831 0.549 [24 0.473 [5904 0.174 [2151 0.247 [7487 1.67 [3929 2.27 [4840 0.919 [2392 6.12 [7476 1.91 [4939 6.18 [5546 0.772 [5037 7.09 [1563 6.08 [4478 2.76 [7369 18.5 [2857 4.1 [5462 0.404 [3342 4.67 [2169 0.636 [4535 45.3 [7502 2.03 [2467 2.87 [37 7.42 [6931 1.67 [6724 11 [7623 6.43 [6879 0.96 [6848 5.65 [2978 5.4 [4896 0.981 [1957 2 [187 3.5 [7369 12.8 [1913 3.67 [166 0.516 [2659 0.484 [4897 0.0886 [38 96] [38 100]] [1436 1.13 [38 85] [38 100]]] [38 100]] [38 71]] [38 82]] [3424 2.15 [2081 3.69 [6848 4.96 [5597 3.19 [1932 1.64 [2736 13.3 [2123 1.21 [2862 10.7 [6207 9.55 [2112 0.0719 [38 90] [38 100]] [38 98]] [38 55]] [38 90]] [38 88]] [38 75]] [38 60]] [38 62]] [6383 0.505 [38 84] [38 66]]] [38 66]]] [38 86]] [38 80]] [38 61]] [5673 0.543 [38 98] [38 100]]] [38 62]] [38 75]] [38 57]] [38 65]] [38 69]] [14 33]] [38 62]] [2259 35.7 [4457 3.72 [17 44] [38 50]] [7038 3.14 [1732 3.78 [4890 10.8 [2241 5.16 [2259 40.7 [2884 10.2 [38 50] [38 80]] [38 95]] [4536 5.62 [2466 5.47 [2939 10.7 [38 87] [38 66]] [38 100]] [38 64]]] [38 66]] [38 100]] [38 100]]]] [38 41]] [17 54]] [38 67]] [69 4.74 [17 85] [38 75]]] [2851 19.9 [14 38] [1239 20.8 [38 66] [38 87]]]] [12 31]] [2939 3.26 [38 81] [38 98]]] [19 42]] [38 50]] [38 58]] [38 63]] [1899 3.65 [7161 3.69 [2242 0.808 [45 1.11 [17 57] [38 91]] [3551 0.439 [61 35.3 [1808 3.22 [38 100] [38 71]] [4536 1.76 [3983 1.7 [38 71] [38 100]] [6824 2.98 [17 75] [38 50]]]] [38 89]]] [7157 0.578 [19 41] [38 60]]] [2392 8.17 [38 43] [1900 4.81 [7439 10.9 [38 100] [38 85]] [38 80]]]]] [16 47]] [5 31]] [6306 5.49 [2466 18.1 [1920 1.3 [38 73] [38 40]] [17 44]] [38 54]]] [5209 0.619 [6 30] [4851 0.914 [1980 5.5 [7391 0.832 [38 92] [17 50]] [38 59]] [2242 1.87 [17 54] [16 42]]]]] [5638 0.509 [19 63] [19 100]]] [5641 7.23 [24 41] [16 100]]] [16 50]] [4651 0.893 [7474 0.241 [2854 2.12 [38 70] [6199 17.1 [17 66] [38 62]]] [7373 1.67 [4943 4.6 [1920 0.441 [5918 0.0908 [4050 1.8 [2952 2.55 [19 45] [17 57]] [1587 1.22 [2093 0.549 [14 25] [14 44]] [17 27]]] [17 75]] [1451 0.539 [17 84] [17 66]]] [7472 1.16 [17 66] [17 100]]] [6 30]]] [35 37]]]] [959 0.509 [5843 2.65 [7680 0.703 [5662 0.625 [6048 6 [7497 0.353 [1011 1.69 [6761 1.41 [1483 0.176 [2004 10.6 [435 2.3 [7512 13.9 [850 3.43 [23 7.06 [5693 12.2 [1069 1.25 [6524 1.12 [5851 23.4 [6745 3.36 [6703 5.45 [5574 1.99 [3342 5.84 [2583 0.882 [1094 11.3 [4893 1.93 [482 17.2 [2813 6.63 [4799 14.2 [7119 5.95 [2548 0.695 [1084 17.8 [7445 3.91 [821 3.24 [660 13.4 [4799 3.97 [1095 10.3 [470 0.499 [3008 19.3 [2947 2.97 [2385 4.02 [5309 6.14 [730 1.2 [2488 0.545 [7491 6.43 [6848 4.95 [2764 4.67 [7085 9.45 [1980 11.4 [7354 18.4 [2562 8.48 [3929 1.93 [7441 1.31 [429 9.12 [7176 8.27 [8 97] [8 85]] [1909 8.85 [4105 1.34 [3057 2.61 [2752 32.9 [4606 3.82 [4852 1.21 [5192 0.821 [2628 2.86 [8 99] [8 100]] [8 100]] [8 100]] [8 100]] [978 21.7 [8 100] [8 83]]] [8 100]] [8 100]] [8 95]]] [8 100]] [8 100]] [8 100]] [8 98]] [8 88]] [8 75]] [8 87]] [35 85]] [8 85]] [3905 0.441 [7241 0.329 [6732 6.63 [5673 7.11 [5211 11.5 [5219 11.4 [8 100] [8 92]] [8 100]] [8 87]] [8 87]] [8 100]] [8 100]]] [7255 0.602 [8 91] [8 88]]] [8 71]] [8 87]] [8 95]] [8 71]] [8 66]] [8 83]] [8 93]] [8 66]] [8 66]] [4895 4.07 [8 66] [8 100]]] [8 66]] [8 62]] [8 54]] [8 71]] [8 68]] [8 71]] [8 62]] [8 54]] [0 80]] [8 66]] [2562 7.17 [6561 0.592 [8 53] [8 100]] [8 100]]] [35 85]] [8 50]] [0 88]] [22 64]] [8 50]] [8 86]] [8 62]] [8 75]] [7241 1.74 [8 60] [10 100]]] [1764 2.15 [8 78] [0 71]]] [23 85]] [6732 1.35 [1929 0.127 [2591 0.231 [6566 2.55 [429 0.986 [8 96] [3927 0.125 [1769 19.4 [8 100] [8 70]] [8 100]]] [2550 1.75 [0 50] [8 100]]] [8 100]] [8 100]] [0 62]]] [5693 0.921 [8 47] [8 66]]] [2 36]] [23 81]] [0 47]] [429 20 [8 67] [5911 2.05 [5969 0.858 [5655 0.81 [23 51] [8 75]] [23 71]] [23 80]]]] [23 55]] [10 90]] [10 100]]] [1913 2.5 [4205 0.963 [1517 2.35 [2983 0.824 [489 1.69 [6177 2.21 [5020 2.89 [365 2.23 [3103 4.35 [3243 1.26 [144 1.98 [6727 5.56 [5472 1.66 [2826 2.24 [3457 3.03 [2749 1.87 [2260 0.813 [4154 2.67 [2616 0.699 [3052 1.08 [3667 1.13 [3931 1.48 [7255 14.2 [5412 2.01 [1078 28.6 [906 2.84 [1400 13.9 [3045 13.2 [2766 4.38 [3262 1.99 [2488 9.43 [6206 4.83 [7274 2.83 [4092 1.45 [7101 9.86 [35 57] [19 28]] [7665 1.66 [35 79] [35 62]]] [26 33]] [4 37]] [8 77]] [35 55]] [35 92]] [35 90]] [26 47]] [35 45]] [2939 2.42 [35 84] [35 64]]] [5211 2.06 [35 23] [22 57]]] [14 40]] [35 52]] [35 93]] [30 87]] [26 56]] [5851 1.41 [4704 1.5 [2259 8.69 [23 1.71 [1899 7.2 [7358 0.234 [35 77] [35 87]] [35 52]] [35 25]] [37 27]] [33 80]] [35 50]]] [3 20]] [26 92]] [3231 1.53 [35 85] [3231 17.5 [35 100] [35 80]]]] [736 4.96 [3041 1.43 [1078 4.53 [5 57] [17 31]] [17 57]] [35 70]]] [13 68]] [35 25]] [6584 0.275 [5034 1.79 [3079 3.42 [35 18] [37 87]] [14 57]] [35 66]]] [2616 1.98 [37 54] [35 70]]] [3857 5.42 [3449 4.79 [2048 1.44 [1085 3.6 [7096 31.2 [1769 3.18 [4312 5.34 [4956 14.3 [3439 1.66 [791 9.55 [35 83] [3153 15 [6621 3.5 [35 95] [35 100]] [35 88]]] [35 66]] [35 81]] [35 50]] [35 50]] [35 62]] [35 60]] [35 100]] [35 55]] [26 45]]] [37 54]] [26 82]] [2580 1.43 [3008 1.27 [25 52] [25 85]] [25 100]]] [3675 11.6 [5025 1.61 [3514 0.816 [394 7.18 [1761 5.09 [3155 5.59 [1676 2.51 [831 25.8 [2745 1.31 [3389 1.01 [7098 6.04 [685 3.6 [2081 0.396 [35 93] [35 96]] [837 0.945 [35 87] [35 66]]] [35 44]] [35 98]] [35 100]] [35 80]] [35 77]] [35 100]] [35 71]] [26 50]] [3450 0.331 [515 1.11 [7092 2.52 [35 96] [35 100]] [35 87]] [35 100]]] [35 75]] [35 77]]] [26 50]] [7722 1.3 [1475 1.86 [37 38] [37 72]] [5 66]]] [262 2.57 [6517 0.713 [5007 9.28 [7693 1.14 [6981 2.93 [4092 3.08 [3234 1.28 [26 56] [18 40]] [3041 4.79 [1899 1.05 [26 87] [26 100]] [35 53]]] [26 60]] [26 83]] [19 33]] [26 50]] [1078 1.63 [26 91] [26 100]]]] [1899 45.5 [6445 3.12 [216 0.172 [7322 4.52 [30 50] [30 100]] [30 92]] [26 35]] [35 88]]]] [7623 1.18 [1306 0.182 [2752 3.76 [4312 2.2 [7426 0.804 [1239 72.5 [933 0.553 [554 1.1 [7615 0.855 [1429 13.9 [688 3.09 [6673 1.08 [5041 0.44 [535 1.17 [609 5.87 [6643 0.377 [5539 1.83 [529 1.18 [5831 1.9 [6317 16.5 [4218 1.33 [634 0.5 [660 2.52 [802 16.3 [534 1.09 [1391 0.258 [822 2.81 [625 2.29 [585 2.5 [7015 1.07 [3 42] [9 75]] [918 0.623 [21 90] [21 44]]] [9 90]] [21 86]] [9 47]] [3 90]] [6191 0.629 [1017 2.26 [6544 2.86 [6015 22.7 [1783 6.85 [1929 2.44 [539 3.23 [5976 3.36 [1101 7.04 [583 4.04 [580 16.1 [5267 19.3 [743 38.5 [2097 2.89 [4135 9.72 [4568 1.39 [6713 5.38 [6306 0.513 [2199 52.1 [7493 1.31 [2081 30 [580 8.93 [4680 4.74 [2167 0.766 [816 1.31 [508 5.72 [6564 1.12 [5154 33.8 [604 2.79 [6279 6.33 [2200 11.9 [2179 12.8 [585 12.3 [6613 3.07 [524 11.9 [7139 20 [6732 2.46 [2993 3.56 [4418 4.27 [569 10.1 [4154 4.59 [534 6.85 [7009 3.4 [5046 2.26 [1995 9.8 [6342 2.59 [1899 19.1 [4883 5.05 [2241 4.13 [538 4.35 [21 48] [21 85]] [21 88]] [21 100]] [21 75]] [21 38]] [4 28]] [9 45]] [21 80]] [3 100]] [3 81]] [21 93]] [32 42]] [3 58]] [13 50]] [21 100]] [21 100]] [3 55]] [3 68]] [3 75]] [3 80]] [21 100]] [3 80]] [3 57]] [21 75]] [21 100]] [21 85]] [25 45]] [21 83]] [9 75]] [2081 55.3 [21 90] [2081 62.6 [21 37] [21 78]]]] [21 100]] [3 88]] [791 40.2 [3 100] [3 85]]] [9 81]] [21 94]] [21 40]] [21 96]] [15 71]] [13 83]] [21 96]] [21 72]] [1899 8.2 [32 33] [28 50]]] [3 100]] [21 100]] [9 71]] [3 56]] [6018 14.9 [4663 17.5 [21 90] [21 100]] [21 66]]] [3 94]] [3 86]] [5692 2.52 [21 58] [21 90]]]] [21 84]] [608 8.84 [21 100] [21 80]]] [328 1.38 [2259 30.6 [1239 1.33 [3 69] [3 100]] [3 54]] [3 100]]] [9 60]] [9 91]] [237 1.18 [3 84] [3 100]]] [3 65]] [2259 1.03 [3 92] [3 100]]] [21 85]] [5918 5.62 [5193 0.448 [747 1.34 [4781 2.95 [6092 1.99 [5692 1.36 [2259 1.63 [743 18 [2083 2.74 [802 34.8 [21 100] [21 98]] [21 100]] [21 87]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 100]] [21 60]]] [6082 26.2 [5324 0.373 [2143 39.6 [544 0.446 [6184 43.4 [2084 0.422 [906 31.1 [518 16.9 [21 100] [5041 16.2 [21 100] [6059 26.3 [21 92] [21 100]]]] [21 96]] [21 100]] [21 98]] [21 100]] [21 60]] [21 100]] [21 71]]] [3 100]] [1354 2.11 [653 1.71 [514 0.911 [7314 3.96 [441 4.92 [4587 33.7 [688 13 [6347 5.26 [4917 1.54 [2178 5.59 [1757 1.72 [24 6.4 [6131 1.22 [642 4.69 [6524 8.98 [6295 0.18 [747 1.42 [4154 4.41 [633 2.09 [915 7.62 [6719 4.19 [6103 5.01 [434 2.54 [6513 1.44 [583 7.35 [5753 4.95 [791 16.8 [21 71] [21 97]] [21 77]] [21 85]] [21 100]] [21 100]] [21 66]] [21 100]] [21 79]] [21 97]] [21 71]] [817 0.258 [517 1.69 [1906 1.24 [535 3.5 [21 80] [21 100]] [21 100]] [21 100]] [21 100]]] [21 100]] [21 77]] [21 64]] [9 92]] [9 88]] [9 62]] [21 100]] [627 5.02 [563 1.09 [5974 3.26 [621 0.1 [915 0.719 [5040 2.06 [21 85] [21 100]] [21 100]] [21 100]] [21 96]] [9 66]] [21 81]]] [21 70]] [583 33.4 [2002 20.1 [5491 16.8 [536 2.16 [2259 37.1 [2526 16.5 [4924 0.692 [1783 12.4 [908 20.4 [919 18.5 [128 1.53 [699 8.2 [5851 8.34 [767 3.36 [6342 0.458 [3095 5.54 [5322 33.1 [6069 0.445 [2993 13.1 [5192 6.37 [6184 4.13 [1769 3.5 [582 0.732 [5049 20.4 [538 3.14 [815 3.6 [21 96] [21 100]] [21 100]] [21 85]] [21 100]] [21 100]] [21 100]] [5040 12.6 [21 100] [21 90]]] [21 100]] [21 100]] [21 96]] [21 75]] [21 96]] [21 71]] [21 75]] [915 15.9 [21 100] [21 66]]] [21 100]] [21 83]] [21 80]] [21 75]] [21 100]] [21 94]] [21 71]] [21 75]] [21 77]] [21 41]] [9 63]]] [21 66]] [21 66]] [3 46]] [9 77]] [21 66]] [9 100]]] [39 2.2 [7305 7.69 [1664 2.2 [766 7.39 [1888 4.76 [899 3.19 [4282 1.85 [429 52 [434 26.5 [7335 0.68 [5110 2.11 [1062 3.24 [2099 1.29 [4218 1.23 [1905 3.35 [2007 1.82 [3989 1.05 [6732 5.88 [9 17] [13 100]] [12 45]] [10 92]] [2 33]] [3 100]] [21 100]] [11 55]] [29 33]] [30 33]] [36 45]] [607 4.5 [4663 17.6 [4794 2.74 [2225 7.34 [371 12.3 [21 56] [21 50]] [17 30]] [688 0.968 [21 90] [21 100]]] [15 40]] [3 100]]] [3 100]] [13 100]] [13 71]] [3 100]] [7210 0.855 [3 96] [3 100]]] [3 96]] [17 71]]] [607 0.759 [3 99] [3 100]]] [5480 7.37 [286 0.31 [915 19.9 [5208 8.67 [3 83] [3 58]] [21 80]] [3 100]] [21 62]]] [3 94]] [1361 2.62 [699 1.3 [1400 1 [2122 16.9 [574 0.181 [505 1.91 [6150 0.901 [5041 0.921 [5206 1.51 [5046 6.6 [616 1.96 [1309 1.52 [791 51 [586 7.38 [537 1.57 [5509 7.75 [6375 2.94 [7615 3.55 [6375 0.322 [4794 2.11 [2039 2.13 [6892 1.86 [1758 0.578 [6380 7.52 [4422 6.49 [2251 1.87 [5692 2.39 [5040 8.53 [4517 3.07 [4832 3.65 [1025 2.16 [7210 20.6 [1279 3.88 [9 56] [9 100]] [3 50]] [21 100]] [9 75]] [21 70]] [21 88]] [21 72]] [9 100]] [21 100]] [9 100]] [9 88]] [906 8.67 [21 66] [21 100]]] [3 28]] [21 80]] [21 85]] [3 100]] [9 85]] [21 88]] [3 100]] [21 100]] [9 42]] [9 100]] [3 100]] [3 100]] [3 90]] [21 100]] [9 95]] [505 9.9 [9 48] [9 71]]] [6017 0.327 [1362 7.42 [806 0.905 [9 96] [9 100]] [9 87]] [9 87]]] [31 100]] [21 89]] [5621 5.26 [5040 10.6 [818 2.07 [5999 0.752 [5535 0.79 [695 4.95 [9 72] [112 0.975 [6802 1.9 [6148 23.8 [5049 16.3 [9 100] [9 88]] [9 75]] [9 83]] [9 100]]] [9 100]] [9 68]] [20 66]] [9 50]] [9 100]]] [3 100]]] [5535 1.34 [802 24.3 [9 100] [9 62]] [9 86]]] [2362 0.913 [7491 10.8 [328 4.21 [2081 26.5 [4925 1.85 [2178 1.47 [504 1.04 [3 66] [21 60]] [5692 1.47 [3 66] [3 100]]] [21 100]] [3 100]] [21 46]] [21 66]] [3 100]]] [4429 1.87 [3768 1.61 [3928 1.18 [1018 1.48 [1239 23.5 [5066 1.24 [907 4.33 [896 8.13 [5797 2.07 [898 1.78 [2271 0.432 [573 0.292 [434 14 [4154 9.28 [1505 1.87 [3376 3.31 [3554 7.64 [1400 10.2 [7600 3.65 [6193 11.1 [2178 6.67 [7009 7.59 [661 4.13 [978 2.01 [6871 4.44 [2081 26.8 [2169 0.448 [15 41] [17 42]] [3 46]] [12 66]] [17 25]] [12 45]] [12 87]] [11 42]] [15 61]] [32 100]] [328 7.64 [1062 8.08 [15 86] [15 66]] [15 56]]] [12 86]] [15 100]] [12 100]] [7491 6.33 [15 50] [15 88]]] [32 53]] [4 40]] [35 100]] [12 100]] [12 100]] [13 87]] [21 63]] [15 100]] [6363 3.45 [4282 1.46 [5040 8.67 [21 35] [21 100]] [3 100]] [21 100]]] [3 100]] [12 91]] [13 100]] [15 95]]] [7086 0.115 [523 2.56 [6101 4.1 [9 88] [9 83]] [9 75]] [9 100]]] [4917 0.484 [5980 0.949 [328 2.55 [4416 9.89 [1078 34 [2426 2.22 [7649 0.914 [7085 0.754 [15 72] [15 88]] [15 100]] [12 100]] [32 50]] [15 100]] [15 45]] [12 100]] [21 66]]]] [3715 0.0986 [3315 0.183 [2321 0.247 [5429 0.962 [7179 0.407 [248 4.43 [3262 0.0753 [3370 0.935 [3292 0.393 [719 0.666 [604 1.3 [3871 0.717 [4234 0.782 [384 0.835 [663 1.53 [7176 0.275 [7722 1.38 [7009 6.68 [6615 3.61 [4014 2.89 [3884 3.33 [2826 1.98 [383 3.94 [7009 1.36 [178 5.01 [8 27] [5 100]] [12 62]] [8 92]] [5692 0.317 [5 64] [5 92]]] [15 70]] [8 100]] [15 100]] [7512 2.22 [5 63] [5 100]]] [1542 0.736 [6557 0.747 [3204 1.32 [7563 7.65 [3972 5.44 [5 55] [5 100]] [5 50]] [5 55]] [5 100]] [5 66]]] [3895 0.666 [5192 0.642 [8 77] [12 60]] [12 100]]] [5198 0.951 [1544 0.477 [4001 1.45 [1011 2.55 [5812 3.4 [2701 0.945 [4154 3.22 [5155 1.31 [5 38] [5 85]] [32 33]] [12 100]] [2826 1.53 [5 66] [5 88]]] [6977 0.603 [5 100] [5 92]]] [5 94]] [12 54]] [5 100]]] [8 82]] [12 100]] [8 100]] [8 100]] [731 2.01 [2616 0.588 [7255 1.03 [2526 1.95 [4414 0.795 [6269 1.31 [695 11.3 [5 66] [13 90]] [13 100]] [13 100]] [13 75]] [13 63]] [1980 0.452 [5 57] [5 28]]] [3929 5.33 [929 0.457 [1011 1.53 [663 0.757 [5 58] [13 21]] [5 75]] [5 66]] [6581 3.74 [5 66] [1429 51.7 [5 75] [5 100]]]]]] [3360 2.94 [2143 0.624 [957 0.57 [1239 0.885 [2259 1.35 [1533 20 [7149 1.01 [37 83] [37 100]] [37 100]] [8 72]] [8 33]] [3978 1.14 [37 66] [37 100]]] [37 100]] [37 75]]] [8 100]] [5650 9.19 [2947 5.62 [1542 2.12 [3159 2.51 [2775 4.5 [3823 1.96 [3561 3.49 [1482 6.55 [3213 0.795 [6955 7.41 [3897 3.43 [1475 0.503 [3027 1.38 [939 7.95 [112 6.71 [37 100] [37 93]] [37 80]] [37 87]] [37 100]] [37 92]] [37 83]] [37 100]] [37 71]] [37 63]] [37 90]] [37 90]] [37 42]] [37 71]] [37 80]] [37 66]]] [6080 0.383 [15 70] [15 100]]] [8 100]] [5753 4.86 [2841 0.849 [5 80] [5 100]] [5 72]]] [8 100]] [6616 6.07 [3435 3.14 [5637 1.37 [141 2.45 [733 2.67 [1079 2.47 [1980 0.225 [5660 0.682 [1539 1.2 [1899 0.605 [6442 0.489 [5154 11.8 [5 100] [2526 13.2 [5 100] [5 85]]] [5 100]] [5 100]] [5 87]] [5 66]] [5 100]] [7241 1.39 [5 85] [5 77]]] [5 77]] [5 75]] [5 40]] [5 56]] [5 76]]] [2151 0.481 [480 0.618 [6333 1.16 [1533 41.8 [1239 2.85 [7169 6.27 [5287 0.129 [1529 0.224 [3365 0.487 [3057 2.2 [37 100] [328 6.44 [37 100] [37 93]]] [37 100]] [37 100]] [37 100]] [3079 24.8 [37 100] [37 87]]] [145 3.54 [3223 0.285 [3361 4.09 [3498 0.469 [312 6.96 [37 100] [37 92]] [37 100]] [37 81]] [37 81]] [37 83]]] [37 80]] [3089 1.04 [19 33] [37 100]]] [15 30]] [37 70]]]] [6991 0.168 [7365 0.276 [7132 0.281 [2677 0.575 [4253 1.19 [6816 0.259 [7742 0.541 [4214 0.861 [1047 4.98 [2744 1.04 [141 0.133 [5847 0.121 [1007 2.05 [6982 0.717 [1899 4.45 [5625 1.14 [2028 1.16 [6074 1.39 [1783 72.8 [2939 1.12 [4964 0.332 [7718 1.07 [4 36] [4 96]] [4 100]] [2676 5.99 [663 2.02 [2 45] [16 38]] [4 66]]] [13 28]] [5692 5.49 [2 70] [2 33]]] [28 31]] [4 96]] [2947 2.68 [5812 0.366 [2616 0.481 [221 6.41 [22 26] [2 29]] [2 46]] [5647 32.1 [663 1.04 [5771 0.476 [7381 3.05 [5575 5.89 [2 75] [4 60]] [4 76]] [5574 15.2 [2 63] [896 13.5 [2 78] [2 71]]]] [1094 0.655 [2570 0.867 [2 91] [2 100]] [2 30]]] [665 1.48 [2 82] [2 100]]]] [2 50]]] [3130 0.43 [4 100] [4 85]]] [7665 16.6 [2 57] [2 83]]] [4218 7.75 [2939 38.1 [6199 1.3 [6047 2.7 [2178 0.213 [5654 7.58 [429 40.5 [7665 27.7 [2743 9.21 [2741 7.38 [4 100] [4 90]] [4 95]] [4 62]] [4 80]] [4 91]] [4 100]] [4 75]] [5412 4.21 [4 92] [4 75]]] [4 78]] [4 85]]] [2739 2.97 [2628 3.26 [2 57] [7693 6.09 [1239 1.23 [573 2.55 [695 6.97 [2 100] [2 83]] [2 90]] [2 85]] [2 77]]] [4 100]]] [5847 0.973 [4 87] [4 100]]] [1640 4.61 [2 75] [2 80]]] [29 60]] [2588 0.472 [665 1.57 [5815 6.61 [670 0.514 [221 3.74 [6984 0.253 [7568 0.695 [4 100] [4 57]] [4 100]] [1069 4.07 [7712 2.03 [5770 21.6 [1888 1.53 [4225 0.241 [6988 0.826 [896 9.53 [6982 0.504 [4 78] [6199 2.67 [4 97] [4 100]]] [4959 0.838 [4 63] [4 100]]] [2 54]] [4 66]] [5847 0.977 [7665 0.52 [7380 1.1 [5770 2.86 [221 48 [4 96] [4 85]] [4 100]] [4 100]] [224 2.82 [906 1.03 [17 1.21 [6982 1.06 [1429 17.6 [4 92] [2 50]] [4 100]] [4 100]] [2 85]] [4 100]]] [4 97]]] [2 70]] [4 100]] [4 55]]] [2 50]] [2 66]] [2 100]] [4 100]]] [2616 8.27 [5651 3.76 [7413 0.684 [6074 10.3 [7722 0.327 [5693 6.73 [2 100] [2 85]] [2 100]] [2 83]] [2 100]] [2 71]] [429 9.92 [2 55] [2 100]]]] [1075 1.36 [2826 0.515 [5847 0.182 [5300 2.74 [5320 7.23 [2560 6.67 [7441 1.08 [4767 1.14 [2939 0.395 [5693 2.06 [2 65] [2 57]] [6363 1.42 [6185 4.85 [328 15.6 [1911 0.379 [5769 14.6 [2674 0.266 [5693 0.675 [4 54] [7693 0.418 [2616 3.34 [2 77] [2 100]] [2 44]]] [1078 57.8 [2571 5.32 [4414 18.2 [2752 21 [5654 6.7 [5574 2.22 [1919 0.404 [2 85] [2 100]] [5851 3.61 [2 100] [7169 10.5 [2 100] [2 90]]]] [2 90]] [1004 0.593 [1007 3.51 [6988 3.64 [2 100] [2 88]] [719 5.17 [2 60] [2 90]]] [2 100]]] [2 91]] [2 71]] [2 66]]] [2259 6.11 [5818 2.44 [2 80] [2 58]] [2 44]]] [4414 0.394 [2178 0.713 [2 93] [2 100]] [2 100]]] [2 77]] [2 50]] [7413 2.02 [2 37] [2 87]]]] [2 57]] [2 57]] [2 66]] [2 57]] [4 58]] [6982 3.8 [145 0.182 [7324 1.09 [4 69] [4 100]] [2 55]] [4 100]]] [4 84]] [7169 3.36 [4235 2.63 [2 71] [5769 7.14 [5771 3.83 [2 100] [407 1.05 [2 100] [2 91]]] [2 81]]] [2 100]]]] [435 0.326 [688 2.07 [178 1.05 [5820 1.89 [5574 12.4 [5818 0.412 [2 91] [2 42]] [2 100]] [2 100]] [2 77]] [2 57]] [2 100]]] [5387 0.52 [2645 4.87 [6732 5.57 [4 100] [5322 2.92 [221 3.25 [4 85] [4 100]] [4 100]]] [4 75]] [4 72]]] [723 2.89 [7335 22.6 [6988 0.836 [4718 4.47 [5769 3.73 [1706 3.52 [4 100] [4 87]] [4 100]] [4 83]] [4 92]] [4 87]] [4 75]]] [5461 8.06 [7766 0.175 [4991 0.0934 [2674 0.273 [2742 0.572 [4959 0.96 [2961 1.1 [134 0.169 [2 51] [4768 0.124 [2 81] [2 100]]] [4 70]] [4 100]] [4 100]] [1259 0.831 [4187 1.26 [6982 0.295 [1436 3.85 [6192 1.13 [228 43.5 [5812 0.364 [5576 11.5 [2 100] [2 66]] [6110 2.65 [6342 1.55 [7413 3.94 [1221 1.1 [2526 8.08 [682 0.292 [2013 0.6 [23 11 [6990 2.5 [2 87] [2 100]] [2 88]] [2 83]] [2 100]] [2674 8.07 [2 100] [2 96]]] [1919 1.36 [2 90] [2 100]]] [2574 1.05 [2 85] [2 100]]] [1068 0.317 [5692 6.92 [2 100] [2 85]] [2 90]]] [2 88]]] [2 45]] [2 85]] [5692 0.678 [2 66] [2 50]]] [4 90]] [2 70]] [2 62]]] [5412 1.24 [1909 5.27 [4991 5.63 [6735 1.62 [2 100] [1078 9.73 [2 100] [2526 14.5 [2 57] [2 100]]]] [324 1.67 [6990 5.44 [999 0.711 [2616 3.01 [2 92] [2 100]] [2 100]] [2 87]] [2 71]]] [2 60]] [1906 2.9 [514 1.99 [2 100] [2 85]] [5812 12 [7566 0.295 [2 93] [2 100]] [2 88]]]]] [2 53]] [13 50]]]] [5158 0.184 [5972 1.93 [3687 1.81 [5264 0.26 [685 0.315 [5092 1.32 [6098 0.651 [3659 0.125 [3332 1.68 [7615 0.606 [2526 4.12 [907 1.6 [7382 0.956 [5225 0.582 [4117 0.656 [7600 0.326 [7473 0.0623 [7340 1.48 [4207 0.304 [2849 8.42 [1722 0.505 [2701 0.0285 [1645 0.0578 [3003 0.34 [5472 0.719 [784 0.0479 [877 0.249 [5824 0.765 [1862 0.169 [701 0.214 [4699 0.329 [2752 3.15 [2470 2.56 [538 1.17 [4154 0.179 [4114 12.5 [1659 0.211 [7624 0.461 [4997 0.651 [906 5.56 [915 3.75 [3292 6.22 [2955 2.12 [7628 1.19 [802 8.49 [1623 0.322 [1664 0.985 [939 2.53 [2913 0.228 [4703 2.39 [2259 0.121 [7665 0.739 [3944 0.174 [5730 7.94 [5482 4.07 [4778 0.366 [5140 1.41 [221 14.9 [6732 3.01 [3311 4.27 [7640 1.25 [2001 0.0889 [819 0.555 [248 7.68 [5498 3.5 [296 1.34 [6457 5.82 [2143 0.211 [7411 10.2 [1429 12.8 [560 1.87 [1277 2.67 [2488 3.69 [2628 13.5 [5621 1.72 [7739 2.22 [4665 3.13 [7634 4.35 [3273 8.4 [7357 2.37 [957 3.21 [330 78.5 [7656 4.21 [2931 1.29 [7441 28.3 [126 2.5 [928 3.82 [5461 12.8 [4809 18.6 [5480 19.2 [7052 5.15 [7512 9.09 [1143 9.35 [1029 2.54 [1055 11.8 [3667 12.3 [4210 7.46 [7606 7.04 [791 0.17 [1095 1.62 [1 23] [1 58]] [7335 27.8 [35 11] [22 63]]] [19 58]] [3 78]] [35 76]] [1056 8.2 [11 60] [11 100]]] [11 100]] [1 86]] [10 24]] [11 100]] [22 50]] [33 47]] [2 100]] [27 90]] [3 50]] [7444 7.69 [429 36.4 [11 66] [11 75]] [11 100]]] [23 51]] [35 26]] [23 83]] [1911 16.3 [963 8.77 [663 18.2 [27 89] [16 35]] [27 100]] [27 62]]] [2023 0.891 [35 81] [35 81]]] [11 35]] [27 92]] [27 35]] [19 53]] [9 100]] [2661 3.07 [5100 1.5 [2684 8.77 [978 6.02 [6425 4.85 [2628 67.6 [5595 8.77 [5577 7.46 [5632 47.7 [16 18] [16 75]] [16 61]] [16 71]] [4739 5.26 [38 32] [16 69]]] [16 55]] [19 37]] [4 100]] [6 32]] [16 36]]] [2489 11.1 [1899 13.9 [8 37] [8 81]] [13 55]]] [9 92]] [18 75]] [896 7.26 [1638 5.15 [7254 1.25 [301 3.3 [23 1.48 [717 21.7 [3990 2.44 [5254 3.4 [3874 2.62 [1888 2.63 [3488 4.02 [780 8.77 [791 2.43 [6328 17.6 [2067 16.5 [4397 8.77 [731 2.73 [6444 5.38 [5540 2.79 [1661 1.92 [6074 6.45 [152 9.43 [774 8.24 [2039 2.67 [1587 7.93 [3079 22.5 [1552 7.46 [4630 15.5 [4977 23.7 [2081 2.42 [1 12] [1 20]] [6 64]] [25 45]] [32 100]] [37 92]] [33 19]] [2108 1.96 [1899 64.5 [1 42] [28 33]] [1 71]]] [27 81]] [18 91]] [13 28]] [18 39]] [13 87]] [8 100]] [5 15]] [28 100]] [1 67]] [6330 4.67 [11 32] [4 37]]] [863 6.85 [7222 0.952 [4920 4.67 [2108 4.33 [1672 1.57 [1436 4.2 [5110 7.82 [5647 18.4 [4781 14.2 [4376 4.35 [6524 7.03 [5994 15.7 [2232 3.75 [1435 23.6 [221 6.71 [2944 4.59 [3438 4.59 [37 7] [11 57]] [21 52]] [25 75]] [35 50]] [2181 4.67 [25 42] [2 37]]] [29 53]] [28 64]] [13 100]] [11 62]] [13 36]] [22 67]] [11 16]] [22 100]] [29 26]] [22 63]] [13 57]] [13 100]]] [27 100]] [37 52]] [7210 12 [4789 10.6 [702 4.04 [5856 1.66 [1909 1.86 [731 5.64 [5 12] [16 23]] [17 44]] [30 62]] [12 50]] [13 37]] [18 31]]] [12 96]] [10 100]] [791 7.25 [37 100] [37 80]]] [36 100]] [130 5.62 [5532 14.7 [429 25.7 [7369 3.61 [6844 7.32 [287 5.99 [169 45.5 [5402 1.04 [6877 5.05 [5467 5.15 [5316 3.23 [6929 1.12 [4948 3.45 [5647 13.1 [4991 23.8 [35 17.5 [4809 3.94 [1078 25.8 [4071 8.2 [5154 4.59 [1078 24 [328 29.2 [2199 1.15 [1395 25.6 [6413 8.53 [33 8] [25 62]] [34 50]] [1 32]] [328 40.7 [33 28] [18 50]]] [5 50]] [33 41]] [12 33]] [1783 7.46 [168 57.3 [35 22] [19 44]] [13 38]]] [22 44]] [21 50]] [15 53]] [1 80]] [3 70]] [3 50]] [28 70]] [12 100]] [25 44]] [13 100]] [19 100]] [32 100]] [33 88]] [287 6.45 [19 23] [32 100]]] [3 18]] [13 86]] [17 75]]] [2982 6.67 [30 63] [30 100]]] [6040 1.64 [5618 20 [2166 5.26 [7254 77.4 [6294 0.741 [33 30] [2 28]] [33 48]] [1 90]] [33 92]] [33 77]]] [14 100]] [7 67]]] [35 48]] [441 3.45 [2184 10.4 [2190 5.7 [1104 5.24 [3404 8.66 [2083 4.42 [1958 1.21 [2247 1.42 [5673 5.08 [2232 0.542 [5926 1.32 [2160 3.91 [168 20.8 [5309 7.46 [2191 1.74 [438 16 [2151 0.974 [1260 52 [2136 2.62 [392 3.11 [2628 3.17 [1913 31.4 [23 13.6 [585 0.042 [2114 5.75 [2145 6.69 [4214 5.87 [1244 6.81 [1253 74.6 [3994 31.8 [6397 11.9 [791 0.504 [1 23] [21 14]] [33 63]] [1 85]] [29 46]] [29 54]] [29 50]] [21 20]] [35 72]] [21 80]] [2145 5.38 [1 22] [3 71]]] [29 34]] [2948 5.35 [16 22] [38 50]]] [35 51]] [29 50]] [25 50]] [328 3.93 [7329 6.85 [2195 1.54 [6449 0.64 [1 15] [7 50]] [1 71]] [4 50]] [13 20]]] [23 30]] [29 44]] [10 70]] [19 76]] [35 47]] [1 83]] [2131 0.14 [1453 28.9 [1912 2.41 [2217 3.16 [29 22] [23 30]] [23 14]] [1 90]] [2136 6 [1452 0.607 [29 45] [2027 0.417 [2168 2.92 [23 45] [23 37]] [11 37]]] [2 33]]]] [35 53]] [2251 4.19 [35 57] [29 76]]] [29 54]] [429 38.3 [6342 8.55 [33 12] [14 28]] [1436 3.7 [1986 13.1 [35 38] [23 20]] [30 88]]]] [3524 2.44 [3269 14.1 [1 80] [1 60]] [1 66]]] [1101 43 [1 19] [1 40]]] [1 65]] [1783 44.3 [1 23] [11 42]]] [27 46]]] [6457 12.2 [25 80] [25 100]]] [1981 0.621 [1078 5.88 [32 59] [10 68]] [32 100]]] [30 98]] [221 10.4 [2124 12.8 [5174 7.6 [7244 1.54 [4656 2.65 [6485 10.2 [2131 7.7 [6634 7.46 [5170 5.66 [252 2.91 [1832 7.25 [4851 6.33 [4948 2.7 [6484 0.606 [5989 19.6 [23 18.5 [201 5.38 [4663 4.75 [5480 12.2 [1069 26.3 [2488 6.49 [7297 19.7 [5524 3.53 [7646 18.3 [1293 7.25 [5322 27.2 [7185 17.2 [6528 4.5 [4799 6.67 [1436 4.41 [4802 2.99 [6959 4 [2108 19.9 [3227 13.9 [7141 23.4 [33 19] [22 50]] [29 33]] [22 28]] [13 81]] [1 44]] [10 25]] [33 70]] [1 76]] [26 42]] [1 73]] [33 50]] [30 57]] [11 100]] [30 42]] [13 85]] [4 100]] [26 71]] [1 52]] [25 62]] [33 40]] [11 52]] [25 84]] [3 91]] [14 26]] [13 100]] [1 59]] [33 75]] [30 100]] [25 35]] [25 100]] [1 100]] [26 80]] [33 58]] [31 100]] [33 100]]] [3527 4.37 [1078 8.77 [27 92] [27 100]] [27 100]]] [29 24]] [5368 3.81 [1429 22 [1 79] [1 65]] [1 100]]] [23 100]] [28 22]] [6853 3.5 [4832 1.58 [5530 3.76 [5673 4.26 [2202 14.4 [1757 1.61 [7210 15.6 [5170 4.59 [5574 12.2 [1899 49.5 [25 10.8 [5040 7.67 [231 9.8 [791 28.6 [1025 16.4 [224 3.06 [429 38.5 [5412 16.1 [3008 31.9 [1078 9.65 [4802 4.78 [33 13] [33 39]] [25 24]] [33 31]] [28 37]] [21 45]] [4 31]] [33 41]] [30 30]] [21 100]] [2 44]] [12 60]] [29 28]] [2 37]] [33 64]] [33 33]] [24 71]] [22 55]] [30 77]] [33 76]] [2 76]] [28 35]]] [2934 3.88 [33 65] [33 57]]] [15 100]] [397 2.76 [7520 4.5 [18 61] [18 71]] [18 100]]] [11 97]] [5816 13.3 [3230 4.07 [3027 0.205 [35 78] [35 100]] [35 100]] [28 44]]] [736 1.86 [11 2.59 [7737 0.832 [5172 1.71 [610 2.24 [1025 1.07 [5432 3.07 [2628 6.58 [6591 4.55 [6643 6.2 [4224 1.28 [177 3.11 [5482 2.16 [7618 1.96 [1611 3.4 [145 11.9 [899 6.58 [3435 4.76 [1240 5.15 [1981 4.76 [4218 4.13 [5170 8.32 [7675 5.05 [7413 6.14 [1690 14.5 [978 8.37 [7023 4 [6486 6.39 [3331 1.87 [7025 10.3 [5693 0.569 [7034 4.07 [6549 37.2 [7665 32.5 [3100 1.83 [1638 6.8 [5377 6.27 [7009 4.07 [285 11.3 [2093 22.1 [6068 5.77 [7755 9.8 [7214 3.07 [4205 29.7 [7609 16.8 [4369 5.58 [6189 9.72 [4657 1.14 [14 14] [1 93]] [25 81]] [32 54]] [8 71]] [26 85]] [14 75]] [20 50]] [33 42]] [26 46]] [33 37]] [2200 2.92 [5 27] [26 100]]] [15 54]] [14 100]] [1 100]] [7032 14.1 [7381 36.2 [7311 6.99 [695 4.42 [7043 12.8 [7693 21.3 [3492 14.9 [1059 26.3 [6977 36.1 [5412 34.1 [6528 9.01 [573 27.6 [23 87.9 [6216 43.3 [14 28] [4 46]] [1783 13.5 [19 38] [3 25]]] [2 62]] [1 80]] [1 16]] [5 73]] [6 66]] [14 70]] [36 41]] [25 93]] [5564 4.42 [5833 19.3 [14 52] [13 72]] [14 100]]] [20 100]] [7 35]] [31 70]]] [32 100]] [13 100]] [7512 28.4 [14 15] [18 14]]] [13 100]] [1 100]] [32 85]] [13 100]] [7512 23.9 [26 16] [5316 4.42 [5 25] [38 34]]]] [17 92]] [7665 42.1 [25 28] [4 24]]] [6 88]] [248 32.7 [33 62] [26 63]]] [2448 7.46 [13 43] [13 100]]] [33 73]] [6732 21.3 [24 100] [24 91]]] [13 83]] [14 27]] [1911 2.26 [19 59] [19 78]]] [5160 19.2 [14 100] [14 85]]] [20 85]] [18 36]] [1982 10.4 [2143 5.76 [19 69] [19 100]] [19 75]]] [13 100]] [13 68]] [896 24 [17 64] [17 48]]] [5 13]] [25 100]] [5733 3.23 [13 31] [24 57]]] [5 89]] [33 88]] [2232 4.13 [1079 12.2 [1452 2.92 [83 8.68 [7169 6.54 [2143 6.06 [6853 3.6 [1239 5.92 [4895 1.95 [107 16.6 [19 51] [13 66]] [19 50]] [19 52]] [10 88]] [19 66]] [20 66]] [7722 2.22 [19 94] [19 100]]] [18 77]] [2180 0.438 [2091 3.22 [7665 26.2 [19 83] [19 62]] [19 55]] [19 100]]] [22 37]]] [31 100]] [7185 27.1 [5693 28.8 [6333 12.8 [3732 6.29 [7169 10.8 [791 43 [978 7.34 [7708 6.71 [17 27] [17 60]] [791 4.48 [17 31] [17 51]]] [4 23]] [5 44]] [3008 20.3 [17 62] [17 100]]] [5 81]] [7512 44.7 [18 33] [4 50]]] [26 35]]]] [5999 2.3 [3931 12.8 [6721 21.4 [682 1.46 [1634 0.77 [6582 1.54 [5759 1.37 [3310 9.53 [4877 0.431 [6767 8.42 [2385 1.81 [2696 0.644 [5258 1.39 [6457 3.65 [1556 1.49 [4674 1.89 [2359 4.24 [5498 0.859 [6809 1.95 [1078 8.94 [3019 3.14 [3401 1.04 [1948 1.38 [4775 8.89 [5211 12.8 [7588 5.41 [5170 3 [5409 7.42 [5254 1.93 [4904 10.5 [7665 0.196 [6260 1.42 [4778 1.52 [1594 2.88 [6560 1.1 [7046 7.46 [3929 1.5 [4550 5.49 [1672 0.258 [1622 2.92 [2424 1.17 [1661 5.57 [788 1.51 [5692 3.96 [4210 0.533 [5015 12.7 [6328 5.48 [1710 4.21 [6506 1.06 [1 9] [7 100]] [30 96]] [2259 51.7 [1340 3.78 [24 22] [2 46]] [11 47]]] [30 55]] [5110 2.02 [3 67] [34 100]]] [5368 1.92 [28 37] [15 22]]] [18 55]] [5991 7.93 [2286 2.31 [18 44] [18 100]] [18 100]]] [10 93]] [7141 5.15 [1239 4.2 [11 94] [11 100]] [11 100]]] [1843 2.48 [22 100] [22 90]]] [31 100]] [3215 0.683 [12 31] [12 87]]] [34 100]] [21 62]] [4 88]] [15 100]] [7428 2.71 [5202 2.67 [22 35] [9 83]] [21 36]]] [6759 2.48 [1239 20 [4851 8.25 [4673 3.94 [3726 2.13 [2445 0.956 [3357 17.9 [7514 0.263 [1 2.6 [7301 2.97 [2340 5.26 [23 0.928 [4421 1.57 [7585 4.2 [5160 8.18 [299 3.23 [247 3.61 [2466 10.6 [36 14] [14 61]] [34 57]] [6 100]] [14 100]] [31 50]] [6 37]] [5410 15.4 [7512 5.95 [794 1.95 [14 14] [11 50]] [14 35]] [20 33]]] [31 100]] [1783 6.2 [14 35] [14 63]]] [2939 2.28 [36 38] [20 90]]] [4897 6.31 [2259 11.8 [19 87] [19 47]] [13 66]]] [31 100]] [7514 20.6 [7301 6.67 [26 18] [18 50]] [19 48]]] [31 100]] [6 96]] [36 47]] [1587 0.196 [1255 1.17 [429 10.8 [144 3.42 [5637 3.23 [7421 4.28 [4414 6.07 [1062 12.5 [7404 4.07 [6 33] [6 64]] [13 28]] [6 42]] [6 100]] [18 50]] [19 50]] [4534 4.59 [6 57] [6 100]]] [19 75]] [19 50]]] [6 100]]] [14 54]] [10 100]] [6 82]] [2945 3.1 [7726 0.998 [1432 2.71 [5753 13.1 [1264 10.7 [248 1.52 [33 48] [248 51.7 [33 78] [11 36]]] [1 88]] [13 30]] [26 70]] [33 83]] [33 50]]] [5 87]] [2434 6.02 [5776 6.33 [30 47] [30 100]] [30 100]]] [2 57]] [2058 5.53 [5898 0.773 [429 12.7 [144 0.863 [2122 22.4 [5412 0.857 [328 10.6 [2212 1.38 [29 23] [1 63]] [38 55]] [23 23]] [1247 3.14 [35 50] [29 44]]] [19 42]] [31 27]] [13 42]] [1429 22.3 [35 50] [33 25]]]] [14 100]] [5732 31.3 [24 95] [24 100]]] [1051 4.7 [5670 2.99 [788 1.88 [7738 1.41 [2008 3.72 [2331 9.07 [2103 0.325 [7381 0.949 [1333 4.24 [7234 12.9 [7491 12.8 [1078 119 [5539 4.78 [1982 1.23 [5673 4.46 [5069 3.4 [1400 19.7 [7512 1.54 [4701 3.7 [1708 0.434 [6306 23.4 [377 0.627 [4761 12.1 [851 1.43 [4369 4.26 [2306 13.2 [2114 11.9 [5412 21.6 [5550 4.3 [1 7] [6 100]] [28 47]] [1 88]] [30 92]] [13 35]] [5 49]] [5312 6.33 [30 33] [12 100]]] [429 19.2 [35 37] [35 50]]] [31 85]] [28 51]] [30 100]] [3414 4.27 [1382 2.94 [6719 2.3 [325 6.02 [168 16.4 [5099 4.42 [6853 11.9 [2293 16.4 [218 2.13 [2260 11.4 [4673 3.6 [31 15] [6 100]] [13 25]] [10 87]] [1980 19.1 [1 33] [18 44]]] [36 60]] [6 85]] [19 93]] [31 100]] [18 62]] [6 92]] [31 100]]] [5211 2.09 [10 47] [10 100]]] [4702 3.4 [30 66] [30 100]]] [4210 6.17 [2039 2.99 [7737 8.55 [7722 2.86 [19 22] [19 66]] [19 55]] [29 25]] [30 100]]] [19 85]] [13 93]] [2234 12.7 [2130 3.24 [1 36] [1 62]] [4 57]]] [31 52]] [6 90]] [10 100]] [2939 0.52 [5 27] [7723 0.52 [5 27] [17 85]]]] [10 100]] [429 30.3 [31 43] [32 88]]] [11 100]] [144 18.4 [19 68] [1933 2.92 [19 85] [19 66]]]] [276 3.31 [2275 19.4 [18 36] [16 57]] [18 65]]] [31 88]] [7739 7.83 [2143 0.766 [5753 12 [10 60] [10 100]] [1 42]] [10 100]]]] [32 100]] [30 100]] [2358 1.96 [7 97] [7 100]]] [1701 3.6 [4736 1.24 [4414 1.93 [7513 21.6 [1078 1.24 [6 91] [6 100]] [6 66]] [6 60]] [6 71]] [6 100]]] [0 100]] [7623 1.17 [25 100] [25 80]]] [10 98]] [2939 41.6 [30 96] [30 85]]] [7537 10.7 [7723 1.23 [7188 4.59 [18 42] [18 71]] [7241 12 [18 49] [18 100]]] [19 64]]] [6960 5.88 [31 92] [31 100]]] [6781 2.16 [14 92] [14 100]]] [29 74]] [1980 19.5 [6260 0.257 [30 93] [30 100]] [30 60]]] [4 94]] [7255 0.131 [7141 0.492 [2127 2.02 [13 100] [13 85]] [13 100]] [13 100]]] [5851 3.8 [31 89] [31 75]]] [30 98]] [2993 3.88 [3379 4.67 [4851 1.57 [6294 1.54 [2700 2.7 [31 64] [31 96]] [8 30]] [5 41]] [1 78]] [11 44]]] [1457 4.59 [185 0.441 [6484 1.47 [2445 0.956 [1089 0.911 [5343 1.64 [1051 0.77 [23 4.13 [7149 20.2 [5076 0.571 [2259 18.5 [3342 3.11 [2225 2.54 [26 15] [1094 1.55 [13 25] [10 100]]] [28 75]] [7285 14.8 [4875 9.43 [6134 4.84 [3027 2.07 [221 9.62 [3993 7.56 [3435 1.27 [6359 0.635 [3136 2.6 [1997 13.7 [5851 14.2 [5267 27.5 [429 6.06 [4398 14 [5617 4.67 [33 20] [0 20]] [33 72]] [23 10]] [1 36]] [1 41]] [14 66]] [26 44]] [1 30]] [11 33]] [38 62]] [13 47]] [7 75]] [30 88]] [1 100]] [13 90]]] [10 100]] [33 33]] [4655 6.9 [2268 2.67 [1189 2.76 [7512 3.45 [221 14.8 [3343 5.49 [1239 39.4 [33 18] [5999 23.3 [33 50] [35 91]]] [28 100]] [3 54]] [25 28]] [28 95]] [28 100]] [1 83]]] [10 88]] [1638 2.81 [26 20] [14 100]]] [10 100]] [5255 4.56 [10 64] [10 100]]] [25 100]] [28 87]] [838 1.14 [28 88] [28 100]]]]] [2199 0.184 [3136 1.1 [5171 1.2 [6031 0.37 [1844 0.688 [107 1.26 [6471 1.06 [4064 1.05 [6959 0.0333 [1812 0.982 [1783 7.57 [12 11] [233 7.53 [2143 10.1 [6610 8.85 [5110 1.2 [5496 1.88 [1783 115 [6525 11.1 [4841 0.879 [1876 1.2 [791 0.578 [328 13 [7329 5.42 [33 24] [33 46]] [33 64]] [1841 4.56 [33 26] [10 71]]] [25 14]] [10 42]] [25 85]] [33 46]] [2 40]] [33 66]] [28 92]] [28 19]] [33 75]]] [2894 1.81 [4655 4.2 [7623 15.4 [4235 0.982 [6342 0.652 [6964 1.68 [33 92] [33 100]] [33 80]] [33 100]] [4682 9.15 [33 66] [33 100]]] [23 7 [1 72] [1 50]]] [33 100]]] [13 47]] [24 19]] [26 78]] [1239 14.6 [33 86] [5172 0.719 [33 96] [33 100]]]] [13 54]] [4564 2.22 [109 1.3 [4703 33.8 [144 3.02 [4768 1.15 [5539 12.3 [6757 1.66 [33 38] [33 66]] [13 100]] [28 40]] [25 33]] [11 25]] [33 71]] [24 27]]] [6655 7.74 [33 91] [33 83]]] [5495 0.633 [3309 3.92 [1899 19.8 [25 17] [15 66]] [11 28]] [31 58]]] [4790 1.73 [7081 0.752 [2752 1.03 [5647 4.7 [6457 0.365 [4414 0.621 [5153 4.98 [7335 4.79 [6040 1.22 [4630 2.77 [2143 3.53 [1783 0.2 [20 30] [28 30]] [10 15]] [15 44]] [30 42]] [22 66]] [33 70]] [2 37]] [25 100]] [33 90]] [24 64]] [10 71]] [10 45]]]] [6721 0.761 [5110 0.517 [6077 1.71 [6584 0.461 [5311 1.79 [7665 15.6 [377 4.35 [4369 3.37 [4971 2.99 [2259 16.9 [788 1.62 [7329 0.114 [1995 0.408 [5211 8.57 [7085 13.1 [392 16.5 [1391 12.2 [6401 2.7 [2466 2.73 [3678 4.76 [1769 23.8 [688 19.6 [2939 12.9 [429 1.13 [44 8.2 [4414 21.4 [30 21] [25 27]] [30 26]] [4235 18.7 [3 29] [26 41]]] [3 46]] [7 75]] [15 58]] [0 100]] [25 23]] [5 100]] [15 50]] [26 46]] [5 75]] [30 81]] [25 38]] [2 20]] [25 88]] [2628 4.91 [1592 1.57 [2068 3.83 [1239 32.8 [30 62] [3 52]] [10 44]] [3 100]] [30 29]]] [30 100]] [32 65]] [7 57]] [32 41]] [31 94]] [7588 4.83 [5 100] [5 69]]] [31 100]] [394 0.437 [2695 7.81 [30 65] [30 100]] [1587 4.72 [30 100] [30 88]]]] [30 89]]] [453 2.88 [5550 3.11 [976 0.535 [4571 5.21 [4968 5.21 [6199 2.39 [429 35.5 [2926 1.98 [957 0.535 [7502 0.525 [3616 6.02 [2086 12.2 [2268 5.01 [3095 3.03 [7032 11.5 [2962 4.85 [1068 9.53 [2143 3.91 [7241 15.7 [6732 10.2 [2039 5.44 [2752 2.59 [1079 1.54 [3457 0.155 [328 65.7 [4781 1.68 [1164 3.4 [13 9] [27 80]] [2 61]] [26 100]] [35 63]] [26 30]] [22 57]] [19 44]] [25 25]] [6 30]] [2086 2.15 [23 14] [15 45]]] [11 58]] [31 100]] [31 100]] [1 33]] [7 37]] [6 58]] [27 80]] [30 72]] [1783 1.61 [27 85] [10 58]]] [31 100]] [3525 4.13 [928 0.664 [1121 1.42 [4315 1.5 [6156 3.7 [503 2.25 [4611 29.7 [1078 58.4 [1239 5.01 [939 28.8 [27 22] [27 39]] [11 22]] [27 70]] [35 50]] [791 27.3 [27 100] [27 71]]] [10 100]] [27 100]] [27 98]] [2081 4.62 [27 92] [27 69]]] [35 72]]] [35 27]] [35 70]] [19 46]] [27 100]] [6 100]] [3097 1.2 [27 91] [27 100]]]] [6781 6.34 [273 2.69 [5386 6.31 [1818 1.62 [3269 1.67 [362 3.14 [23 12.2 [6134 3.76 [23 10.2 [4643 3.64 [6809 3.27 [6777 3.34 [1638 1.01 [6320 6.59 [7381 1.72 [3 51] [19 28]] [3 100]] [14 100]] [14 100]] [32 100]] [32 37]] [32 60]] [7392 1.89 [1664 9.18 [14 50] [6915 2.92 [14 42] [14 96]]] [14 100]]] [3 61]] [3 100]] [19 54]] [3 100]] [14 66]] [32 77]] [14 94]]] [11 100]] [429 81.4 [1318 1.98 [6260 20.8 [4480 7.01 [587 1.47 [573 12.4 [4210 6.67 [6380 4.35 [607 8.77 [7077 7.53 [747 9.37 [569 3.23 [635 2.96 [625 19.7 [21 29] [9 85]] [9 52]] [21 88]] [429 39.6 [11 40] [21 100]]] [21 100]] [3 100]] [9 85]] [3 100]] [13 50]] [21 100]] [9 69]] [9 74]] [6148 3.95 [9 95] [9 100]]] [21 70]]] [3130 7.31 [5753 0.675 [5851 6.19 [35 66] [29 33]] [35 50]] [35 35]]] [7281 0.191 [7369 6.35 [2690 0.312 [4896 0.458 [6380 3.3 [2955 17.6 [2006 1.08 [3008 0.846 [2939 107 [2974 6.39 [7122 25.9 [5681 2.65 [1429 15.2 [4738 2.58 [5102 0.615 [1932 0.205 [38 46] [38 90]] [5100 16.9 [26 37] [6 50]]] [16 46]] [7255 5.49 [1576 7.18 [4564 4.13 [38 27] [30 50]] [6 88]] [6 28]]] [6 25]] [2733 5.18 [16 72] [16 30]]] [17 44]] [2683 3.94 [3679 4.26 [190 0.521 [4716 4.33 [38 70] [16 50]] [38 53]] [38 100]] [5 25]]] [30 22]] [1896 0.695 [2023 0.818 [38 58] [38 84]] [38 81]]] [7428 9.62 [2655 3.14 [2978 5.76 [2733 10.1 [3243 20.4 [2644 6.98 [5635 14.4 [1980 0.829 [38 59] [328 0.84 [38 80] [38 91]]] [16 63]] [6409 13.3 [4717 41.7 [16 62] [16 37]] [7 22]]] [38 100]] [2681 4.59 [16 63] [16 84]]] [16 50]] [16 43]] [8 27]]] [7401 1.26 [38 31] [17 100]]] [4895 7.53 [17 76] [17 22]]] [2689 6.31 [17 46] [16 51]]] [4878 3 [187 0.389 [4754 4.73 [2143 2.51 [1564 8.56 [5058 24.1 [17 57] [19 40]] [32 54]] [17 42]] [17 90]] [1452 1.37 [7301 0.462 [14 30] [17 69]] [17 100]]] [14 84]]] [5577 0.382 [2951 28.4 [1078 2.02 [18 36] [6 20]] [6 45]] [5985 19.8 [16 33] [16 86]]]]] [3379 6.67 [3079 0.297 [37 56] [663 1.81 [3477 0.701 [1429 26.5 [37 94] [37 100]] [37 100]] [37 100]]] [1 92]]] [535 1.29 [5034 2.86 [5619 11.6 [1078 47.8 [1266 3.23 [21 38] [21 100]] [32 40]] [9 84]] [3 94]] [4768 27 [7085 19.8 [6791 3.45 [21 98] [21 100]] [21 90]] [21 87]]]] [6015 27.2 [5937 5.5 [7318 3.07 [1986 0.38 [6274 5.62 [4218 1.61 [609 5.64 [2199 7.09 [248 2.89 [1078 1.38 [693 1.52 [6344 6.07 [2146 13.8 [5170 9.9 [5891 5.35 [4587 5.38 [221 9.3 [5336 3.31 [1239 105 [4898 2.65 [5467 6.67 [802 7.46 [3057 1.21 [7085 16.3 [5094 20.4 [3929 4.69 [3095 27.6 [4048 8.47 [4414 35.5 [2002 4.07 [5753 11.6 [2488 3.7 [126 11.5 [3 29] [3 57]] [13 66]] [29 16]] [21 57]] [1239 2.99 [3 70] [3 50]]] [21 100]] [11 55]] [32 33]] [9 100]] [21 36]] [37 66]] [802 24.2 [21 64] [915 13.2 [21 78] [21 100]]]] [12 70]] [9 75]] [9 71]] [9 100]] [21 75]] [3 62]] [3 100]] [33 66]] [21 90]] [15 100]] [21 100]] [27 10]] [33 25]] [2149 4.76 [21 63] [32 66]]] [21 95]] [3 88]] [22 100]] [544 0.76 [5753 2.54 [21 66] [21 40]] [21 80]]] [3 100]] [2084 2.65 [5042 6.7 [743 21.9 [4810 3.27 [7451 4.95 [4478 3.82 [21 86] [9 100]] [6091 4.95 [21 89] [21 100]]] [21 100]] [21 37]] [9 66]] [21 100]]] [791 27.8 [5040 7.46 [21 62] [21 100]] [4918 3.6 [906 18.9 [21 87] [21 93]] [21 100]]]]] [7 100]] [5122 20.8 [7502 0.886 [7049 6.3 [30 100] [30 95]] [30 100]] [30 92]]] [5840 11.5 [1581 0.386 [4884 0.682 [1750 0.168 [3254 1.24 [5564 0.143 [5891 19 [4089 0.425 [6776 0.381 [17 40] [1997 1.56 [1659 10.4 [17 60] [19 36]] [32 38]]] [7374 1.12 [2764 0.66 [19 82] [19 54]] [17 46]]] [1429 103 [6389 0.446 [17 45] [17 71]] [6388 3.76 [2029 1.07 [6076 0.195 [4457 0.144 [2187 0.912 [695 1.25 [3597 1.1 [1654 0.723 [17 57] [5940 1.11 [17 66] [14 45]]] [4661 7.68 [3996 2.08 [5940 18.6 [1512 0.855 [17 84] [17 57]] [3 63]] [17 50]] [17 100]]] [17 87]] [19 57]] [17 100]] [4639 12.6 [2966 5.58 [4643 0.584 [17 69] [5891 24 [17 100] [17 88]]] [17 70]] [17 94]]] [14 66]] [19 73]]]] [1638 11.2 [14 100] [3898 3.37 [14 100] [14 85]]]] [5891 16.5 [1980 3.16 [32 90] [32 100]] [4572 1.23 [1638 0.402 [5844 0.552 [17 38] [17 58]] [14 100]] [17 57]]]] [1961 7.62 [4083 1.99 [5836 1.39 [248 3.62 [38 100] [19 45]] [38 53]] [7334 0.504 [17 46] [19 60]]] [17 40]]] [5940 1.55 [32 75] [1664 3.45 [32 100] [32 75]]]] [3 100]] [6681 4.72 [3 100] [14 46]]]] [6524 18.2 [2023 14.8 [4315 1.24 [791 4.24 [2003 1.48 [1587 2.57 [7442 2.92 [3031 3.23 [23 3.7 [4152 2.16 [4116 0.732 [2901 1.07 [4326 2.56 [2707 17.5 [2091 17.8 [221 9.43 [3269 6.67 [2461 4.42 [968 1.55 [7512 7.69 [499 2.39 [27 16] [4320 5.26 [957 2.39 [27 66] [27 100]] [27 100]]] [13 43]] [27 100]] [27 100]] [9 35]] [10 33]] [1 57]] [19 25]] [27 100]] [27 100]] [27 100]] [27 100]] [3 22]] [27 84]] [27 100]] [30 27]] [22 30]] [3735 29.3 [1078 16.1 [5692 9.74 [524 2.82 [1078 3.94 [27 33] [27 30]] [21 100]] [14 55]] [5692 3.11 [5480 10.8 [944 1.98 [27 90] [27 100]] [27 57]] [27 81]]] [27 55]]] [27 100]] [27 25]] [28 35]]] [1592 3.57 [5547 0.345 [3073 0.341 [4851 0.166 [5041 0.873 [5891 0.0332 [1159 0.242 [7739 0.326 [5170 1.86 [6064 1.05 [590 1.19 [939 6.49 [6767 6.65 [1163 0.222 [172 0.103 [616 0.808 [6051 1.65 [4867 0.536 [4181 0.709 [555 2.43 [6668 0.607 [1133 0.485 [6859 5.9 [4193 5.43 [607 1.15 [5917 1.09 [4430 13.7 [569 5.37 [3928 0.715 [6414 0.392 [24 28 [534 0.618 [2143 14.6 [554 3.67 [3554 4.41 [4682 2.62 [4114 34.2 [1672 2.47 [5576 5.85 [2517 0.486 [6538 2.96 [811 1.65 [3728 1.81 [1239 13.3 [1617 0.182 [1397 1.89 [4183 12.5 [426 0.762 [3931 14.1 [4359 3.37 [3527 3.31 [7022 2.11 [819 0.975 [915 3.18 [4342 3.18 [2380 1.46 [5047 1.71 [4338 1.34 [788 1.12 [4865 9.9 [5766 0.467 [2707 25 [978 4.81 [5163 0.849 [6853 6.31 [28 5] [34 72]] [30 100]] [1783 8.92 [5192 9.59 [5 17] [17 44]] [18 41]]] [38 75]] [28 91]] [3 100]] [1783 6.19 [18 36] [18 75]]] [2 27]] [3 100]] [31 94]] [24 94]] [3 65]] [27 100]] [13 100]] [26 58]] [20 90]] [4171 3.55 [27 59] [32 82]]] [1 95]] [32 96]] [27 100]] [10 100]] [4655 2.27 [4868 2 [3794 3.09 [791 11.2 [3963 4.89 [1955 18.8 [5403 5.93 [7176 2.73 [5538 0.846 [145 5.53 [7060 9.27 [968 11.2 [536 3.65 [4186 0.849 [641 3.4 [5412 0.216 [4904 15.2 [1250 19.7 [1457 4.93 [6082 3.02 [2048 0.972 [3 15] [24 23]] [5991 4.86 [11 28] [11 60]]] [30 63]] [1959 26.4 [24 91] [24 50]]] [10 68]] [7428 1.66 [6230 0.304 [5851 10.5 [7472 0.117 [1915 3.13 [11 12] [18 44]] [17 54]] [14 57]] [17 36]] [32 34]]] [3 100]] [32 77]] [3 100]] [28 70]] [33 87]] [19 47]] [0 100]] [33 83]] [3 100]] [24 78]] [21 100]] [7502 0.114 [2944 4.26 [2130 0.81 [1400 6.73 [1379 13.2 [1318 2.59 [2939 0.237 [221 9.02 [1951 0.99 [3 50] [24 33]] [21 28]] [33 18]] [9 61]] [30 87]] [21 57]] [26 25]] [29 57]] [22 33]]] [2081 3.43 [29 60] [29 81]]] [3 100]] [1 90]]] [32 100]] [328 9.37 [1161 1.56 [1786 1.56 [4279 2.46 [10 79] [10 50]] [10 100]] [10 100]] [15 71]]] [2 100]] [24 84]] [978 3.76 [2 87] [2 100]]] [22 100]] [27 73]] [4704 5.82 [1812 3.63 [33 72] [33 100]] [2259 1.41 [33 60] [2 30]]]] [429 30.1 [1764 12.2 [32 66] [12 85]] [27 42]]] [7449 6.8 [5404 3.6 [3 83] [3 100]] [3 100]]] [2235 1.63 [791 57.3 [5073 2.65 [2184 10.8 [7522 8.49 [7314 4.95 [1101 8.52 [6065 14 [4655 3.7 [2042 1.06 [4282 6.49 [5393 2.16 [5412 5.38 [29 21] [28 52]] [36 40]] [3 82]] [29 44]] [1 92]] [22 100]] [6397 2.54 [15 31] [15 36]]] [3 95]] [13 55]] [4279 19.6 [3 90] [3 45]]] [28 63]] [21 52]] [30 47]]] [2199 2.13 [5509 3.94 [1980 5.15 [3 96] [3 100]] [3 100]] [3 100]]] [29 83]] [5777 0.414 [3989 0.931 [2062 0.249 [7 90] [7 83]] [7 77]] [7 100]]] [5809 2.23 [2232 0.231 [4991 0.344 [2178 0.836 [12 36] [12 23]] [12 75]] [328 0.403 [24 60] [18 64]]] [5 85]]] [3 90]] [3 91]] [4926 0.617 [4362 5.05 [7210 1.11 [4292 2.74 [10 30] [10 98]] [10 78]] [10 100]] [10 100]]] [3 100]] [4680 6.02 [3 90] [3 100]]] [6738 21.3 [5789 2.04 [1078 8.85 [24 85] [5267 2.37 [28 40] [36 57]]] [24 71]] [24 75]]] [3027 0.917 [26 57] [27 50]]] [5943 0.169 [28 57] [1239 8.8 [429 10.2 [28 75] [28 100]] [28 100]]]] [5034 1.31 [6643 3.31 [3 79] [3 92]] [3 100]]] [35 80]] [3 100]] [3 100]] [6544 32.1 [3 100] [3 90]]] [2048 0.472 [2068 6.43 [1452 1.69 [176 27 [3027 9.16 [145 26.4 [7687 2.62 [19 61] [4154 21 [176 2.7 [13 25] [19 41]] [19 81]]] [1932 1.14 [107 2.18 [57 8.21 [5641 2.73 [4198 14.7 [19 74] [18 41]] [19 87]] [19 65]] [19 100]] [19 100]]] [19 44]] [7687 6.34 [19 86] [19 85]]] [7 25]] [22 33]] [19 86]]] [10 100]] [1980 0.655 [31 93] [31 100]]] [2259 5.18 [4176 0.431 [3843 2.96 [7491 1.71 [1108 4.4 [3735 0.86 [774 0.671 [4114 4.84 [3966 4.93 [957 1.54 [2091 2.46 [27 27] [27 66]] [27 100]] [27 100]] [27 100]] [1995 2.59 [2081 3.11 [27 98] [27 87]] [27 47]]] [27 100]] [15 66]] [27 40]] [27 100]] [27 100]] [27 13]]] [5404 1.19 [3 91] [3 100]]] [22 100]] [1912 7.16 [7330 2.88 [5086 3.06 [5192 2.11 [98 11.2 [2232 0.849 [4703 0.219 [33 85] [4768 4.51 [33 98] [33 85]]] [1 50]] [1 60]] [1239 45.3 [33 100] [33 85]]] [33 83]] [33 71]] [33 60]]] [5017 8.7 [1183 0.328 [338 17.8 [1400 3.48 [1997 3.93 [38 11.2 [296 0.627 [6342 8.77 [6279 2.86 [1110 0.537 [3095 8.02 [107 12.8 [4154 0.804 [18 54] [6920 0.682 [2052 5.88 [5386 0.69 [169 1.21 [5673 5.61 [2081 9.03 [2199 7.44 [429 3.63 [7737 4.47 [14 42] [19 60]] [18 27]] [19 85]] [18 38]] [19 83]] [2199 4.18 [1955 3.11 [5918 5.26 [19 84] [19 55]] [19 71]] [19 57]]] [18 41]] [19 57]] [19 26]]] [18 45]] [19 37]] [10 66]] [10 80]] [19 40]] [10 100]] [19 25]] [19 38]] [10 100]] [25 100]] [1221 0.891 [10 84] [10 100]]] [7512 25.2 [18 55] [19 80]]]] [4176 15.4 [6294 0.502 [1104 0.645 [1094 0.52 [957 2.09 [27 77] [27 100]] [27 100]] [27 100]] [27 100]] [27 61]]] [1018 1.2 [4862 1.36 [4630 0.135 [4473 3.06 [23 13.4 [4867 2.22 [5270 0.869 [2993 5.1 [6134 0.299 [4559 0.331 [2402 1.67 [7210 11.6 [366 1.51 [1659 4.96 [3 32] [1 40]] [14 100]] [3 100]] [14 50]] [14 33]] [14 81]] [3 50]] [32 38]] [534 1.47 [3 96] [3 100]]] [5941 0.578 [3 80] [3317 4.59 [3 54] [3 33]]]] [32 100]] [6806 2.9 [5564 0.43 [4564 1.2 [5891 11.7 [32 28] [4684 0.509 [498 1.14 [6227 0.11 [17 49] [17 81]] [17 84]] [17 30]]] [38 46]] [1606 0.231 [2342 2.02 [5840 2.68 [4895 1.64 [14 100] [14 87]] [14 87]] [14 100]] [14 100]]] [32 100]]] [3 100]] [3 100]]] [6017 1.92 [6726 0.904 [1906 3.5 [21 85] [21 100]] [21 100]] [21 100]]] [2738 2.11 [5271 0.156 [4687 1.9 [4799 6.47 [301 6.85 [2011 9.14 [5567 0.165 [6944 1.36 [1609 0.692 [7548 12.1 [1565 0.853 [5566 0.0796 [23 82 [2023 3.28 [7731 1.93 [4279 5.38 [1011 2.54 [7449 2.05 [6382 0.451 [32 18] [17 43]] [12 33]] [5 42]] [3 24]] [16 37]] [29 42]] [19 66]] [14 100]] [32 80]] [32 100]] [5151 1.57 [24 57] [36 66]]] [32 100]] [4154 2.85 [14 100] [1783 1.26 [14 83] [14 100]]]] [29 100]] [30 100]] [32 100]] [17 100]] [2178 0.12 [32 96] [32 100]]] [32 100]]] [6471 0.901 [2130 0.544 [4160 5.1 [7203 1.4 [3675 0.269 [1932 1.64 [26 87] [26 100]] [26 85]] [26 100]] [26 99]] [26 100]] [26 62]]] [13 100]] [4574 3.48 [851 4.15 [6134 1.22 [6918 1.82 [5179 2.92 [7241 0.536 [1980 7.85 [4684 2.45 [7428 0.718 [3 99] [3 66]] [3 68]] [1445 2 [3 84] [3 100]]] [3 100]] [3 42]] [3 100]] [3 40]] [6562 0.466 [4863 2.59 [4948 5.1 [14 50] [17 70]] [3 100]] [17 71]]] [32 64]]]] [7451 1.89 [5919 2.82 [553 2.54 [5832 0.496 [791 25.4 [7210 8.48 [9 50] [9 86]] [803 1.86 [805 20.3 [1429 6.49 [6015 8 [4810 3.23 [659 3.4 [21 79] [21 81]] [21 97]] [21 95]] [21 69]] [9 90]] [21 100]]] [201 6.67 [9 90] [21 57]]] [21 97]] [9 100]] [1906 2.39 [21 97] [21 100]]]] [4520 1.65 [3235 1.09 [1411 1.92 [820 2.89 [7512 0.0829 [4851 4.08 [7255 0.988 [7117 0.453 [328 3.66 [4154 30.1 [4663 23.9 [4414 26.2 [7361 0.994 [2379 0.282 [2259 23.5 [429 8.62 [1913 13.5 [4017 0.423 [5343 1.57 [1429 1.78 [15 37] [1899 15.3 [1795 1.23 [25 23] [25 100]] [30 60]]] [25 66]] [11 37]] [1239 18.4 [16 25] [10 58]]] [7292 1.95 [5816 0.118 [6184 13.4 [2628 3.38 [2939 3.65 [726 25.7 [5234 3.27 [2471 3.07 [3452 2.62 [4929 5.7 [4326 1.94 [4 21] [27 30]] [4 100]] [11 100]] [15 100]] [11 100]] [10 58]] [15 73]] [4 79]] [15 58]] [4 94]] [24 57]]] [1400 34.2 [6970 0.374 [5270 3.3 [5110 3.07 [30 24] [30 91]] [791 1.33 [6767 4.5 [31 76] [31 100]] [31 97]]] [24 57]] [15 100]]] [4063 0.299 [4 90] [4 88]]] [31 85]] [15 73]] [15 86]] [15 81]] [2914 0.677 [5480 2.02 [2526 0.095 [6721 5.88 [5343 0.283 [5753 6.96 [1116 3.55 [1400 31 [5776 11.2 [7185 5.18 [30 27] [1 42]] [30 62]] [15 83]] [30 80]] [30 89]] [5412 1.19 [30 37] [25 80]]] [30 100]] [30 61]] [3308 1.95 [4 84] [4 50]]] [30 100]]] [328 13 [5904 0.239 [25 93] [25 100]] [25 71]]] [2132 0.99 [2350 0.258 [2913 3.31 [6342 1.66 [6298 2.35 [31 51] [31 100]] [31 45]] [15 68]] [31 100]] [31 90]]] [1710 5.15 [30 81] [30 54]]] [7172 0.441 [6578 0.686 [2739 1.51 [2259 15.2 [4154 1.79 [5110 8.48 [4517 1.18 [728 7.17 [4 57] [31 78]] [26 83]] [7665 19.7 [4 75] [4 81]]] [1783 2.05 [4 24] [25 36]]] [5590 1.24 [7525 1.58 [3052 2.3 [2081 0.249 [23 13.8 [4718 4.17 [1011 13.2 [7381 5.65 [5602 1.01 [6982 27.3 [2380 2.22 [3116 1.28 [4414 6.25 [2913 11.8 [31 64] [30 50]] [31 100]] [31 100]] [31 100]] [4 83]] [31 100]] [4 50]] [6 62]] [5 36]] [9 30]] [21 28]] [30 100]] [30 100]] [30 100]]] [7255 1.66 [4 100] [4 55]]] [31 100]] [31 100]]] [3698 1.87 [11 85] [11 50]]] [1403 1.92 [15 95] [15 100]]] [11 95]] [11 100]]] [896 0.0932 [2471 0.42 [3454 0.121 [6394 0.528 [2825 3.42 [6178 0.395 [596 0.223 [3125 0.0998 [6859 1.4 [3990 1.18 [4769 0.346 [6524 0.646 [5809 3.28 [5122 0.211 [338 7.18 [731 0.414 [4322 1.06 [7255 8.62 [5211 0.785 [4114 14.7 [6106 0.706 [4342 1.19 [4338 1.05 [3586 0.37 [4414 37.5 [3803 0.241 [248 3.31 [968 2.93 [1888 1.85 [5462 3.29 [4168 1.09 [5316 4.1 [2259 4.91 [2232 4.85 [5065 1.13 [7412 0.615 [3909 0.618 [6921 2.11 [3998 1.29 [2461 0.511 [6031 7.2 [1913 0.0854 [2828 1.79 [976 0.542 [4101 3.07 [3299 0.415 [2474 1.64 [3691 2.01 [5106 3.61 [791 7.23 [2678 0.502 [7548 3.38 [7512 5.34 [7623 0.43 [3972 4.51 [1226 2.76 [4092 0.57 [2488 4.91 [2802 4.19 [978 0.891 [1917 16.8 [2847 1.06 [4555 2.04 [939 27.5 [5073 3.03 [2081 52.2 [7009 8.58 [5170 0.317 [14 8] [33 85]] [5 31]] [23 43]] [28 72]] [27 48]] [23 96]] [22 87]] [23 83]] [435 4.73 [981 0.521 [1049 3.07 [1463 4.5 [6539 1.6 [2913 25.4 [6640 21 [663 1.46 [23 22] [17 26]] [23 100]] [25 77]] [2 100]] [5 63]] [2 80]] [23 100]] [23 54]]] [29 40]] [13 77]] [35 76]] [23 89]] [37 48]] [2763 2.56 [5851 2.76 [3095 14.2 [1263 4.31 [6276 1.17 [15 35] [25 37]] [5 40]] [3 28]] [35 30]] [33 37]]] [5480 6.54 [5599 3.28 [100 0.713 [6977 13.1 [5165 1.11 [7685 7.47 [7009 4 [7269 3.81 [5566 2.2 [7522 0.615 [7497 3.36 [1391 1.7 [2929 5.87 [3616 20.2 [5904 4.51 [14 21] [19 66]] [22 90]] [5 56]] [22 57]] [22 70]] [2225 3.7 [23 45] [20 33]]] [14 100]] [5 88]] [5 40]] [7512 46.1 [20 90] [20 100]]] [14 95]] [6199 22.2 [2628 5.41 [14 73] [5 42]] [14 91]]] [100 15.6 [22 35] [22 91]]] [22 78]] [144 4 [2752 20.4 [18 77] [18 38]] [18 83]]]] [14 87]] [16 68]] [6544 1.21 [978 3.36 [312 1.03 [7512 2.47 [7441 1.71 [5693 0.147 [7411 3.73 [6230 2.02 [3141 0.643 [3972 9.33 [3452 0.685 [7657 8.47 [5732 0.506 [429 44.1 [2199 37 [3292 4.36 [5034 16.7 [7465 2.51 [28 14] [15 83]] [5034 20.1 [14 83] [14 100]]] [37 82]] [23 73]] [1167 2.56 [5911 12.9 [3262 3.4 [939 1.46 [11 16] [11 40]] [37 96]] [5912 2.8 [23 44] [11 91]]] [29 100]]] [28 72]] [12 89]] [3860 3.33 [1239 0.685 [11 72] [11 100]] [11 100]]] [37 67]] [35 100]] [5034 8.95 [30 30] [5034 20.5 [14 90] [14 100]]]] [7461 3.07 [6184 21.7 [1980 15.6 [7085 1.55 [15 74] [15 83]] [5 28]] [15 91]] [15 100]]] [2826 0.775 [887 0.587 [11 22] [11 82]] [14 66]]] [1227 1.42 [742 2.02 [904 4.42 [887 2.65 [1986 2.15 [11 48] [11 71]] [11 100]] [11 100]] [11 100]] [11 100]]] [14 35]] [11 31]] [7453 9.31 [2826 2.02 [7241 5.49 [1429 37.2 [3905 5.29 [328 1.66 [584 5.88 [435 9.65 [2029 4.95 [1068 1.61 [23 39] [2 45]] [23 77]] [23 85]] [23 100]] [23 92]] [4 28]] [38 17]] [16 42]] [19 20]] [23 100]]] [2091 4.27 [14 82] [14 100]]]] [28 100]] [3498 1.31 [1924 17.2 [5650 3.88 [2753 7.28 [2939 2.18 [37 81] [5 50]] [37 50]] [37 100]] [37 71]] [37 100]]] [15 100]] [695 6.99 [37 56] [3783 4.13 [37 80] [3262 5.15 [37 86] [37 100]]]]] [37 65]] [27 100]] [695 0.924 [28 86] [28 100]]] [4149 3.69 [1445 0.447 [6920 2.53 [4114 2.9 [5368 0.637 [1955 13.2 [791 14.7 [2521 4.2 [4424 5.09 [1089 3.47 [2470 5.89 [23 37] [15 57]] [2093 2.15 [23 23] [4 50]]] [28 77]] [4 27]] [11 41]] [29 45]] [11 42]] [23 85]] [29 41]] [203 6.37 [31 14] [31 93]]] [11 70]]] [6032 3.68 [22 93] [11 18]]] [448 1.18 [1162 0.751 [7634 1.15 [2143 3.55 [27 96] [27 90]] [27 100]] [27 100]] [27 100]]] [4071 12 [3292 1.29 [2081 1.92 [1239 3.5 [37 62] [37 88]] [6 36]] [37 100]] [37 57]]] [23 86]] [15 100]] [15 100]] [3130 2.79 [1400 1.12 [3905 2.99 [15 98] [15 100]] [15 100]] [15 100]]] [5732 1.8 [1445 2.02 [5647 14.4 [939 7.71 [7522 1.96 [2200 3.97 [2214 4.27 [2793 13.5 [328 15.8 [392 1.82 [2072 4.58 [7343 0.707 [3033 4.59 [2062 6.84 [2764 17.2 [1078 86.9 [23 30] [27 27]] [23 72]] [23 50]] [1899 6.37 [23 100] [23 75]]] [2 33]] [23 40]] [28 30]] [28 51]] [23 56]] [36 60]] [26 27]] [22 36]] [11 15]] [2 30]] [23 58]] [28 94]]] [2008 1.33 [7411 4.9 [3806 0.307 [6809 3.26 [1634 0.855 [7548 1.43 [5439 3.25 [2012 0.237 [6031 10.9 [660 4.85 [6145 1.24 [6199 7.31 [2103 1.79 [978 0.107 [1713 1.55 [1400 6.9 [3262 3.16 [756 1.94 [3905 4.3 [7101 2.58 [5753 4.44 [7287 7.08 [4997 3.7 [5891 0.459 [791 16.5 [6462 1.49 [6437 1.85 [939 11.1 [7734 6.34 [6310 1.38 [6604 2.49 [178 4.17 [2846 3.16 [1238 0.381 [2826 3.07 [30 7] [14 73]] [10 93]] [18 22]] [24 39]] [30 100]] [14 38]] [18 58]] [10 42]] [14 87]] [25 100]] [7512 6.23 [890 4.07 [5883 1.33 [4279 14.9 [5333 2.37 [1980 8.98 [7255 4.05 [6078 4.31 [1058 0.3 [36 14] [11 41]] [4 42]] [12 57]] [3273 0.583 [11 24] [11 100]]] [11 100]] [1239 9.35 [15 27] [3 63]]] [11 70]] [36 100]] [2846 3.11 [14 24] [32 58]]]] [5180 7.73 [4231 1.02 [7065 2.79 [1658 5.66 [2939 0.417 [2091 2.48 [364 0.846 [1664 0.269 [14 43] [1783 1.66 [17 66] [32 42]]] [14 50]] [32 33]] [17 60]] [32 46]] [17 50]] [14 66]] [17 50]]] [7 100]] [11 94]] [567 1.93 [328 19.7 [7441 7.07 [6230 3.62 [5412 4.39 [3929 4.12 [4398 3.54 [28 19] [30 83]] [5 37]] [5968 7.62 [7428 4.98 [4533 2.46 [404 2.92 [1429 38.9 [28 73] [28 60]] [28 81]] [11 28]] [28 54]] [28 62]]] [30 57]] [28 76]] [29 37]] [1899 10.7 [5413 2.62 [29 25] [29 100]] [29 54]]]] [22 41]] [14 39]] [30 78]] [3069 0.752 [37 100] [16 50]]] [221 3.71 [6544 4 [1429 17.4 [4197 5.75 [811 3.7 [15 58] [10 70]] [15 100]] [12 35]] [14 82]] [1219 2.49 [10 95] [10 100]]]] [6768 6.67 [31 77] [31 100]]] [4997 0.213 [760 6.33 [7421 2.79 [7354 1.79 [4253 3.03 [5290 0.208 [728 1.73 [5034 2.62 [6791 14.6 [5480 9.84 [23 34] [18 66]] [2 62]] [14 94]] [17 44]] [23 66]] [2 70]] [3515 1.77 [23 26.5 [18 31] [19 60]] [19 75]]] [16 72]] [23 100]] [7 100]]] [10 84]] [2466 0.296 [939 3.44 [5267 1.93 [14 38] [10 75]] [26 35]] [17 23]]] [10 100]] [2803 4.13 [4197 2.44 [3622 4.5 [15 29] [29 100]] [7464 2.44 [15 50] [15 100]]] [15 100]]] [1436 2.91 [791 20.8 [2831 4.13 [7329 6.17 [22 79] [28 50]] [22 100]] [22 100]] [11 40]]] [10 100]] [6026 2.89 [811 1.1 [10 40] [939 1.23 [10 84] [10 100]]] [10 100]]] [2320 4.98 [1078 16.4 [5776 1.75 [14 77] [14 100]] [2259 29.7 [14 54] [32 83]]] [32 100]]] [13 100]] [4663 2.65 [2939 10.8 [32 92] [32 100]] [32 100]]] [10 100]] [15 50]] [11 95]]] [2846 17.9 [6403 2.3 [7704 2.33 [32 46] [32 100]] [32 100]] [14 84]]] [4801 1.05 [4885 2.62 [3554 2.16 [6184 4.74 [2476 3.7 [4894 10.5 [15 55] [32 100]] [15 93]] [15 100]] [32 80]] [32 100]] [32 100]]] [5769 3.65 [4011 1.06 [221 4.8 [3032 4.37 [3103 1.64 [7456 18.2 [756 6.28 [112 2.08 [7082 6.41 [4231 1.67 [4533 8.76 [4764 0.678 [7449 16.8 [7210 0.715 [7722 1.29 [695 12.2 [3008 34.7 [7411 3.64 [28 24] [35 66]] [35 89]] [28 83]] [14 69]] [3989 3.93 [5509 5.03 [7169 2.02 [14 14] [4 20]] [13 50]] [25 50]]] [23 36]] [35 69]] [35 81]] [10 100]] [28 85]] [5007 2.74 [4154 2.56 [28 33] [28 50]] [28 100]]] [3 60]] [5 84]] [35 100]] [35 87]] [28 47]] [28 79]] [4 62]]] [985 1.15 [4213 1.32 [5703 1.69 [7512 1.82 [695 2.77 [774 2.87 [5967 6.85 [6397 4.13 [7354 6.58 [5510 3.14 [738 11.7 [4159 7.23 [5776 1.99 [5034 2.16 [221 13.5 [4478 2.16 [5 9] [8 33]] [12 30]] [14 77]] [7 25]] [14 100]] [18 57]] [14 83]] [4533 6.52 [18 29] [36 85]]] [14 78]] [13 100]] [27 63]] [5732 5.06 [1899 7 [1078 25.3 [7185 12.9 [14 41] [14 72]] [28 42]] [14 42]] [14 90]]] [2628 5.53 [3698 1.72 [5564 1.56 [3027 15.8 [7722 1.56 [4170 4.07 [1899 8.55 [828 3.94 [2793 4.21 [2259 13.6 [4611 1.55 [14 39] [7210 5.39 [14 86] [14 62]]] [14 26]] [14 85]] [32 62]] [5753 6.14 [36 22] [36 66]]] [32 100]] [7324 3.39 [5412 2.12 [6199 5.56 [7533 2.73 [7210 10.7 [14 70] [32 57]] [14 100]] [14 93]] [3008 2.16 [7428 0.639 [14 68] [32 45]] [14 66]]] [5 38]]] [32 62]] [4574 1.94 [7548 1.12 [14 97] [14 100]] [14 87]]] [32 90]] [5 23]]] [13 100]] [12 100]] [695 4.95 [1025 18 [5851 1.24 [4 13] [2 34]] [4 77]] [14 29]]]] [7567 2.67 [4154 11.1 [1684 1.77 [899 2.62 [6147 1.67 [6340 1.03 [6401 2.09 [5034 22.6 [2062 0.0935 [7381 2.7 [5187 0.593 [7451 5.02 [1 2.16 [4851 1.59 [3905 2.43 [2259 6.72 [1783 22.2 [221 6.96 [5652 1.32 [28 74] [11 33]] [6300 1.83 [28 97] [28 100]]] [4 33]] [1630 1.33 [1951 0.0429 [2393 1.42 [2039 5.85 [4517 2.76 [28 35] [13 36]] [35 37]] [28 91]] [19 44]] [28 100]]] [15 54]] [394 5.15 [28 93] [28 100]]] [11 30]] [28 30]] [11 33]] [4 57]] [429 25.8 [33 50] [17 33]]] [4057 8.26 [2259 7.25 [28 84] [32 94]] [32 100]]] [32 76]] [1783 1.37 [5381 4.95 [28 100] [28 90]] [28 100]]] [11 100]] [32 100]] [276 41.1 [11 88] [4 60]]] [5766 1.28 [2793 4.49 [968 4.26 [2081 4.1 [11 25] [29 83]] [1410 1.85 [3938 1.3 [2259 5.78 [28 64] [6294 2.39 [6550 3.04 [5967 2.01 [1888 2.16 [5753 4.62 [7343 8.91 [4168 2.18 [7495 4.07 [32 79] [32 66]] [32 100]] [32 100]] [28 100]] [32 100]] [28 70]] [32 100]] [29 50]]] [32 100]] [15 100]]] [28 88]] [28 100]]] [32 100]]] [233 0.471 [7516 2.64 [3480 0.754 [6809 2.15 [5637 1.47 [5561 3.62 [5969 6.36 [3751 2.71 [1429 4.32 [4682 0.795 [4369 12.3 [6080 2.82 [5617 5.46 [7455 2.86 [5360 2.09 [6177 0.695 [2263 3.7 [424 1.73 [430 13.6 [435 15.3 [248 26.8 [7665 37 [4665 3.7 [7623 5.66 [7461 3.5 [1068 1.44 [26 25] [2 33]] [15 75]] [15 41]] [1 57]] [33 55]] [429 30.7 [1400 41.8 [392 18.7 [6472 1.64 [6131 9.71 [5695 1.95 [1213 1.65 [2752 80.9 [1079 3.36 [4611 2.49 [5412 2.28 [2470 28.5 [2892 16.2 [408 4.13 [26 41] [26 90]] [26 50]] [25 45]] [33 55]] [26 100]] [26 90]] [1 42]] [26 87]] [26 93]] [26 91]] [26 94]] [25 77]] [25 54]] [29 24]]] [26 89]] [26 76]] [26 100]] [33 42]] [25 81]] [5692 10.2 [5701 5.72 [33 66] [33 100]] [33 100]]] [15 100]] [2 36]] [15 100]] [15 54]] [33 100]] [408 0.395 [532 0.726 [5110 6.53 [6544 2.02 [1576 2.06 [4768 1.81 [7491 2.63 [5205 6.32 [6844 4.63 [1783 32.4 [1400 4.58 [5732 7.19 [2760 3.24 [6471 2.66 [5480 5 [5170 3.63 [4061 1.9 [362 8.62 [7472 6.49 [2799 3.65 [6091 7.68 [980 1.6 [851 6.27 [719 10.1 [2229 5.48 [4159 4.18 [5941 0.579 [2902 3.15 [2752 69.5 [4895 9.64 [1094 0.606 [2259 64.4 [29 8] [18 77]] [11 50]] [25 35]] [2 29]] [1 62]] [19 33]] [29 61]] [11 33]] [14 87]] [14 63]] [26 71]] [15 57]] [26 71]] [38 89]] [26 66]] [30 36]] [33 41]] [18 53]] [6471 8.7 [26 53] [6471 15.9 [26 100] [26 75]]]] [19 50]] [15 78]] [1404 3.7 [1429 65.5 [15 72] [18 37]] [15 100]]] [33 20]] [33 88]] [26 93]] [29 50]] [328 2.42 [4 27] [15 25]]] [2 50]] [14 100]] [15 63]] [29 75]] [26 64]]] [15 100]] [29 42]] [33 70]] [2241 0.136 [26 62] [26 33]]] [32 85]] [4768 3.02 [826 1.41 [15 84] [15 90]] [15 100]]] [1429 20 [26 65] [7512 13.1 [16 50] [18 23]]]] [33 95]]] [11 100]] [5034 2.16 [4279 8.07 [1400 7.41 [5007 3.86 [178 7.25 [4533 6.76 [7665 27.1 [2178 15.8 [4669 20.9 [4419 4.26 [4424 28 [2759 5.99 [695 4.85 [7623 3.65 [15 16] [12 28]] [13 35]] [18 27]] [23 18]] [15 22]] [22 28]] [23 39]] [14 61]] [35 53]] [25 25]] [4416 2.89 [15 87] [15 100]]] [15 95]] [4179 3.3 [2081 14.2 [7623 4.42 [15 46] [15 87]] [28 19]] [4353 10 [6015 3.14 [7116 6.85 [15 95] [15 100]] [15 100]] [15 72]]]] [32 40]]] [4398 4.44 [3458 0.843 [3606 1.25 [4424 2.04 [15 93] [15 100]] [15 100]] [15 100]] [15 85]]] [2225 12.2 [5412 0.392 [2518 6.49 [2199 3.24 [1981 0.308 [1812 0.766 [5692 0.914 [4518 0.445 [7292 4.19 [6015 13.9 [2108 3.7 [145 6.17 [2259 11.5 [23 22] [3643 9.31 [7354 2.46 [1025 4.67 [2259 52.3 [24 58] [19 25]] [24 91]] [18 64]] [24 64]]] [25 45]] [23 55]] [7 42]] [4 100]] [3654 3.55 [24 96] [24 100]]] [4348 0.632 [24 30] [33 90]]] [33 100]] [33 100]] [1025 11.7 [23 53] [24 42]]] [24 83]] [978 10.6 [1025 0.481 [108 0.917 [33 51] [33 100]] [24 50]] [23 50]]] [23 86]]] [2341 6.1 [6333 6.17 [24 87] [24 100]] [6520 7.04 [24 97] [24 100]]]] [4171 0.471 [3907 0.821 [2929 1.46 [435 1.09 [4799 11.5 [32 85] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]]] [4136 12.6 [4279 3.53 [1899 25.7 [1436 0.544 [1899 1.32 [3619 0.938 [1986 2.33 [4139 0.75 [1062 6.26 [27 44] [27 78]] [27 100]] [23 83]] [11 42]] [27 75]] [11 83]] [25 17]] [23 29]] [11 62]]] [1913 1.22 [6350 0.816 [2847 0.453 [5480 0.202 [996 1.03 [5120 1.79 [4312 5.34 [6604 0.978 [6675 0.938 [5883 3.43 [7674 1.25 [6230 1.06 [2004 1.3 [5231 0.223 [5234 0.722 [567 1.99 [4373 10.1 [2384 1.62 [6970 0.404 [7737 1.11 [1995 0.458 [2746 4.26 [2763 9.49 [850 3.55 [1429 12.6 [429 23.6 [2759 2.2 [6294 4.93 [1899 7.68 [30 27] [22 52]] [22 100]] [8 66]] [7409 8 [2470 7.6 [10 36] [11 88]] [10 54]]] [3071 1.61 [5034 1.47 [7210 17.4 [248 2.67 [23 16.9 [22 22] [30 58]] [26 40]] [30 57]] [4984 4.27 [30 92] [30 100]]] [30 100]]] [35 85]] [22 43]] [8 36]] [6352 4.08 [5110 1.56 [2902 3.07 [11 20] [30 66]] [4279 1.53 [11 74] [22 100]]] [11 100]]] [1995 6.33 [10 76] [10 81]]] [28 14]] [10 100]] [10 100]] [791 17.5 [11 33] [11 76]]] [11 100]] [11 100]] [6621 1.36 [2004 12.5 [23 82] [23 99]] [23 77]]] [1239 8.69 [30 68] [19 20]]] [10 100]] [5192 1.57 [429 10.1 [23 42] [1068 8.1 [7442 0.565 [2259 5.9 [11 100] [11 50]] [11 100]] [11 81]]] [11 100]]] [30 100]] [2143 5.08 [30 88] [30 88]]] [429 39.3 [30 84] [30 36]]] [22 100]] [384 1.85 [2004 0.57 [23 60] [23 100]] [23 100]]] [1764 2.4 [996 4.46 [2845 0.469 [7491 16.4 [5486 0.924 [2004 10.8 [550 6.16 [5731 1.73 [7512 2.05 [5228 1.01 [7441 3.02 [1171 2.22 [5753 7.3 [434 2.57 [6727 1.66 [7210 8.24 [1906 0.214 [1980 30.5 [2199 0.898 [5482 2.09 [22 77] [22 100]] [22 70]] [11 33]] [22 88]] [11 44]] [11 30]] [12 33]] [791 13.5 [22 83] [22 100]]] [22 50]] [22 58]] [22 100]] [1079 1.31 [1219 5.13 [2763 2.68 [1078 37.6 [22 96] [22 80]] [22 100]] [22 100]] [22 100]]] [11 100]] [11 58]] [23 55]] [23 100]] [11 54]] [23 100]] [23 90]] [22 97]]] [2259 22.8 [22 100] [22 90]]] [10 100]] [4279 2.92 [11 60] [30 40]]]] [4283 2.56 [7428 7.76 [414 1.21 [6342 28.4 [7170 2.24 [3310 2.67 [5732 5.73 [5066 1.61 [4520 1.13 [392 4.74 [5270 9.74 [248 2.04 [4451 11.9 [5316 6.85 [788 1.95 [4718 0.53 [1648 0.602 [4522 3.07 [6294 4.95 [705 1.75 [3111 0.935 [429 5.41 [4426 16.1 [12 44] [12 84]] [978 39.6 [957 6.42 [791 24.6 [12 21] [5812 8.7 [15 32] [12 66]]] [4 20]] [8 92]]] [791 11.2 [15 83] [15 100]]] [12 100]] [2752 26.5 [4154 5.07 [22 30] [11 54]] [12 81]]] [11 100]] [14 71]] [12 77]] [18 65]] [32 95]] [12 100]] [15 43]] [31 45]] [1078 10.1 [429 10.8 [2268 16.8 [26 30] [14 60]] [14 50]] [19 41]]] [11 100]] [15 100]] [1400 4.5 [15 91] [15 100]]] [3308 13.1 [29 66] [23 46]]] [15 100]] [12 95]] [16 22]] [12 86]] [15 100]]] [3693 1.13 [1119 1.62 [1552 1.42 [4312 5.19 [957 1.31 [7542 2.33 [4057 1.68 [32 79] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]] [32 100]]] [423 1.52 [1400 4.9 [6544 2.41 [2913 2.83 [1740 1.04 [724 1.51 [1754 1.21 [1838 1.31 [2671 4.93 [3057 2.31 [3136 6.84 [5462 7.45 [2749 1.42 [7548 1.66 [3724 3.41 [7334 1.11 [1580 2.83 [6239 0.426 [6581 3.77 [4859 3.75 [663 4.41 [4338 3.22 [7324 6.16 [3667 2.37 [3995 8.71 [560 2.29 [228 2.07 [2004 2.99 [6960 3.35 [1913 1.18 [328 2.71 [178 3 [7665 16.1 [4001 4.07 [2470 6.33 [7253 1.34 [2760 12.8 [2939 2.77 [7354 2.99 [1783 8.21 [7512 7.3 [4870 4.3 [1011 0.603 [1201 1.78 [7449 2.7 [3905 7.56 [5 20] [17 44]] [4 50]] [17 62]] [17 69]] [17 52]] [5 45]] [17 35]] [788 8.95 [18 37] [16 37]]] [19 33]] [2752 29.2 [17 54] [17 53]]] [17 85]] [4 100]] [5 87]] [1078 8.47 [7 29] [7 50]]] [4154 4.98 [5 41] [5 55]]] [5412 2.73 [7354 3.65 [7210 6.04 [733 1.98 [7 16] [7 36]] [17 42]] [7737 1.53 [7 23] [18 50]]] [4 28]]] [26 83]] [31 62]] [23 60]] [4 78]] [18 89]] [5 87]] [35 41]] [5 84]] [24 30]] [929 7 [1621 2.18 [7693 0.564 [2526 3.26 [5034 2.13 [2707 7.14 [2813 3.14 [6240 3.98 [6131 7.76 [5716 11.1 [5789 3.14 [5389 2.17 [6040 2.79 [4851 2.11 [7446 0.669 [1011 0.797 [5 25] [18 42]] [17 63]] [14 33]] [17 62]] [16 50]] [17 70]] [16 57]] [5 44]] [19 72]] [18 46]] [16 58]] [14 100]] [26 33]] [18 37]] [1078 4.89 [10 35] [17 62]]] [17 48]]] [18 80]] [3798 1.7 [6581 17.3 [17 43] [5 41]] [17 66]]] [1888 1.69 [17 47] [14 71]]] [17 62]] [14 77]] [5 94]] [14 100]] [26 86]] [5 48]] [5 100]] [5 89]] [18 83]] [19 60]] [4895 4 [38 65] [38 66]]] [134 5.95 [725 5.66 [2628 7.99 [4154 1.16 [17 54] [5 40]] [19 43]] [5 35]] [17 59]]] [134 10.7 [1980 6.9 [19 53] [19 60]] [19 40]]] [6241 2.73 [5 55] [5 100]]] [6396 1.46 [14 77] [6977 2.76 [5799 0.873 [6599 7.36 [5509 6.62 [130 4.37 [31 8.02 [728 6.66 [17 62] [17 87]] [19 50]] [17 85]] [16 37]] [19 42]] [17 92]] [7588 5.69 [17 100] [17 75]]]]] [5574 0.945 [134 6.85 [392 1.24 [408 5.62 [429 10.8 [5007 15.8 [26 72] [26 50]] [4 67]] [26 90]] [26 72]] [26 51]] [4 62]]] [178 0.864 [26 83] [26 100]]]] [7185 1.47 [1911 3.96 [5878 7.35 [431 2.39 [2766 1.29 [2929 2.06 [4851 3.7 [4198 1.66 [422 6.49 [26 56] [26 70]] [25 100]] [26 66]] [25 95]] [26 100]] [26 94]] [26 100]] [25 80]] [26 90]]] [5034 7.59 [5122 2.84 [30 88] [5163 0.782 [1062 1.05 [2259 24.2 [429 2.18 [30 89] [30 93]] [30 100]] [30 100]] [30 100]]] [5110 9.45 [30 66] [30 100]]]] [3884 0.609 [221 0.478 [791 26.8 [7411 2.89 [5412 8.09 [2826 4.35 [4154 12.4 [14 19] [15 30]] [14 54]] [15 86]] [3606 2.18 [4369 2.07 [15 98] [15 100]] [15 100]]] [2760 5.69 [3608 2.79 [15 97] [15 100]] [828 2.7 [15 88] [15 100]]]] [28 29]] [241 1.26 [328 12.9 [15 100] [15 88]] [15 100]]]] [5462 0.3 [5110 2.42 [5228 0.231 [2826 1.73 [5692 2.36 [3706 0.618 [5215 4.95 [7305 1.07 [6031 3.37 [5420 0.325 [5809 3.88 [6566 4.74 [201 1.48 [3459 2.35 [5211 2.2 [7335 3.46 [252 5.28 [250 3.52 [3698 7.82 [2831 3.4 [5844 1.85 [2752 51.4 [6997 0.341 [3237 0.996 [6544 7.94 [7665 3.39 [2474 3.4 [6528 2.3 [6063 0.962 [5647 37.7 [2225 7.49 [6524 8.7 [5637 1.55 [28 77] [28 36]] [730 1.71 [6532 4.77 [6199 6.17 [4235 6.88 [2939 34 [504 23.8 [5851 15.2 [23 46.6 [2939 1.79 [7016 6.17 [4611 15 [1084 1.38 [1925 11.8 [1078 10.8 [1888 6.71 [28 55] [36 50]] [1429 22.4 [28 54] [28 85]]] [28 100]] [28 81]] [15 33]] [22 83]] [28 42]] [22 47]] [22 33]] [22 50]] [22 93]] [25 40]] [28 75]] [11 100]] [28 96]]] [1 40]] [22 57]] [22 100]] [5170 3.94 [2143 3.23 [15 36] [15 63]] [33 85]]] [15 100]] [328 18.4 [1 16] [22 38]]] [14 50]] [11 100]] [2752 17.2 [22 72] [28 90]]] [791 6.41 [22 46] [6529 34.3 [28 43] [22 100]]]] [2752 27.1 [22 83] [22 100]]] [22 100]] [28 100]] [1 59]] [1 100]] [2259 8.74 [1 86] [1 62]]] [7453 2.73 [22 76] [22 87]]] [15 100]] [25 45]] [11 100]] [15 73]] [791 10.6 [28 82] [28 95]]] [6184 2.51 [144 2.04 [660 2.33 [7620 2.99 [22 98] [22 100]] [22 100]] [22 100]] [22 100]]] [1899 0.603 [5211 8.96 [22 42] [11 100]] [11 80]]] [22 100]] [1 100]] [1626 1.3 [3333 3.55 [4398 2.4 [2904 0.364 [7016 6.79 [5412 0.266 [4253 3.23 [7583 1.56 [7139 2.37 [7176 1.24 [7449 21.8 [1888 0.612 [28 66] [17 54]] [28 54]] [22 76]] [11 25]] [2752 20.9 [1 66] [1 50]]] [673 4.96 [25 57] [25 90]]] [5668 8.1 [5194 0.599 [7512 0.986 [221 6.98 [28 84] [1078 7.85 [28 85] [25 44]]] [28 50]] [695 0.64 [2393 3.47 [28 100] [28 80]] [28 100]]] [28 66]]] [22 100]] [28 97]] [15 46]] [1 72]] [22 88]]] [602 3.37 [1888 3.72 [7 63] [14 50]] [14 36]]] [22 100]] [859 2.59 [2764 1.06 [7338 1.52 [1400 1.36 [6791 3.2 [1391 5.48 [2993 0.808 [3424 1.04 [15 26] [28 44]] [22 37]] [22 72]] [33 62]] [15 96]] [22 100]] [22 57]] [2199 8.81 [2753 1.83 [1913 2.91 [22 82] [22 100]] [22 100]] [22 100]]]] [7453 7.25 [36 0.684 [377 0.3 [7512 9.57 [6034 1.45 [7329 0.944 [6732 3.17 [4517 0.385 [6529 10 [6997 3.92 [5851 6.55 [4530 0.931 [2764 2 [1025 1.15 [7081 2.16 [429 4.69 [28 28] [5753 2.42 [28 85] [28 100]]] [13 37]] [880 0.797 [28 100] [28 87]]] [11 50]] [28 37]] [28 100]] [28 75]] [28 40]] [15 33]] [28 97]] [28 71]] [28 66]] [7 25]] [28 88]] [22 100]] [11 60]]]] [5007 0.107 [2259 8.16 [438 4.72 [1253 0.869 [5322 0.748 [1114 7.27 [6112 1.1 [29 64] [29 100]] [29 100]] [15 33]] [29 62]] [23 52]] [4279 8.93 [29 38] [10 44]]] [2802 0.212 [29 65] [1456 0.206 [29 100] [29 92]]]]] [312 1.72 [5034 2.89 [3612 1.8 [4414 4.44 [3587 0.818 [1783 15.5 [1078 33.7 [5776 5.39 [1429 103 [834 0.162 [3308 1.73 [1769 7.2 [1539 2.35 [23 46.7 [115 1.66 [7149 2.86 [5227 4.35 [2754 0.283 [6936 5.06 [3468 13 [3084 0.69 [3213 1.98 [1980 6.38 [3468 7.27 [37 99] [37 92]] [3905 1.79 [5662 1.79 [37 95] [37 100]] [37 100]]] [37 100]] [37 100]] [37 83]] [37 83]] [37 100]] [37 88]] [37 66]] [37 100]] [37 84]] [37 88]] [37 86]] [37 60]] [37 100]] [37 87]] [37 66]] [37 59]] [37 70]] [37 100]] [4414 8.58 [37 33] [1078 7.15 [37 89] [37 75]]]] [37 100]] [14 57]] [3319 0.318 [6347 0.322 [37 74] [37 35]] [3262 11.4 [1253 0.746 [313 2.27 [37 54] [37 66]] [16 33]] [16 57]]]]] [2763 0.276 [6922 1.18 [2846 3.18 [7722 3.08 [1 4.39 [3051 0.904 [4344 2.22 [6896 1.11 [4495 1.99 [1078 1.15 [1888 11.1 [5462 5.62 [6333 3.18 [4279 7.11 [6266 4.07 [791 5.41 [112 4.95 [6853 35.8 [3636 5.75 [24 33] [24 85]] [28 40]] [36 60]] [28 30]] [24 100]] [4154 18.2 [24 78] [5792 4.07 [24 85] [24 100]]]] [4396 13.4 [28 71] [28 100]]] [28 50]] [791 1.14 [36 42] [36 72]]] [4907 3.4 [4519 4.75 [1899 12.6 [6776 0.697 [5211 3.39 [7419 8.31 [6857 0.326 [7169 7.5 [1911 0.89 [28 55] [28 42]] [28 90]] [631 3.23 [28 40] [3338 6.76 [6641 1.69 [5776 3.42 [7210 0.457 [4011 0.578 [710 2.03 [28 94] [28 88]] [28 100]] [28 100]] [28 83]] [28 71]] [28 50]]]] [28 50]] [7210 2.51 [30 48] [22 63]]] [28 100]] [434 5.55 [28 43] [36 50]]] [24 100]] [36 100]]] [24 100]] [22 100]] [24 100]] [30 100]] [36 61]] [684 0.792 [5725 1.9 [36 79] [31 100]] [31 100]]] [22 68]] [4519 2.73 [36 56] [24 100]]] [631 1.03 [36 46] [7665 0.756 [957 0.22 [6529 3.89 [1429 76.5 [2421 0.418 [2199 0.813 [5967 0.693 [6853 51.9 [28 100] [28 87]] [28 100]] [28 100]] [28 100]] [28 71]] [28 57]] [28 100]] [28 50]]]]] [3831 3.23 [6347 0.399 [4015 0.86 [5412 0.608 [3691 3.23 [2259 4.48 [7185 0.778 [1899 10.2 [312 13.9 [3718 0.397 [37 88] [37 100]] [37 69]] [37 81]] [16 42]] [37 42]] [37 100]] [37 66]] [2753 0.396 [708 1.34 [37 90] [37 100]] [37 100]]] [37 100]] [37 94]]] [28 93]] [25 100]] [28 95]] [1980 0.998 [4011 2.07 [7483 2.54 [15 97] [15 100]] [15 100]] [15 100]]] [11 100]] [791 59.7 [4154 33.3 [1078 29 [504 0.548 [7465 2.46 [1429 1.13 [2444 0.785 [2923 2.3 [15 99] [15 100]] [15 100]] [15 100]] [15 100]] [15 100]] [5007 2.61 [15 100] [15 80]]] [15 95]] [15 88]]] [7354 1.32 [134 0.0932 [431 1.24 [4390 1.64 [1429 13.3 [673 4.03 [3637 1.46 [7381 0.471 [1429 5.36 [7512 23.4 [1025 7 [7665 9.69 [7742 4.6 [429 32.1 [25 31] [29 60]] [4 57]] [7449 26.5 [5730 5.05 [6526 4.07 [14 19] [25 100]] [32 100]] [32 57]]] [24 53]] [23 46.6 [2939 5.92 [660 3.4 [494 4.67 [14 25] [14 80]] [14 33]] [4 33]] [14 93]]] [429 5.43 [24 33] [6853 3.9 [5605 5.99 [1025 7.04 [7665 6.85 [1899 3.62 [2 23] [4 44]] [3558 2.06 [2260 2.86 [4799 2.54 [14 62] [32 82]] [14 100]] [5 28]]] [24 33]] [19 37]] [24 60]]]] [1400 2.08 [1239 3.81 [520 0.943 [5 22] [2 71]] [17 69]] [896 6.35 [4 55] [4 76]]]] [3653 1.89 [4519 2.89 [24 90] [24 100]] [24 83]]] [6581 1.21 [6729 0.448 [7054 4.22 [2232 2.36 [6375 0.602 [771 1.85 [5192 8.13 [2628 8.46 [257 4.42 [2011 2.37 [2081 4.06 [17 5.52 [6184 10.8 [26 84] [25 80]] [26 100]] [26 50]] [1 66]] [26 100]] [25 33]] [26 43]] [25 100]] [25 45]] [25 83]] [1 63]] [26 80]] [1888 1.86 [26 100] [26 75]]]] [5430 0.552 [6866 0.544 [2331 0.362 [6022 4.45 [7548 1.24 [3929 3.29 [125 0.812 [328 12.9 [4896 2 [3014 0.818 [5034 0.602 [4349 1.02 [6471 3.29 [1035 2.73 [3520 9.1 [4611 2.96 [6859 0.464 [4101 4.21 [429 24.6 [2518 2.65 [168 7.47 [145 2.55 [5007 1.13 [5969 2.94 [4063 0.688 [7254 4.95 [1611 0.719 [7449 7.32 [5211 1.95 [673 1.98 [4457 0.85 [7734 8.55 [899 0.764 [7598 8.71 [642 0.956 [6581 14.5 [7588 0.216 [6588 4.66 [14 25] [14 63]] [16 44]] [17 61]] [5 66]] [14 62]] [14 83]] [18 62]] [5 46]] [5692 4.89 [18 35] [38 66]]] [4 40]] [7 47]] [14 100]] [1 66]] [17 50]] [2 27]] [19 40]] [5 68]] [18 66]] [24 100]] [5160 1.61 [6353 2.57 [731 2.38 [7512 22.3 [2526 3.13 [4478 5.17 [6040 2.46 [7185 20.1 [17 18] [38 29]] [1671 10.8 [18 44] [18 42]]] [17 100]] [38 54]] [14 33]] [1648 3.74 [17 44] [7665 12.1 [19 53] [38 30]]]] [5 50]] [14 64]]] [5 100]] [5790 2.46 [24 51] [36 100]]] [7210 1.3 [14 57] [14 57]]] [19 100]] [24 100]] [26 90]] [24 80]] [6091 2.01 [899 2.52 [5640 2.35 [14 91] [14 100]] [14 80]] [32 66]]] [7566 2.22 [4806 0.275 [2902 5.34 [178 4.06 [5651 1.27 [5675 0.645 [3794 3.55 [17 50] [1078 8.1 [929 1.36 [978 25.4 [38 62] [19 50]] [17 42]] [862 4.14 [38 61] [16 57]]]] [17 77]] [19 66]] [19 50]] [14 42]] [31 0.377 [429 22.3 [16 33] [7512 16.3 [19 100] [19 28]]] [19 46]]] [2526 1.24 [14 33] [16 44]]]] [1429 47.7 [14 55] [14 92]]] [5565 1.01 [5564 0.732 [6732 7.23 [1783 0.592 [7693 4.2 [5482 4 [14 66] [18 62]] [14 100]] [14 40]] [14 42]] [14 100]] [14 100]]] [2939 0.406 [14 75] [14 83]]] [7210 5.49 [989 3.55 [1542 2.73 [1704 0.96 [14 33] [5692 6.22 [2081 1.5 [17 45] [17 71]] [17 92]]] [5 57]] [17 80]] [5 62]]] [6437 13 [4801 0.87 [2753 0.707 [6134 2.49 [494 1.09 [7214 1.91 [392 0.772 [1630 1.47 [2913 7.04 [6380 2.81 [6732 0.949 [721 8.15 [896 17.5 [14 78] [14 100]] [14 66]] [14 86]] [14 100]] [32 100]] [14 100]] [14 100]] [14 90]] [14 100]] [14 100]] [14 100]] [32 100]] [14 76]]] [7 100]] [32 78]] [896 6.95 [5 88] [5 97]]] [4111 6.51 [913 1.73 [2753 4.16 [5 89] [5 71]] [5 77]] [5 54]]]] [26 100]] [332 2.76 [731 0.728 [791 27.9 [2081 1.75 [673 8 [25 46] [26 100]] [25 100]] [26 77]] [1078 7.86 [26 40] [26 55]]] [26 100]]] [7384 0.135 [4594 1.81 [1704 1.91 [2799 0.51 [7251 0.09 [5430 0.978 [4338 8.24 [6910 3.65 [6557 3.34 [6358 6.9 [7552 0.773 [5480 1.38 [4326 2.88 [485 5.92 [1063 5.88 [6177 4.82 [731 2.88 [663 10.3 [17 16] [1980 0.864 [5 35] [2 62]]] [6333 3.23 [1888 7.12 [3014 4.12 [19 25] [17 61]] [17 64]] [5 100]]] [25 71]] [5 77]] [17 60]] [25 53]] [6831 0.857 [1888 4.98 [7734 2.09 [26 50] [18 40]] [26 45]] [18 57]]] [26 100]] [16 57]] [5 81]] [19 92]] [7529 1.04 [24 89] [24 100]]] [5 89]] [1666 0.494 [5784 1.2 [1089 0.579 [1838 0.514 [6240 0.0932 [6910 0.246 [17 38] [2526 2.24 [19 69] [19 100]]] [19 100]] [19 100]] [17 62]] [722 0.472 [14 60] [17 83]]] [3515 0.354 [2826 4.03 [19 28] [7381 1.23 [19 75] [19 100]]] [19 100]]]] [2799 2.88 [26 100] [26 88]]] [5413 0.359 [6534 1.17 [17 77] [6549 5.64 [6535 3.53 [19 37] [17 70]] [17 30]]] [2570 1.16 [2628 1.64 [6549 1.33 [38 54] [17 72]] [3908 0.64 [16 33] [17 70]]] [19 66]]]] [2 100]] [1059 1.96 [1899 1.71 [7192 0.832 [5729 0.236 [5155 1.73 [2259 7.9 [17 89] [7 60]] [17 66]] [17 100]] [17 100]] [17 69]] [17 41]]]] [2259 5.75 [1463 0.539 [7665 2.21 [7449 3.26 [4927 10.5 [1671 0.157 [1899 5.24 [18 42] [18 55]] [19 58]] [18 75]] [18 75]] [1669 1.31 [7722 8.91 [6074 6.49 [5429 2.92 [931 1.84 [7665 14.4 [4568 0.664 [1500 3.51 [560 0.773 [7381 2.95 [2526 3.33 [6727 2 [4851 3.71 [429 31.8 [1011 5.47 [5 46] [1011 8.56 [19 36] [19 55]]] [6581 2.16 [19 42] [19 66]]] [5 57]] [19 62]] [5 62]] [5 68]] [7722 1.39 [18 80] [18 85]]] [5 75]] [16 60]] [18 32]] [5 50]] [5 76]] [7 100]] [5 57]] [7 100]]] [5873 4.33 [7014 2.16 [4571 0.606 [4805 2.11 [7601 1.36 [6230 7.02 [5 42] [5 100]] [5 66]] [5 100]] [19 57]] [5 92]] [5 100]]] [1783 2.67 [5789 4.26 [978 0.794 [32 32] [3463 0.715 [896 8.7 [1899 3.59 [23 18.4 [18 38] [18 80]] [18 80]] [18 27]] [5 37]]] [6859 3.31 [36 84] [36 100]]] [7735 3.07 [7737 2.8 [4573 3.91 [3905 1.46 [3515 1.21 [2467 1.44 [560 1.71 [18 33] [18 72]] [30 33]] [19 72]] [7 66]] [7 75]] [18 70]] [7 73]]]]]]] [6172 17.6 [2151 1.81 [1429 15 [2048 1.44 [7111 18 [2345 7.93 [7521 7.87 [5034 9.66 [2241 11.5 [7539 20.8 [7210 0.428 [5962 0.867 [7539 0.861 [7665 96 [2081 0.87 [7620 0.975 [20 99] [20 100]] [20 100]] [20 88]] [20 100]] [20 100]] [20 100]] [20 66]] [20 80]] [20 83]] [20 80]] [20 87]] [20 91]] [20 85]] [6453 16.7 [6395 0.0482 [4690 7.7 [20 90] [1980 6.32 [20 100] [20 91]]] [20 80]] [20 55]]] [20 94]] [20 83]]] [6184 0.312 [1078 23.4 [5406 0.565 [1239 4.84 [10 44] [774 1.18 [10 75] [10 100]]] [31 100]] [2752 0.979 [6342 1.71 [1899 5.86 [695 11.8 [10 42] [5467 1.73 [3573 4 [10 65] [10 100]] [10 100]]] [10 100]] [10 100]] [5469 15.7 [4781 0.967 [1980 13.8 [6667 1.18 [3573 0.486 [5753 4.87 [1239 1.94 [10 98] [10 100]] [36 66]] [10 100]] [10 100]] [10 80]] [10 100]] [10 90]]]] [6406 17.6 [1926 0.287 [493 1.28 [859 0.905 [10 96] [10 100]] [10 100]] [10 100]] [10 88]]]] [4809 0.895 [2280 4.06 [2216 1.09 [5278 0.769 [3136 1.17 [4632 2.6 [5622 0.284 [6218 2.75 [1876 3.04 [7428 7.53 [3130 12.1 [1813 27.3 [5637 3.2 [30 100] [30 87]] [30 85]] [30 90]] [30 80]] [30 100]] [30 95]] [30 75]] [30 77]] [30 71]] [30 81]] [30 71]] [30 60]] [30 50]]] [2480 0.179 [2461 2.3 [7258 1.24 [4154 1.91 [5730 0.126 [5662 1.19 [176 8.22 [1429 36.8 [5918 0.246 [4140 0.713 [650 1.16 [6320 2.02 [1429 14.1 [811 3.88 [3779 3.8 [5923 3.05 [6670 4.46 [7009 8.09 [758 1.01 [3156 2.2 [4968 2.12 [1145 1.82 [7512 0.838 [2939 4.57 [2470 1.25 [11 50] [5410 3.86 [2913 1.32 [5824 55.6 [11 100] [11 50]] [11 100]] [11 100]]] [11 30]] [30 18]] [27 70]] [35 66]] [35 73]] [11 100]] [35 22]] [10 85]] [11 96]] [37 100]] [10 66]] [5673 0.967 [2470 3.66 [1104 0.575 [11 14] [11 60]] [11 91]] [30 54]]] [11 17]] [11 100]] [27 94]] [1899 1.01 [3052 2.42 [7149 4.73 [35 22] [35 80]] [30 100]] [25 30]]] [2181 0.93 [5205 1.54 [30 44] [30 100]] [15 58]]] [19 91]] [4781 0.536 [5767 1.35 [2470 0.652 [11 73] [11 100]] [11 100]] [11 100]]] [11 100]] [4781 0.684 [2913 5.03 [112 2.07 [5211 1.51 [11 17] [11 50]] [3 30]] [3 44]] [11 90]]] [11 100]] [27 100]] [11 100]]] [5007 0.133 [6276 0.914 [22 100] [22 85]] [22 100]]] [2939 8.93 [328 19.4 [6946 0.821 [1788 1.24 [1089 10.5 [4120 0.449 [7623 5.95 [2023 0.814 [1078 35.1 [15 26] [2752 16.4 [27 94] [10 50]]] [27 100]] [1139 1.2 [774 22.3 [1161 15.4 [429 13.8 [27 60] [1429 2.83 [2241 0.551 [4533 1.37 [3566 7.32 [2793 4.94 [3530 1.2 [475 1.61 [1400 6.6 [27 100] [10 91]] [27 100]] [27 100]] [27 83]] [27 100]] [27 100]] [27 100]] [7634 8.19 [286 10.6 [27 82] [27 75]] [27 57]]]] [27 100]] [27 100]] [27 100]]] [27 100]] [27 63]] [27 62]] [10 100]] [15 37]] [27 60]]] [7009 0.494 [4677 0.447 [5790 0.526 [3770 0.631 [7032 2.73 [4037 0.158 [4557 0.179 [632 0.359 [7067 0.473 [2752 9.27 [656 0.347 [4087 0.707 [5476 0.362 [5782 1.53 [6853 1.68 [1783 1.35 [2320 1.73 [2259 15.4 [917 1.75 [1400 1.25 [580 9.92 [537 8.2 [5267 3.53 [7381 6.67 [5403 1.27 [2488 2.16 [1899 16.4 [13 59] [13 36]] [6791 1.53 [5814 1.53 [5658 1.29 [2902 2.16 [13 97] [13 100]] [13 100]] [13 100]] [13 100]]] [13 37]] [2 50]] [13 96]] [3 100]] [21 100]] [7590 7.46 [36 41] [36 100]]] [21 53]] [7409 2.93 [36 84] [36 100]]] [4308 1.73 [36 93] [36 100]]] [1429 4.06 [3 44] [13 83]]] [1400 4.76 [4611 1.49 [6607 2.96 [36 76] [28 100]] [36 100]] [36 95]]] [36 100]] [87 0.813 [660 0.949 [3410 2.59 [1587 1.39 [2199 1.53 [4768 2.31 [1521 24.2 [13 100] [13 75]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]]] [36 100]] [13 100]] [3905 0.402 [7373 1.1 [74 1.73 [6416 0.805 [7591 1.21 [4025 1.5 [5782 1.29 [429 40.7 [5668 0.277 [112 2.6 [2434 1.02 [1094 0.381 [7623 6.95 [782 1.01 [6260 8.33 [4568 6.27 [2241 0.321 [6732 23.5 [429 10.6 [36 70] [2793 1.99 [7665 0.876 [15 21] [36 65]] [36 88]]] [13 36]] [11 33]] [13 66]] [13 73]] [13 100]] [27 33]] [11 30]] [36 100]] [36 83]] [36 100]] [13 44]] [36 100]] [36 100]] [36 100]] [13 96]] [13 100]] [36 100]] [36 90]]] [36 100]] [36 100]] [4084 0.179 [7156 1.18 [1747 0.609 [2441 0.55 [36 54] [36 100]] [36 100]] [36 100]] [7068 11.5 [36 100] [36 90]]]] [36 100]] [4369 4.99 [30 1.4 [906 1.22 [3931 6.55 [4154 7.2 [3696 6.24 [7665 34.8 [719 8.75 [5400 2.06 [13 90] [13 100]] [13 100]] [13 80]] [13 100]] [13 60]] [31 36]] [13 54]] [13 100]] [13 100]]] [13 100]] [7722 0.526 [36 88] [36 100]]] [36 100]] [3905 12 [2466 2.93 [5753 10.9 [2299 1.04 [6320 2.41 [1011 2.24 [3768 0.297 [4761 1 [1239 18.8 [2939 5.06 [731 0.952 [168 0.494 [3391 0.824 [7025 0.517 [1520 1.44 [6091 1.34 [6732 5.05 [783 1.09 [7722 4.26 [6199 2.2 [13 96] [13 100]] [5400 4.18 [13 77] [13 100]]] [13 100]] [6416 1.5 [7255 0.829 [13 98] [13 100]] [13 100]]] [13 100]] [13 100]] [13 100]] [7512 15.9 [13 75] [13 100]]] [13 100]] [13 62]] [13 80]] [13 75]] [13 80]] [13 100]] [13 44]] [13 58]] [13 66]] [13 50]] [144 0.942 [36 71] [13 100]]] [36 52]]]] [5345 0.238 [3282 1.89 [1239 27.7 [27 100] [27 88]] [27 100]] [27 100]]] [4530 0.36 [4235 53.6 [15 100] [15 85]] [15 100]]] [241 0.395 [906 1 [5482 0.137 [3480 0.387 [7012 1.01 [959 0.31 [2143 0.116 [3559 2.16 [6416 0.611 [774 3.57 [2703 1.08 [2225 0.449 [258 0.677 [7497 1.23 [7722 1.69 [4414 8.09 [5338 0.517 [3905 0.935 [5473 2.28 [1628 1.36 [5110 2.13 [2505 2.35 [5393 7.12 [2259 26.1 [3492 1.08 [6198 0.724 [6621 19.6 [2793 1.15 [5851 19.2 [628 2.28 [248 3.13 [3323 8.61 [7036 0.303 [811 6.9 [4978 3.39 [3959 1.51 [7343 10.4 [896 15.3 [7335 11.8 [5995 2.26 [5970 7.48 [5007 5.74 [7512 15.3 [145 1.47 [4369 1.69 [2701 46.6 [1429 94.8 [2902 14.4 [29 72] [29 42]] [12 61]] [1078 7.94 [29 36] [29 86]]] [12 46]] [29 92]] [112 4.27 [2701 48.4 [7665 33.4 [13 31] [13 100]] [32 50]] [13 42]]] [29 94]] [29 100]] [29 100]] [12 33]] [32 83]] [12 27]] [5007 0.671 [29 100] [29 88]]] [29 100]] [10 92]] [29 100]] [10 57]] [7512 12.9 [663 1.67 [5995 3.27 [4154 3.11 [29 76] [29 87]] [29 100]] [29 100]] [29 66]]] [32 57]] [29 28]] [15 62]] [13 50]] [29 100]] [15 87]] [1932 5.46 [10 28] [29 80]]] [32 55]] [13 100]] [5267 6.16 [6653 3.96 [5739 1.15 [5692 15.2 [4154 1.13 [1414 2.46 [2260 2.67 [15 89] [15 100]] [15 100]] [2701 10.4 [15 87] [15 100]]] [15 100]] [15 100]] [15 70]] [15 53]]] [29 100]] [13 100]] [6080 0.935 [15 71] [15 100]]] [29 100]] [5412 13.2 [2004 2.73 [6733 1.03 [4398 10.5 [1411 1.39 [791 48.2 [6184 12.1 [2471 1.23 [4369 4.15 [2023 2.38 [2081 4.93 [15 53] [29 54]] [15 75]] [15 85]] [15 100]] [15 100]] [15 36]] [15 100]] [15 100]] [15 100]] [29 92]] [2259 9.43 [32 75] [32 87]]]] [13 61]] [29 82]] [6602 1.98 [15 96] [15 100]]] [3623 0.349 [29 75] [29 100]]] [567 1 [2704 1.2 [5322 10.7 [29 86] [15 37]] [29 97]] [29 100]]] [7680 1.39 [10 63] [10 100]]] [13 100]] [32 90]] [4830 1.92 [7241 0.0764 [6910 1.06 [2143 53.8 [2053 0.317 [4424 13.2 [1888 1.09 [5007 0.0734 [1429 6.41 [1062 1.82 [1112 7.22 [2001 0.548 [29 78] [29 88]] [29 71]] [29 61]] [5110 2.54 [7460 3.6 [429 0.759 [29 64] [6656 4.53 [2131 0.881 [29 92] [29 100]] [29 100]]] [29 83]] [15 70]]] [476 0.0734 [1256 1.05 [2091 0.196 [29 99] [29 100]] [29 77]] [29 100]]] [32 40]] [29 54]] [10 100]] [1 47]] [15 83]] [13 30]] [13 100]]] [10 100]] [13 92]] [7722 1.89 [6191 5.19 [2143 0.458 [2474 0.456 [4768 1.55 [2476 8.79 [1429 28.5 [2913 8.91 [2259 8.11 [15 100] [15 44]] [15 83]] [15 100]] [15 83]] [15 100]] [15 100]] [15 100]] [15 75]] [36 50]]] [6304 8.6 [540 0.858 [939 14.2 [5851 6.19 [221 0.625 [4312 2.15 [1628 7.13 [29 100] [29 87]] [29 100]] [29 100]] [29 92]] [29 94]] [29 100]] [29 80]]] [7623 0.69 [5402 0.589 [2808 1.01 [1068 9.8 [4288 6.03 [24 0.876 [2913 1.99 [7665 15.8 [6082 4.2 [1089 0.406 [7251 2.45 [6015 14.3 [1899 6.76 [328 15.1 [5574 7.88 [4770 0.424 [5368 0.52 [2201 0.423 [435 20.9 [2143 0.677 [6872 0.78 [3027 3.13 [1899 0.77 [6230 3.16 [4895 0.982 [3424 1.92 [5480 1.54 [7766 1.26 [2766 1.24 [4414 12.2 [2849 2.41 [23 2.82 [29 97] [29 100]] [29 100]] [29 77]] [29 100]] [29 100]] [29 100]] [29 100]] [29 100]] [29 66]] [29 100]] [29 88]] [29 100]] [29 100]] [29 66]] [29 100]] [29 100]] [29 100]] [29 83]] [29 83]] [2752 17.4 [2704 3.69 [23 6.42 [29 94] [29 28]] [29 100]] [29 98]]] [29 88]] [29 80]] [29 100]] [13 70]] [7665 16.1 [29 62] [1429 9.85 [1062 1.61 [29 93] [29 87]] [29 73]]]] [32 100]] [2259 1.24 [29 100] [29 50]]] [32 90]] [10 37]] [15 100]] [13 100]] [897 3.16 [3243 0.684 [1069 0.795 [29 51] [15 100]] [15 100]] [15 91]]]] [15 100]]] [6899 11 [6413 2.65 [4154 1.15 [6883 0.454 [144 1.37 [5641 1.78 [7314 1.24 [107 4.68 [6031 1.41 [1834 1.53 [5170 3.41 [33 43] [33 89]] [33 66]] [23 21]] [33 100]] [33 92]] [33 42]] [33 42]] [30 26]] [2274 1.53 [1429 19.5 [7210 3.1 [33 97] [4154 3.59 [33 71] [33 100]]] [1429 22.8 [33 42] [33 66]]] [33 37]]] [13 57]] [5412 14.7 [144 11.9 [1452 3.28 [2945 3.36 [5360 1.31 [6524 1.9 [2048 2.65 [4809 18.3 [1769 17.2 [1742 2.76 [4754 7.63 [7512 12.3 [33 94] [33 60]] [10 35]] [33 100]] [33 77]] [33 66]] [33 100]] [33 55]] [33 100]] [33 75]] [1 42]] [33 37]] [33 60]]]] [5637 0.317 [4851 0.769 [4704 2.88 [2632 0.202 [2884 0.268 [4573 1.14 [6346 2.7 [6257 3.56 [1078 10.9 [7489 4 [7480 13.5 [2733 3.05 [67 3.41 [5900 3.96 [4622 5.29 [2890 1.29 [2656 3.69 [5480 2.24 [2763 1.81 [2405 1.71 [2689 1.06 [2853 0.836 [7623 0.322 [1701 3.87 [6207 18.1 [2725 3.18 [2749 4.43 [2665 3.09 [4743 2.24 [4431 5.67 [6371 14.1 [7474 9.44 [7132 16.7 [2707 3.22 [2628 0.64 [112 4.22 [2241 6.01 [4154 39 [134 1.04 [7329 2.7 [4832 11.6 [33 26] [2 100]] [13 81]] [5 56]] [6 63]] [2849 50.8 [13 50] [15 38]]] [29 31]] [16 22]] [2127 0.647 [2939 91.7 [4478 0.843 [6970 6.23 [75 1 [194 6.05 [4762 8 [6940 3.7 [2941 18.9 [2713 0.272 [1239 19.2 [7372 2.58 [5492 5.05 [2628 60.6 [6406 0.945 [6961 3.58 [7048 10.8 [2259 18.1 [2849 62.2 [7499 2.51 [1943 2.09 [7255 1.12 [38 36] [5594 0.752 [6134 0.692 [38 24] [17 33]] [16 63]]] [38 100]] [38 100]] [2628 25.6 [2939 20.8 [5 42] [5 27]] [38 66]]] [2852 0.511 [38 21] [38 83]]] [16 90]] [16 60]] [16 42]] [38 68]] [14 97]] [16 92]] [5673 11.3 [7472 1.59 [2869 1.35 [94 2.86 [38 40] [6 30]] [17 40]] [38 36]] [38 43]]] [5100 27.2 [16 34] [6 46]]] [6 55]] [16 47]] [7 34]] [6207 10.4 [2649 40.6 [4937 6.97 [1429 28.3 [16 31] [5 21]] [7 77]] [6 82]] [7 33]]] [16 57]] [38 100]] [5 38]] [38 53]] [2955 4.36 [38 50] [38 100]]]] [2680 4.2 [13 27] [2649 15.2 [7 91] [7 66]]]] [7343 10.4 [38 85] [38 57]]] [16 55]] [5724 11.1 [1253 3.53 [194 3.04 [16 56] [6 50]] [6 42]] [16 100]]] [16 92]] [6757 1.34 [38 75] [38 100]]] [26 62]] [1239 62.4 [7 95] [7 88]]] [4414 11 [7665 10.6 [2849 36.6 [38 39] [38 59]] [22 45]] [16 30]]] [2709 11.9 [4716 8.2 [2628 36.8 [16 68] [16 42]] [16 83]] [16 75]]] [3008 3.64 [5368 1.17 [33 45] [1 50]] [30 40]]] [38 51]] [1660 2.06 [16 50] [16 100]]] [7157 6.81 [7149 1.9 [5678 7.74 [38 93] [38 78]] [38 90]] [19 38]]] [2851 1.11 [33 25] [23 59.8 [13 81] [13 100]]]] [18 50]] [7619 1.79 [5594 2.29 [2891 2.65 [2748 1.07 [6371 2.73 [2628 64.2 [2207 1.7 [2850 3.42 [5799 50.7 [1896 12.5 [221 8.87 [312 2.41 [7281 2.28 [6134 18.8 [2644 7.65 [37 8.35 [5205 2.39 [16 59] [16 81]] [1239 9.92 [5435 18.5 [16 89] [7255 20.7 [16 84] [16 53]]] [16 75]]] [16 50]] [26 64]] [16 28]] [16 81]] [7 75]] [16 38]] [16 94]] [7 33]] [16 100]] [6 41]] [6207 1.74 [16 45] [16 77]]] [26 73]] [13 40]] [7679 2.01 [2653 6.25 [7150 3.88 [16 66] [26 46]] [16 70]] [18 70]]] [28 62]]] [3199 8.3 [5 71] [37 64]]] [3338 0.919 [194 15.4 [3419 2.79 [3694 0.117 [2850 1.06 [328 1.92 [4738 5.39 [37 37] [37 71]] [37 75]] [37 61]] [5 50]] [37 80]] [18 57]] [6877 9.1 [1897 3.12 [37 66] [5 61]] [37 88]]]] [1253 1.06 [7354 7.83 [1239 9.56 [18 46] [4997 2.95 [23 15.5 [16 30] [6 46]] [7 100]]] [17 36]] [5900 19.4 [6833 10.7 [16 33] [18 62]] [18 59]]]] [33 84]] [7210 0.408 [1395 4.95 [4515 0.572 [16 65] [4717 0.102 [7038 1.62 [16 52] [16 35]] [16 90]]] [16 45]] [16 60]]] [38 86]] [5799 0.84 [2951 12.5 [38 100] [6850 1.32 [4947 6.35 [38 88] [38 100]] [38 100]]] [38 57]]] [6656 1.04 [2701 0.473 [1218 3.54 [1078 34.2 [3422 4.9 [7679 1.55 [2470 2.42 [4769 3.77 [3107 1.86 [650 3.28 [5368 5.93 [6203 1.01 [4011 2.11 [248 18.3 [1888 1.9 [6133 3.62 [731 1.63 [112 6.71 [38 14] [2259 15.7 [2849 23.8 [28 61] [29 66]] [29 33]]] [16 87]] [6 50]] [16 50]] [26 35]] [28 72]] [10 81]] [11 53]] [11 100]] [7762 2.04 [187 4.48 [5 84] [5 68]] [5 77]]] [29 100]] [11 60]] [18 50]] [6 62]] [7287 2.28 [5995 9.09 [1078 122 [1895 5.51 [29 31] [16 33]] [1 41]] [29 100]] [11 100]]] [906 7.64 [29 84] [29 66]]] [2764 0.546 [4770 3.82 [6491 0.924 [7449 2.3 [2849 23.8 [29 100] [29 71]] [29 100]] [29 100]] [29 97]] [29 100]]] [6656 8.38 [29 100] [1078 26.8 [29 100] [29 66]]]]] [2891 6.82 [5412 1.38 [2656 20.8 [5692 7.55 [5901 1.48 [6827 2.15 [18 68] [18 87]] [18 62]] [7 60]] [7 73]] [18 100]] [7 90]]] [5799 1.41 [38 94] [38 100]]] [7372 0.849 [194 0.634 [2716 1.82 [95 7.36 [7 30] [16 42]] [7 66]] [7255 14.8 [7419 6.55 [7 100] [7 81]] [7 90]]] [16 76]]] [5753 0.564 [4154 3.17 [5414 1.87 [1899 0.151 [7260 5.16 [429 1.99 [1783 14.2 [2663 1.71 [38 80] [17 60]] [1429 51.9 [6384 3.79 [5959 13.5 [7009 12.1 [2405 9.34 [7038 9.04 [38 100] [38 96]] [187 3.72 [4538 70.2 [2367 5.44 [2392 9.04 [38 100] [38 77]] [38 100]] [38 71]] [38 100]]] [38 85]] [38 75]] [38 77]] [38 70]]] [38 100]] [32 41]] [2939 30.1 [38 100] [38 85]]] [38 100]] [32 42]] [38 66]]] [5 78]] [5171 19 [33 81] [33 100]]] [328 2.81 [6382 0.462 [429 0.176 [6256 5.37 [5985 16.3 [6517 0.578 [23 0.877 [5632 21.1 [7488 11.4 [2649 18.8 [2983 19.3 [2858 9.02 [6942 39.1 [1078 3.78 [5647 23 [2728 11.5 [6959 6.51 [6 31] [16 71]] [16 81]] [6 83]] [2707 5.26 [6 88] [2707 24.2 [30 72] [6 30]]]] [6 60]] [6 75]] [16 39]] [5962 4.2 [5753 1.01 [6 58] [6 54]] [6 91]]] [38 92]] [16 73]] [7488 2.11 [2954 1.04 [1820 1.08 [2891 2.81 [4951 1.37 [196 0.655 [5891 2.04 [4854 19.5 [4880 20 [7057 5.26 [5563 2.45 [4896 8.65 [6425 3.94 [2680 3.79 [6310 3.87 [5110 2.29 [2259 16.2 [7417 1.78 [4427 5.9 [2649 1.97 [4622 6.96 [5633 0.62 [2722 1.47 [5898 15.9 [6961 6.41 [91 10.9 [16 35] [16 71]] [16 76]] [18 50]] [16 34]] [16 66]] [37 70]] [5577 13.4 [2683 5.57 [5100 18.6 [0 3.36 [7241 1.69 [4457 3.75 [1587 0.52 [4528 4.19 [6920 0.454 [2029 0.976 [23 27.5 [7282 1.59 [1980 7.23 [4414 24.6 [16 67] [16 57]] [2851 1.82 [18 62] [16 33]]] [16 55]] [6 44]] [16 72]] [18 54]] [6 52]] [16 77]] [6 27]] [16 81]] [6 75]] [2655 1.24 [18 34] [6 90]]] [16 100]] [6 42]]] [5099 12 [6942 1.33 [18 42] [16 72]] [6 65]]] [38 50]] [167 5.2 [6959 0.946 [2628 46.4 [6779 1.57 [7260 1.15 [16 22] [16 60]] [3120 0.763 [112 1.59 [3544 3.92 [5102 3.82 [2259 21.8 [18 40] [3435 9.47 [5 28] [5 60]]] [16 62]] [6 70]] [5 81]] [5 60]]] [14 70]] [16 44]] [14 55]]] [30 100]] [5 80]] [7 77]] [1429 3.63 [6 77] [6 40]]] [17 50]] [6 54]] [17 31]] [6 70]] [195 9.81 [312 3.47 [78 8.37 [6134 1.13 [7512 1.44 [5099 49.6 [2955 13.3 [2649 7.35 [5985 13.8 [1429 6.3 [7041 1.54 [190 18 [2709 22.5 [6959 1.83 [6756 9.36 [5010 4.66 [95 6.46 [5626 6.98 [7260 3.57 [16 68] [16 57]] [16 56]] [6207 13.7 [18 88] [16 57]]] [6 50]] [16 77]] [16 88]] [18 70]] [6 55]] [6 71]] [6 44]] [18 63]] [2660 4.03 [6222 3.37 [16 59] [6 58]] [2868 1.11 [6 50] [5801 1.52 [6 45] [6 28]]]]] [2707 26.7 [5100 14.4 [23 18.4 [6 50] [7150 1.4 [2628 35.3 [6 71] [6 100]] [6 87]]] [6 41]] [1078 0.929 [2951 19.6 [190 17.6 [16 60] [6 42]] [62 5.72 [7260 0.319 [6 53] [6 75]] [18 28]]] [6 55]]]] [7255 3.94 [6 59] [6 76]]] [6 33]] [26 33]] [6 46]] [18 77]] [5099 84.1 [18 40] [18 55]]]] [17 64]] [2241 0.206 [7154 1.11 [2955 9.4 [1429 19.8 [18 90] [6 40]] [7 92]] [6 50]] [18 40]]] [14 31]] [7 57]] [2466 6.34 [2951 7.87 [5643 3.39 [6 100] [6 50]] [6 34]] [6 90]]] [30 100]] [38 100]]] [2707 11.5 [26 27] [2752 2.29 [2679 12.1 [2952 0.621 [5007 3 [7759 4.17 [2259 8.74 [2858 6.96 [190 10.2 [6848 1.31 [26 22] [16 50]] [5931 11 [5438 4.63 [6 50] [16 81]] [16 88]]] [26 71]] [30 43]] [28 53]] [16 84]] [2259 0.78 [16 70] [16 44]]] [16 91]] [14 22]]]] [2649 4.52 [6 48] [193 4.83 [5985 25.9 [2713 19.1 [1783 5.41 [6 75] [6 50]] [16 80]] [2640 1.72 [5626 9.57 [1429 3.5 [6 77] [6 88]] [6 100]] [6 71]]] [4854 12.4 [16 42] [6 40]]]]] [5593 1.5 [7347 1.29 [2719 5.01 [5753 10.8 [5985 1.08 [18 65] [7 76]] [18 85]] [18 100]] [18 85]] [18 50]]] [2707 5.53 [5647 2.48 [2939 4.11 [7665 1.14 [695 1.43 [28 43] [28 100]] [7512 9.85 [16 63] [14 21]]] [7512 10.6 [6 32] [26 37]]] [18 85]] [7325 0.324 [6779 1.93 [2891 1.46 [5122 0.805 [5435 11.2 [301 9.17 [4764 0.146 [7123 3.7 [7665 11.3 [673 1.3 [6257 11.9 [5484 0.882 [5931 14.6 [1356 0.287 [4527 3.68 [5595 1.31 [6831 1.74 [4939 0.556 [791 22.4 [1980 0.828 [2667 8.82 [5753 0.359 [2685 2.9 [78 2.44 [16 55] [16 54]] [18 55]] [16 66]] [38 40]] [16 36]] [37 71]] [16 91]] [16 85]] [18 44]] [6 55]] [6 53]] [26 37]] [7734 2.84 [18 77] [18 60]]] [5801 3.03 [18 95] [18 85]]] [26 62]] [32 50]] [95 3.8 [1239 4.85 [16 53] [16 80]] [16 44]]] [18 75]] [30 58]] [1895 3.76 [6199 1.86 [6 62] [26 52]] [17 44]]] [30 100]] [5673 0.286 [18 44] [18 43]]] [37 40]] [5579 1.04 [7048 2.67 [16 50] [5 55]] [5 85]]]]] [17 60]] [5102 2.82 [5635 0.994 [5492 2.7 [6574 1.2 [6910 0.506 [5110 2.73 [4205 2.9 [248 4.65 [37 6.58 [2445 0.385 [7149 7.07 [16 20] [18 75]] [16 54]] [37 33]] [16 55]] [26 54]] [30 100]] [18 78]] [17 100]] [14 100]] [7 50]] [2259 3.32 [1429 18.2 [7343 3.18 [978 3.3 [6471 0.921 [78 4.16 [6 50] [6 28]] [26 62]] [26 90]] [18 57]] [2939 24.4 [18 33] [30 80]]] [6941 0.711 [7512 7.66 [2260 5.75 [2695 0.69 [30 42] [5568 0.864 [30 83] [30 100]]] [30 100]] [18 33]] [6 44]]]]]] [7255 0.252 [4851 0.186 [4890 0.265 [6961 1 [2259 34.3 [4050 1.7 [4104 0.668 [2167 0.99 [7726 0.458 [5637 31.2 [3238 3.09 [6035 4.26 [6425 3.63 [6940 9.83 [3554 1.72 [7423 6.26 [2632 0.426 [7042 0.937 [2207 0.322 [7303 2.32 [5100 1.12 [4861 2.98 [5546 3.83 [2862 2.7 [38 26] [1429 32.4 [38 57] [1789 5.53 [2442 2.06 [2993 11.2 [5345 1.17 [38 23] [26 25]] [25 37]] [5 66]] [1429 41 [38 69] [38 100]]]]] [16 28]] [5 75]] [2075 2.02 [4426 4.42 [2939 27.6 [16 41] [18 44]] [6 46]] [13 28]]] [17 46]] [16 28]] [38 100]] [5 53]] [16 68]] [19 75]] [6822 6.1 [16 57] [16 100]]] [16 88]] [7 36]] [5593 6.49 [16 95] [2955 11.6 [16 42] [16 80]]]] [16 48]] [2752 2.87 [6216 0.244 [5 38] [37 75]] [5 62]]] [38 100]] [187 11.8 [2849 64.2 [4895 11.6 [5 78] [37 66]] [166 0.64 [5 60] [37 45]]] [37 73]]] [1783 21.9 [16 87] [16 41]]] [1913 4.35 [2075 0.168 [2444 1.04 [6380 1.57 [5379 12.7 [4897 8.34 [1732 8.17 [3983 2.22 [2885 1.62 [38 82] [5380 4.52 [38 98] [38 85]]] [6108 14.3 [5682 7.57 [2638 4.25 [2628 9.57 [17 66] [2404 0.902 [38 100] [38 80]]] [38 46]] [38 84]] [19 50]]] [38 50]] [38 58]] [4535 70 [38 100] [38 92]]] [38 60]] [38 100]] [7390 8.57 [4716 2.02 [6342 0.411 [2075 4.19 [1897 2.43 [38 100] [38 44]] [38 94]] [2440 3.92 [38 100] [38 91]]] [38 69]] [38 62]]] [38 44]]] [4725 9.77 [6687 1.66 [2628 19.5 [5673 8.78 [5673 3.39 [6832 1.6 [16 77] [1997 0.971 [16 54] [18 50]]] [6 50]] [16 77]] [2983 4.15 [2955 6.26 [16 68] [194 3.32 [2649 1.27 [16 87] [16 100]] [6 33]]] [16 86]]] [16 50]] [16 63]]] [1783 28.2 [2851 0.645 [2872 3.62 [38 90] [38 100]] [38 100]] [7475 4.45 [38 55] [38 100]]]] [5099 24.2 [5891 2.45 [5345 0.243 [6953 2.54 [7210 1.46 [4513 2.06 [5641 4.58 [2983 8.85 [5983 3.92 [1916 1.15 [7132 2.88 [5716 1.58 [4879 0.242 [1384 0.234 [1661 2.74 [5641 1.95 [26 40] [38 45]] [6 66]] [16 38]] [16 57]] [6 30]] [38 85]] [16 83]] [6 53]] [6 70]] [5721 7.93 [2952 0.827 [2979 11.3 [16 49] [6 44]] [16 100]] [6 71]]] [16 76]] [16 55]] [7391 0.814 [19 45] [17 100]]] [17 56]] [17 62]] [23 20.1 [5871 0.598 [4431 6.14 [6 77] [16 53]] [6 85]] [6 36]]]] [2364 0.554 [2849 46.6 [1789 0.327 [5732 1.95 [4854 6.17 [7512 2.46 [97 0.409 [7042 11.7 [5003 0.682 [2939 17.1 [4939 8 [5345 0.778 [1587 0.881 [6 30] [16 52]] [5 23]] [16 100]] [6831 5.04 [2978 0.667 [2671 1.38 [5635 0.221 [38 46] [7048 1.05 [16 64] [17 37]]] [16 78]] [5578 1.37 [6199 3.52 [1445 0.241 [6 62] [16 50]] [16 100]] [16 92]]] [2689 1.9 [6687 0.673 [18 66] [16 86]] [2862 3.64 [18 50] [16 37]]]]] [7 100]] [6 100]] [38 51]] [6831 3.66 [187 13.8 [5753 0.231 [16 30] [18 37]] [26 36]] [5130 2.04 [7206 3.6 [731 0.495 [6831 9.42 [18 83] [18 42]] [4716 2.88 [16 28] [18 50]]] [19 40]] [18 53]]]] [5641 3.37 [7665 0.458 [6129 1.37 [6688 1.58 [3239 0.449 [4854 17.2 [18 57] [16 75]] [6 71]] [1452 1.18 [16 93] [16 71]]] [6 50]] [26 42]] [94 3.15 [194 2.96 [6 87] [6 33]] [16 66]]]] [2862 0.346 [1783 16.2 [7 70] [7 88]] [6 25]]] [2628 15.3 [17 44] [4895 6.16 [2377 18.7 [2468 2.38 [38 76] [5 33]] [38 100]] [38 62]]]] [7423 0.994 [1587 7.14 [4874 0.416 [6133 0.617 [6131 1.42 [7210 5.6 [4977 0.111 [6409 1.84 [4762 4.05 [7343 14.9 [94 10.3 [16 24] [2873 2.35 [38 33] [8 50]]] [16 88]] [16 30]] [16 25]] [6 100]] [26 55]] [10 33]] [16 72]] [26 62]] [16 85]] [16 85]]] [1895 4.1 [38 100] [38 62]]]]]] [6310 1 [896 10.6 [6791 12 [221 0.284 [5673 4.77 [29 97] [29 85]] [29 100]] [29 85]] [29 90]] [29 71]]] [7009 1.83 [276 0.444 [5480 1.86 [4154 1.65 [802 12.1 [5316 3.46 [2824 2.37 [2628 15.3 [5009 6.95 [112 1.14 [2624 4.35 [6332 0.87 [1011 6.06 [663 5.61 [4375 0.998 [6231 0.778 [673 13.9 [6544 1.27 [429 4.75 [4896 3.45 [32 38] [32 100]] [6757 3.71 [392 0.626 [5961 0.994 [7188 10.3 [6853 4.27 [978 8.33 [7512 0.797 [2470 2.18 [2939 23.7 [5812 0.921 [2752 1.89 [21 23] [2752 23.4 [5007 3.4 [939 2.76 [2939 1.86 [32 88] [32 100]] [32 100]] [32 83]] [889 12.5 [32 81] [32 100]]]] [12 50]] [12 50]] [2471 0.532 [15 56] [15 83]]] [32 83]] [12 22]] [28 53]] [12 77]] [32 100]] [11 63]] [28 42]]] [1888 13.1 [32 84] [32 100]]] [26 85]] [12 92]] [32 100]] [1911 1.62 [32 83] [32 80]]] [2 42]] [32 27]] [23 16.1 [12 95] [12 100]]] [905 2 [7441 6.84 [5843 3.08 [5192 3.32 [2083 7.7 [2826 0.579 [6370 2.13 [1980 3.85 [4663 36.9 [1980 2.5 [3872 4.31 [32 94] [32 85]] [32 83]] [32 77]] [32 100]] [32 83]] [32 100]] [32 80]] [32 83]] [32 83]] [11 58]] [32 60]]] [19 37]] [2851 1.01 [2649 2.65 [12 27] [16 40]] [38 50]]] [12 100]] [32 95]] [21 54]] [248 4.61 [2232 8.27 [1239 32.4 [2132 1.31 [6960 3.82 [7512 1.4 [5746 0.488 [1445 7.23 [695 20.5 [1429 7.49 [32 72] [23 31.7 [2701 4.27 [1239 4.23 [4369 2.08 [5192 0.414 [2023 1.42 [3095 4.35 [32 93] [32 100]] [32 91]] [32 90]] [4801 1.69 [7210 1.28 [4375 16.1 [32 98] [32 85]] [32 100]] [32 100]]] [6809 3.72 [32 84] [32 100]]] [32 85]] [32 80]]] [32 75]] [32 42]] [32 100]] [5753 5.46 [2259 2.27 [503 1.53 [7449 3.27 [1888 1.41 [32 75] [32 85]] [32 87]] [32 100]] [2902 5.14 [6333 16.9 [1711 0.864 [5206 7.64 [3728 0.436 [7340 5.15 [7731 1.14 [3265 1.47 [6353 0.393 [791 4.9 [32 80] [32 100]] [32 100]] [32 100]] [32 100]] [7255 0.81 [7704 0.96 [435 0.392 [4611 1.49 [32 100] [32 92]] [32 100]] [32 100]] [32 100]]] [32 100]] [32 85]] [32 100]] [32 83]] [6103 2.46 [32 83] [32 100]]]] [939 0.805 [32 83] [32 100]]]] [31 57]] [32 53]] [3 58]] [32 42]] [5110 2.13 [5891 0.701 [32 64] [32 88]] [15 91]]]] [5192 2 [2470 13 [6732 15.1 [2868 1.42 [2466 4.05 [5647 1.63 [18 29] [29 45]] [19 85]] [18 62]] [5 30]] [11 100]] [1078 2.54 [18 50] [11 30]]]] [7354 3.39 [7354 0.627 [18 48] [19 36]] [2756 8.36 [560 2.53 [5693 1.82 [18 70] [18 100]] [5161 1.28 [16 52] [19 66]]] [18 100]]]] [1078 1.07 [6230 2.22 [12 77] [32 54]] [7287 3.76 [6184 0.703 [660 2.13 [7016 1.27 [1400 4.78 [6124 5.62 [1888 12.3 [13 37] [32 33]] [12 100]] [12 42]] [22 77]] [12 66]] [13 100]] [12 100]]]]] [6822 8.74 [62 0.272 [4904 0.282 [6574 1.36 [4132 0.671 [4105 0.917 [4587 0.143 [7065 0.241 [6380 5.87 [2689 0.481 [7242 0.217 [5994 0.752 [4948 2.21 [2951 11 [6931 0.225 [1955 0.863 [328 3.49 [2860 1.78 [3243 5.98 [4537 0.677 [5480 0.174 [2951 0.837 [7473 11.2 [38 63] [38 74]] [4889 0.717 [5918 4.93 [4533 0.465 [2093 2.62 [3006 1.82 [7301 0.517 [1253 2.46 [2875 0.574 [1948 0.199 [38 86] [38 100]] [38 100]] [38 85]] [38 100]] [38 50]] [38 42]] [38 66]] [26 33]] [38 88]]] [19 55]] [2707 10.6 [2410 3.55 [3984 4.49 [7474 7.64 [6933 5.75 [1860 0.695 [38 88] [4896 1.42 [2628 11.9 [2885 1.28 [38 97] [38 100]] [38 100]] [38 80]]] [38 66]] [38 87]] [6824 2.33 [38 58] [38 92]]] [17 42]] [5958 3.66 [38 85] [19 30]]]] [38 50]] [2241 5.65 [38 71] [17 60]]] [38 46]] [19 37]] [8 21]] [6184 2.38 [5568 1.54 [4571 2.11 [1983 7.9 [4920 0.993 [3524 0.29 [2164 0.6 [5546 1.26 [6824 3.09 [5635 0.854 [6874 0.885 [6007 0.474 [6449 1.59 [37 1.45 [6758 0.265 [7370 3.85 [6229 0.628 [2207 1.49 [5130 0.17 [3008 1.64 [7303 0.147 [2875 1.71 [5068 11.7 [45 2.1 [2939 87.9 [1783 20.9 [2048 2.11 [1783 8.25 [38 100] [38 85]] [38 85]] [38 60]] [38 100]] [38 87]] [38 70]] [38 75]] [38 100]] [5209 2.17 [38 90] [38 85]]] [38 80]] [38 86]] [38 71]] [2665 17 [38 84] [38 75]]] [38 100]] [7390 1.47 [1900 3.75 [38 90] [38 55]] [38 87]]] [38 57]] [38 100]] [4517 0.511 [1800 2.16 [38 100] [2849 47.4 [38 100] [38 85]]] [38 100]]] [38 70]] [38 78]] [38 71]] [38 75]] [38 70]] [38 47]] [38 46]] [6 44]] [38 63]] [2241 3.04 [38 75] [14 30]]]] [12 46]] [16 40]] [94 3.19 [4478 1.64 [6413 0.685 [4535 2.46 [6383 0.984 [1262 2.34 [38 85] [38 42]] [38 44]] [1429 22.7 [5958 8.81 [23 38.5 [2750 5.85 [38 100] [38 75]] [38 64]] [23 63.2 [4536 2.09 [38 71] [2386 0.96 [45 3.27 [17 60] [38 80]] [38 100]]] [38 100]]] [4897 7.17 [38 100] [38 80]]]] [6915 0.351 [5381 4.56 [5829 5.67 [17 50] [38 100]] [5148 0.541 [17 55] [2955 7.39 [16 55] [38 63]]]] [17 66]]] [5 45]] [6874 2.66 [5 44] [38 33]]]] [4895 0.496 [6199 3.03 [38 75] [38 38]] [2854 1.36 [16 60] [24 51]]]] [1787 2.61 [5637 5.79 [1899 7.66 [38 71] [17 44]] [38 64]] [2707 17.9 [16 52] [38 70]]]] [4896 1.17 [1749 0.121 [1900 2.17 [7241 0.44 [38 41] [17 33]] [5892 7.89 [17 57] [17 72]]] [6208 12 [17 57] [17 100]]] [16 38]]] [26 71]] [8 54]] [1748 5.37 [7231 11.9 [2879 3.65 [4725 3.08 [190 3.81 [2752 1.19 [38 100] [38 84]] [38 100]] [38 71]] [2360 0.456 [4133 1.33 [38 57] [38 100]] [38 100]]] [38 88]] [2429 10.9 [38 89] [16 55]]]] [190 9.19 [17 70] [38 50]]] [14 40]] [4687 0.333 [4893 2.97 [2259 21.3 [17 48] [38 100]] [5 40]] [17 90]]] [1754 0.329 [2093 0.45 [17 47] [17 77]] [17 100]]]] [5034 0.502 [5637 2.29 [660 14.8 [2259 8.41 [2752 1.28 [31 57] [5192 4.88 [814 3.31 [6413 1.86 [5154 1.82 [1906 1.59 [32 96] [32 100]] [32 57]] [32 66]] [32 70]] [32 75]]] [32 80]] [22 57]] [32 78]] [6408 8.44 [3905 11.5 [1079 2.41 [791 5.18 [5851 0.397 [2178 1.65 [7169 2.54 [32 100] [32 70]] [32 100]] [32 100]] [5593 4 [5034 2.4 [695 0.792 [32 77] [32 100]] [855 3.22 [32 100] [32 96]]] [5593 5.96 [32 85] [32 100]]]] [6091 0.543 [32 75] [32 100]]] [4309 0.756 [5673 7.76 [5693 8.63 [32 100] [32 80]] [32 62]] [32 100]]] [32 83]]]] [5356 0.524 [2083 3.09 [1400 10.5 [4332 1.09 [4373 0.637 [961 0.917 [1101 0.794 [500 0.668 [4122 26.9 [3027 1.23 [1997 1.93 [4114 28.3 [3527 2.76 [957 7.05 [27 93] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [27 85]] [27 100]] [27 100]] [27 100]] [27 100]] [27 100]] [10 66]] [27 83]] [27 100]]] [5753 0.198 [6732 0.339 [5222 0.442 [2259 26.5 [5900 2.01 [430 0.585 [7176 1.23 [788 0.3 [996 1.22 [878 0.773 [3676 0.736 [695 0.759 [429 40.2 [7674 3.37 [4184 10.9 [2759 6.59 [978 2.13 [1786 7.02 [1913 0.232 [4680 1.32 [7428 15.3 [1218 7.21 [2143 0.463 [5692 8.05 [2470 1.16 [4288 13.9 [5034 1.25 [30 82] [30 97]] [30 71]] [6199 16.6 [1078 7.13 [30 100] [5110 7.6 [30 100] [30 84]]] [30 88]]] [6696 2.37 [7241 1.57 [6438 3.23 [6853 4.85 [221 1.51 [30 98] [30 100]] [30 100]] [30 100]] [30 100]] [30 100]]] [5211 12.5 [30 66] [1899 2.42 [30 94] [30 87]]]] [23 71]] [30 55]] [30 62]] [30 61]] [30 88]] [23 73]] [1679 1.43 [8 54] [30 88]]] [22 62]] [10 100]] [998 1.01 [23 65] [23 100]]] [1424 2.49 [2752 15.3 [30 45] [791 2.22 [22 55] [22 78]]] [10 100]]] [8 97]] [10 100]] [23 100]] [5467 2.25 [10 57] [10 100]]] [7665 11.3 [4184 2.23 [7182 0.914 [7201 1.02 [2011 0.639 [1436 2.83 [1 1.21 [864 1.29 [1679 4.37 [5851 7.92 [7512 0.956 [1899 9.62 [2199 0.75 [5480 0.876 [22 90] [22 100]] [22 100]] [429 13.5 [22 100] [429 20 [22 54] [22 94]]]] [22 100]] [22 66]] [22 75]] [22 62]] [22 75]] [22 100]] [22 100]] [22 100]] [22 100]] [22 100]] [22 85]]] [22 100]] [30 100]] [5421 6.17 [6524 1.27 [1899 6.75 [5676 0.522 [4971 1.48 [5900 6.92 [429 22.9 [355 15.2 [4210 0.864 [4497 2.04 [5904 19.7 [5205 2.59 [30 89] [30 100]] [30 75]] [30 100]] [30 100]] [30 76]] [10 33]] [30 75]] [30 100]] [30 43]] [5225 11.2 [22 35] [30 62]]] [22 87]] [23 88]]] [4985 9.37 [5067 0.515 [1429 30.6 [5692 1.03 [3051 1.58 [5673 2.02 [1078 22.1 [5211 52 [30 80] [30 100]] [30 51]] [30 100]] [30 100]] [30 97]] [6436 17.5 [5110 14.5 [30 100] [30 83]] [30 96]]] [30 100]] [30 77]]] [867 0.302 [6470 2.11 [5205 1.53 [7428 0.42 [5662 0.609 [7664 1.17 [7461 1.23 [1391 1.13 [2434 2.22 [3105 1.57 [663 13.6 [2752 23.6 [5412 4.08 [1611 1.8 [2913 9.66 [712 2.13 [30 89] [22 75]] [30 100]] [30 100]] [30 57]] [22 86]] [22 100]] [30 100]] [30 100]] [22 100]] [22 100]] [30 75]] [22 97]] [22 62]] [30 100]] [22 100]] [430 0.593 [1239 9.37 [2753 5.04 [4851 0.419 [1078 13.3 [22 82] [1089 2.92 [2143 0.315 [1429 44.1 [22 100] [22 85]] [22 100]] [22 88]]] [30 72]] [22 72]] [22 100]] [22 100]]]] [798 1.31 [7324 1.04 [2993 3.07 [5765 0.198 [6675 0.442 [7101 0.677 [1 1.35 [4982 0.525 [2470 1.69 [5480 0.442 [22 56] [22 100]] [30 63]] [30 53]] [221 5.75 [30 38] [30 75]]] [5692 7.77 [22 100] [22 96]]] [30 100]] [22 100]] [6375 1.71 [7289 1.29 [4984 0.805 [429 16.6 [7169 4.94 [30 100] [30 83]] [30 60]] [30 100]] [30 100]] [22 50]]] [30 91]] [23 100]]]] [4279 2.98 [4349 0.485 [2453 1.14 [1919 0.634 [2628 2.15 [7210 2.28 [1011 19.2 [978 7.62 [7381 5.6 [24 57] [24 77]] [24 57]] [2 71]] [24 41]] [4 46]] [2 46]] [7520 14 [3101 1.7 [7665 35.3 [978 19 [24 95] [24 91]] [24 62]] [24 100]] [24 84]]] [7590 1.25 [3639 2.69 [896 6.67 [2458 0.754 [1429 42.3 [24 100] [24 95]] [24 100]] [1390 5.14 [24 92] [24 77]]] [19 50]] [24 100]]] [208 2.23 [2752 16.9 [4533 4.19 [4519 3.27 [1011 1.63 [4338 5.97 [24 70] [24 100]] [24 71]] [24 100]] [24 87]] [4145 1.42 [2275 1.54 [978 3.37 [4279 26.3 [5789 1.57 [6853 4.07 [24 66] [24 100]] [24 100]] [24 66]] [24 73]] [24 100]] [24 100]]] [2259 19.2 [24 60] [24 95]]]]] [6051 1.14 [505 1.71 [622 1.08 [5915 0.3 [5502 0.682 [4748 0.631 [4805 1.95 [1664 2.2 [3884 1.54 [5938 1.95 [4867 0.725 [5040 3.89 [4312 2.56 [4568 0.635 [517 0.826 [237 0.879 [5549 0.78 [529 2.82 [756 3.47 [2760 3.16 [5446 1.59 [4282 0.832 [554 2.89 [4279 3.98 [1365 7.31 [2156 26 [376 2.82 [634 0.504 [7318 7.46 [2470 1.13 [574 3.59 [917 5.47 [524 1.12 [21 55] [6261 3.24 [21 96] [21 100]]] [1239 40.4 [21 86] [21 95]]] [9 87]] [15 80]] [3 100]] [21 100]] [21 100]] [21 100]] [9 75]] [2993 1.47 [3 50] [21 44]]] [3 100]] [5403 3.7 [1907 0.513 [3 97] [3 100]] [3 100]]] [9 100]] [15 40]] [4948 1.51 [3 56] [3 100]]] [3 80]] [9 87]] [1429 0.879 [3 96] [3 83]]] [7086 0.879 [495 1.82 [4663 14.2 [21 90] [21 83]] [21 100]] [21 100]]] [5753 1.84 [660 0.635 [6017 2.33 [21 81] [21 100]] [21 100]] [21 62]]] [429 29.7 [3 66] [1783 2.16 [907 14.3 [3 96] [3 88]] [3 100]]]] [2993 0.873 [2259 17.7 [6177 0.99 [920 1.9 [4533 0.807 [21 99] [21 100]] [21 100]] [21 85]] [9 60]] [749 0.13 [803 9.8 [21 100] [21 96]] [21 90]]]] [3 100]] [7088 9.63 [1436 5.46 [800 5.17 [5513 4.95 [535 1.12 [21 92] [21 100]] [21 83]] [21 92]] [21 85]] [21 75]]] [15 100]] [3 100]] [3 94]] [7085 1.55 [9 84] [4679 1.22 [9 91] [9 71]]]] [6306 0.682 [802 6.88 [3 90] [21 57]] [3 100]]] [328 11.7 [9 100] [9 83]]] [3 100]] [756 4.56 [7211 5.09 [9 60] [2624 1.95 [9 100] [9 83]]] [21 60]]] [3 100]]] [5211 4.92 [7305 2.99 [6991 0.196 [3928 0.227 [3998 0.665 [2417 0.234 [6984 0.11 [3652 0.431 [6182 0.12 [3905 0.0664 [2739 0.975 [6537 0.599 [673 0.947 [2551 0.158 [6582 0.925 [2081 8.66 [7373 0.794 [2569 1.69 [6284 0.79 [6557 0.26 [1071 0.554 [7588 0.77 [7665 0.732 [4214 1.21 [4122 13.8 [906 2.11 [7154 0.321 [4703 0.759 [7742 6.58 [3233 0.146 [5170 2.17 [6853 5.16 [286 2.63 [6263 1.18 [6230 0.0543 [6560 0.39 [3851 2.24 [3055 0.632 [6848 3.13 [7038 1.57 [1226 3.73 [495 1.6 [7363 0.893 [1013 5.07 [2426 0.907 [2849 2.63 [267 2.11 [1047 2.19 [4690 0.586 [360 3.96 [2493 3.13 [6167 0.775 [2793 0.885 [5140 4.99 [1713 2.96 [819 1.05 [2488 6.64 [5904 1.5 [1382 7.94 [7032 6.88 [4928 2.11 [1400 6.81 [6806 0.782 [6013 0.472 [6717 4.63 [6550 1.35 [6985 4.76 [2259 12.4 [4205 27.6 [1218 4.01 [1429 35.4 [2607 1.24 [1995 4.63 [3933 3.65 [6189 13.2 [3450 2.2 [1888 9.93 [2938 2.11 [791 7.01 [2470 12.9 [426 0.69 [6177 28.4 [4858 2.35 [5815 2.79 [178 5.68 [436 6.99 [1170 4.54 [7729 4 [2207 23.4 [2 11] [2 87]] [1 85]] [27 46]] [4 90]] [25 40]] [2 82]] [23 100]] [25 96]] [1 100]] [4 86]] [3525 3.82 [537 3.55 [7381 20.8 [5041 2.7 [2541 10.6 [978 1.9 [4790 0.911 [3003 5.88 [580 1.87 [2259 0.22 [35 9] [9 23]] [9 54]] [27 100]] [29 33]] [23 31]] [7 45]] [21 91]] [2 58]] [3 100]] [35 100]]] [25 94]] [3095 6.49 [4 37] [4 57]]] [35 91]] [25 100]] [27 100]] [23 46]] [18 48]] [5673 1.31 [2048 0.962 [6413 1.96 [1899 20.5 [429 35.7 [7241 53.2 [5716 2.96 [3292 2.73 [1475 17.2 [4146 11.1 [3994 3.11 [1429 80.1 [978 4.5 [5 13] [5 30]] [5 35]] [21 22]] [24 100]] [8 100]] [35 62]] [24 60]] [27 80]] [6040 9.8 [4 17] [18 75]]] [23 25]] [17 38]] [1 47]] [18 33]]] [23 62]] [26 79]] [6382 1.27 [4852 6.49 [6499 3.9 [6749 11.7 [822 1.47 [978 7.31 [4997 4.25 [4292 5.16 [5314 2.62 [1239 56.9 [3379 0.703 [5270 3.73 [4775 1.57 [6342 16.5 [5480 24.8 [2212 0.696 [6276 10.9 [1786 7.67 [7340 7.46 [2043 0.655 [5637 3.63 [1 8] [18 39]] [12 36]] [12 100]] [1 80]] [29 50]] [2199 1.19 [1 33] [1 70]]] [8 79]] [0 35]] [2 60]] [31 29]] [1 72]] [6 57]] [18 63]] [3 52]] [7 100]] [1899 17.3 [23 30] [23 45]]] [21 46]] [6 93]] [6 100]] [8 100]] [6380 9.87 [17 47] [1624 1.22 [1997 2.51 [14 41] [14 66]] [14 57]]]]] [8 100]] [791 1.35 [4 25] [791 10.1 [17 45] [144 4.59 [17 61] [17 86]]]]] [32 64]] [21 100]] [32 100]] [1786 1.98 [10 19] [10 100]]] [32 100]] [1025 2.68 [312 4 [2 39] [2 64]] [5812 0.894 [2 64] [2 100]]]] [6 92]] [19 63]] [3760 2.7 [8 84] [8 100]]] [27 100]] [31 100]] [5754 4.42 [1980 21.1 [33 76] [1 25]] [33 100]]] [5347 3.64 [4154 7.64 [1995 2.22 [2259 1.18 [23 84] [23 75]] [23 66]] [3404 9.52 [3033 1.47 [24 40] [23 94]] [27 85]]] [27 100]]] [2259 52.1 [6168 0.775 [6 100] [6 66]] [6 100]]] [8 100]] [7 100]] [3224 0.629 [8 83] [8 100]]] [2 43]] [18 100]] [75 1.54 [6551 2.86 [5103 1.04 [1997 0.4 [144 1.19 [2849 40.7 [2707 2.35 [5480 1.87 [33 22] [18 72]] [2983 7.07 [2621 7.46 [1429 23.7 [2951 15.4 [2939 17.6 [18 21] [4431 2.16 [6 28] [18 42]]] [16 66]] [16 45]] [6 42]] [16 75]]] [2628 29.1 [16 50] [5 42]]] [26 29]] [38 43]] [190 4.5 [16 57] [16 46]]] [26 100]] [16 77]]] [8 86]] [23 100]] [6596 7.46 [4 82] [4 100]]] [27 47]] [23 72]] [2259 24.6 [7153 0.711 [2985 6.03 [2656 6.58 [1899 15.2 [5397 1.55 [2450 0.201 [2685 2.94 [7423 9.53 [5962 7.56 [1366 1.27 [2649 8.62 [2618 0.975 [5593 0.462 [7041 1.21 [1 22] [16 80]] [16 100]] [6 33]] [6 50]] [9 33]] [18 77]] [6 63]] [18 75]] [16 83]] [16 100]] [16 100]] [16 20]] [16 90]] [16 59]] [2619 4.43 [23 32 [6 51] [18 45]] [2679 2.67 [6 43] [16 90]]]]] [7354 12 [7132 1.07 [695 5.57 [2707 3.94 [434 9.87 [3273 1.53 [1676 3.11 [5753 13.4 [35 67] [5 50]] [35 87]] [35 86]] [35 58]] [38 52]] [5 35]] [38 100]] [5 76]]] [0 100]] [2759 12.2 [2526 10.7 [791 6.54 [35 37] [35 100]] [1239 4.76 [35 97] [35 100]]] [1 55]]] [5308 5.05 [4085 0.573 [939 8.92 [7009 6 [2143 4.49 [985 0.879 [2590 1.73 [4851 2.26 [3952 0.824 [2488 6.47 [1429 17.6 [8 67] [8 47]] [2562 2.2 [8 100] [8 71]]] [8 100]] [8 100]] [8 100]] [8 100]] [8 57]] [8 100]] [8 37]] [8 100]] [21 100]]] [7168 5.33 [2280 1.36 [328 7.66 [5647 25.5 [4071 1.58 [4870 6.75 [6231 3.92 [429 41.6 [4479 2.06 [5007 1.6 [5130 3.5 [3099 3.99 [7381 1.38 [2048 1.13 [6413 0.41 [4851 7.1 [5809 2.43 [957 4.76 [3897 2.99 [4364 4.85 [1253 3.04 [1997 3.18 [939 4.79 [5 40] [38 71]] [0 25]] [5 77]] [32 80]] [5 87]] [7 16]] [7 50]] [6 33]] [0 85]] [0 37]] [4 50]] [35 61]] [7 42]] [4 27]] [18 36]] [2526 14.7 [17 34] [34 21]]] [25 33]] [17 41]] [5 83]] [4 46]] [7 33]] [34 80]] [4 66]]] [8 100]] [7491 0.69 [5812 2.59 [7091 0.501 [5721 2.96 [1400 2.05 [221 3.7 [663 7.24 [1980 1.39 [4663 6.14 [2752 3.86 [27 18] [7623 2.82 [23 54] [27 81]]] [23 100]] [6524 2.94 [2161 0.84 [7385 0.934 [1919 6.71 [1899 15.7 [7424 0.759 [6921 1.75 [2939 2.59 [978 1.73 [23 50] [2259 2.22 [1429 1.53 [23 57] [23 100]] [23 100]]] [23 22]] [23 100]] [23 100]] [23 60]] [23 100]] [23 100]] [23 100]] [25 55]]] [2 50]] [11 23]] [7623 2.01 [1078 8.26 [32 42] [27 70]] [27 75]]] [6 81]] [23 94]] [2 76]] [23 87]]] [7449 1.58 [2517 2.18 [4279 13.2 [24 57] [24 100]] [6853 16.5 [24 93] [24 100]]] [24 100]]] [4424 2.73 [5635 4.15 [2005 4.2 [6655 1.72 [2640 1.04 [5386 4.05 [2600 2.13 [5115 2.62 [33 51] [7415 1.56 [328 3.76 [33 87] [33 62]] [33 100]]] [33 93]] [33 57]] [26 57]] [33 78]] [33 71]] [26 72]] [26 62]]] [3944 4.67 [35 78] [1165 6 [35 90] [35 100]]]] [7512 3.31 [2813 3.36 [25 34] [18 100]] [1078 34.6 [134 1.24 [4154 22.2 [4 36] [2 69]] [5 37]] [4 60]]]] [1445 0.304 [5495 1.02 [1783 1.18 [17 38] [3308 2.06 [6375 7.35 [6177 2.86 [5386 10.9 [233 0.724 [134 2.2 [33 56] [25 66]] [2900 3.89 [5301 6.86 [4768 2.33 [1239 12.1 [33 87] [6899 1.18 [33 93] [33 100]]] [33 100]] [33 57]] [33 75]]] [1 50]] [25 85]] [33 50]] [11 57]]] [4 25]] [33 18]]] [4940 0.243 [6034 3.69 [7476 0.713 [101 2.25 [2939 7.71 [5435 4.04 [2225 3.94 [2939 4.73 [16 13] [2 37]] [4 40]] [8 38]] [7343 4.34 [7206 6.11 [5641 4.57 [190 3.35 [23 10.6 [16 46] [6 44]] [16 66]] [18 28]] [7 37]] [18 37]]] [8 55]] [16 71]] [6613 6.65 [5 28] [19 84]]] [7139 0.668 [6207 6.72 [6409 0.631 [16 55] [19 28]] [16 100]] [16 25]]]] [5938 0.431 [822 0.303 [627 0.571 [6809 1.63 [286 11.2 [7116 3.04 [2488 13.1 [5046 4.15 [545 2.39 [5049 2.15 [6310 7.04 [569 0.327 [1812 0.36 [2752 2.39 [906 12 [3 40] [21 45]] [2628 3.83 [248 13.2 [6921 1.51 [5753 0.891 [928 1.66 [896 0.952 [23 20] [5 33]] [27 90]] [2081 1.67 [2 50] [29 37]]] [23 83]] [33 80]] [33 37]]] [33 100]] [5041 1.22 [3 57] [21 100]]] [21 88]] [6529 4.94 [21 65] [9 50]]] [21 89]] [3 100]] [8 100]] [3 100]] [23 54]] [32 100]] [915 1.77 [21 84] [3 50]]] [7449 4.84 [505 6.39 [5040 1.63 [4611 1.59 [21 45] [3 54]] [915 0.321 [21 92] [21 100]]] [13 50]] [21 50]]] [5040 2.22 [21 83] [739 2.43 [21 100] [21 85]]]]] [5345 0.419 [2005 7.25 [27 83] [27 61]] [27 100]]] [2849 0.945 [6260 1.31 [6184 4.85 [2752 18.8 [4286 3.4 [2763 3.53 [7169 1.1 [33 43] [33 77]] [33 100]] [3 36]] [2517 13.3 [429 4.16 [24 90] [24 98]] [19 46]]] [33 91]] [6520 4.2 [1429 3.94 [24 80] [24 100]] [24 100]]] [33 100]]] [6287 3.09 [7009 1.91 [6853 1.51 [6735 0.736 [7354 0.541 [7549 0.466 [2262 2.88 [5155 0.225 [5597 7.78 [1011 0.122 [3667 1.68 [7222 4.14 [5402 1.42 [4929 1.81 [5140 3.47 [7266 2.46 [2436 0.592 [7683 0.484 [2541 4.88 [5812 1.66 [3629 4.93 [896 0.173 [5792 3.18 [2591 1.54 [5034 1.98 [1888 5.98 [4891 11.4 [7043 0.649 [5732 7.84 [1400 0.551 [791 2.34 [23 3.87 [5405 9.8 [4725 2.43 [6923 3.26 [6883 3.45 [7563 8.2 [7325 4.13 [1429 28.4 [1382 2.09 [2370 4.76 [2752 3 [2962 5.75 [5396 4.24 [4675 3.86 [3019 25.4 [4235 15.1 [5623 3.7 [6032 3.88 [7566 3.4 [4889 17.7 [5637 11.1 [6 21] [22 76]] [6 100]] [17 38]] [22 42]] [6 100]] [429 18.8 [26 50] [26 100]]] [24 100]] [6 93]] [6 65]] [31 73]] [4114 1.67 [2755 4.5 [1059 13.6 [7265 9.43 [2570 3.17 [1899 13.2 [25 18] [2 44]] [978 10.7 [1 31] [2 41]]] [24 44]] [2 87]] [25 41]] [13 20]]] [6 100]] [6 100]] [7241 3.39 [1436 1.59 [731 0.234 [248 4.5 [1382 6.51 [4889 15.5 [1239 20.8 [6 36] [6 90]] [6 100]] [2526 42.7 [6 94] [6 55]]] [328 4.85 [6 20] [25 33]]] [17 35]] [6036 13 [24 38] [26 70]]] [18 25]]] [5 100]] [5 77]] [5 69]] [5409 21.7 [6 63] [5349 23.3 [6 88] [6 55]]]] [6 84]] [31 100]] [6524 2.75 [2649 2.11 [4940 1.01 [2939 17.2 [4703 0.64 [19 12] [33 76]] [16 28]] [16 100]] [2653 1.1 [6 53] [6 63]]] [183 2.62 [2005 2.61 [25 83] [1 80]] [25 83]]]] [5673 6.18 [6406 24.1 [6732 19.3 [2004 0.952 [1445 3.8 [4851 2.79 [5480 4.98 [2826 9.69 [7101 0.719 [24 22] [6 33]] [5 42]] [18 40]] [7 21]] [1 44]] [29 70]] [2526 40 [24 52] [24 100]]] [1 83]] [24 75]]] [31 27]] [7 53]] [1427 8.91 [25 92] [25 66]]] [7675 17.9 [6 85] [6 100]]] [6591 6.25 [5412 17.5 [6740 4.7 [5509 6.46 [814 8.45 [2753 5.33 [4663 1.38 [2081 5.84 [2793 2.35 [728 3.5 [24 16] [5 42]] [24 90]] [4 62]] [31 37]] [14 45]] [4 77]] [5 31]] [18 38]] [31 75]] [5 54]]] [5267 2.46 [663 6.85 [1400 1.07 [719 1.45 [7722 3.03 [32 54] [14 88]] [14 100]] [14 100]] [32 66]] [32 100]]] [731 21.7 [17 50] [26 41]]] [24 96]] [269 7.27 [5480 3.55 [4253 0.669 [4891 3.18 [6526 0.347 [7609 0.734 [1429 13.4 [6260 1.19 [6123 3.57 [6581 0.327 [7381 0.775 [1025 0.0434 [2849 6.04 [4184 5.88 [2470 4.82 [134 7.64 [7449 12.8 [7169 18.7 [4741 2.99 [7248 5.15 [7085 0.682 [4154 11.5 [25 34] [2 14]] [1 40]] [7 26]] [2 28]] [25 61]] [25 61]] [25 64]] [4 90]] [1 47]] [26 54]] [1888 7.48 [1253 0.521 [4 42] [2 88]] [4 42]]] [2902 7.64 [5660 1.73 [1400 15.5 [1429 1.86 [655 3.76 [2 31] [2 73]] [2 53]] [4 80]] [4 70]] [4 55]]] [5316 1.96 [6977 17.4 [3008 8.13 [7665 30.8 [5 45] [5509 3.5 [17 83] [5 100]]] [17 55]] [5 50]] [17 44]]] [6 100]] [2793 8.32 [24 100] [24 87]]] [6584 0.888 [4037 1.57 [2826 0.907 [4534 3.82 [2811 4.44 [7382 1.75 [2986 9.29 [2628 20.4 [6524 5.38 [1640 0.52 [6977 6.19 [6199 23 [5 19] [6 25]] [17 37]] [2 54]] [7 66]] [7 47]] [5 77]] [24 80]] [5 62]] [6 100]] [5 49]] [24 100]] [6413 0.949 [695 4.34 [16 25] [17 59]] [17 77]]]] [25 100]] [25 100]] [6 100]] [1813 1.01 [25 60] [25 100]]] [18 50]] [26 100]]] [7535 3.4 [24 91] [24 100]]] [3526 2.07 [2628 17.9 [5034 3.85 [4519 0.463 [1723 2.42 [7544 4.34 [4110 2.18 [1074 2.74 [6586 1.34 [6310 2.55 [6927 3.46 [5820 1.32 [4766 3.28 [2752 27.6 [1482 2.33 [5971 6.54 [6584 0.615 [2526 12.7 [688 3.3 [4741 3.83 [6581 5.41 [1429 29.1 [5812 2.93 [4 42] [2 50]] [2 25]] [17 80]] [22 50]] [5 58]] [7563 3.7 [2567 7.34 [573 1.58 [7459 2.69 [1025 2.01 [2 20] [1883 1.09 [4 41] [2 78]]] [4 58]] [1077 4.47 [4414 24.7 [5413 13.6 [4338 11.8 [4338 5.25 [2470 1.43 [1993 1.01 [2570 16 [1023 19.6 [2081 2.16 [2752 24.2 [6732 15.1 [7568 11.5 [2 23] [36 42]] [2 50]] [4 75]] [4 30]] [2 57]] [5 66]] [4 72]] [1888 4.35 [7512 24.2 [4 90] [4 100]] [4 84]]] [4 94]] [24 66]] [4 33]] [2 77]] [5412 9.02 [2 42] [5 66]]]] [2 68]] [12 57]]] [2591 1.23 [17 61] [17 85]]] [17 66]] [5 100]] [328 0.99 [5660 4.28 [978 5.38 [7413 5.88 [2143 5.53 [1025 16.1 [6977 4.7 [1980 0.894 [2752 45.7 [1073 1.98 [4 32] [4 25]] [12 35]] [24 29]] [17 60]] [2 62]] [4 44]] [17 50]] [5662 2.35 [2 45] [4184 4.36 [4 42] [2 28]]]] [2 45]] [2 91]]] [5 62]] [4 54]] [2 72]] [5 42]] [7563 3.6 [17 51] [5 50]]] [2536 2.6 [2 43] [2 80]]] [5 100]] [2 80]] [4 33]] [24 100]] [14 100]] [5769 2.35 [4 41] [4 68]]] [5 81]]] [728 1.03 [724 2.46 [2541 11 [17 62] [17 51]] [17 50]] [17 83]]] [7512 10.3 [1 66] [1 100]]] [23 5.05 [1062 2.62 [2566 8.05 [1078 1.01 [1429 17.1 [6 75] [6 100]] [6 73]] [6 71]] [6 88]] [6 61]]] [223 4.89 [7034 19.7 [7265 29.4 [2560 0.975 [7292 1.87 [2 72] [7266 14.4 [2 88] [2 100]]] [2 100]] [2 93]] [4338 8.47 [2 91] [2 100]]] [2 66]]] [7678 6.85 [4682 0.385 [5413 1.45 [33 75] [5 37]] [33 100]] [33 58]]] [1574 1.86 [736 0.338 [2555 9.93 [5320 4.71 [6926 3.64 [1078 22.4 [5692 10.4 [2143 0.96 [5007 2.17 [2966 1.34 [1047 1.47 [2684 1.96 [4932 2.82 [4 58] [4 88]] [4 100]] [4 60]] [4 100]] [4 91]] [4 55]] [4718 5.48 [4 57] [4 57]]] [1429 6.02 [2 62] [4 43]]] [2 60]] [31 63]] [2 50]] [4 62]] [4 100]]] [13 97]] [5396 0.795 [2602 5.34 [187 2.42 [7665 13.9 [5408 1.09 [6 37] [6 100]] [6116 2.36 [6 86] [6 100]]] [6 50]] [6 93]] [6 50]]] [7693 4.43 [5812 4.28 [2536 0.907 [6926 3.4 [4929 1.26 [2 50] [4 42]] [2 96]] [4 68]] [5054 1.09 [6577 4.25 [5693 6.02 [7414 4.87 [2760 1.04 [2 40] [2 82]] [2 53]] [2616 6.68 [2 81] [2 94]]] [2 100]] [2 53]]] [4 63]]] [7068 0.456 [6184 0.949 [5734 0.813 [1239 30.2 [3056 1.61 [2628 11.5 [6575 0.571 [4479 0.268 [3014 1.77 [144 5.96 [3008 5.45 [5820 1.15 [643 0.311 [1993 2.05 [6982 0.327 [682 0.257 [7253 3.18 [5461 1.15 [2259 41 [1755 11 [393 0.258 [7187 0.352 [3671 1.03 [5054 0.381 [6927 1.01 [4932 0.891 [2910 6.24 [4214 3.15 [1025 0.461 [1081 2.18 [2470 0.911 [2902 12.1 [7188 20.4 [978 14.3 [5480 11.5 [660 1.54 [5753 4.54 [719 6.51 [7677 2 [896 13.1 [1011 3.16 [2259 0.77 [5 80] [14 33]] [1899 6.89 [17 37] [2 25]]] [2752 13.6 [5 41] [5 80]]] [28 50]] [5 63]] [5 68]] [17 57]] [18 100]] [1011 4.83 [731 4 [38 57] [17 60]] [913 8.89 [5 19] [3 33]]]] [7 75]] [2 50]] [2628 2.65 [695 3.83 [4 81] [4 57]] [4 100]]] [25 80]] [7384 1.18 [1075 2.92 [429 17.1 [7185 0.597 [2 75] [2 60]] [4 42]] [2 81]] [4 50]]] [29 60]] [17 63]] [4 100]] [7742 1.01 [567 1.58 [2 60] [2 58]] [4 91]]] [4 84]] [2 68]] [4 94]] [26 100]] [24 60]] [6 71]] [2 100]] [1429 32 [5 62] [17 60]]] [736 0.772 [5413 3.43 [4 58] [2 88]] [4 100]]] [4338 0.422 [7693 0.653 [573 1.42 [4 93] [4 100]] [4 100]] [4 77]]] [2536 4.7 [7718 1.58 [2081 4.07 [2 50] [17 50]] [2 42]] [2 25]]] [2 100]] [2 81]] [17 43]] [2526 18.3 [1239 5.56 [788 1.83 [5574 3.18 [4 32] [15 63]] [19 76]] [4840 5.85 [18 50] [19 87]]] [2 86]]] [2616 5.68 [17 90] [19 66]]] [1630 2.59 [1073 5.76 [429 44.4 [1078 2.94 [17 33] [17 83]] [7 41]] [19 50]] [17 62]]] [17 57]] [4 37]] [21 2.52 [5 81] [5 60]]] [6 86]] [7512 10.4 [7 85] [7 100]]] [7424 0.155 [1059 1.34 [17 2.7 [7561 1.65 [7414 3.6 [896 7.11 [7381 6.1 [2628 0.602 [6791 0.389 [25 33] [2 28]] [4 31]] [2 87]] [6791 1.36 [2 84] [2 40]]] [1 25]] [4 55]] [7413 1.09 [2 88] [2 90]]] [1911 0.617 [2 100] [2 77]]] [2 100]]] [5345 3.68 [4896 0.963 [7711 2.2 [2752 20.2 [17 71] [38 84]] [32 37]] [17 50]] [17 75]]]] [2005 2.62 [6 78] [6 55]]] [3315 0.324 [3734 0.572 [7722 1.02 [178 0.402 [6866 1.45 [17 33] [5 100]] [5 62]] [1632 1.6 [6535 0.225 [731 12 [17 35] [5 68]] [17 67]] [19 100]]] [17 79]] [5 81]]] [187 8.07 [5409 25.8 [5408 14.7 [1 9.43 [6920 11.2 [6701 11.1 [6 92] [6 83]] [6 66]] [6 100]] [4889 20.2 [6 66] [6 87]]] [6 42]] [6 100]]] [7134 0.781 [7283 0.552 [7421 15.1 [5593 1.66 [6 93] [6 70]] [6 69]] [6 80]] [7 100]]] [6550 0.948 [353 0.37 [4184 1.21 [1877 0.849 [6529 1.87 [7325 0.707 [6042 0.485 [4504 4.17 [1062 7.03 [7742 0.332 [4997 2.38 [2707 15.8 [5482 0.169 [6740 3.75 [328 0.141 [5626 0.766 [5692 19.1 [688 3.6 [282 1.25 [5673 0.539 [1011 5.81 [6977 5.24 [719 14.4 [4478 0.998 [5412 1.77 [2607 17.2 [4806 0.756 [3867 1.52 [248 2.92 [5430 2.13 [7665 6.77 [38 31] [7512 21 [18 28] [5692 8.21 [7 37] [5 60]]]] [5 67]] [18 36]] [12 55]] [5 66]] [32 50]] [7354 18.8 [2616 2.9 [5413 1.93 [7354 10.2 [13 66] [13 57]] [32 23]] [26 23]] [18 30]]] [7 65]] [7 51]] [5 94]] [5 65]] [2939 2.53 [5680 3.85 [719 1.55 [5673 6.28 [2 37] [5 42]] [18 50]] [5 37]] [7260 0.601 [19 60] [16 40]]]] [18 83]] [7512 13 [18 42] [7 86]]] [18 62]] [18 81]] [2023 0.831 [18 28] [16 44]]] [18 65]] [1997 0.403 [2143 1.02 [5480 19.6 [5485 4.52 [6830 2.51 [1888 12.5 [18 42] [18 100]] [18 75]] [18 50]] [18 100]] [18 37]] [16 42]]] [5130 0.528 [16 88] [16 71]]] [7 100]] [5281 5.15 [5267 1.27 [2763 3.3 [7590 1.81 [2846 0.596 [7188 5.85 [736 0.278 [7742 4.4 [18 63] [18 31]] [16 50]] [18 100]] [7185 2.89 [16 60] [18 41]]] [144 2.88 [18 70] [18 90]]] [18 41]] [16 57]] [18 66]]] [23 8.5 [18 60] [5132 0.952 [18 43] [16 58]]]] [284 9.18 [2259 28.9 [18 63] [19 68]] [19 81]]] [6043 4.61 [2143 1.69 [6342 1.11 [5007 2.92 [18 92] [18 76]] [18 80]] [18 62]] [19 50]]] [1429 31.5 [19 50] [5753 0.707 [5 80] [5 100]]]] [7 100]] [2466 3.94 [1919 1.27 [1078 0.72 [26 46] [2 37]] [30 40]] [22 40]]] [1186 3.89 [5819 1.58 [1025 0.234 [7665 7.21 [5654 2.51 [5009 1.23 [18 47] [19 81]] [18 64]] [2809 9.43 [5873 7.09 [2628 3.98 [1429 41.9 [18 100] [18 87]] [2868 0.644 [18 70] [18 100]]] [18 44]] [18 50]]] [1911 0.36 [7 27] [16 33]]] [5 31]] [19 72]]] [7 100]] [1059 5.28 [2939 0.588 [1429 39.3 [7601 0.766 [16 41] [5 45]] [5 66]] [5 76]] [26 100]]]] [567 3.34 [4959 3.7 [2470 2.71 [5693 5.02 [6170 3.15 [978 1.1 [1239 5.61 [5819 0.217 [2 40] [2 66]] [7512 20.9 [4 50] [24 71]]] [791 8.61 [5574 15.4 [663 10.1 [2674 0.465 [23 5.72 [2 62] [1899 6.34 [2 100] [2 70]]] [2 100]] [4 57]] [2 42]] [5770 0.763 [2960 2.16 [1986 1.1 [2 70] [2 100]] [2 57]] [4 64]]]] [2 84]] [5662 0.664 [435 0.921 [1078 28.4 [7292 1.08 [7722 5.58 [6074 0.858 [2 75] [5576 2.92 [2 90] [2 100]]] [2 60]] [2 100]] [2 38]] [4 57]] [2 37]]] [6732 15.2 [4 96] [4 88]]] [4 100]] [1429 8.35 [2616 6.09 [2 75] [2 100]] [2 71]]]] [5693 0.595 [2939 3.57 [6907 2.42 [7188 2.82 [5673 0.949 [2518 0.593 [4907 7.3 [6232 1.77 [4518 0.829 [7601 1.42 [5662 3.7 [2777 1.95 [5454 3.66 [5692 13.7 [5725 1.18 [1025 4.22 [6855 14.1 [7255 2.49 [811 6.47 [7067 3.4 [2593 10.6 [24 58] [24 91]] [24 81]] [31 81]] [31 44]] [31 100]] [24 92]] [31 100]] [24 100]] [24 100]] [24 100]] [18 42]] [36 53]] [4519 9.62 [24 100] [5793 1.19 [1429 10 [24 71] [4338 13.9 [24 84] [24 100]]] [24 100]]]] [31 100]] [24 50]] [4518 3.62 [7382 1.12 [2793 5.11 [24 100] [24 85]] [24 100]] [1919 3.38 [24 85] [24 77]]]] [208 5.67 [24 92] [24 85]]] [18 75]] [25 100]] [2700 3.03 [5412 2.68 [1429 14.8 [31 85] [18 50]] [31 100]] [31 100]]] [655 0.615 [7672 0.55 [1389 0.525 [24 67] [791 16 [24 100] [24 93]]] [24 100]] [24 100]]]] [5472 0.813 [2826 0.241 [5413 1.48 [2617 5.06 [1980 6.18 [228 0.65 [4718 19.1 [2259 34.3 [3714 7.25 [7535 0.459 [6581 0.474 [4 33] [2849 3.31 [7191 3.51 [7381 0.474 [4279 0.657 [5 75] [19 42]] [791 12.9 [5 71] [5 100]]] [5 91]] [16 42]]] [5 44]] [26 100]] [7019 21.1 [12 46] [12 94]]] [12 50]] [7169 1.8 [2752 9.12 [2 83] [4 62]] [4 57]]] [2 21]] [4 100]] [5198 1.94 [4 66] [4 75]]] [6589 8.2 [6883 4.52 [4154 5.4 [4222 0.398 [5904 1.29 [736 2.57 [735 0.911 [6581 0.756 [7677 1.88 [1078 4.67 [5 68] [896 6.4 [5 78] [5 61]]] [5 100]] [5 91]] [735 3.76 [12 25] [5 75]]] [7693 1.29 [1011 3.04 [5 61] [5 70]] [19 30]]] [19 66]] [5 100]] [4332 6.81 [7169 1.66 [7712 1.53 [1210 4.99 [5 39] [5 38]] [5 81]] [5 100]] [5 90]]] [5 100]] [5 33]]] [2939 4 [429 26.5 [13 72] [13 100]] [13 72]]]] [5988 4.43 [5969 1.68 [4889 4.76 [7505 7.57 [5798 1.06 [6353 0.791 [1011 2.07 [6007 4.61 [6361 11.7 [4534 15.9 [6220 1.85 [1239 28.2 [7038 8.5 [6 71] [6 100]] [6 92]] [6 100]] [16 57]] [6 66]] [6 75]] [6 100]] [4 42]] [16 57]] [6 44]] [1364 0.818 [6 87] [6 100]]] [16 50]] [6 100]]]] [731 5.75 [5891 1.74 [1666 0.617 [1429 46.1 [5509 3.45 [4851 8.57 [731 3.57 [7185 1.21 [5 50] [17 45]] [5 75]] [6589 43.7 [6230 2.11 [7588 11.6 [5 73] [7711 17.6 [5 34] [5 72]]] [2591 18.3 [5 93] [19 41]]] [19 58]]] [7241 3.17 [1017 7.8 [610 1.08 [1017 3.59 [4876 2.29 [6550 1.55 [4851 35.8 [724 1.27 [6590 10.8 [6575 3.19 [5812 6.79 [5 59] [5 58]] [5 100]] [5 90]] [19 61]] [5 94]] [7590 7.77 [2594 8.11 [6584 3.15 [5 44] [6550 10 [5 66] [5 87]]] [5 100]] [5 90]]] [5 55]] [5 100]] [5 100]] [19 75]] [5 100]]] [5 40]] [38 50]] [17 50]] [719 7.04 [738 2.96 [6883 2.83 [7742 3.94 [2752 26 [5692 1.85 [2526 11.2 [5 45] [17 83]] [429 29.4 [5 46] [38 55]]] [896 2.13 [5 66] [5 88]]] [17 76]] [5 91]] [26 55]] [7605 2.15 [2591 7.18 [5 37] [5 66]] [5 81]]]]] [1062 0.507 [4235 1.04 [1783 0.998 [6083 0.431 [7558 1.59 [13 89] [13 100]] [13 100]] [13 100]] [13 100]] [13 100]]] [3562 0.945 [6333 0.52 [7346 6.14 [1073 3.3 [728 2.48 [4071 0.523 [978 25.6 [23 0.657 [7693 0.188 [5155 1.45 [2259 0.756 [5 48] [17 53]] [5 57]] [17 87]] [5 79]] [17 100]] [5 66]] [17 60]] [5 72]] [5 90]] [791 4.01 [5 75] [429 22.5 [5 100] [3214 1.96 [647 0.26 [999 3.57 [5 98] [5 50]] [5 100]] [5 100]]]]] [38 55]]] [1078 33.5 [24 99] [2259 1.29 [6285 20.4 [24 89] [24 100]] [24 100]]]] [2030 2.16 [5480 0.761 [4891 0.338 [4737 3.55 [2618 0.581 [6961 2.28 [1911 1.31 [4725 2.43 [6940 17.7 [6289 5.15 [1701 0.593 [4673 1.47 [7491 3.28 [7041 2.72 [2569 5.27 [6 36] [1980 4.22 [1899 3.19 [5099 9.35 [6398 3.27 [5598 11.9 [6 54] [6 91]] [6 90]] [16 55]] [6 85]] [16 42]]] [1239 6.24 [7231 1.72 [16 64] [16 83]] [7 28]]] [6 55]] [6424 1.53 [2368 1.55 [7041 7.41 [7419 17.9 [6 100] [6 69]] [6 77]] [6 100]] [6 71]]] [1355 12.9 [6 100] [6 77]]] [6 46]] [16 66]] [16 54]] [16 41]] [5100 4.75 [16 87] [16 100]]] [5103 0.581 [16 87] [18 40]]] [6 100]] [2126 5.15 [429 5.86 [7419 3 [6 100] [2628 3.92 [7419 10.1 [6 100] [6 83]] [7419 8.73 [6 53] [16 66]]]] [6 100]] [6 100]]] [791 1.31 [16 66] [16 50]]] [5595 2.15 [5090 3.08 [2628 10.6 [5716 4.26 [6 93] [6 100]] [6 60]] [6 100]] [6 100]]]] [7185 0.33 [6920 3.9 [2752 6.64 [6550 0.78 [4154 3.88 [6732 1.2 [7 32] [38 36]] [24 84]] [17 75]] [4025 0.562 [4519 0.835 [3554 0.96 [5812 3.77 [7156 1.67 [7734 0.719 [2241 0.891 [2793 1.31 [655 2.73 [2548 0.914 [7512 8.19 [23 6.11 [24 25] [36 50]] [24 40]] [24 100]] [24 86]] [24 93]] [28 50]] [16 30]] [19 41]] [1023 0.542 [19 44] [19 33]]] [5 37]] [221 4.34 [4154 5.62 [24 85] [2763 0.598 [4191 2.65 [24 100] [24 91]] [24 81]]] [24 87]]] [24 100]]] [1020 0.581 [4495 1.03 [1980 4.43 [24 84] [24 71]] [24 100]] [24 100]]] [5454 3.16 [4189 1.72 [1201 0.307 [6804 1.22 [19 22] [3989 0.33 [4457 1.5 [17 45] [16 40]] [17 77]]] [17 53]] [24 100]] [24 100]]]] [2089 0.425 [5347 0.662 [4122 13.3 [2099 0.763 [906 8.77 [5812 2.26 [4865 3.23 [250 1.5 [2088 0.484 [3033 1.02 [7395 5.48 [4891 1.92 [2559 1.79 [6289 5.48 [5448 1.22 [5693 2.16 [248 1.42 [2139 8.85 [2149 16.5 [739 0.346 [1742 3.02 [6848 2.79 [762 0.498 [2760 0.629 [7512 0.321 [384 1.76 [981 0.766 [7491 18.2 [4342 3.82 [1980 21.4 [791 9.86 [1429 22 [2259 18.4 [1104 4.2 [7449 4.52 [4832 5.05 [2081 17.4 [27 18] [1 25]] [2 30]] [23 42]] [18 41]] [12 18]] [2178 1.8 [1239 22.6 [8 26] [1 16]] [5 19]]] [328 9.81 [23 26] [3 37]]] [1456 11.3 [3931 1.1 [6294 5.49 [2488 9.22 [2939 1.78 [2093 11.5 [1078 57 [4338 4.78 [1078 4.06 [23 25] [2763 6.81 [4663 3.04 [1993 2.76 [1239 1.59 [23 44] [23 81]] [23 100]] [23 55]] [23 42]]] [23 81]] [27 65]] [23 75]] [1 20]] [8 70]] [21 28]] [1 66]] [1 71]]] [12 50]] [23 83]] [23 100]] [23 100]] [1059 1.02 [7590 10.4 [1788 10.9 [2539 14.1 [7623 0.761 [6524 2.26 [1888 2 [2151 1.28 [6 12] [14 50]] [5 20]] [1 50]] [18 50]] [31 80]] [23 45]] [18 63]] [6 88]]] [23 64]] [23 100]] [35 91]] [1 63]] [21 100]] [791 2.53 [27 75] [23 58]]] [34 84]] [33 30]] [2616 12.5 [2011 1.11 [248 29.2 [4655 2.2 [4 14] [1 85]] [25 87]] [1 37]] [18 37]]] [32 92]] [6 88]] [33 82]] [6 88]] [32 100]] [2101 16.6 [2793 6.66 [23 60] [23 91]] [23 70]]] [328 12.9 [4768 1.47 [23 53] [23 100]] [4 50]]] [6528 1.13 [33 84] [251 8.43 [1 87] [1 50]]]] [3 100]] [2143 16.6 [1239 5.25 [7009 1.71 [2 33] [4 66]] [4288 1.13 [1980 20.7 [17 26] [23 50]] [2 53]]] [4 44]]] [5041 2.24 [1062 2.99 [21 48] [21 35]] [21 100]]] [826 0.763 [23 40] [23 100]]] [27 88]] [27 100]] [5692 3.05 [7665 0.0878 [4114 14.9 [2179 1.64 [822 4.05 [4663 16.1 [6490 0.928 [1065 0.509 [929 0.632 [1454 0.678 [2766 10.7 [774 1.42 [23 92] [23 57]] [23 72]] [23 100]] [23 100]] [23 100]] [23 100]] [23 85]] [23 60]] [23 66]] [23 75]] [2 56]] [4 35]]]] [7395 7.16 [2570 0.931 [5812 77.9 [5771 15 [6199 28.6 [7451 4.86 [4932 7.97 [1783 0.932 [5767 1.19 [6342 1.03 [2902 0.785 [7265 8.42 [7365 1.42 [1023 1.96 [6575 1.58 [1062 1.18 [2259 62.6 [1078 6.9 [5769 2.35 [7702 1.98 [6732 18.5 [4 99] [4 85]] [4 100]] [4 100]] [4 97]] [4 77]] [4 100]] [4 100]] [4 100]] [4 100]] [4 76]] [4 100]] [4 100]] [4 90]] [4 100]] [4 90]] [4 81]] [4 83]] [4 85]] [4 60]] [4 100]] [32 100]]] [695 1.41 [2241 0.515 [1896 1.44 [5641 0.728 [2955 8.41 [6353 0.0696 [4514 4.33 [5093 14.8 [2752 4.67 [2526 12.1 [6 50] [1011 1.9 [2656 0.978 [6514 1.16 [4726 49.6 [434 0.782 [7281 2.04 [5623 0.244 [6293 1.5 [4727 13.9 [2368 0.975 [2038 8.07 [2849 5.09 [6 100] [6 55]] [6 50]] [6 75]] [6 80]] [6 100]] [6289 1.71 [6 92] [6 100]]] [6 100]] [6 100]] [6 60]] [2207 4.43 [6398 3.07 [2387 0.436 [2262 1.38 [5598 5.33 [6 100] [2080 3.55 [2602 3.56 [6 71] [6 60]] [6 87]]] [7540 3.42 [6 75] [6 87]]] [6 100]] [16 71]] [6 100]]] [6 50]] [6 100]]] [6 56]] [6 58]] [2549 0.986 [6 87] [6 100]]] [6 33]] [7231 9.79 [4891 1.21 [6 38] [7 44]] [16 78]]] [4528 0.0582 [2752 0.473 [2712 0.424 [6 50] [6 50]] [7 28]] [16 83]]] [5635 0.635 [16 64] [6 72]]] [7123 1.02 [5598 1.19 [6 50] [6 88]] [16 83]]] [16 55]]] [5432 0.948 [5345 1 [1003 0.295 [6471 0.141 [4221 1.3 [7576 0.589 [6525 0.556 [2938 0.787 [5431 0.994 [5079 3.25 [5480 0.434 [567 1.53 [6524 0.402 [7255 1.56 [6424 0.283 [7609 2.46 [2936 1.19 [3008 7.15 [7414 3.75 [266 2.18 [1919 10.4 [5716 5 [6251 5.85 [7742 1.35 [202 3.46 [221 2.86 [3207 1.86 [1919 4.65 [26 53] [26 86]] [26 53]] [25 63]] [26 100]] [25 76]] [25 83]] [26 100]] [25 48]] [26 100]] [25 81]] [2616 0.808 [25 60] [6 86]]] [25 100]] [25 100]] [6 90]] [26 80]] [7720 1.27 [5654 0.575 [6251 1.86 [2769 2.86 [25 65] [25 100]] [673 10.5 [1 100] [1 75]]] [25 100]] [1 100]]] [3333 0.858 [5654 12.9 [1 100] [1 90]] [1 100]]] [957 1.78 [681 0.621 [248 17.7 [18 42] [2526 11.7 [978 10.6 [6581 1.32 [26 60] [26 83]] [26 84]] [731 0.441 [1888 2.16 [5480 27.1 [695 1.19 [1078 4 [26 72] [26 100]] [26 76]] [26 71]] [26 100]] [26 100]]]] [7722 0.859 [26 66] [26 100]]] [18 78]]] [826 1.16 [7583 1.64 [25 84] [25 100]] [25 100]]] [5410 5.34 [26 88] [9 50]]] [25 100]] [178 0.855 [1 75] [25 91]]] [25 100]] [929 0.556 [2752 38.4 [26 97] [19 57]] [26 75]]] [1239 9.4 [2956 3.36 [994 4.52 [5626 3.09 [724 0.287 [5695 0.536 [2081 13.6 [7668 0.141 [791 10.4 [328 0.761 [95 1.38 [26 88] [26 100]] [2749 1.37 [26 77] [26 100]]] [26 90]] [7516 3.68 [26 100] [26 88]]] [26 83]] [26 100]] [26 80]] [26 88]] [26 62]] [26 66]] [2867 0.129 [5692 5.69 [26 70] [16 40]] [16 57]]]] [6177 0.931 [896 1.09 [1078 4.96 [25 63] [26 54]] [25 76]] [25 100]]] [5873 0.537 [2259 14.9 [719 0.623 [676 3.92 [1995 0.805 [1223 0.623 [26 86] [26 100]] [25 50]] [18 33]] [7722 0.702 [19 44] [1078 3.23 [26 80] [18 50]]]] [248 13.5 [26 50] [18 33]]] [26 100]]] [25 100]]] [6983 1.52 [6177 8.19 [3099 0.168 [5110 7.69 [5661 6.1 [7640 4.46 [5171 1.15 [7176 5.19 [2939 26.5 [1742 9.52 [2470 1.53 [6949 0.133 [4832 0.301 [725 2.01 [6276 1.57 [2261 0.69 [2597 8 [2013 4.9 [1059 20.6 [738 0.484 [2902 9.43 [4338 10.8 [3667 0.381 [1007 18.2 [1081 1.94 [2674 1.33 [1085 1.46 [6920 2.46 [7210 3.04 [4684 0.582 [5661 3.22 [5601 12 [5692 12.9 [6186 1.47 [134 4.4 [292 1.87 [7561 7.11 [5664 1.37 [6732 15.4 [2752 4.44 [2 83] [2201 0.664 [5659 6.11 [4324 2.39 [7461 7.06 [2101 5 [286 1.23 [665 7.49 [2 92] [2 100]] [2 100]] [2 87]] [2 94]] [2 100]] [2 91]] [2 90]]] [2 75]] [2 100]] [2 62]] [2 66]] [1011 0.632 [2 100] [2 70]]] [2 100]] [2 60]] [22 50]] [2 71]] [2 71]] [2 66]] [2 56]] [2 95]] [2757 15.6 [3302 0.956 [1110 1.22 [6989 5.56 [6988 3.14 [1078 27.5 [2 100] [2 85]] [2 100]] [4418 2.79 [2587 17.2 [7512 13.7 [2 100] [5660 3.07 [2 100] [2 60]]] [2 87]] [5812 20.1 [2 66] [2 100]]]] [2 100]] [2 100]] [2 88]]] [1 40]] [2 60]] [6197 2.82 [6184 0.528 [978 8.74 [2 80] [2 100]] [2 100]] [2 66]]] [2 68]] [2616 10.2 [4235 9.13 [6077 1.34 [5812 1.83 [2 83] [2 90]] [2 100]] [2 31]] [2 100]]] [2 100]] [2 55]] [1 25]] [2 66]] [6989 3.66 [2 100] [1078 10.8 [2 85] [2 100]]]] [2 69]] [4 50]] [1640 19.6 [5913 0.0837 [6926 15.9 [2676 7.58 [2745 3.01 [3163 1.46 [7340 5.94 [6736 2.62 [1079 9.66 [4418 5.03 [7335 3.81 [2616 16.8 [4584 4.83 [666 19.2 [202 0.251 [3353 1.57 [6666 0.522 [655 9.62 [2229 1.57 [5140 2.69 [7241 2.83 [1986 3.78 [292 6.62 [141 6.26 [1007 10.3 [7665 13.3 [2 100] [1190 0.419 [4929 4.91 [2 100] [2 90]] [2 100]]] [2 91]] [2 96]] [1640 2.67 [2 100] [5647 6.39 [2 100] [2 83]]]] [292 0.412 [4995 1.42 [228 3.82 [2 87] [2 100]] [2 100]] [2 100]]] [2 83]] [2 80]] [2 91]] [2 89]] [2 80]] [2 80]] [2 92]] [2 85]] [2 87]] [2 80]] [2 81]] [4833 0.515 [2 63] [2 100]]] [2 66]] [4159 0.655 [4154 3.41 [2 63] [2 100]] [2 100]]] [2 71]] [2 60]] [6816 1.29 [2 80] [2 100]]] [2 77]] [2 78]] [2 66]] [2 60]]] [248 2.16 [2 84] [25 83]]] [4 75]] [1 37]] [2 57]] [33 57]] [33 75]] [1 82]] [1 57]] [3441 2.13 [261 1.47 [2763 2.79 [33 59] [2 66]] [33 100]] [33 100]]] [1 98]] [248 39 [25 80] [25 100]]] [2536 0.497 [4 95] [4 83]]]] [6537 1.52 [2479 1.09 [2164 1.22 [6178 2.86 [29 0.245 [4765 4.69 [2185 2.05 [178 1.19 [4594 8.26 [957 2.73 [7392 0.732 [233 1.7 [6077 1.29 [4968 1.16 [4530 0.332 [4114 1.04 [7133 0.377 [573 2.79 [5843 0.457 [2526 10.7 [4279 0.762 [4 40] [1 25]] [1769 0.535 [791 30 [7343 5.45 [2760 4.93 [5299 1.93 [726 0.707 [5192 10 [4847 19.7 [5820 0.349 [2752 30.2 [7254 1.79 [328 4.03 [2676 0.492 [2567 0.762 [5345 2.18 [6363 5.05 [4 92] [4 60]] [4 100]] [4 100]] [4 100]] [4 46]] [4 100]] [4 60]] [4 100]] [4 75]] [4 42]] [4 100]] [4 44]] [4 66]] [4 33]] [4 54]] [4 46]]] [2 85]] [4 89]] [4 100]] [4 33]] [4 95]] [2 62]] [4154 1.42 [5660 1.3 [5239 2.38 [4 83] [4 100]] [4 100]] [4 100]]] [33 100]] [4 50]] [4 53]] [2 55]] [7149 0.527 [1239 11.1 [6068 4.96 [1253 2.18 [1000 0.861 [5625 4.13 [1047 3.27 [7314 3.11 [17 3.69 [438 0.276 [731 0.418 [4 97] [4 100]] [4 100]] [4 95]] [4 80]] [4 87]] [4 66]] [4 91]] [4 75]] [4 81]] [4 72]] [4 60]]] [2 54]] [5 45]] [2 77]] [25 100]] [4 52]] [2470 13.4 [1062 0.187 [4 85] [4 100]] [7032 5.57 [5192 0.366 [7324 1.06 [663 7.07 [1400 1.01 [5299 0.502 [7665 4.69 [4 96] [4 100]] [4 100]] [4 100]] [4 88]] [4 100]] [4 100]] [4 84]]]] [6538 1.75 [665 3.89 [286 2.12 [2 33] [2 100]] [2 44]] [6791 1.85 [5413 4.26 [2 62] [4 66]] [4 83]]]]] [6911 0.341 [5673 0.497 [5509 9.2 [6550 0.137 [4279 11.9 [6732 0.703 [5523 0.821 [1600 0.256 [4718 6.5 [988 0.774 [7009 0.655 [5892 1.68 [4928 2.09 [3990 0.38 [4485 0.716 [7701 2.95 [2434 1.1 [6199 26.3 [1580 2.39 [731 4.19 [4235 13.9 [312 6.29 [5447 5.89 [4799 3.22 [2608 5.81 [5034 0.997 [3562 0.897 [2846 3.96 [6524 2.31 [2902 1.69 [6581 0.507 [2636 1.47 [2199 2.57 [5110 2.88 [4061 1.26 [999 0.798 [4369 3.71 [7 23] [10 57]] [8 62]] [14 50]] [5 36]] [17 45]] [1078 28.1 [7 69] [17 50]]] [5316 4.55 [2259 4.34 [4061 2.51 [1919 1.07 [19 47] [17 50]] [19 60]] [17 41]] [17 66]]] [16 21]] [6529 1.72 [7 50] [7 100]]] [14 72]] [17 60]] [2826 2.84 [32 68] [14 85]]] [7 92]] [32 53]] [5447 10.6 [32 100] [32 87]]] [0 53]] [5 40]] [1451 0.671 [178 10.6 [1633 4.24 [4332 5.14 [3563 4.12 [1919 3.28 [1239 3.13 [17 41] [1011 1.85 [2829 3.97 [2826 3.71 [7 37] [17 33]] [19 54]] [17 50]]] [17 76]] [19 62]] [19 33]] [19 83]] [35 42]] [14 57]]] [17 85]] [7 58]] [14 100]] [31 100]] [38 85]] [8 81]] [32 100]] [17 60]] [5 25]] [17 1.82 [2753 0.858 [7512 12.9 [1429 42.4 [19 77] [0 27]] [7 88]] [19 63]] [35 45]]] [7 75]] [7 100]] [19 78]] [4997 0.754 [3515 0.431 [584 0.411 [5154 4.88 [3480 0.629 [6529 1.21 [7533 10.3 [221 0.797 [5907 1.59 [6311 1.63 [5566 1.83 [3377 0.756 [2470 4.5 [134 4.44 [5891 4.08 [7712 0.482 [5693 0.571 [7598 2.8 [6859 2.82 [4806 0.734 [1078 29.1 [2526 37.9 [1059 0.978 [2628 3.19 [17 48] [6584 6.97 [19 29] [17 75]]] [17 50]] [19 36]] [35 33]] [17 55]] [31 55]] [19 47]] [5693 7.84 [17 63] [17 40]]] [7192 3.37 [5197 0.617 [1239 0.675 [17 77] [2826 1.68 [17 100] [17 87]]] [19 50]] [17 40]]] [2591 3.64 [429 18.6 [17 81] [17 100]] [17 71]]] [7210 0.997 [1980 4.12 [17 54] [978 5.69 [17 27] [2 50]]] [5 37]]] [15 66]] [7 100]] [14 100]] [1980 0.588 [7 37] [12 41]]] [19 62]] [2 42]] [7 64]] [7 100]] [15 50]] [1769 3.87 [3014 0.632 [5692 6.28 [1888 0.739 [429 34 [6310 2.16 [17 37] [17 76]] [19 50]] [978 6.71 [38 50] [17 52]]] [2829 1.28 [7 40] [19 85]]] [19 86]] [38 57]]] [19 82]] [2752 17.5 [19 66] [4806 1.52 [19 62] [19 100]]]] [7 100]]] [32 33]] [3518 0.566 [3820 1.62 [2207 0.356 [7453 0.142 [3315 0.87 [429 19.3 [6550 4.45 [6732 0.657 [8 20] [3734 0.332 [17 73] [14 50]]] [6358 0.493 [6848 0.168 [2077 4.57 [6978 0.564 [7665 36.1 [896 11.4 [7533 0.79 [3579 5.55 [5142 1.08 [17 40] [17 100]] [19 90]] [17 75]] [5812 0.971 [19 69] [17 62]]] [19 58]] [17 71]] [17 100]] [19 44]] [35 62]]] [5729 6.54 [3858 1.64 [1253 1.45 [4130 0.957 [469 0.244 [7185 0.801 [5296 1.64 [7735 0.178 [141 0.642 [2849 12.5 [2939 10.9 [6557 1.13 [7722 9.71 [6310 10.7 [7210 2.42 [6554 2.67 [5154 1.17 [2829 0.994 [17 54] [38 80]] [19 36]] [19 46]] [17 80]] [17 100]] [14 45]] [17 50]] [5 71]] [17 66]] [17 100]] [2616 1.72 [17 100] [17 62]]] [19 71]] [7188 12.5 [6184 2.02 [6557 2.69 [1668 1.35 [6199 0.75 [7595 0.456 [6550 4.55 [17 53] [3008 2.4 [17 90] [17 100]]] [429 23.1 [17 83] [17 96]]] [17 100]] [17 77]] [17 44]] [17 80]] [17 47]]] [19 80]] [38 100]] [6977 0.413 [17 40] [19 66]]] [35 85]] [14 60]]] [5 100]] [17 90]] [17 100]] [2526 14.5 [19 83] [19 100]]] [19 96]]] [429 32.5 [2752 22.5 [3554 1.78 [5 63] [5 50]] [17 33]] [7 42]]] [724 0.693 [1883 2.29 [5520 0.962 [2913 0.457 [4457 0.268 [3516 0.986 [1745 4.03 [7708 0.142 [3964 2.47 [429 22.9 [4218 1.48 [647 1.28 [6413 3.38 [472 1.35 [19 55] [17 50]] [14 50]] [7 25]] [1151 1.74 [38 41] [19 40]]] [5154 4.92 [1239 4.4 [6310 6.84 [663 1.77 [5742 1.41 [7711 2.03 [3120 1.22 [4851 7.01 [17 45] [17 70]] [17 83]] [3008 10.1 [17 56] [17 92]]] [17 50]] [6514 5.45 [4218 0.478 [7068 0.91 [7381 3.4 [17 85] [17 62]] [38 46]] [17 60]] [19 45]]] [7 36]] [16 42]] [19 83]]] [17 76]] [2829 0.512 [17 50] [17 54]]] [38 50]] [19 93]] [5693 0.901 [38 50] [17 56]]] [429 17.5 [7 30] [7 83]]] [6358 2.93 [19 100] [19 85]]] [38 50]] [469 0.137 [5521 0.868 [5729 0.0664 [5953 1.71 [5673 2.48 [38 44] [4851 0.807 [17 43] [2636 0.569 [999 0.427 [19 61] [19 87]] [3905 7.59 [19 100] [19 88]]]]] [38 23]] [2829 0.378 [17 57] [38 77]]] [6240 0.218 [19 54] [19 100]]] [6584 0.137 [19 90] [19 100]]]]] [7735 0.735 [7526 2.17 [6413 0.313 [7689 0.156 [726 2.41 [17 36] [6 53]] [567 0.143 [6576 2.21 [6910 3.48 [695 2.15 [19 66] [5198 0.641 [17 54] [17 90]]] [19 42]] [3908 1.77 [19 78] [19 40]]] [5390 0.632 [2628 2.48 [19 66] [19 100]] [7722 3.32 [19 92] [17 53]]]]] [2939 0.971 [1783 0.762 [35 57] [5647 0.696 [17 38] [19 71]]] [38 52]]] [985 0.392 [1666 0.183 [19 54] [19 85]] [19 100]]] [144 0.817 [5154 1.23 [17 57] [19 58]] [3908 1.81 [649 0.423 [3732 3.14 [19 75] [19 88]] [17 37]] [19 100]]]]]] [6621 8.21 [5753 0.895 [7691 0.144 [6182 7.14 [1068 0.552 [5079 0.222 [6178 0.577 [25 77] [1003 0.913 [25 100] [25 85]]] [25 100]] [25 100]] [25 100]] [25 100]] [2586 0.929 [25 100] [25 77]]] [25 87]]] [208 3.76 [2570 10.9 [5267 6.76 [7241 2.22 [6860 0.443 [5198 9.92 [4184 3.1 [7742 2.92 [4339 9.31 [2902 2.3 [2259 4.55 [5198 1.98 [2526 18.5 [24 88] [24 100]] [24 100]] [7665 7.25 [24 100] [978 6.4 [24 100] [24 92]]]] [24 100]] [24 81]] [24 85]] [24 71]] [24 87]] [24 100]] [24 87]] [3640 2.63 [7520 6.02 [1429 18.2 [7712 0.736 [24 88] [24 66]] [24 100]] [24 85]] [19 50]]] [24 55]] [4491 2.02 [3636 6.57 [7378 1.34 [5427 1.93 [24 90] [24 100]] [24 100]] [19 58]] [19 55]]]] [312 8.95 [2986 3.67 [2763 16.7 [1089 6.67 [5192 4.87 [4929 11.9 [2676 14.3 [665 1.28 [5873 1.15 [7032 10.4 [6920 13.7 [7584 2.76 [5239 0.269 [6217 0.781 [4 85] [5818 2.4 [5692 0.49 [7365 0.821 [7363 1.04 [7327 7.94 [4 100] [4 98]] [4 100]] [4 100]] [4 100]] [4 95]]] [4 100]] [4 90]] [4 87]] [4 87]] [4 91]] [4 87]] [4 85]] [4 90]] [7169 0.11 [4 88] [4 100]]] [4 80]] [4 83]] [4959 2.95 [4 81] [4 100]]] [4 94]]] [7343 2.45 [7380 4.7 [7133 0.423 [7593 0.234 [5462 2.57 [1239 23.2 [221 0.224 [4154 0.37 [978 22.3 [4 92] [4 63]] [4 64]] [7742 3.35 [6982 5.35 [4 100] [4 87]] [4 100]]] [26 54]] [4 75]] [4 75]] [6074 0.268 [7324 0.726 [4 100] [4 71]] [4 100]]] [4 100]] [2417 2.33 [4 85] [4 62]]]] [3813 1.4 [6920 0.59 [1262 0.6 [5110 5.66 [695 15.8 [7677 1.48 [735 3.65 [7665 3.86 [5 72] [723 3.88 [17 1.1 [1072 0.271 [3313 0.655 [6708 1.17 [7512 27.6 [5155 0.401 [6230 4.02 [3999 1.93 [429 18.5 [19 41] [5 66]] [5 77]] [1011 3.42 [5 85] [5 95]]] [5 100]] [5 96]] [5 42]] [144 1.4 [1980 1.24 [7381 8.32 [5 100] [5 87]] [5 100]] [5 100]]] [5 100]] [6581 13.8 [5 100] [5 91]]] [5 71]]] [5 50]] [3220 0.451 [5 33] [5 100]]] [719 5.12 [5 38] [5 90]]] [8 60]] [19 45]] [5 62]] [5 50]]] [6074 0.184 [1633 0.226 [5904 0.237 [1492 0.0691 [7326 0.204 [6334 0.659 [4097 0.617 [6883 1.98 [7324 1.45 [7381 0.705 [5429 0.811 [5969 2.48 [429 9.87 [6242 2.93 [5 19] [5 85]] [7354 0.538 [2903 3.23 [4071 0.603 [7491 12.2 [1704 2.78 [6524 6.11 [6294 1.85 [7009 1.42 [5843 0.306 [5348 0.627 [3910 0.846 [2259 4.94 [434 1.86 [494 0.457 [7722 1.37 [5 25] [17 42]] [5 30]] [17 55]] [0 25]] [17 70]] [17 53]] [38 62]] [5 81]] [5 54]] [17 100]] [31 0.814 [6708 1.42 [5812 5.05 [126 1.74 [6395 9.8 [7534 1.29 [731 12.5 [17 78] [17 58]] [17 100]] [17 92]] [17 85]] [5412 7.72 [17 100] [17 84]]] [17 71]] [6544 5.44 [17 33] [2005 0.818 [5412 0.799 [17 92] [17 62]] [17 100]]]]] [12 75]] [5 87]] [5 36]] [5 36]]] [998 2.04 [17 77] [17 55]]] [1062 0.901 [3928 4.12 [5 50] [5 100]] [5 92]]] [5677 2.56 [1499 0.832 [6581 0.253 [17 46] [5605 1.09 [5851 0.882 [663 9.81 [2591 0.121 [5654 0.339 [7414 2.64 [1703 0.724 [7192 1.35 [7512 7.61 [17 81] [5753 0.484 [5812 3.1 [2752 24.2 [5 30] [5 100]] [5 57]] [5 40]]] [17 80]] [17 100]] [5693 1.08 [17 42] [17 100]]] [2570 3.2 [17 71] [17 100]]] [2573 10.4 [5192 0.313 [7566 2.07 [17 90] [17 85]] [17 100]] [17 78]]] [7722 2.41 [7333 0.457 [17 36] [14 50]] [738 0.803 [6591 5.18 [17 100] [23 1.47 [17 55] [17 90]]] [17 71]]]] [5647 6.03 [2588 3.96 [7566 2.16 [17 100] [17 85]] [17 85]] [17 66]]] [19 44]]] [5 64]] [38 57]]] [429 16.9 [4 42] [6581 2.63 [896 5.89 [2829 0.805 [5 95] [5 100]] [5 63]] [5 68]]]] [5 67]] [728 1.43 [5 57] [5 85]]] [731 2.86 [1128 2.44 [5 77] [5 100]] [2752 15.6 [5 90] [6576 3.54 [5 100] [5 90]]]]] [7722 6.94 [7520 2.8 [7563 5.08 [3972 0.886 [5 58] [3313 2.11 [5 78] [5 100]]] [2594 15.7 [5 30] [19 84]]] [5 100]] [2752 10.2 [7665 29.3 [5 85] [6977 3.14 [5 64] [5 50]]] [5647 8.23 [7324 6.91 [5 100] [5 87]] [5 100]]]]] [6866 0.183 [3367 0.511 [7324 4.95 [8 83] [5 100]] [5 100]] [7354 2.46 [5 100] [5 80]]]] [1078 13.6 [2526 5.86 [19 52] [3554 0.457 [5297 0.704 [6732 1.32 [663 7.53 [5 42] [19 70]] [19 66]] [19 100]] [19 100]]] [19 50]]] [6910 0.161 [5390 0.186 [2570 0.232 [2829 0.419 [17 70] [17 33]] [19 100]] [19 100]] [2902 0.806 [19 100] [19 83]]]] [6708 0.926 [2826 0.31 [5820 0.275 [17 64] [2 50]] [5521 0.294 [5641 0.446 [7381 6.76 [5856 1.26 [5340 0.351 [6581 0.81 [17 42] [4851 4.35 [1429 88.3 [6729 0.741 [1557 0.102 [4956 0.73 [5838 0.486 [7251 0.266 [6313 0.212 [2841 0.404 [2826 10.6 [1073 2.34 [429 22 [17 100] [5413 2.86 [17 100] [17 88]]] [5887 0.514 [17 87] [17 100]]] [17 84]] [17 100]] [17 100]] [17 100]] [17 75]] [17 100]] [17 100]] [17 62]] [17 80]] [2763 4.98 [2752 9.6 [17 83] [17 93]] [17 44]]]] [17 57]] [17 71]] [2939 0.759 [5157 0.631 [1919 5.06 [6548 1.18 [6413 0.46 [3915 2.44 [17 88] [17 63]] [17 91]] [695 6.02 [17 83] [17 100]]] [12 28]] [17 100]] [17 83]]] [4533 0.446 [6227 0.236 [17 45] [17 100]] [19 55]]] [17 50]]] [19 52]]]] [2564 0.302 [6982 0.126 [931 3.02 [4630 3.16 [1755 0.589 [2939 17.7 [6935 0.447 [7461 4.22 [4225 5.38 [1989 1.57 [6989 0.112 [2576 0.717 [695 0.763 [2 83] [2 71]] [2 100]] [1072 11.2 [5449 13.4 [7742 8.16 [4772 2.09 [6540 0.171 [7392 0.839 [6197 1.92 [5353 1.1 [4768 3.93 [6989 3.92 [2 100] [2 98]] [573 3.9 [2 100] [2 87]]] [1429 10.3 [1059 1.25 [896 2.41 [2 66] [2 100]] [2 100]] [2 100]]] [2 85]] [1072 1.39 [6184 7.45 [2 100] [2 80]] [2 87]]] [2 100]] [2 88]] [2 87]] [2 88]] [2 80]]] [2 71]] [2 83]] [2 81]] [6074 0.726 [2 75] [2 100]]] [2 89]] [2 62]] [2 50]] [2 71]] [144 1.62 [2023 0.735 [2574 1.81 [4 100] [4 91]] [4 57]] [2 57]]] [5197 0.185 [978 15.5 [6074 0.667 [2 50] [2 100]] [2 66]] [2 55]]]] [4611 3.23 [2530 0.392 [2597 2.13 [5270 4.26 [326 2.09 [2752 2.92 [5063 0.998 [5403 4.7 [3820 4.07 [2612 2.29 [2259 21.9 [6184 10 [6230 12.2 [7008 1.04 [968 3.6 [6524 5.65 [2526 16.9 [5110 4.97 [6749 2.44 [25 26] [35 100]] [3 42]] [1888 2.62 [25 55] [31 30]]] [25 96]] [35 85]] [25 100]] [0 81]] [6184 19.2 [25 95] [25 100]]] [23 4.32 [31 22] [21 60]]] [0 73]] [26 60]] [6317 2.11 [2628 2.44 [31 92] [31 100]] [31 100]]] [31 100]] [6364 0.579 [7308 1.53 [6471 1.95 [6178 0.891 [2580 1.73 [3424 12.1 [1888 2.72 [429 22.7 [2199 2.64 [1783 15.3 [2759 2.76 [7008 1.24 [7516 1.92 [25 44] [26 90]] [25 100]] [18 25]] [1980 2.96 [25 86] [25 100]]] [25 100]] [23 18]] [5647 14.3 [5605 1.56 [1239 4.94 [6199 3.83 [5692 1.66 [2 28] [17 25]] [5 62]] [17 55]] [24 33]] [4 72]]] [26 80]] [25 100]] [178 0.379 [7665 0.662 [1081 6.49 [2580 9.92 [25 100] [1995 4.33 [25 97] [25 100]]] [25 100]] [25 100]] [25 100]]] [26 85]] [31 100]] [6363 4.63 [7691 0.555 [6949 0.803 [25 95] [25 100]] [25 100]] [25 100]]]] [31 100]] [2299 0.451 [7512 9.43 [2251 1.59 [31 100] [31 87]] [31 50]] [31 80]]] [31 82]] [1094 3.97 [178 3.94 [2759 5.12 [6177 1.56 [25 90] [25 100]] [25 71]] [2915 0.759 [5695 4.41 [978 15.7 [25 100] [25 87]] [25 93]] [25 100]]] [25 75]]] [26 32]]] [2259 13.3 [2752 21.4 [4696 0.863 [2902 0.41 [5229 0.585 [3016 2.17 [3830 0.706 [3985 0.961 [5219 4.98 [3069 13 [4474 4.05 [6178 1.59 [4959 0.876 [7246 0.458 [5420 0.5 [2562 4.92 [6581 3.08 [1400 20.4 [5662 2.19 [2657 2.73 [4690 1.13 [5110 4.72 [23 15] [33 57]] [2752 1.13 [8 44] [23 4.19 [4 75] [4 88]]]] [4 92]] [2 66]] [10 97]] [2470 14.7 [929 0.507 [17 37] [17 100]] [11 100]]] [6342 7.36 [5192 5.8 [0 34] [22 36]] [0 71]]] [23 81]] [10 100]] [4 97]] [25 100]] [0 100]] [8 100]] [6575 8.36 [7742 4.76 [6406 4.42 [6848 3.5 [4320 1.74 [4876 13.4 [7210 0.395 [1426 3.65 [5108 2.86 [2572 8.21 [5812 3.6 [673 0.669 [6203 3.3 [929 9.71 [2603 0.87 [429 6.85 [8 87] [3760 4.64 [4601 1.51 [4414 11.7 [7185 0.739 [3369 1.29 [1089 19.6 [3952 1.18 [978 1.24 [8 88] [791 12.2 [8 98] [2562 2.6 [5211 12.2 [8 80] [8 60]] [8 100]]]] [8 100]] [8 75]] [8 100]] [8 77]] [8 57]] [8 100]] [8 83]]] [8 100]] [8 80]] [22 60]] [8 75]] [2 80]] [8 75]] [8 66]] [10 100]] [4302 0.541 [23 0.829 [6375 8.07 [4414 0.379 [3492 0.303 [791 1.15 [4154 1.95 [1899 1.33 [5219 11.6 [8 83] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]] [8 83]] [8 71]] [8 100]]] [8 70]] [8 62]] [35 100]] [8 58]] [2 44]] [8 57]]] [0 100]] [8 100]] [3652 2.02 [24 94] [24 100]]] [2628 0.75 [5219 4.37 [7431 0.699 [1764 2.89 [0 78] [5420 5.31 [0 100] [0 87]]] [0 100]] [35 57]] [0 80]]] [1995 5.75 [4832 0.994 [1190 2.01 [4960 1.55 [2004 0.24 [1023 0.888 [5225 3.52 [1906 0.992 [1888 1.71 [939 2.51 [5692 8.95 [4 34] [10 66]] [10 37]] [4 61]] [2 28]] [22 68]] [17 42]] [23 100]] [4 100]] [2 52]] [2526 17.5 [4 57] [2 84]]] [10 69]]] [5218 0.282 [5219 3.71 [0 84] [8 100]] [8 100]]] [2589 2.89 [7176 1.97 [7382 3.85 [6230 2.11 [7665 4.51 [2470 1.47 [4663 20.2 [2201 5.26 [429 6.18 [4154 3 [5211 30.8 [1078 1.93 [8 35] [23 58]] [8 68]] [23 55]] [2562 0.431 [5211 32.3 [6970 3.2 [134 1.04 [2628 9.09 [1769 3.29 [2005 11.3 [1899 0.654 [1226 2.49 [1197 0.967 [1062 2.22 [978 0.829 [23 70] [2793 5.79 [23 76] [23 100]]] [23 96]] [23 100]] [23 100]] [5225 11.9 [23 95] [23 80]]] [23 72]] [23 57]] [23 60]] [19 28]] [23 66]] [8 69]] [6375 3.21 [6191 10.6 [5192 0.236 [791 1.33 [23 78] [6191 1.48 [2905 3.49 [859 0.466 [7428 0.741 [2844 16.6 [2259 8.57 [1913 1.33 [7507 0.717 [2143 1.2 [23 84] [23 100]] [23 100]] [23 100]] [23 100]] [23 71]] [23 100]] [23 100]] [23 66]] [23 100]]] [7453 0.589 [5911 15.3 [5887 0.761 [286 1.23 [2571 1.28 [23 96] [23 100]] [23 100]] [23 100]] [23 90]] [23 100]]] [23 72]] [23 62]]]] [22 54]] [4414 24.6 [22 54] [23 80]]] [11 85]] [2 27]] [2259 3.37 [5693 1.08 [30 22] [17 53]] [23 50]]] [24 100]] [1993 3.63 [328 6.63 [1079 1.33 [6260 0.352 [1 0.189 [5225 1.18 [22 36] [5192 0.709 [22 83] [22 100]]] [11 77]] [22 66]] [22 100]] [8 80]] [23 60]]] [8 100]]] [7554 0.953 [7449 6.04 [605 2.52 [2550 0.371 [5857 1.34 [2526 30.9 [3957 0.489 [968 0.202 [1980 13 [2488 1.56 [286 8.09 [7578 1.31 [896 6.17 [791 10.5 [7695 1.39 [978 17.7 [8 28] [8 76]] [30 40]] [6285 9.69 [5467 2.02 [2902 1.46 [772 2.15 [5574 2.97 [2541 2.37 [5753 1.93 [1899 9.28 [8 24] [23 60]] [22 28]] [24 100]] [24 100]] [24 66]] [22 66]] [10 100]] [24 100]]] [18 40]] [10 100]] [23 80]] [8 65]] [5716 1.04 [1253 1.23 [23 83] [23 93]] [23 100]]] [8 93]] [8 100]] [5969 1.96 [3616 7.87 [1389 7.25 [873 3.86 [2259 21.2 [6401 2.54 [6670 2.75 [5420 2.3 [5692 1.99 [6413 2.59 [978 2.62 [1980 7.46 [8 51] [23 70]] [8 91]] [0 100]] [8 93]] [23 50]] [0 100]] [8 100]] [2804 0.228 [3243 6.05 [2334 1.78 [2394 2.13 [491 3.11 [2583 3.45 [1998 3.53 [3492 0.861 [968 3.45 [2316 3.27 [2259 69.7 [7665 4.53 [5828 15.5 [4072 5.15 [2488 36.7 [8 73] [0 57]] [8 100]] [0 55]] [6 28]] [8 88]] [8 100]] [8 100]] [8 91]] [0 53]] [0 100]] [8 100]] [0 100]] [8 100]] [0 53]] [2488 1.37 [7512 12.5 [8 100] [8 80]] [8 100]]]] [0 100]] [1640 5.05 [24 91] [24 100]]] [23 66]] [0 50]]] [0 100]] [3576 0.844 [3985 1.04 [7354 0.257 [3182 4.46 [2492 0.358 [4789 1.89 [6050 1.17 [3495 1.21 [5860 0.826 [2804 0.766 [5110 7.75 [2526 80.1 [8 84] [8 66]] [8 100]] [8 100]] [0 100]] [8 100]] [0 100]] [8 100]] [0 75]] [0 62]] [6581 0.118 [2426 9.11 [6560 0.0901 [5224 0.745 [5114 0.603 [8 99] [8 100]] [8 100]] [8 100]] [429 19.1 [8 96] [8 100]]] [8 100]]] [0 100]] [0 72]]] [24 95]] [2752 25 [8 67] [1068 1.33 [23 88] [23 100]]]] [10 100]]]]] [7624 0.873 [4712 1.05 [2306 1.62 [5122 0.4 [4457 3.65 [2902 0.757 [1911 2.41 [4188 0.337 [1679 3.03 [5110 8.77 [1786 0.333 [2199 5.17 [7329 1.8 [2913 21.2 [4862 0.517 [5596 8.84 [1078 31.1 [2058 0.34 [4851 5.08 [7118 5.54 [148 47.2 [4233 0.458 [4557 0.421 [2260 6.42 [5205 24 [4861 1.29 [6724 15.7 [5692 5.26 [6920 0.907 [5647 13.2 [4611 0.768 [2470 4.37 [4292 3.18 [144 0.756 [5585 1.49 [4948 1.19 [3381 18.5 [4430 3.76 [6091 22.6 [114 1.86 [590 1.06 [4218 20.1 [126 1.33 [616 2.54 [23 14 [5007 22.3 [2259 13.4 [774 4.02 [3 92] [3 100]] [221 1.74 [2993 4.48 [1899 4.36 [3 99] [3 100]] [3 100]] [3 100]]] [3 87]] [3 100]] [3 100]] [3 100]] [3 83]] [3 100]] [3 100]] [3 87]] [3 100]] [3 81]] [3 100]] [3 100]] [3 100]] [3 83]] [30 60]] [3 100]] [3 60]] [3 100]] [3 91]] [3 85]] [3 100]] [3 85]] [3 77]] [3 88]] [3 100]] [3 68]] [3 77]] [3 63]] [3 75]] [3 60]] [3 76]] [3 100]] [5047 1.27 [5211 2.16 [2913 68.6 [3 68] [30 72]] [30 100]] [3 100]]] [30 60]] [3 100]] [3 73]] [4154 7.07 [10 42] [3 83]]] [30 70]] [3 100]] [3 57]] [30 63]] [30 75]] [30 88]] [10 50]] [30 83]] [30 93]]] [7381 0.519 [7693 1.72 [2892 0.891 [831 2.39 [1081 0.99 [3389 1.73 [134 0.855 [7340 1.29 [4602 1.39 [6959 0.351 [1533 3.36 [6761 8.2 [7722 1.87 [6380 0.478 [2253 2.33 [980 2.18 [1813 1.01 [5034 1.79 [2259 3.86 [7665 1.13 [6727 7.42 [6375 9.84 [1587 1.86 [3424 12.6 [3435 48.6 [3851 26 [6445 7.97 [2939 38.5 [1783 28.8 [3045 51.4 [144 0.703 [3629 3.02 [3724 4 [312 17.4 [3905 8.05 [1104 3.84 [731 9.28 [1084 14.1 [4876 29.2 [6616 8.56 [5851 4.82 [3438 2.18 [1913 3.61 [5873 6.13 [4279 62.5 [6727 1.35 [4764 2.19 [3273 5.65 [7255 30.4 [3538 0.873 [7241 1.31 [1783 4.82 [3134 21 [3045 17.3 [1911 0.911 [939 17 [3045 5.28 [5322 8.89 [2225 2.92 [5962 1.07 [6353 14.9 [3272 0.87 [4326 4.35 [3103 9.62 [3852 12.9 [3447 11.5 [3944 19.5 [35 89] [35 55]] [35 97]] [35 85]] [5673 28.6 [35 96] [35 83]]] [35 100]] [35 85]] [1031 7.04 [35 53] [35 83]]] [35 83]] [35 50]] [35 87]] [1899 5.78 [35 100] [35 71]]] [35 83]] [35 100]] [4154 14.8 [35 89] [35 87]]] [35 83]] [3045 9.87 [35 52] [35 50]]] [35 70]] [17 0.8 [3850 3.76 [35 95] [35 100]] [35 100]]] [17 44]] [3457 1.03 [1980 2.39 [35 98] [35 100]] [35 100]]] [4768 0.741 [35 97] [35 100]]] [35 66]] [35 80]] [35 71]] [35 66]] [35 100]] [35 80]] [35 50]] [30 50]] [8 42]] [26 50]] [35 76]] [35 30]] [35 60]] [35 55]] [35 57]] [35 53]] [35 66]] [35 30]] [35 60]] [26 25]] [35 50]] [13 44]] [35 61]] [35 53]] [35 53]] [26 42]] [35 42]] [1896 0.246 [2711 5.03 [5753 0.805 [2178 7.83 [1888 8.49 [489 2.92 [5692 0.963 [2276 2.65 [377 1.29 [6199 2.95 [7411 0.732 [35 32] [3 50]] [1899 1.49 [13 35] [30 28]]] [30 52]] [35 77]] [28 40]] [3849 7.54 [35 80] [35 95]]] [26 36]] [21 71]] [30 35]] [37 45]] [774 1.36 [16 50] [37 62]]]] [14 40]] [7 22]] [26 85]] [30 81]] [33 21]] [144 3.36 [5 39] [19 33]]] [980 1.93 [26 36] [26 88]]] [8 62]] [13 42]] [26 69]] [6091 1.27 [6955 9.62 [2846 2.09 [32 54] [32 100]] [32 62]] [32 100]]] [5412 3.12 [3332 16.1 [2826 3.6 [4092 2.3 [7255 1.69 [26 37] [35 37]] [26 77]] [5 47]] [35 62]] [5 33]]] [3272 0.328 [3538 1.18 [2947 1.18 [7062 3.2 [35 91] [35 62]] [35 75]] [35 96]] [35 100]]] [26 67]] [35 90]] [23 10.5 [673 6.49 [18 37] [6727 10.2 [26 100] [26 83]]] [33 42]]] [6131 0.99 [26 67] [19 66]]] [6584 0.389 [5 47] [7169 0.652 [35 50] [35 71]]]]] [4767 2.25 [3640 0.578 [1 3.82 [3905 0.152 [4560 2.38 [5866 14.1 [663 7.18 [5211 10.7 [7199 0.952 [2792 8.53 [208 9.69 [6363 0.446 [6286 45.7 [3642 1.53 [7241 1.99 [4189 0.436 [5812 10.9 [4583 1.82 [2760 12.1 [6764 4.02 [5675 11.9 [7152 3.07 [6406 13.9 [4601 1.71 [7530 7.94 [1025 38.8 [2178 0.447 [4214 17.4 [5779 17.2 [4818 0.856 [791 8.25 [6338 2.3 [2792 3.52 [6853 25 [1911 8.57 [6199 2.26 [1034 0.38 [7255 3.4 [4533 0.998 [5969 0.835 [4340 0.559 [5637 9.5 [3637 5.66 [3662 0.885 [6374 1.64 [5792 1.26 [24 90] [24 100]] [24 100]] [772 4.92 [24 100] [24 85]]] [24 87]] [24 85]] [24 100]] [24 100]] [24 100]] [24 77]] [24 80]] [24 85]] [24 83]] [24 50]] [24 83]] [19 83]] [6373 1.2 [605 30.1 [6732 3.85 [5675 6.26 [1035 0.581 [1047 12.2 [178 0.125 [24 99] [24 100]] [1025 11.6 [24 100] [24 95]]] [24 100]] [24 88]] [2453 2.85 [24 78] [24 100]]] [24 91]] [24 94]]] [2777 0.477 [3648 5.26 [24 100] [24 92]] [24 100]]] [24 62]] [24 78]] [2795 4.55 [24 90] [24 70]]] [24 84]] [24 83]] [24 82]] [24 66]] [24 60]] [24 50]] [24 45]] [24 66]] [24 63]] [24 100]] [631 11.1 [3022 0.236 [7535 2.79 [3637 4.68 [429 0.835 [4145 2.45 [4279 7.81 [24 100] [24 50]] [24 66]] [3629 0.219 [6199 6.62 [2341 0.47 [429 30.1 [24 100] [24 85]] [24 100]] [24 83]] [24 100]]] [24 85]] [773 3.16 [5647 5.33 [2760 1.95 [2763 2.96 [655 0.408 [5267 6.81 [24 92] [24 87]] [3650 0.48 [7067 0.73 [791 10.5 [24 83] [24 92]] [24 100]] [24 100]]] [24 80]] [24 71]] [24 80]] [24 80]]] [24 100]] [24 69]]] [24 64]] [7024 1.74 [3008 10.8 [5851 4.04 [2457 2.24 [5662 1.08 [1919 1.37 [3642 7.46 [5719 1.41 [4338 16.3 [6337 3.2 [24 81] [24 53]] [3652 0.904 [24 100] [6335 0.338 [5007 0.849 [24 100] [24 57]] [24 88]]]] [24 75]] [24 63]] [24 100]] [24 100]] [24 100]] [24 52]] [24 53]] [38 80]]] [19 54]] [35 50]] [2411 4.81 [2518 12.3 [6337 9.65 [5211 0.607 [3665 4.74 [4279 10.2 [1240 4.91 [24 88] [24 50]] [24 95]] [16 40]] [24 100]] [6337 18.7 [24 68] [19 50]]] [19 60]] [19 61]]] [24 63]] [24 55]] [2456 2.15 [24 73] [2628 20.6 [1429 17 [24 89] [24 57]] [24 72]]]] [36 83]] [38 60]] [19 81]] [36 56]] [5198 1.1 [36 54] [24 75]]] [4530 1.14 [2932 0.785 [5462 1.27 [5792 1.75 [5654 1.14 [6741 0.431 [5641 5.15 [655 0.362 [24 77] [5728 1.31 [7535 0.611 [4340 0.485 [24 100] [24 81]] [24 100]] [24 70]]] [19 60]] [24 60]] [19 50]] [7381 0.717 [5413 1.99 [24 71] [24 100]] [5662 0.509 [7512 10.8 [19 38] [24 87]] [19 77]]]] [19 65]] [6336 0.6 [19 71] [24 77]]] [19 80]]] [3652 1.21 [24 60] [5789 0.608 [1025 14.4 [19 71] [24 50]] [19 84]]]]] [2709 0.0553 [6207 0.0361 [2849 17.9 [7731 0.725 [7618 1.12 [6355 0.741 [2620 0.539 [794 0.291 [2826 0.728 [5067 0.0468 [7206 0.476 [1769 1.45 [6732 0.596 [5598 0.876 [4895 2.52 [6490 0.661 [2368 16.6 [5716 1.1 [2262 12.1 [7101 20 [1376 6.81 [2939 4.12 [1239 18.8 [6 63] [5721 2.72 [1303 0.8 [5568 0.493 [2262 10.6 [6100 0.319 [5931 5.42 [221 23.3 [2387 2.42 [2301 6.08 [7421 0.292 [1974 2.26 [6098 11 [791 1.85 [6 50] [6 55]] [2579 9.21 [6 75] [6 93]]] [6 100]] [7667 5.25 [429 1.46 [6 94] [6 100]] [6 83]]] [6 100]] [6 83]] [6 66]] [6 58]] [5409 8.38 [4891 22.8 [7603 11.4 [7153 0.319 [1276 1.36 [6422 6.78 [6 100] [7038 2.04 [6 95] [6 100]]] [6 100]] [6 100]] [6 77]] [6 83]] [6 86]]] [6 55]] [6 72]] [6 78]] [6 63]]] [2283 6.51 [7667 2.97 [7512 7.83 [1429 13 [5593 0.382 [6 60] [6 88]] [6 41]] [6 94]] [4725 3.26 [16 75] [6 62]]] [6 30]]] [6 57]] [6 53]] [5396 4.15 [6 100] [6 87]]] [7301 4.52 [7512 4.64 [6 66] [7574 0.557 [6 89] [6 100]]] [6 100]]] [6 50]] [20 44]] [6 44]] [1239 29.6 [2461 6.01 [5580 1.91 [7512 5.25 [1364 1.8 [6 74] [6 38]] [1059 7.7 [6690 11.2 [6514 13.1 [7545 0.574 [7549 9.62 [1940 1.16 [2616 8.77 [6747 1.87 [3020 1.52 [6749 2.03 [1429 8.69 [2259 70.7 [6 100] [6 83]] [16 50]] [6 100]] [6 100]] [6 62]] [2279 4.13 [6515 3.19 [4822 0.588 [4712 0.47 [300 7.56 [2569 12.8 [6 78] [6098 16.7 [6 100] [6 87]]] [6 75]] [6749 0.623 [6 87] [6 100]]] [6 100]] [2030 1.23 [6 94] [6 100]]] [2616 14.6 [6 84] [6 71]]]] [6 75]] [6 44]] [7040 0.29 [6934 0.855 [1239 18.8 [6 100] [6 71]] [6 100]] [6 100]]] [6 100]] [6 53]] [6 100]]] [6 57]] [6 50]] [7149 4.84 [5167 13.8 [2223 9.59 [6100 10.3 [1289 1.26 [0 7.79 [2599 4.2 [4713 9.07 [7040 6.21 [6501 0.713 [7582 0.649 [2280 0.496 [2292 10.4 [2143 0.22 [6199 3.65 [5797 0.243 [4820 9.82 [6761 1.11 [2275 0.64 [5721 3.65 [2533 1.81 [6 95] [6 100]] [6 100]] [6 100]] [6 87]] [6 70]] [6 100]] [6 83]] [6 100]] [6 87]] [7040 1.22 [5408 9.23 [2143 1.08 [4737 2.53 [6 100] [6 80]] [6 88]] [6 66]] [6 57]]] [6100 4.95 [6 100] [6 95]]] [6 80]] [6 83]] [6 86]] [6 60]] [2528 12.4 [6 75] [6 66]]] [6 100]] [6 83]] [2579 1.65 [6 84] [6 70]]] [6 75]] [1363 4.61 [6 90] [16 77]]]]] [23 33]] [6 50]] [2955 14.2 [4727 0.274 [7574 1.51 [6 69] [6 50]] [16 70]] [16 87]]] [16 50]] [7722 0.52 [16 55] [7 33]]] [29 70]] [16 64]] [7 80]] [20 87]] [429 15.9 [18 50] [18 37]]] [1062 0.128 [7122 6.46 [5102 2.23 [4050 1.63 [7665 0.963 [5681 11.2 [2259 40.1 [5104 1.55 [5637 0.575 [16 60] [16 33]] [16 73]] [6 43]] [5673 16.4 [18 54] [6 30]]] [3239 0.597 [2079 2.07 [1919 2.46 [6 66] [16 50]] [16 50]] [6 77]]] [16 100]] [6 63]] [6920 0.147 [16 57] [16 100]]] [16 80]]] [1646 2.47 [2187 0.357 [2850 3.12 [7488 4.11 [6876 1.29 [1078 1.09 [2939 27.8 [7423 0.321 [7512 1.06 [18 64] [16 42]] [16 66]] [5681 1.23 [7 55] [16 70]]] [1820 1.68 [5397 0.339 [1078 8.73 [5963 0.194 [16 42] [16 66]] [18 37]] [6 70]] [6 66]]] [6 71]] [38 100]] [16 94]] [16 100]] [5732 6.29 [7 85] [7 100]]]] [5480 0.966 [4712 1.43 [7281 3.27 [6424 1.35 [7260 0.373 [190 2.29 [2406 0.381 [6 62] [16 84]] [5100 0.326 [16 55] [1239 35.9 [16 94] [16 66]]]] [1364 0.78 [5632 2.32 [6 50] [16 90]] [6 54]]] [4725 1.34 [16 50] [6422 2.4 [6 81] [16 60]]]] [187 10.6 [6 71] [16 55]]] [2619 0.383 [6 95] [6 37]]] [26 72]]]] [5240 0.585 [221 3.86 [1680 0.0926 [3798 0.444 [6475 0.357 [7497 1.12 [4279 1.54 [7156 15.6 [5154 6.54 [2143 1.46 [1391 0.62 [22 76] [22 100]] [22 100]] [22 37]] [24 55]] [22 45]] [6821 0.695 [22 98] [22 100]]] [22 100]] [19 37]] [22 100]] [28 37]] [4 100]]] [5366 0.27 [1420 0.277 [3553 0.0542 [2531 0.261 [7722 0.38 [2748 1.12 [5995 0.739 [5728 0.077 [4603 0.0457 [5749 0.431 [2755 2.9 [3870 0.124 [978 0.766 [1888 2.31 [4784 0.126 [5130 1.02 [2461 0.354 [7734 2.06 [429 5.76 [7421 2.05 [2737 2.67 [2526 1.71 [6508 1.06 [5336 1.54 [5194 0.243 [2436 4.83 [6952 2.48 [6531 2.18 [5462 2.06 [5480 5.19 [5122 1.81 [3342 5.5 [1116 2.19 [7225 2.51 [1679 3.07 [5897 1.07 [2831 1.18 [7665 16.2 [4768 1.12 [3449 10.4 [4851 4.88 [2891 1.87 [2470 1.14 [3444 6.78 [5154 10.9 [2951 1.11 [6524 0.918 [2753 21.9 [3424 3.77 [2488 5.38 [6015 7.12 [7185 18.2 [2004 1.36 [4895 24.5 [3667 0.753 [112 26.8 [6363 2.39 [4565 11.7 [6715 0.673 [384 4.17 [1429 10.7 [4231 1.33 [2752 16.1 [27 24] [23 18]] [10 62]] [4541 2.44 [403 2.76 [1986 0.0546 [2826 2.26 [4159 1.63 [5900 0.761 [28 27] [7 50]] [28 40]] [14 81]] [28 27]] [30 38]] [18 100]]] [23 22]] [18 45]] [16 55]] [28 71]] [22 54]] [35 83]] [28 69]] [28 55]] [26 80]] [12 75]] [8 100]] [23 50]] [27 38]] [1783 2.57 [28 65] [22 66]]] [7123 4.97 [6848 0.547 [377 0.668 [16 30] [26 57]] [16 57]] [16 60]]] [27 53]] [35 81]] [26 41]] [26 93]] [16 27]] [35 100]] [29 47]] [791 2.13 [14 60] [14 33]]] [22 72]] [30 58]] [30 100]] [22 100]] [1239 1.81 [328 5.4 [30 95] [30 60]] [30 100]]] [14 48]] [30 100]] [7187 6.17 [4946 2.76 [389 10.6 [18 25] [26 50]] [18 100]] [26 94]]] [28 55]] [22 48]] [17 90]] [6 60]] [28 100]] [6 88]] [7 100]] [5336 0.894 [178 1.08 [1660 2.88 [383 10.3 [7206 0.36 [5219 6.49 [384 10.3 [5634 2.95 [3207 1.11 [7491 0.32 [3759 3.7 [7176 1.31 [1813 5.95 [26 14] [25 75]] [8 33]] [7 100]] [6 87]] [6 62]] [7 100]] [7540 13.9 [2530 12.5 [1239 21.3 [25 36] [23 36]] [26 83]] [6 100]]] [8 100]] [2691 0.18 [16 81] [6 62]]] [8 78]] [6 92]] [6178 3.03 [1429 11.2 [25 55] [7 66]] [25 92]]] [7149 0.722 [6 90] [6 100]]]] [5412 7.43 [6103 1.19 [38 76] [38 100]] [38 70]]] [2549 1.57 [7038 1.36 [6 90] [2978 0.474 [2611 1.68 [6 38] [6 75]] [16 28]]] [2370 4.01 [5597 11 [6 94] [16 53]] [6 100]]]] [5289 0.183 [5034 0.0906 [2764 0.692 [7357 2.56 [1400 0.215 [3041 2.89 [939 13.4 [1628 0.73 [4486 0.722 [5225 0.747 [6117 1.36 [7512 5.63 [2802 0.395 [3003 1.14 [619 0.498 [404 0.736 [2526 7.22 [6363 2.45 [1936 11.9 [976 1.31 [5480 3.13 [5566 3.41 [5730 0.588 [1391 2.58 [7241 1.3 [794 2.15 [4769 1.19 [4158 0.345 [6498 4.19 [3103 2.06 [3633 1.66 [6656 2.35 [6850 3.23 [418 2.86 [4067 5.32 [927 5.36 [1509 6.17 [4630 1.26 [2713 3.6 [2393 1.67 [2913 2.42 [5107 3.47 [1980 18.1 [384 3.76 [630 2.49 [6260 7.55 [6206 1.07 [7324 7.93 [850 0.838 [695 1.62 [6711 13.8 [5322 0.885 [286 8.93 [5194 1.87 [6529 9.95 [2251 6.7 [4497 5.92 [1630 7.84 [3849 2.54 [1742 2.04 [4011 1.39 [2707 3.98 [1911 0.851 [23 0.967 [394 16.7 [1170 4.2 [1078 28.8 [1783 16.6 [380 22.7 [28 26] [8 44]] [7 25]] [35 30]] [27 28]] [28 46]] [29 26]] [28 76]] [2259 0.376 [16 55] [17 33]]] [28 86]] [11 40]] [35 65]] [28 50]] [28 70]] [10 71]] [22 88]] [28 100]] [28 31]] [28 18]] [22 83]] [28 64]] [35 44]] [23 57]] [28 93]] [22 54]] [35 88]] [392 22.1 [23 41] [35 85]]] [23 30]] [28 100]] [30 50]] [28 100]] [21 23]] [4279 1.04 [25 22] [18 36]]] [28 100]] [1 66]] [35 78]] [28 83]] [38 100]] [29 90]] [35 92]] [35 93]] [25 100]] [695 0.978 [28 57] [28 100]]] [29 82]] [1429 40.1 [28 77] [28 92]]] [10 29]] [4611 1.28 [22 68] [35 85]]] [11 100]] [14 100]] [883 0.273 [1078 28.6 [1391 1.42 [1429 26.5 [22 53] [18 69]] [377 4.46 [22 100] [22 83]]] [23 29]] [22 40]]] [27 100]] [30 56]] [28 64]] [2628 10 [1919 1.05 [6353 0.208 [8 54] [23 83]] [2526 35.4 [23 42] [8 40]]] [8 53]]] [1980 10.5 [906 2.15 [28 92] [28 83]] [28 77]]] [1078 21.8 [28 90] [28 75]]] [27 100]] [5480 1.47 [6653 0.424 [29 73] [29 75]] [29 87]]] [5693 20 [7101 3.36 [7259 4.52 [6040 0.189 [5345 7.88 [5692 9.74 [6310 0.651 [6531 1.95 [7601 8.73 [5322 3.55 [23 14.6 [18 20] [13 46]] [30 63]] [18 80]] [7 50]] [5 27]] [16 25]] [18 63]] [18 60]] [14 88]] [22 62]] [7 63]]] [28 100]] [22 58]] [7199 0.213 [1078 12.6 [22 50] [22 100]] [22 100]]] [29 100]] [1159 1.44 [2939 0.525 [7623 1.93 [27 36] [27 85]] [27 100]] [27 100]]] [3953 0.95 [35 68] [35 100]]] [112 4.02 [976 1.14 [269 1.11 [811 2.33 [392 16.1 [26 23] [26 72]] [10 42]] [26 76]] [27 100]] [28 60]]] [35 80]] [859 0.327 [6732 0.686 [930 1.75 [1187 0.904 [2470 1.27 [2407 1.09 [2897 2.25 [504 4.55 [3332 0.342 [286 3.8 [5662 1.32 [28 27] [22 60]] [5420 3.07 [23 31] [23 100]]] [35 61]] [29 45]] [1062 3.48 [28 70] [28 33]]] [23 56]] [5231 0.318 [11 86] [11 100]]] [11 66]] [23 100]] [22 44]] [663 0.327 [859 3.31 [4781 0.231 [22 72] [11 100]] [1078 13.7 [23 62] [1429 19.6 [11 53] [22 83]]]] [22 100]]]] [3905 1.33 [7369 2.04 [883 0.222 [5225 0.482 [6339 0.0906 [383 2.94 [710 7.37 [6856 1.66 [613 1.93 [2259 32.6 [6544 1.56 [6653 0.232 [2903 1.48 [5393 0.797 [6597 1.53 [7512 8.15 [420 2.29 [730 1.72 [2199 4.12 [6184 0.588 [6857 0.613 [3698 0.569 [4289 0.982 [4205 1.62 [5753 1.39 [28 77] [28 100]] [28 100]] [28 100]] [28 100]] [28 94]] [28 83]] [28 75]] [28 97]] [28 100]] [14 96]] [16 33]] [28 33]] [28 100]] [1783 2.28 [28 96] [28 90]]] [14 100]] [14 77]] [14 75]] [434 0.459 [6310 0.51 [28 97] [28 100]] [28 100]]] [28 52]] [14 41]] [3742 8.21 [28 100] [28 85]]] [30 98]] [6981 0.605 [2143 0.356 [1068 0.599 [968 0.695 [28 37] [4414 3.62 [28 100] [28 84]]] [28 70]] [28 100]] [28 62]]] [14 75]] [14 42]]] [4611 6.09 [5157 0.356 [5439 2.28 [2466 1.27 [4279 0.218 [791 21.2 [794 0.273 [1630 0.632 [28 92] [28 100]] [28 100]] [28 80]] [28 100]] [28 90]] [28 68]] [28 100]] [28 44]]]] [3008 8.07 [685 5.95 [2260 0.949 [5626 4.17 [19 25] [18 55]] [18 85]] [6230 7.21 [2053 1.9 [7601 3.4 [187 1.66 [788 6.45 [4198 6.05 [5734 1.53 [2268 23.9 [6585 1.74 [1023 5.42 [6353 3.22 [6074 1.96 [7742 8.93 [7598 2.49 [4560 1.47 [284 1.66 [7354 13 [4205 7.1 [7546 2.88 [4507 18.4 [18 69] [18 100]] [18 66]] [7 30]] [18 57]] [19 50]] [18 83]] [7 37]] [18 100]] [7 71]] [7186 5.26 [384 12.3 [5482 0.888 [18 55] [18 80]] [719 4.13 [18 91] [18 80]]] [18 100]]] [18 78]] [26 90]] [18 40]] [7 100]] [19 60]] [18 43]] [18 91]] [18 87]] [7 85]] [7 53]]] [26 50]]] [3404 0.0905 [4851 0.275 [2180 0.175 [1986 4.1 [4117 0.0904 [4663 0.368 [3934 0.728 [5851 0.543 [2526 14.1 [27 98] [27 60]] [27 100]] [27 100]] [27 100]] [27 100]] [27 85]] [27 100]] [27 60]] [27 100]]] [2678 1.1 [2688 6.11 [1262 0.102 [7203 0.358 [384 2.71 [6658 3.08 [2268 4.09 [5673 9.1 [4338 6.94 [7679 2.02 [1062 7.68 [380 3.15 [7427 9.32 [5131 8.87 [132 12.4 [16 35] [6 27]] [18 90]] [18 81]] [6 62]] [18 71]] [18 78]] [6 40]] [16 61]] [18 58]] [383 5.58 [18 61] [18 87]]] [18 59]] [2897 0.203 [2671 1 [16 30] [16 50]] [16 42]]] [2868 0.614 [28 66] [16 100]]] [4574 1.28 [38 85] [38 100]]] [16 84]]] [2763 0.154 [2268 0.126 [1206 0.674 [6419 2.1 [4279 0.319 [28 94] [5925 1.16 [28 100] [28 57]]] [28 100]] [968 1.06 [28 55] [28 100]]] [28 100]] [28 50]]] [3342 1.87 [7734 0.389 [7179 1.1 [7513 7.17 [6414 2.26 [7245 1.13 [7384 1.2 [423 1.68 [2983 1.29 [7737 1.5 [6040 2.73 [5219 0.858 [5480 3.88 [4895 2.02 [286 1.33 [7168 1.03 [394 7.05 [17 1.04 [14 25] [17 37]] [26 50]] [14 50]] [11 42]] [37 44]] [2752 14.8 [18 56] [26 41]]] [8 100]] [18 87]] [18 62]] [6 37]] [7 55]] [7 100]] [18 57]] [7 100]] [18 73]] [8 100]] [4706 3.3 [7185 7.68 [5598 1.26 [168 4.15 [719 9.48 [4478 1.16 [5482 11.6 [1023 3.57 [2225 0.472 [7241 4.79 [2259 36.9 [18 74] [18 47]] [18 33]] [18 100]] [16 30]] [19 39]] [12 40]] [1429 18.3 [18 70] [18 100]]] [18 87]] [19 71]] [2756 5.41 [1671 1.65 [18 93] [18 100]] [18 80]]] [6 30]]] [14 72]]] [4540 0.568 [7512 1.9 [7251 0.262 [2607 0.393 [1463 1.09 [992 0.711 [398 1.66 [4926 0.778 [951 0.557 [1980 8.68 [1062 3.37 [2913 6.37 [791 2.97 [276 0.53 [1631 0.831 [4288 1.99 [2752 3.15 [4991 4.15 [8 59] [8 100]] [1226 3.42 [1696 0.395 [408 0.393 [1911 3.11 [1400 6.02 [3554 2.4 [1483 2.46 [6920 2.06 [6102 6.85 [3287 0.873 [6353 0.154 [18 21] [35 40]] [7 75]] [23 100]] [23 100]] [8 100]] [7 100]] [26 64]] [16 62]] [26 100]] [26 85]] [23 93]]] [23 100]] [16 57]] [731 2.67 [18 72] [18 80]]] [4158 1.99 [3440 0.703 [1483 1 [2550 0.873 [2752 4.89 [35 38] [1025 4.12 [2470 1.81 [2562 5.31 [2931 1.85 [5999 1.16 [23 30] [23 100]] [23 100]] [8 93]] [23 66]] [23 57]]] [5211 11.4 [8 100] [8 66]]] [8 100]] [35 100]] [8 90]]] [269 4.27 [26 55] [26 75]]] [2550 0.541 [8 42] [8 100]]] [1597 0.935 [2011 0.841 [808 3.09 [5412 2.45 [23 65] [2005 7.6 [23 88] [23 56]]] [23 100]] [22 42]] [23 100]]] [27 100]] [384 12.7 [18 85] [18 57]]] [2764 0.215 [2488 1.93 [6068 0.522 [6920 0.747 [1218 3.72 [978 9.55 [384 0.864 [2752 19.1 [25 33] [22 33]] [23 64]] [760 4.53 [394 11.1 [5362 8.29 [1078 12.2 [23 56] [328 16.9 [6490 1.6 [23 85] [23 100]] [23 71]]] [23 100]] [23 70]] [23 100]]] [23 100]] [23 93]] [23 100]] [8 63]] [2005 2.63 [2752 19.3 [23 57] [23 100]] [23 100]]]] [8 100]] [731 3.71 [8 100] [8 80]]] [887 0.448 [2562 0.701 [4926 0.778 [429 7.87 [18 47] [8 67]] [18 62]] [8 100]] [8 100]]] [7323 0.383 [2562 0.606 [8 65] [8 100]] [8 100]]] [6077 0.36 [5211 3.41 [7310 0.426 [727 0.599 [7354 1.57 [719 4.06 [1600 1.41 [221 4.08 [2470 2.53 [551 0.994 [6531 1.25 [7187 2.04 [1023 0.921 [7552 0.345 [4859 0.506 [6136 0.275 [1993 2.89 [7445 3.25 [980 4.52 [7085 3.45 [5480 1.99 [2846 3.47 [2199 2.07 [7 31] [23 83]] [14 81]] [788 2.86 [4508 4.27 [282 1.25 [6199 4.02 [377 5.72 [5192 2.19 [5345 1.19 [18 56] [30 33]] [26 42]] [26 33]] [19 44]] [19 61]] [19 72]] [7723 8.36 [18 93] [19 50]]]] [23 60]] [26 80]] [19 57]] [673 10 [18 28] [26 100]]] [16 66]] [18 81]] [26 76]] [5007 6 [5482 2.11 [5 28] [6732 6.6 [18 66] [18 90]]] [7301 3.96 [19 85] [18 62]]]] [26 84]] [7 84]] [23 100]] [26 70]] [4726 0.607 [7210 1.24 [2616 1.11 [25 75] [25 42]] [25 91]] [6 87]]] [7 100]] [7154 1.15 [7516 5.05 [4897 0.821 [4508 0.634 [2259 32.5 [18 49] [18 63]] [18 60]] [18 40]] [26 75]] [18 87]]] [3238 0.454 [2628 2.94 [6707 0.501 [2029 3.9 [3742 0.214 [4486 0.743 [5283 4.02 [7472 0.966 [1023 3.66 [7302 0.972 [6658 3.17 [5413 1.86 [547 1.43 [276 5.57 [422 0.515 [7699 1.74 [141 0.971 [5480 0.479 [7 53] [5871 0.184 [429 37.8 [5599 0.617 [2809 5.62 [2260 2.94 [6230 3.68 [23 6.48 [6373 0.507 [4587 0.699 [5485 1.02 [4517 0.784 [4859 0.626 [896 0.432 [18 75] [4159 1.26 [2259 0.816 [5693 5.74 [18 100] [18 85]] [18 100]] [18 100]]] [18 55]] [18 71]] [18 76]] [18 50]] [18 75]] [18 40]] [18 75]] [791 4.62 [18 61] [19 50]]] [18 42]] [16 66]] [18 53]] [6294 0.368 [18 90] [18 100]]]] [18 50]] [16 50]] [19 50]] [4860 2.31 [1011 0.539 [731 9.03 [685 18.9 [18 100] [18 80]] [18 58]] [738 1.47 [18 100] [18 75]]] [18 69]]] [2752 12.9 [18 90] [18 100]]] [18 91]] [6 30]] [4859 1.53 [19 75] [18 100]]] [738 2.85 [18 93] [4927 1.37 [18 64] [18 83]]]] [38 75]] [16 69]] [134 1.08 [18 48] [16 55]]] [144 10.3 [7512 7.79 [7 72] [1078 12.3 [397 0.882 [19 80] [18 71]] [18 64]]] [19 47]]] [16 69]] [377 1.87 [1012 5.92 [5482 4.04 [18 87] [18 100]] [18 87]] [18 57]]] [719 3.54 [2644 1.61 [2570 6.01 [688 0.158 [1913 0.641 [5132 2.87 [328 0.778 [23 4.58 [2752 15.1 [18 50] [17 30]] [19 37]] [4854 3.35 [685 2.72 [16 50] [18 68]] [16 50]]] [16 47]] [18 80]] [16 42]] [18 51]] [5099 4.19 [16 63] [28 40]]] [6833 3.79 [964 0.689 [7419 0.945 [5681 4.33 [18 43] [18 100]] [16 63]] [18 85]] [18 90]]]] [6040 1.24 [2955 8.03 [2607 0.255 [2584 0.498 [16 80] [16 88]] [16 100]] [16 50]] [16 50]]]] [248 26.1 [26 80] [26 100]]] [25 100]] [1614 1.37 [1429 13 [407 2.03 [23 70] [23 100]] [2259 11.9 [8 31] [5219 1.27 [18 50] [8 100]]]] [7734 7.28 [18 50] [18 100]]]] [2763 0.36 [221 1.89 [7 100] [7 87]] [2 50]]]] [2260 4.4 [1995 0.398 [1429 42.1 [18 100] [1429 46.3 [18 71] [18 90]]] [18 100]] [18 66]]]] [7210 1.56 [3971 2.57 [491 0.35 [8 77] [6560 0.339 [8 81] [8 100]]] [8 80]] [5851 3.54 [8 100] [8 71]]]] [2586 1.37 [6757 0.421 [6179 0.583 [6585 0.635 [1759 3.17 [4859 0.724 [248 21.1 [673 1.65 [2752 18.5 [7185 0.701 [18 29] [6 36]] [1429 36 [18 42] [18 60]]] [18 68]] [7576 2.22 [7305 6.49 [1012 0.441 [1400 1.99 [26 64] [23 15.8 [6791 3.5 [144 6.85 [2755 21.2 [26 91] [4205 4.72 [26 62] [26 100]]] [26 85]] [25 56]] [26 72]]] [18 62]] [1400 26.3 [25 100] [26 42]]] [25 100]]] [18 72]] [978 6.99 [18 100] [18 62]]] [5799 0.537 [328 6.58 [384 9.47 [978 12 [26 100] [19 50]] [248 50.1 [19 42] [26 72]]] [4602 0.635 [26 82] [26 100]]] [26 71]]] [25 100]] [8 29]] [25 100]]] [435 2.26 [5883 1.72 [4158 0.264 [6325 1.12 [3513 2.11 [23 96] [23 100]] [28 57]] [28 68]] [23 100]] [23 100]]] [7187 3.8 [4684 1.85 [2466 2.09 [6230 10.1 [178 5.11 [7139 4.56 [2225 6.97 [328 1.05 [26 81] [806 6.13 [4895 0.76 [896 5.81 [4604 4.3 [187 2.54 [7149 6.6 [2259 6.38 [7693 3.14 [26 100] [26 71]] [26 92]] [26 50]] [26 80]] [26 80]] [26 100]] [26 88]] [26 80]]] [26 69]] [26 71]] [26 84]] [26 75]] [248 26.1 [26 100] [26 47]]] [26 75]] [5174 2.2 [1429 17.9 [6581 0.3 [2755 9.65 [26 66] [26 93]] [2913 7.53 [26 96] [2259 1.52 [26 60] [26 100]]]] [35 53]] [26 40]]]] [5833 0.077 [6560 0.96 [8 35] [8 100]] [3887 0.219 [1466 0.569 [1888 0.228 [2555 0.516 [5219 7.65 [8 71] [8 100]] [8 100]] [8 100]] [8 100]] [8 100]]]] [394 0.551 [1062 2.1 [1161 1.57 [435 0.559 [5851 0.78 [794 0.756 [29 88] [29 100]] [29 66]] [29 100]] [27 100]] [29 100]] [29 100]]] [5900 1.84 [4133 0.588 [7473 0.57 [1429 4.65 [7255 6.8 [1783 15.5 [257 6.28 [5647 0.378 [5194 0.705 [2685 3.7 [2143 1.4 [432 2.25 [7203 0.945 [6027 1.19 [5017 1.36 [7210 2.56 [4426 0.792 [6761 1.91 [187 6.4 [791 6.12 [26 79] [26 60]] [26 55]] [26 57]] [26 75]] [26 92]] [26 100]] [26 100]] [26 70]] [26 96]] [26 70]] [6 62]] [16 44]] [26 92]] [26 44]] [26 57]] [2883 0.98 [26 64] [16 64]]] [724 4.44 [6007 4.13 [2430 2.07 [6616 6.1 [719 0.918 [338 18.5 [4603 8.55 [77 0.579 [4431 2.86 [1395 2.39 [5174 5.15 [248 0.637 [2748 21.5 [26 78] [26 100]] [995 2.93 [7259 2.1 [6877 2.14 [265 0.867 [7301 0.559 [2755 0.442 [26 98] [26 100]] [26 100]] [26 100]] [26 90]] [26 90]] [26 95]]] [26 76]] [26 71]] [26 62]] [26 60]] [26 75]] [26 60]] [695 7.78 [18 28] [26 87]]] [26 50]] [26 52]] [16 71]] [26 75]]] [38 45]] [2360 1.75 [38 81] [38 100]]] [2649 1.89 [16 54] [16 50]]]] [2749 0.296 [407 3.23 [1595 1.67 [1429 8.64 [7723 0.506 [7576 0.27 [5484 1.59 [7718 1.39 [235 0.664 [5695 1.52 [328 45.3 [392 19.9 [5480 2.05 [731 1.21 [14 26] [2902 0.543 [731 10.6 [26 41] [7 33]] [26 36]]] [662 0.531 [26 82] [26 100]]] [14 55]] [26 92]] [7055 0.466 [178 5.54 [5662 0.855 [7693 1.71 [5431 0.816 [26 96] [26 100]] [913 2.83 [398 1.05 [7057 1.2 [719 1.12 [906 0.319 [2616 2.27 [385 2.69 [26 87] [26 83]] [26 83]] [26 60]] [26 100]] [26 66]] [26 100]] [26 100]]] [26 100]] [25 55]] [19 28]]] [25 75]] [7 53]] [18 57]] [25 100]] [1239 1.52 [18 80] [19 33]]] [7737 0.419 [5695 0.417 [4851 1.32 [2530 2.83 [7346 1.64 [6826 0.53 [2654 0.196 [397 1.85 [1668 0.912 [504 0.997 [6544 0.513 [573 1.02 [737 1.36 [673 2.74 [5368 1.45 [6015 2.8 [5007 1.05 [1451 1.91 [6732 3.22 [5597 0.849 [7425 2.07 [7512 13.9 [2813 1.13 [1239 13.5 [7381 1.38 [5132 0.404 [18 22] [16 70]] [5 30]] [14 60]] [18 70]] [112 1.56 [1062 8.7 [5412 3.48 [377 4.33 [5480 2.86 [14 30] [5484 2.16 [16 71] [18 92]]] [14 50]] [7 58]] [18 71]] [14 53]]] [16 35]] [6 66]] [18 56]] [1453 2.08 [14 83] [17 50]]] [19 40]] [896 3.39 [14 100] [14 90]]] [7354 1.55 [1888 0.75 [23 0.328 [14 44] [14 75]] [14 94]] [18 55]]] [2259 5.98 [7693 0.579 [26 77] [26 100]] [18 57]]] [16 76]] [4 46]] [14 84]] [32 70]] [4154 14.3 [2259 10.7 [4414 0.454 [733 0.265 [16 33] [18 75]] [18 91]] [18 86]] [5412 1.82 [24 62] [18 50]]]] [18 83]] [16 65]] [18 96]] [7693 2.56 [18 100] [7 33]]] [26 100]] [7449 0.695 [6544 1.17 [5895 1.11 [7679 0.623 [392 3.89 [384 0.353 [7354 0.41 [2826 5.16 [6199 3.18 [14 53] [14 71]] [14 100]] [7 38]] [7 46]] [5187 3.68 [7588 1.96 [7 63] [26 90]] [7 100]]] [16 52]] [14 100]] [6544 4.74 [14 100] [14 80]]] [7491 1.91 [7512 19.4 [32 33] [7 57]] [7 71]]]] [6581 0.278 [7354 0.692 [2752 10.3 [26 44] [1078 8.69 [26 100] [26 80]]] [18 77]] [26 72]]] [403 0.184 [5155 1.11 [1094 0.246 [23 10.2 [719 3.31 [7203 1.66 [4920 0.903 [5386 0.562 [6256 0.545 [4205 0.937 [7241 0.779 [6703 0.321 [7512 20.4 [18 34] [18 100]] [16 50]] [5348 0.761 [18 80] [18 62]]] [16 33]] [18 100]] [18 92]] [18 63]] [7737 6.57 [18 57] [19 55]]] [4706 0.407 [731 6.55 [7724 0.404 [7722 2.66 [18 100] [695 5.91 [18 62] [18 90]]] [18 100]] [18 54]] [18 100]]] [5480 8.53 [5099 0.325 [5904 0.152 [14 50] [19 70]] [18 62]] [16 53]]] [19 33]] [16 45]] [2259 4.66 [28 83] [19 55]]]]] [7381 1.27 [2752 2.89 [7 100] [2428 1.88 [7 57] [7 100]]] [7 100]]] [3312 0.541 [394 11.1 [6524 0.44 [6413 0.849 [26 39] [5692 2.3 [7 100] [7 64]]] [978 6.26 [7 100] [7 74]]] [26 88]] [3759 0.541 [7 80] [7 100]]]] [7381 0.243 [5962 0.986 [6830 3.64 [4517 1.75 [3332 3.69 [733 0.299 [6203 1.06 [2616 5.77 [5660 0.423 [4799 0.492 [312 0.467 [5673 9.31 [956 2.89 [3959 0.87 [6831 1.37 [4221 1.59 [26 100] [26 85]] [26 85]] [26 83]] [26 83]] [26 83]] [26 85]] [26 50]] [26 80]] [26 69]] [26 54]] [26 100]] [26 77]] [26 75]] [26 71]] [26 57]] [26 66]]]] [23 100]] [8 100]] [1400 5.56 [25 75] [732 7.88 [4279 5.29 [25 100] [25 88]] [25 80]]]] [3095 2.82 [6732 0.714 [2897 1.1 [2237 2.43 [1089 4.2 [6294 2.75 [6920 0.137 [4424 0.368 [7204 0.414 [2151 1.46 [23 0.399 [1226 0.561 [2752 38 [23 100] [392 0.534 [23 91] [23 100]]] [23 100]] [23 60]] [23 87]] [23 100]] [23 100]] [23 100]] [23 83]] [23 56]] [23 42]] [791 4.38 [23 55] [5563 0.0889 [28 84] [28 87]]]] [23 44]] [23 100]]]] [324 2.32 [1995 4.67 [328 2.33 [13 100] [5260 4.86 [13 86] [13 100]]] [13 92]] [2259 4.79 [13 100] [13 88]]]] [6199 1.81 [7255 0.565 [2939 8.64 [3912 0.277 [6732 1.41 [5400 1.83 [7179 1.47 [5211 0.79 [5013 2.86 [7472 1.44 [3089 0.271 [7514 0.994 [3934 5.87 [2752 7.23 [695 3.11 [3831 1.92 [2260 6.25 [663 8.05 [6406 2.11 [4601 1.31 [2526 0.861 [978 1.1 [481 5.75 [6883 2.11 [6353 3.8 [2130 5.62 [37 23] [35 44]] [25 45]] [37 40]] [37 100]] [18 33]] [5350 1.78 [1 18] [6 85]]] [26 57]] [16 40]] [37 75]] [36 54]] [37 100]] [3921 2.06 [17 0.956 [37 59] [13 100]] [37 100]]] [7601 0.978 [978 2.66 [4564 5.98 [6131 2.5 [2488 5.3 [2766 2.13 [7139 0.657 [4630 2.83 [5287 0.441 [7241 1.06 [796 2.57 [5595 1.36 [4083 9.25 [7251 1.11 [4414 19.5 [1429 15.8 [37 77] [1992 2.04 [2826 2.16 [5480 1.01 [112 2.99 [6626 18.8 [3831 0.423 [7354 1.26 [2469 1.47 [6727 9.61 [4061 3.35 [1911 12.6 [3374 16.2 [843 11.2 [791 5.68 [37 91] [3365 0.581 [5692 3.52 [1429 21 [429 26.4 [37 75] [2752 18.7 [37 83] [37 100]]] [474 3.82 [3687 23.1 [2844 2.33 [3262 0.649 [144 11.5 [37 96] [37 71]] [328 1.29 [1535 1.14 [132 12.3 [3191 0.849 [37 99] [37 100]] [37 80]] [37 100]] [37 100]]] [37 88]] [37 96]] [37 80]]] [37 70]] [37 100]]] [37 75]] [37 81]] [37 87]] [37 75]] [37 81]] [37 83]] [13 33]] [37 100]] [37 75]] [429 3.85 [145 2.94 [37 73] [37 50]] [2752 52.5 [3085 5.55 [145 10.8 [4061 1.5 [1533 9.62 [3292 0.599 [1911 1.89 [37 93] [37 100]] [37 100]] [37 86]] [37 92]] [37 75]] [695 8.91 [37 100] [37 80]]] [37 72]]]] [37 71]] [37 81]] [434 2.25 [37 70] [37 100]]]] [37 64]] [37 77]] [37 54]] [37 80]] [16 55]] [37 42]] [4235 0.678 [37 98] [37 100]]] [37 46]] [37 69]] [3990 1.67 [37 56] [37 100]]] [1513 1.78 [37 90] [13 100]]] [3929 0.496 [37 60] [37 80]]] [18 37]] [17 23]] [5 81]]] [27 77]] [19 75]] [3089 5.52 [37 100] [1533 2.76 [37 100] [37 77]]]] [1079 1 [5129 2.39 [2849 1.81 [3929 4.79 [38 60] [37 50]] [38 100]] [38 72]] [38 55]]] [25 77]] [8 25]] [8 100]] [13 100]] [6416 0.263 [13 44] [13 100]]] [7446 4.76 [5999 0.335 [4369 4.07 [3910 0.536 [7169 7.77 [3288 0.25 [567 0.649 [2754 0.705 [3086 20.5 [1078 2.96 [37 96] [37 100]] [37 87]] [37 100]] [37 100]] [37 100]] [37 91]] [37 100]] [37 90]] [37 100]] [37 75]]] [2982 1.98 [2709 0.568 [2713 4.27 [37 33] [16 60]] [16 50]] [30 85]]] [5735 0.324 [3359 0.329 [6732 1.42 [7038 0.813 [2488 1.74 [37 37] [13 75]] [6 33]] [13 87]] [37 90]] [13 100]]] [2851 2.07 [7203 0.448 [3292 1.51 [791 9.73 [1676 3.8 [5393 1.24 [2764 0.474 [1997 1.14 [2951 12.1 [19 14] [1429 8.06 [16 63] [16 37]]] [38 42]] [22 42]] [3 28]] [30 42]] [2753 5.91 [1180 1.92 [1429 51.7 [791 18.6 [22 53] [13 66]] [37 85]] [13 100]] [37 50]]] [37 93]] [14 29]] [38 100]]]] [5047 0.259 [2398 0.145 [802 6.74 [719 0.211 [6231 0.957 [896 0.253 [3480 0.318 [2962 0.508 [3027 0.275 [7742 2.8 [2342 0.592 [4374 0.21 [4088 0.398 [5980 0.313 [901 0.808 [2818 0.443 [3000 1.47 [7657 0.852 [1018 0.938 [248 1.93 [2526 3.7 [4814 1.31 [4079 1.02 [5049 0.617 [3644 1.25 [15 1.02 [6173 1.7 [1641 0.513 [7571 0.69 [536 1.33 [5974 1.26 [554 1.41 [5472 0.945 [1429 26.9 [583 1.07 [3905 1.18 [5403 2.85 [4593 1.36 [6529 1.05 [5705 1.22 [1888 8.2 [312 4.32 [4398 3.19 [6524 6.87 [2993 4.53 [6697 1.92 [6068 11.5 [2843 4.13 [5192 5.33 [7009 0.787 [682 7.32 [4213 1.62 [4420 7.43 [2822 1.67 [2149 10.6 [5368 0.824 [2701 2.2 [110 7.54 [1783 12.2 [558 3.45 [11 4.85 [6261 4.85 [145 3.11 [978 9.13 [6342 0.504 [4851 8.73 [7501 5.63 [7453 1.27 [6732 1.72 [2826 7.94 [2793 2.7 [429 36.7 [12 62] [12 50]] [36 54]] [12 100]] [1078 9.34 [12 50] [15 61]]] [12 90]] [12 100]] [36 60]] [12 38]] [31 84]] [36 52]] [36 100]] [31 100]] [12 100]] [7169 2.11 [12 29] [28 33]]] [12 100]] [15 68]] [12 28]] [4279 3.7 [12 66] [15 90]]] [12 100]] [12 100]] [12 100]] [31 100]] [12 93]] [7176 5.95 [33 62] [12 59]]] [31 100]] [906 2.71 [15 40] [12 50]]] [20 100]] [36 66]] [15 73]] [31 51]] [31 64]] [532 1.34 [2260 2.24 [5999 2.73 [978 5.9 [6935 6.19 [7176 13.7 [1888 24.3 [2698 2.06 [705 3.23 [5467 1.51 [4418 5.52 [12 80] [12 100]] [12 100]] [12 100]] [12 100]] [7449 9.43 [702 2.16 [12 67] [12 60]] [12 100]]] [12 100]] [12 50]] [31 80]] [12 66]] [12 70]] [36 63]]] [36 85]] [36 59]] [15 100]] [31 68]] [3458 3.31 [206 2.35 [1899 1.19 [36 43] [36 56]] [36 81]] [15 100]]] [6884 1.07 [5040 1.67 [6547 4.69 [3 79] [3 100]] [21 81]] [21 66]]] [3222 9.18 [6264 1.17 [6767 10.4 [7434 1.43 [4677 0.73 [7449 10.8 [4546 1.74 [558 1.14 [7354 2.72 [7185 4.6 [5597 1.51 [6230 2.19 [5668 7.38 [7722 4.75 [3243 1.61 [2259 17.9 [6155 2.2 [221 1.1 [3205 5.62 [112 4.16 [5692 25 [2939 3.4 [2902 1.18 [4424 16.3 [1429 76.2 [1995 4 [7149 11.5 [12 55] [36 55]] [12 100]] [36 56]] [12 100]] [36 88]] [12 76]] [36 87]] [36 55]] [12 100]] [5108 2.92 [12 71] [12 100]]] [12 100]] [2832 6.72 [4045 1.75 [1888 14.3 [118 3.11 [36 77] [36 100]] [12 50]] [36 71]] [36 66]]] [2939 1.69 [12 57] [12 90]]] [112 2.39 [899 3.14 [36 46] [36 100]] [36 100]]] [12 100]] [12 92]] [7491 1.51 [36 71] [36 100]]] [12 91]] [36 97]] [12 100]] [36 100]] [2753 3.03 [12 88] [12 100]]] [36 100]] [12 100]] [31 100]] [36 100]] [12 100]]] [7009 4.01 [6853 1.67 [850 2.04 [7693 1.61 [1899 2.16 [36 68] [36 100]] [36 100]] [36 100]] [36 100]] [36 87]]] [3 98]] [21 67]] [23 16.7 [3 81] [3 60]]] [6727 1.16 [6865 1.92 [7354 0.69 [36 62] [7354 17.2 [36 100] [36 88]]] [36 100]] [36 90]]] [36 100]] [31 100]] [36 100]] [5267 22.9 [36 100] [36 75]]] [1907 1.03 [6406 0.617 [583 6.89 [6503 9.72 [9 75] [9 66]] [688 15.2 [21 86] [9 72]]] [9 95]] [21 100]]] [31 100]] [1723 1.31 [7169 1.74 [4036 3.48 [811 3.78 [5716 7.21 [4819 1.33 [36 82] [36 91]] [36 100]] [36 100]] [36 100]] [36 100]] [36 100]]] [4790 1.26 [7009 4.49 [2143 4.28 [6578 1.21 [5693 3.31 [6173 1.4 [1783 6.22 [4282 1.1 [2470 2.59 [1997 10.9 [1089 1.57 [731 5.69 [2266 3.4 [7449 12.1 [5972 14.3 [538 3.72 [5267 3.79 [12 27] [31 83]] [21 88]] [2616 11.6 [1899 16.8 [7354 2.7 [12 62] [36 50]] [12 100]] [31 66]]] [2081 1.55 [12 64] [12 100]]] [31 100]] [36 45]] [36 58]] [12 100]] [31 91]] [3 94]] [31 48]] [31 100]] [36 80]] [31 100]] [4301 1.49 [1104 5.69 [1436 27.6 [2081 2.46 [12 41] [12 72]] [12 100]] [31 85]] [12 100]]] [12 75]] [31 100]]] [7516 1.36 [695 0.759 [1404 1.04 [5311 1.13 [23 10.7 [2701 0.967 [6528 2.44 [5368 1.2 [15 44] [33 42]] [33 44]] [15 100]] [1062 1.24 [15 50] [33 77]]] [31 70]] [15 100]] [429 3.97 [15 40] [5753 3.16 [1980 3.93 [15 97] [15 72]] [38 57]]]] [36 100]]] [3 100]] [3993 5.58 [2189 0.852 [504 11.8 [4630 4.99 [12 100] [12 60]] [12 77]] [12 100]] [12 85]]] [36 100]] [3523 1.36 [7009 0.403 [1400 24.5 [4179 7.81 [4398 2 [7454 1.09 [4814 1.82 [4414 18.3 [3928 0.439 [7185 1.22 [7659 1.76 [6541 1.65 [5267 6.35 [3554 3.75 [2990 1.42 [1913 7.75 [5812 5.96 [2760 7.1 [7623 2.47 [12 86] [15 64]] [12 61]] [12 86]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [4663 24.7 [12 73] [12 100]]] [12 77]] [15 57]] [15 91]] [15 100]] [15 66]] [2488 5.33 [12 100] [12 66]]] [15 100]]] [3742 0.697 [7512 1.66 [36 79] [5270 1.12 [811 1.19 [6530 1.62 [36 86] [36 100]] [36 100]] [36 100]]] [36 62]]] [874 0.399 [3931 0.374 [2178 0.368 [7115 29.5 [5267 7.81 [1980 0.428 [5647 4.2 [3554 2.39 [7428 0.816 [2818 2.7 [12 98] [12 100]] [12 100]] [12 100]] [12 100]] [12 100]] [12 90]] [12 85]] [12 100]] [12 100]] [12 100]]] [2273 0.96 [36 100] [36 81]]] [5972 3.45 [12 53] [4611 0.612 [3057 0.595 [1980 0.498 [5467 0.816 [3895 2.7 [6719 5.29 [7185 6.69 [7176 8.79 [12 94] [12 87]] [12 100]] [12 75]] [12 100]] [791 16.2 [12 100] [906 3.78 [12 100] [12 87]]]] [12 100]] [12 100]] [12 100]]]] [2241 2.33 [4154 30.2 [6529 0.609 [7169 3.16 [939 2.98 [6853 5.18 [3658 1.02 [168 0.824 [36 74] [36 100]] [36 100]] [36 100]] [36 72]] [36 83]] [36 100]] [31 44]] [36 45]]] [1164 2.89 [6767 4 [5978 1.27 [312 1.63 [2929 9.08 [31 75] [31 62]] [31 100]] [31 100]] [31 100]] [31 100]]] [5140 2.13 [3905 9.2 [111 0.162 [7657 0.763 [5192 4.42 [731 4.07 [4154 6.11 [2260 1.06 [7434 0.645 [4235 6.93 [12 81] [31 42]] [12 100]] [36 87]] [12 42]] [31 100]] [12 95]] [12 100]] [12 100]] [36 80]] [33 88]]] [6230 0.703 [7742 1.47 [3905 4.28 [2526 2.11 [31 75] [31 100]] [4615 1.2 [31 66] [36 92]]] [31 100]] [31 100]]] [5472 1.98 [2411 1.02 [4283 0.285 [2470 1.72 [5972 14.3 [7009 2.13 [2993 1.43 [36 75] [36 100]] [12 44]] [2320 1.07 [36 90] [36 100]]] [7613 0.505 [15 97] [15 100]]] [3209 0.285 [1253 0.542 [1429 1.01 [15 89] [15 100]] [15 100]] [15 100]]] [36 100]] [3480 10.9 [36 100] [36 97]]]] [3004 0.416 [2913 1.2 [791 6.77 [6233 0.867 [312 1.56 [7305 2.03 [1077 0.767 [36 54] [36 75]] [31 100]] [1980 0.843 [31 100] [31 80]]] [31 100]] [721 1.89 [5225 0.935 [323 4 [3431 1.6 [6853 20.1 [6530 3.22 [7119 2.83 [4414 7.19 [2637 7.41 [4851 0.119 [5753 12.3 [7305 3.27 [6230 2.48 [826 4.87 [5509 4.66 [896 11.4 [1253 2.69 [583 6.45 [4805 2.34 [1011 0.894 [2178 2.55 [429 8.88 [36 55] [7108 1.64 [2526 2.06 [5782 1.01 [2411 0.425 [642 5.01 [36 100] [36 83]] [36 100]] [36 100]] [36 83]] [36 92]]] [36 81]] [31 50]] [36 83]] [36 70]] [36 84]] [36 72]] [36 50]] [31 100]] [36 30]] [31 83]] [31 52]] [5472 0.253 [5972 11.3 [36 66] [36 87]] [36 100]]] [31 62]] [31 61]] [5692 3.42 [36 100] [19 77]]] [7722 5.14 [36 100] [36 98]]] [36 60]] [36 100]] [31 100]] [30 100]] [7428 2.13 [632 1.02 [4154 1.04 [2993 0.864 [6853 1.49 [36 96] [36 100]] [36 100]] [36 100]] [36 100]] [36 80]]]] [3699 1.19 [2822 0.6 [31 61] [31 100]] [31 100]]] [434 0.252 [6708 3.35 [36 100] [36 71]] [36 100]]]] [435 2.83 [6231 17.9 [2846 0.666 [663 0.894 [5151 0.542 [312 1.26 [5270 0.956 [7703 1.42 [31 90] [31 55]] [31 100]] [31 100]] [31 100]] [31 100]] [12 92]] [31 100]] [31 57]]] [6853 0.77 [6404 0.347 [118 0.675 [13 0.36 [3429 1.27 [2259 24.2 [5509 4.83 [791 10.9 [2846 1.1 [6077 0.334 [6230 2.37 [2752 39.4 [429 1.71 [7665 17.2 [31 42] [31 50]] [31 69]] [36 76]] [5803 1.95 [1899 1.65 [7139 4.78 [31 74] [31 100]] [31 100]] [31 100]]] [4414 6.77 [2939 6.5 [31 100] [2628 13 [31 100] [31 88]]] [1101 6.37 [31 100] [31 82]]]] [31 33]] [4611 0.504 [731 0.705 [5692 6.92 [7512 14.5 [36 60] [2259 3.14 [31 50] [3307 1.22 [429 30.2 [31 86] [31 41]] [31 100]]]] [36 77]] [2616 6.09 [2482 0.959 [31 96] [31 100]] [31 87]]] [5405 1.49 [36 79] [31 100]]]] [31 100]] [4081 1.03 [4612 1.36 [4943 1.39 [2939 9.11 [7571 17.3 [5671 1.39 [2628 8.93 [2081 1.96 [3663 0.489 [5270 0.556 [31 50] [31 90]] [36 100]] [5403 2.88 [36 55] [31 100]]] [2628 15.3 [31 80] [31 100]]] [31 100]] [31 100]] [31 100]] [31 62]] [36 100]] [31 100]]] [36 100]] [31 100]] [36 100]] [721 3.82 [2793 5.41 [36 100] [36 85]] [4611 1.25 [36 100] [36 71]]]] [1400 2.96 [7512 24.1 [6230 2.78 [6401 0.211 [4630 0.535 [14 0.227 [2526 0.91 [1641 0.675 [2266 0.723 [36 98] [31 50]] [36 100]] [5978 2.02 [31 75] [31 100]]] [36 100]] [31 83]] [36 100]] [6859 3.73 [4414 3.56 [31 100] [31 50]] [682 3.55 [31 88] [31 100]]]] [1429 34.5 [6404 1.92 [5753 5.3 [929 1 [31 77] [31 100]] [36 68]] [36 100]] [36 83]]] [118 0.205 [884 0.441 [5077 0.793 [683 0.579 [5403 1.62 [2273 1.33 [642 1.11 [5763 0.491 [1593 1.29 [36 100] [3646 2.95 [36 88] [36 100]]] [36 100]] [36 85]] [36 100]] [31 100]] [31 100]] [5705 1.56 [36 100] [36 80]]] [2320 0.991 [36 100] [36 71]]] [2260 0.262 [36 95] [36 100]]]]]] [6306 1.23 [743 0.413 [5248 0.397 [1401 1.41 [688 1.08 [4369 6.9 [3072 1.81 [6897 2.06 [6310 4.34 [538 1.53 [7461 2.99 [5040 1.06 [569 3.35 [7493 23.5 [2752 1.43 [3 72] [12 79]] [3 50]] [3 94]] [5972 15.1 [21 100] [21 84]]] [15 68]] [21 68]] [21 100]] [9 86]] [12 100]] [12 83]] [5246 1.28 [2260 5.74 [514 0.911 [7211 0.632 [802 27.1 [2260 0.182 [5534 1.98 [574 0.818 [572 2.07 [6970 0.855 [5871 4.29 [567 7.64 [5692 0.75 [535 1.24 [586 1.14 [7085 1.07 [21 59] [6199 0.5 [21 80] [21 75]]] [538 2.6 [21 85] [21 100]]] [21 100]] [7015 2.39 [1899 1.04 [1341 1.62 [6333 2.28 [907 2.76 [21 91] [21 100]] [21 100]] [21 100]] [21 100]] [21 57]]] [21 42]] [21 61]] [6260 2.28 [21 58] [9 50]]] [9 57]] [918 0.55 [9 84] [9 100]]] [9 91]] [21 66]] [6342 1.13 [609 1.29 [583 18.6 [2143 1.36 [1906 13 [6884 5.34 [328 11.9 [1980 10.2 [4810 1.77 [21 89] [21 100]] [21 75]] [21 100]] [21 100]] [21 100]] [21 100]] [21 66]] [21 100]] [21 77]]] [589 2.11 [9 81] [21 60]]] [6562 6.07 [9 96] [9 57]]] [9 81]] [1332 1.37 [9 55] [9 100]]]] [12 100]] [21 100]] [1429 18.8 [5549 1.52 [4982 3.84 [4154 13.6 [1980 3.08 [4663 3.53 [609 0.18 [6883 2.98 [21 89] [21 61]] [21 100]] [21 100]] [5937 4.72 [6015 0.538 [6048 1.44 [766 2.59 [21 95] [21 77]] [21 100]] [21 100]] [21 95]]] [3 57]] [9 55]] [9 100]] [21 60]]] [3 94]]] [7701 1.23 [3337 0.196 [899 1.11 [695 3.65 [6745 1.43 [2939 12.5 [7693 2.7 [577 0.58 [4279 16.7 [2826 0.243 [1068 0.332 [558 0.747 [2616 1.22 [2005 11 [12 100] [12 83]] [12 83]] [12 100]] [12 100]] [12 100]] [12 88]] [12 80]] [12 50]] [12 100]] [12 63]] [5979 0.431 [978 1.87 [6665 0.335 [7009 0.187 [2657 0.994 [5816 4.87 [6184 1.32 [6074 1.23 [12 100] [31 60]] [12 100]] [31 71]] [12 100]] [12 100]] [12 100]] [31 95]] [12 100]]] [2259 17 [12 75] [31 87]]] [31 57]] [31 100]]] [7409 0.302 [1659 3.91 [3 100] [3 89]] [3 100]]]] [1166 0.139 [1535 0.662 [5637 0.723 [5371 2.16 [2752 0.894 [3779 8.81 [37 98] [37 88]] [808 0.327 [4533 6.08 [695 13.8 [37 100] [3506 1.32 [37 100] [37 85]]] [37 92]] [6865 5.03 [37 100] [37 66]]]] [37 83]] [2466 1.32 [19 57] [37 100]]] [37 100]] [37 85]]]))

;; END AUTO-GENERATED CODE

(provide 'language-detection)

;;; language-detection.el ends here
